{-# LANGUAGE  MultiParamTypeClasses,  FunctionalDependencies #-}

-- | 
-- Module      : Text.CHXHtml.XHtml1_transitional
-- Copyright   : (c) Paul Talaga 2011,
--
-- License     : BSD-style
--
-- Maintainer  : paul@fuzzpault.com
-- Stability   : experimental
-- Portability : portable
--
--  Description : CHXHtml (Compliant Haskell XHtml) produces W3C valid XHTML1 content by building a datastructure based on the DTD.  
--  Nesting and allowed tags are limited at compile time by recursive types.  Required children, child ordering, and required attributes can be reported at runtime by the
--  @pageErrors function.
--
--  To simplify usage, type classes are used to substitute the correct constructor for the given context, or throw a type error if the tag is not allowed in that context.
--  As a result, a single function exists per tag as well as for attribute names.
--
--  Each tag has two variants, one with and one without taking parameters, specified as @_{tag} [{children tags}]@ or @{tag}_ [{attributes}] [{children tags}]@.
--  Underscores prevents namespace conflicts with @Prelude@ as well as cleaning up the syntax otherwise present using import qualified.
--
--  Textual data is entered with the function @pcdata "String"@ wherever pcdata is allowed.  pcdata is HTML escaped for safety.
--  For speed the variant @pcdata_bs "Data.ByteString"@ can be used which bypasses escaping.
--  A handful of character entities (&quot;,&amp;,&lt;,&gt;,&copy;,&reg;,&nbsp;,) can also be used wherever pcdata is allowed by using 
--  the functions: @ce_quot@,@ce_amp@,@ce_lt@,@ce_gt@,@ce_copy@,@ce_reg@,@ce_nbsp@,
--
--  Attributes are specified by the functions  @{attribute name}_att@, followed by its value of the correct type.  See below for specifics.
--  For W3C compliance only the first attribute will be used if duplicate names exist.
--
--  Rendering to a "String" is done with the 'render' function, or to a "Data.ByteString" via the 'render_bs' function.  Note that "Data.ByteString" is significatly faster than Strings.
--
--  Under the hood we use a myriad of datatypes for tags and attributes whos details have been omitted below for brevity.  To assist in selecting allowed tags and attributes
--  'htmlHelp' is provided which produces allowed children and attributes given a tag's nesting position.  See 'htmlHelp' below for usage.
--
--
module Text.CHXHtml.XHtml1_transitional(  
    -- * Validation
 childErrors,pageErrors,
    -- * Tag & Attribute Help
 htmlHelp,
    -- * Rendering
 render, render_bs,    -- * Tags
pcdata, pcdata_bs,s2b, _html, html_,_a ,a_ ,_abbr ,abbr_ ,_acronym ,acronym_ ,_address ,address_ ,_applet ,applet_ ,_area ,area_ ,_b ,b_ ,_base ,base_ ,_basefont ,basefont_ ,_bdo ,bdo_ ,_big ,big_ ,_blockquote ,blockquote_ ,_body ,body_ ,_br ,br_ ,_button ,button_ ,_caption ,caption_ ,_center ,center_ ,_cite ,cite_ ,_code ,code_ ,_col ,col_ ,_colgroup ,colgroup_ ,_dd ,dd_ ,_del ,del_ ,_dfn ,dfn_ ,_dir ,dir_ ,_div ,div_ ,_dl ,dl_ ,_dt ,dt_ ,_em ,em_ ,_fieldset ,fieldset_ ,_font ,font_ ,_form ,form_ ,_h1 ,h1_ ,_h2 ,h2_ ,_h3 ,h3_ ,_h4 ,h4_ ,_h5 ,h5_ ,_h6 ,h6_ ,_head ,head_ ,_hr ,hr_ ,_i ,i_ ,_iframe ,iframe_ ,_img ,img_ ,_input ,input_ ,_ins ,ins_ ,_isindex ,isindex_ ,_kbd ,kbd_ ,_label ,label_ ,_legend ,legend_ ,_li ,li_ ,_link ,link_ ,_map ,map_ ,_menu ,menu_ ,_meta ,meta_ ,_noframes ,noframes_ ,_noscript ,noscript_ ,_object ,object_ ,_ol ,ol_ ,_optgroup ,optgroup_ ,_option ,option_ ,_p ,p_ ,_param ,param_ ,_pre ,pre_ ,_q ,q_ ,_s ,s_ ,_samp ,samp_ ,_script ,script_ ,_select ,select_ ,_small ,small_ ,_span ,span_ ,_strike ,strike_ ,_strong ,strong_ ,_style ,style_ ,_sub ,sub_ ,_sup ,sup_ ,_table ,table_ ,_tbody ,tbody_ ,_td ,td_ ,_textarea ,textarea_ ,_tfoot ,tfoot_ ,_th ,th_ ,_thead ,thead_ ,_title ,title_ ,_tr ,tr_ ,_tt ,tt_ ,_u ,u_ ,_ul ,ul_ ,_var ,var_ ,
    -- * Attributes
http_equiv_att, http_equiv_att_bs,clear_att, content_att, content_att_bs,nohref_att, onkeydown_att, onkeydown_att_bs,target_att, target_att_bs,onkeyup_att, onkeyup_att_bs,onreset_att, onreset_att_bs,onmouseup_att, onmouseup_att_bs,scope_att, code_att, code_att_bs,onmouseover_att, onmouseover_att_bs,align_att, lang_att, lang_att_bs,valign_att, name_att, name_att_bs,charset_att, charset_att_bs,scheme_att, scheme_att_bs,prompt_att, prompt_att_bs,accept_charset_att, accept_charset_att_bs,frameborder_att, onmousedown_att, onmousedown_att_bs,rev_att, rev_att_bs,span_att, span_att_bs,title_att, title_att_bs,onclick_att, onclick_att_bs,start_att, start_att_bs,width_att, width_att_bs,vlink_att, vlink_att_bs,enctype_att, enctype_att_bs,ismap_att, usemap_att, usemap_att_bs,nowrap_att, coords_att, coords_att_bs,frame_att, onblur_att, onblur_att_bs,datetime_att, datetime_att_bs,size_att, size_att_bs,dir_att, face_att, face_att_bs,color_att, color_att_bs,summary_att, summary_att_bs,bgcolor_att, bgcolor_att_bs,text_att, text_att_bs,method_att, vspace_att, vspace_att_bs,standby_att, standby_att_bs,tabindex_att, tabindex_att_bs,language_att, language_att_bs,background_att, background_att_bs,style_att, style_att_bs,onmousemove_att, onmousemove_att_bs,height_att, height_att_bs,codetype_att, codetype_att_bs,char_att, char_att_bs,multiple_att, codebase_att, codebase_att_bs,xmlns_att, xmlns_att_bs,profile_att, profile_att_bs,rel_att, rel_att_bs,onsubmit_att, onsubmit_att_bs,ondblclick_att, ondblclick_att_bs,axis_att, axis_att_bs,cols_att, cols_att_bs,marginwidth_att, marginwidth_att_bs,abbr_att, abbr_att_bs,onchange_att, onchange_att_bs,readonly_att, href_att, href_att_bs,media_att, media_att_bs,id_att, id_att_bs,compact_att, for_att, for_att_bs,src_att, src_att_bs,value_att, value_att_bs,data_att, data_att_bs,hreflang_att, hreflang_att_bs,checked_att, declare_att, onkeypress_att, onkeypress_att_bs,label_att, label_att_bs,class_att, class_att_bs,type_att, type_att_bs,shape_att, accesskey_att, accesskey_att_bs,headers_att, headers_att_bs,disabled_att, object_att, object_att_bs,scrolling_att, rules_att, rows_att, rows_att_bs,alink_att, alink_att_bs,onfocus_att, onfocus_att_bs,colspan_att, colspan_att_bs,rowspan_att, rowspan_att_bs,defer_att, cellspacing_att, cellspacing_att_bs,charoff_att, charoff_att_bs,cite_att, cite_att_bs,marginheight_att, marginheight_att_bs,maxlength_att, maxlength_att_bs,link_att, link_att_bs,onselect_att, onselect_att_bs,accept_att, accept_att_bs,alt_att, alt_att_bs,archive_att, archive_att_bs,classid_att, classid_att_bs,longdesc_att, longdesc_att_bs,onmouseout_att, onmouseout_att_bs,border_att, border_att_bs,noshade_att, onunload_att, onunload_att_bs,hspace_att, hspace_att_bs,action_att, action_att_bs,onload_att, onload_att_bs,cellpadding_att, cellpadding_att_bs,valuetype_att, selected_att, 
    -- ** Enumerated Attribute Values
ValuetypeEnum(..),RulesEnum(..),ScrollingEnum(..),ShapeEnum(..),MethodEnum(..),DirEnum(..),FrameEnum(..),FrameborderEnum(..),ValignEnum(..),AlignEnum(..),ScopeEnum(..),ClearEnum(..),
    -- ** Character Entities (just a few until I can find a more elegant implementation)
ce_quot,ce_amp,ce_lt,ce_gt,ce_copy,ce_reg,ce_nbsp,
  ) where 

import qualified Data.ByteString.Lazy as B
import qualified Data.ByteString.Lazy.UTF8 as U
import qualified Data.ByteString.Char8 as C
import Data.List (nubBy,sort,intersperse,(\\))
import Data.Char
import Text.Regex.XMLSchema.String
-- | 'htmlHelp' provides a way of finding allowed children tags and attributes.  For example a @h1@ inside a @body@ tag inside an @html@ tag is queried with
--
-- > htmlHelp ["html","body","h1"]
--
-- > = [["a","abbr",..,"tt","var"],["alt_att","class_att","dir_att",..,"usemap_att","width_att"]]
--
-- which returns a list of 2 elements, each their own list.  The first is the allowed children tags, in this case 34.  The second is a list of allowed attributes for
-- the @h1@ tag.  Remember to add a @_@ as a prefix or suffix of all tags, as well as @_bs@ if providing a 'Data.ByteString' to an attribute.
--
htmlHelp :: [String] -> [[String]]
htmlHelp (x:xs) 
    | (map toLower x) == "html" = htmlHelp2 0 (toNdx "html") xs
    | otherwise = [["First tag needs to be \"html\"!"],[]]
    
htmlHelp2 :: Int -> Int -> [String] -> [[String]]
htmlHelp2 i lst [] = [ (sort (map (\(t,n)->fst (tagList !! t)) (groups !! i))), sort(map (\a->a++"_att") (attList !! (snd (tagList !! lst))))]
htmlHelp2 i lst (x:xs)
    | n == -1 = [[x ++ " not a child" ],["No attributes"]]
    | n == 99999 && xs == [] = [[x ++ " can not contain any inner nodes"], sort(map (\a->a++"_att") (attList !! (snd (tagList !! (toNdx x)))))]
    | n == 99999 = [[x ++ " can not contain any inner nodes"], []]
    | otherwise = htmlHelp2 n (toNdx x) xs
    where n = getNext (groups !! i) (toNdx x)

getNext ((a,b):xs) t
    | a == t = b
    | otherwise = getNext xs t 
getNext [] t = -1

toNdx :: String -> Int
toNdx s = toNdx2 s tagList 0
toNdx2 s (x:xs) n
    | (map toLower s) == (map toLower (fst x)) = n
    | otherwise = toNdx2 s xs (n+1)
toNdx2 s [] _ = (-1)
tagList = [("html",0),("head",1),("title",2),("base",3),("meta",4),("link",6),("style",7),("script",9),("noscript",10),("iframe",11),("noframes",10),("body",12),("div",13),("p",13),("h1",13),("h2",13),("h3",13),("h4",13),("h5",13),("h6",13),("ul",14),("ol",15),("menu",16),("dir",16),("li",17),("dl",16),("dt",10),("dd",10),("address",10),("hr",18),("pre",19),("blockquote",20),("center",10),("ins",21),("del",21),("a",22),("span",10),("bdo",10),("br",25),("em",10),("strong",10),("dfn",10),("code",10),("samp",10),("kbd",10),("var",10),("cite",10),("abbr",10),("acronym",10),("q",20),("sub",10),("sup",10),("tt",10),("i",10),("b",10),("big",10),("small",10),("u",10),("s",10),("strike",10),("basefont",26),("font",28),("object",29),("param",30),("applet",32),("img",35),("map",38),("area",40),("form",41),("label",43),("input",44),("select",45),("optgroup",46),("option",48),("textarea",49),("fieldset",10),("legend",52),("button",53),("isindex",54),("table",55),("caption",13),("thead",56),("tfoot",56),("tbody",56),("colgroup",57),("col",57),("tr",58),("th",59),("td",59),("pcdata",-1),("cdata",-1),("none",-1),("",1)]
attList = [["lang","dir","id","xmlns"],["lang","dir","id","profile"],["lang","dir","id"],["id","href","target"],["lang","dir","id","http_equiv","name","content","scheme"],["content"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","charset","href","hreflang","type","rel","rev","media","target"],["lang","dir","id","type","media","title"],["type"],["id","charset","type","language","src","defer"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup"],["id","class","style","title","longdesc","name","src","frameborder","marginwidth","marginheight","scrolling","align","height","width"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","onload","onunload","background","bgcolor","text","link","vlink","alink"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","align"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","type","compact"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","type","compact","start"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","compact"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","type","value"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","align","noshade","size","width"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","width"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","cite"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","cite","datetime"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","accesskey","tabindex","onfocus","onblur","charset","type","name","href","hreflang","rel","rev","shape","coords","target"],["id","class","style","title","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","lang","dir"],["dir"],["id","class","style","title","clear"],["id","size","color","face"],["size"],["id","class","style","title","lang","dir","size","color","face"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","declare","classid","codebase","data","type","codetype","archive","standby","height","width","usemap","name","tabindex","align","border","hspace","vspace"],["id","name","value","valuetype","type"],["name"],["id","class","style","title","codebase","archive","code","object","alt","name","width","height","align","hspace","vspace"],["width"],["height"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","src","alt","name","longdesc","height","width","usemap","ismap","align","border","hspace","vspace"],["src"],["alt"],["lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","id","class","style","title","name"],["id"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","accesskey","tabindex","onfocus","onblur","shape","coords","href","nohref","alt","target"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","action","method","name","enctype","onsubmit","onreset","accept","accept_charset","target"],["action"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","for","accesskey","onfocus","onblur"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","accesskey","tabindex","onfocus","onblur","type","name","value","checked","disabled","readonly","size","maxlength","src","alt","usemap","onselect","onchange","accept","align"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","name","size","multiple","disabled","tabindex","onfocus","onblur","onchange"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","disabled","label"],["label"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","selected","disabled","label","value"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","accesskey","tabindex","onfocus","onblur","name","rows","cols","disabled","readonly","onselect","onchange"],["rows"],["cols"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","accesskey","align"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","accesskey","tabindex","onfocus","onblur","name","value","type","disabled"],["id","class","style","title","lang","dir","prompt"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","summary","width","border","frame","rules","cellspacing","cellpadding","align","bgcolor"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","align","char","charoff","valign"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","span","width","align","char","charoff","valign"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","align","char","charoff","valign","bgcolor"],["id","class","style","title","lang","dir","onclick","ondblclick","onmousedown","onmouseup","onmouseover","onmousemove","onmouseout","onkeypress","onkeydown","onkeyup","abbr","axis","headers","scope","rowspan","colspan","align","char","charoff","valign","nowrap","bgcolor","width","height"]]
groups  = [[(1,1),(11,4)],[(2,2),(3,99999),(4,99999),(5,99999),(6,2),(7,2),(62,3),(78,99999)],[(89,99999)],[(7,2),(8,4),(9,4),(10,4),(12,4),(13,5),(14,5),(15,5),(16,5),(17,5),(18,5),(19,5),(20,6),(21,6),(22,6),(23,6),(25,7),(28,8),(29,99999),(30,9),(31,4),(32,4),(33,4),(34,4),(35,10),(36,5),(37,5),(38,99999),(39,5),(40,5),(41,5),(42,5),(43,5),(44,5),(45,5),(46,5),(47,5),(48,5),(49,5),(50,5),(51,5),(52,5),(53,5),(54,5),(55,5),(56,5),(57,5),(58,5),(59,5),(60,99999),(61,5),(62,3),(63,99999),(64,3),(65,99999),(66,66),(68,67),(69,113),(70,99999),(71,130),(74,2),(75,132),(77,133),(78,99999),(79,134),(89,99999)],[(7,2),(8,4),(9,4),(10,4),(12,4),(13,5),(14,5),(15,5),(16,5),(17,5),(18,5),(19,5),(20,6),(21,6),(22,6),(23,6),(25,7),(28,8),(29,99999),(30,9),(31,4),(32,4),(33,4),(34,4),(35,10),(36,5),(37,5),(38,99999),(39,5),(40,5),(41,5),(42,5),(43,5),(44,5),(45,5),(46,5),(47,5),(48,5),(49,5),(50,5),(51,5),(52,5),(53,5),(54,5),(55,5),(56,5),(57,5),(58,5),(59,5),(60,99999),(61,5),(62,3),(64,3),(65,99999),(66,66),(68,67),(69,113),(70,99999),(71,130),(74,2),(75,132),(77,133),(78,99999),(79,134),(89,99999)],[(7,2),(9,4),(33,4),(34,4),(35,10),(36,5),(37,5),(38,99999),(39,5),(40,5),(41,5),(42,5),(43,5),(44,5),(45,5),(46,5),(47,5),(48,5),(49,5),(50,5),(51,5),(52,5),(53,5),(54,5),(55,5),(56,5),(57,5),(58,5),(59,5),(60,99999),(61,5),(62,3),(64,3),(65,99999),(66,66),(69,113),(70,99999),(71,130),(74,2),(77,133),(89,99999)],[(24,4)],[(26,5),(27,4)],[(7,2),(9,4),(13,5),(33,4),(34,4),(35,10),(36,5),(37,5),(38,99999),(39,5),(40,5),(41,5),(42,5),(43,5),(44,5),(45,5),(46,5),(47,5),(48,5),(49,5),(50,5),(51,5),(52,5),(53,5),(54,5),(55,5),(56,5),(57,5),(58,5),(59,5),(60,99999),(61,5),(62,3),(64,3),(65,99999),(66,66),(69,113),(70,99999),(71,130),(74,2),(77,133),(89,99999)],[(7,2),(33,4),(34,4),(35,10),(36,5),(37,5),(38,99999),(39,5),(40,5),(41,5),(42,5),(43,5),(44,5),(45,5),(46,5),(47,5),(48,5),(49,5),(52,5),(53,5),(54,5),(57,5),(58,5),(59,5),(69,113),(70,99999),(71,130),(74,2),(77,133),(89,99999)],[(7,11),(9,12),(33,12),(34,12),(36,10),(37,10),(38,99999),(39,10),(40,10),(41,10),(42,10),(43,10),(44,10),(45,10),(46,10),(47,10),(48,10),(49,10),(50,10),(51,10),(52,10),(53,10),(54,10),(55,10),(56,10),(57,10),(58,10),(59,10),(60,99999),(61,10),(62,33),(64,33),(65,99999),(66,34),(69,35),(70,99999),(71,63),(74,11),(77,65),(89,99999)],[(89,99999)],[(7,11),(8,12),(9,12),(10,12),(12,12),(13,10),(14,10),(15,10),(16,10),(17,10),(18,10),(19,10),(20,13),(21,13),(22,13),(23,13),(25,14),(28,15),(29,99999),(30,16),(31,12),(32,12),(33,12),(34,12),(36,10),(37,10),(38,99999),(39,10),(40,10),(41,10),(42,10),(43,10),(44,10),(45,10),(46,10),(47,10),(48,10),(49,10),(50,10),(51,10),(52,10),(53,10),(54,10),(55,10),(56,10),(57,10),(58,10),(59,10),(60,99999),(61,10),(62,33),(64,33),(65,99999),(66,34),(68,17),(69,35),(70,99999),(71,63),(74,11),(75,28),(77,65),(78,99999),(79,29),(89,99999)],[(24,12)],[(26,10),(27,12)],[(7,11),(9,12),(13,10),(33,12),(34,12),(36,10),(37,10),(38,99999),(39,10),(40,10),(41,10),(42,10),(43,10),(44,10),(45,10),(46,10),(47,10),(48,10),(49,10),(50,10),(51,10),(52,10),(53,10),(54,10),(55,10),(56,10),(57,10),(58,10),(59,10),(60,99999),(61,10),(62,33),(64,33),(65,99999),(66,34),(69,35),(70,99999),(71,63),(74,11),(77,65),(89,99999)],[(7,11),(33,12),(34,12),(36,10),(37,10),(38,99999),(39,10),(40,10),(41,10),(42,10),(43,10),(44,10),(45,10),(46,10),(47,10),(48,10),(49,10),(52,10),(53,10),(54,10),(57,10),(58,10),(59,10),(69,35),(70,99999),(71,63),(74,11),(77,65),(89,99999)],[(7,74),(8,17),(9,17),(10,17),(12,17),(13,18),(14,18),(15,18),(16,18),(17,18),(18,18),(19,18),(20,19),(21,19),(22,19),(23,19),(25,20),(28,21),(29,99999),(30,22),(31,17),(32,17),(33,17),(34,17),(36,18),(37,18),(38,99999),(39,18),(40,18),(41,18),(42,18),(43,18),(44,18),(45,18),(46,18),(47,18),(48,18),(49,18),(50,18),(51,18),(52,18),(53,18),(54,18),(55,18),(56,18),(57,18),(58,18),(59,18),(60,99999),(61,18),(62,75),(64,75),(65,99999),(66,76),(69,43),(70,99999),(71,83),(74,74),(75,23),(77,85),(78,99999),(79,24),(89,99999)],[(7,74),(9,17),(33,17),(34,17),(36,18),(37,18),(38,99999),(39,18),(40,18),(41,18),(42,18),(43,18),(44,18),(45,18),(46,18),(47,18),(48,18),(49,18),(50,18),(51,18),(52,18),(53,18),(54,18),(55,18),(56,18),(57,18),(58,18),(59,18),(60,99999),(61,18),(62,75),(64,75),(65,99999),(66,76),(69,43),(70,99999),(71,83),(74,74),(77,85),(89,99999)],[(24,17)],[(26,18),(27,17)],[(7,74),(9,17),(13,18),(33,17),(34,17),(36,18),(37,18),(38,99999),(39,18),(40,18),(41,18),(42,18),(43,18),(44,18),(45,18),(46,18),(47,18),(48,18),(49,18),(50,18),(51,18),(52,18),(53,18),(54,18),(55,18),(56,18),(57,18),(58,18),(59,18),(60,99999),(61,18),(62,75),(64,75),(65,99999),(66,76),(69,43),(70,99999),(71,83),(74,74),(77,85),(89,99999)],[(7,74),(33,17),(34,17),(36,18),(37,18),(38,99999),(39,18),(40,18),(41,18),(42,18),(43,18),(44,18),(45,18),(46,18),(47,18),(48,18),(49,18),(52,18),(53,18),(54,18),(57,18),(58,18),(59,18),(69,43),(70,99999),(71,83),(74,74),(77,85),(89,99999)],[(7,74),(8,17),(9,17),(10,17),(12,17),(13,18),(14,18),(15,18),(16,18),(17,18),(18,18),(19,18),(20,19),(21,19),(22,19),(23,19),(25,20),(28,21),(29,99999),(30,22),(31,17),(32,17),(33,17),(34,17),(36,18),(37,18),(38,99999),(39,18),(40,18),(41,18),(42,18),(43,18),(44,18),(45,18),(46,18),(47,18),(48,18),(49,18),(50,18),(51,18),(52,18),(53,18),(54,18),(55,18),(56,18),(57,18),(58,18),(59,18),(60,99999),(61,18),(62,75),(64,75),(65,99999),(66,76),(69,43),(70,99999),(71,83),(74,74),(75,23),(76,18),(77,85),(78,99999),(79,24),(89,99999)],[(80,18),(81,25),(82,25),(83,25),(84,26),(85,99999),(86,27)],[(86,27)],[(85,99999)],[(87,17),(88,17)],[(7,11),(8,12),(9,12),(10,12),(12,12),(13,10),(14,10),(15,10),(16,10),(17,10),(18,10),(19,10),(20,13),(21,13),(22,13),(23,13),(25,14),(28,15),(29,99999),(30,16),(31,12),(32,12),(33,12),(34,12),(36,10),(37,10),(38,99999),(39,10),(40,10),(41,10),(42,10),(43,10),(44,10),(45,10),(46,10),(47,10),(48,10),(49,10),(50,10),(51,10),(52,10),(53,10),(54,10),(55,10),(56,10),(57,10),(58,10),(59,10),(60,99999),(61,10),(62,33),(64,33),(65,99999),(66,34),(68,17),(69,35),(70,99999),(71,63),(74,11),(75,28),(76,10),(77,65),(78,99999),(79,29),(89,99999)],[(80,10),(81,30),(82,30),(83,30),(84,31),(85,99999),(86,32)],[(86,32)],[(85,99999)],[(87,12),(88,12)],[(7,11),(8,12),(9,12),(10,12),(12,12),(13,10),(14,10),(15,10),(16,10),(17,10),(18,10),(19,10),(20,13),(21,13),(22,13),(23,13),(25,14),(28,15),(29,99999),(30,16),(31,12),(32,12),(33,12),(34,12),(36,10),(37,10),(38,99999),(39,10),(40,10),(41,10),(42,10),(43,10),(44,10),(45,10),(46,10),(47,10),(48,10),(49,10),(50,10),(51,10),(52,10),(53,10),(54,10),(55,10),(56,10),(57,10),(58,10),(59,10),(60,99999),(61,10),(62,33),(63,99999),(64,33),(65,99999),(66,34),(68,17),(69,35),(70,99999),(71,63),(74,11),(75,28),(77,65),(78,99999),(79,29),(89,99999)],[(7,11),(8,12),(10,12),(12,12),(13,10),(14,10),(15,10),(16,10),(17,10),(18,10),(19,10),(20,13),(21,13),(22,13),(23,13),(25,14),(28,15),(29,99999),(30,16),(31,12),(32,12),(33,12),(34,12),(67,99999),(68,17),(75,28),(78,99999),(79,29)],[(7,36),(9,37),(33,37),(34,37),(36,35),(37,35),(38,99999),(39,35),(40,35),(41,35),(42,35),(43,35),(44,35),(45,35),(46,35),(47,35),(48,35),(49,35),(50,35),(51,35),(52,35),(53,35),(54,35),(55,35),(56,35),(57,35),(58,35),(59,35),(60,99999),(61,35),(62,58),(64,58),(65,99999),(66,59),(70,99999),(71,60),(74,36),(77,62),(89,99999)],[(89,99999)],[(7,36),(8,37),(9,37),(10,37),(12,37),(13,35),(14,35),(15,35),(16,35),(17,35),(18,35),(19,35),(20,38),(21,38),(22,38),(23,38),(25,39),(28,40),(29,99999),(30,41),(31,37),(32,37),(33,37),(34,37),(36,35),(37,35),(38,99999),(39,35),(40,35),(41,35),(42,35),(43,35),(44,35),(45,35),(46,35),(47,35),(48,35),(49,35),(50,35),(51,35),(52,35),(53,35),(54,35),(55,35),(56,35),(57,35),(58,35),(59,35),(60,99999),(61,35),(62,58),(64,58),(65,99999),(66,59),(68,42),(70,99999),(71,60),(74,36),(75,53),(77,62),(78,99999),(79,54),(89,99999)],[(24,37)],[(26,35),(27,37)],[(7,36),(9,37),(13,35),(33,37),(34,37),(36,35),(37,35),(38,99999),(39,35),(40,35),(41,35),(42,35),(43,35),(44,35),(45,35),(46,35),(47,35),(48,35),(49,35),(50,35),(51,35),(52,35),(53,35),(54,35),(55,35),(56,35),(57,35),(58,35),(59,35),(60,99999),(61,35),(62,58),(64,58),(65,99999),(66,59),(70,99999),(71,60),(74,36),(77,62),(89,99999)],[(7,36),(33,37),(34,37),(36,35),(37,35),(38,99999),(39,35),(40,35),(41,35),(42,35),(43,35),(44,35),(45,35),(46,35),(47,35),(48,35),(49,35),(52,35),(53,35),(54,35),(57,35),(58,35),(59,35),(70,99999),(71,60),(74,36),(77,62),(89,99999)],[(7,77),(8,42),(9,42),(10,42),(12,42),(13,43),(14,43),(15,43),(16,43),(17,43),(18,43),(19,43),(20,44),(21,44),(22,44),(23,44),(25,45),(28,46),(29,99999),(30,47),(31,42),(32,42),(33,42),(34,42),(36,43),(37,43),(38,99999),(39,43),(40,43),(41,43),(42,43),(43,43),(44,43),(45,43),(46,43),(47,43),(48,43),(49,43),(50,43),(51,43),(52,43),(53,43),(54,43),(55,43),(56,43),(57,43),(58,43),(59,43),(60,99999),(61,43),(62,78),(64,78),(65,99999),(66,79),(70,99999),(71,80),(74,77),(75,48),(77,82),(78,99999),(79,49),(89,99999)],[(7,77),(9,42),(33,42),(34,42),(36,43),(37,43),(38,99999),(39,43),(40,43),(41,43),(42,43),(43,43),(44,43),(45,43),(46,43),(47,43),(48,43),(49,43),(50,43),(51,43),(52,43),(53,43),(54,43),(55,43),(56,43),(57,43),(58,43),(59,43),(60,99999),(61,43),(62,78),(64,78),(65,99999),(66,79),(70,99999),(71,80),(74,77),(77,82),(89,99999)],[(24,42)],[(26,43),(27,42)],[(7,77),(9,42),(13,43),(33,42),(34,42),(36,43),(37,43),(38,99999),(39,43),(40,43),(41,43),(42,43),(43,43),(44,43),(45,43),(46,43),(47,43),(48,43),(49,43),(50,43),(51,43),(52,43),(53,43),(54,43),(55,43),(56,43),(57,43),(58,43),(59,43),(60,99999),(61,43),(62,78),(64,78),(65,99999),(66,79),(70,99999),(71,80),(74,77),(77,82),(89,99999)],[(7,77),(33,42),(34,42),(36,43),(37,43),(38,99999),(39,43),(40,43),(41,43),(42,43),(43,43),(44,43),(45,43),(46,43),(47,43),(48,43),(49,43),(52,43),(53,43),(54,43),(57,43),(58,43),(59,43),(70,99999),(71,80),(74,77),(77,82),(89,99999)],[(7,77),(8,42),(9,42),(10,42),(12,42),(13,43),(14,43),(15,43),(16,43),(17,43),(18,43),(19,43),(20,44),(21,44),(22,44),(23,44),(25,45),(28,46),(29,99999),(30,47),(31,42),(32,42),(33,42),(34,42),(36,43),(37,43),(38,99999),(39,43),(40,43),(41,43),(42,43),(43,43),(44,43),(45,43),(46,43),(47,43),(48,43),(49,43),(50,43),(51,43),(52,43),(53,43),(54,43),(55,43),(56,43),(57,43),(58,43),(59,43),(60,99999),(61,43),(62,78),(64,78),(65,99999),(66,79),(70,99999),(71,80),(74,77),(75,48),(76,43),(77,82),(78,99999),(79,49),(89,99999)],[(80,43),(81,50),(82,50),(83,50),(84,51),(85,99999),(86,52)],[(86,52)],[(85,99999)],[(87,42),(88,42)],[(7,36),(8,37),(9,37),(10,37),(12,37),(13,35),(14,35),(15,35),(16,35),(17,35),(18,35),(19,35),(20,38),(21,38),(22,38),(23,38),(25,39),(28,40),(29,99999),(30,41),(31,37),(32,37),(33,37),(34,37),(36,35),(37,35),(38,99999),(39,35),(40,35),(41,35),(42,35),(43,35),(44,35),(45,35),(46,35),(47,35),(48,35),(49,35),(50,35),(51,35),(52,35),(53,35),(54,35),(55,35),(56,35),(57,35),(58,35),(59,35),(60,99999),(61,35),(62,58),(64,58),(65,99999),(66,59),(68,42),(70,99999),(71,60),(74,36),(75,53),(76,35),(77,62),(78,99999),(79,54),(89,99999)],[(80,35),(81,55),(82,55),(83,55),(84,56),(85,99999),(86,57)],[(86,57)],[(85,99999)],[(87,37),(88,37)],[(7,36),(8,37),(9,37),(10,37),(12,37),(13,35),(14,35),(15,35),(16,35),(17,35),(18,35),(19,35),(20,38),(21,38),(22,38),(23,38),(25,39),(28,40),(29,99999),(30,41),(31,37),(32,37),(33,37),(34,37),(36,35),(37,35),(38,99999),(39,35),(40,35),(41,35),(42,35),(43,35),(44,35),(45,35),(46,35),(47,35),(48,35),(49,35),(50,35),(51,35),(52,35),(53,35),(54,35),(55,35),(56,35),(57,35),(58,35),(59,35),(60,99999),(61,35),(62,58),(63,99999),(64,58),(65,99999),(66,59),(68,42),(70,99999),(71,60),(74,36),(75,53),(77,62),(78,99999),(79,54),(89,99999)],[(7,36),(8,37),(10,37),(12,37),(13,35),(14,35),(15,35),(16,35),(17,35),(18,35),(19,35),(20,38),(21,38),(22,38),(23,38),(25,39),(28,40),(29,99999),(30,41),(31,37),(32,37),(33,37),(34,37),(67,99999),(68,42),(75,53),(78,99999),(79,54)],[(72,61),(73,36)],[(73,36)],[(7,36),(8,37),(10,37),(12,37),(13,35),(14,35),(15,35),(16,35),(17,35),(18,35),(19,35),(20,38),(21,38),(22,38),(23,38),(25,39),(28,40),(29,99999),(30,41),(31,37),(32,37),(33,37),(34,37),(36,35),(37,35),(38,99999),(39,35),(40,35),(41,35),(42,35),(43,35),(44,35),(45,35),(46,35),(47,35),(48,35),(49,35),(50,35),(51,35),(52,35),(53,35),(54,35),(55,35),(56,35),(57,35),(58,35),(59,35),(60,99999),(61,35),(62,58),(64,58),(65,99999),(66,59),(79,54),(89,99999)],[(72,64),(73,11)],[(73,11)],[(7,11),(8,12),(10,12),(12,12),(13,10),(14,10),(15,10),(16,10),(17,10),(18,10),(19,10),(20,13),(21,13),(22,13),(23,13),(25,14),(28,15),(29,99999),(30,16),(31,12),(32,12),(33,12),(34,12),(36,10),(37,10),(38,99999),(39,10),(40,10),(41,10),(42,10),(43,10),(44,10),(45,10),(46,10),(47,10),(48,10),(49,10),(50,10),(51,10),(52,10),(53,10),(54,10),(55,10),(56,10),(57,10),(58,10),(59,10),(60,99999),(61,10),(62,33),(64,33),(65,99999),(66,34),(79,29),(89,99999)],[(7,2),(8,4),(10,4),(12,4),(13,5),(14,5),(15,5),(16,5),(17,5),(18,5),(19,5),(20,6),(21,6),(22,6),(23,6),(25,7),(28,8),(29,99999),(30,9),(31,4),(32,4),(33,4),(34,4),(67,99999),(68,67),(75,132),(78,99999),(79,134)],[(7,68),(8,67),(9,67),(10,67),(12,67),(13,69),(14,69),(15,69),(16,69),(17,69),(18,69),(19,69),(20,70),(21,70),(22,70),(23,70),(25,71),(28,72),(29,99999),(30,73),(31,67),(32,67),(33,67),(34,67),(35,18),(36,69),(37,69),(38,99999),(39,69),(40,69),(41,69),(42,69),(43,69),(44,69),(45,69),(46,69),(47,69),(48,69),(49,69),(50,69),(51,69),(52,69),(53,69),(54,69),(55,69),(56,69),(57,69),(58,69),(59,69),(60,99999),(61,69),(62,86),(64,86),(65,99999),(66,87),(69,88),(70,99999),(71,105),(74,68),(75,107),(77,108),(78,99999),(79,109),(89,99999)],[(89,99999)],[(7,68),(9,67),(33,67),(34,67),(35,18),(36,69),(37,69),(38,99999),(39,69),(40,69),(41,69),(42,69),(43,69),(44,69),(45,69),(46,69),(47,69),(48,69),(49,69),(50,69),(51,69),(52,69),(53,69),(54,69),(55,69),(56,69),(57,69),(58,69),(59,69),(60,99999),(61,69),(62,86),(64,86),(65,99999),(66,87),(69,88),(70,99999),(71,105),(74,68),(77,108),(89,99999)],[(24,67)],[(26,69),(27,67)],[(7,68),(9,67),(13,69),(33,67),(34,67),(35,18),(36,69),(37,69),(38,99999),(39,69),(40,69),(41,69),(42,69),(43,69),(44,69),(45,69),(46,69),(47,69),(48,69),(49,69),(50,69),(51,69),(52,69),(53,69),(54,69),(55,69),(56,69),(57,69),(58,69),(59,69),(60,99999),(61,69),(62,86),(64,86),(65,99999),(66,87),(69,88),(70,99999),(71,105),(74,68),(77,108),(89,99999)],[(7,68),(33,67),(34,67),(35,18),(36,69),(37,69),(38,99999),(39,69),(40,69),(41,69),(42,69),(43,69),(44,69),(45,69),(46,69),(47,69),(48,69),(49,69),(52,69),(53,69),(54,69),(57,69),(58,69),(59,69),(69,88),(70,99999),(71,105),(74,68),(77,108),(89,99999)],[(89,99999)],[(7,74),(8,17),(9,17),(10,17),(12,17),(13,18),(14,18),(15,18),(16,18),(17,18),(18,18),(19,18),(20,19),(21,19),(22,19),(23,19),(25,20),(28,21),(29,99999),(30,22),(31,17),(32,17),(33,17),(34,17),(36,18),(37,18),(38,99999),(39,18),(40,18),(41,18),(42,18),(43,18),(44,18),(45,18),(46,18),(47,18),(48,18),(49,18),(50,18),(51,18),(52,18),(53,18),(54,18),(55,18),(56,18),(57,18),(58,18),(59,18),(60,99999),(61,18),(62,75),(63,99999),(64,75),(65,99999),(66,76),(69,43),(70,99999),(71,83),(74,74),(75,23),(77,85),(78,99999),(79,24),(89,99999)],[(7,74),(8,17),(10,17),(12,17),(13,18),(14,18),(15,18),(16,18),(17,18),(18,18),(19,18),(20,19),(21,19),(22,19),(23,19),(25,20),(28,21),(29,99999),(30,22),(31,17),(32,17),(33,17),(34,17),(67,99999),(75,23),(78,99999),(79,24)],[(89,99999)],[(7,77),(8,42),(9,42),(10,42),(12,42),(13,43),(14,43),(15,43),(16,43),(17,43),(18,43),(19,43),(20,44),(21,44),(22,44),(23,44),(25,45),(28,46),(29,99999),(30,47),(31,42),(32,42),(33,42),(34,42),(36,43),(37,43),(38,99999),(39,43),(40,43),(41,43),(42,43),(43,43),(44,43),(45,43),(46,43),(47,43),(48,43),(49,43),(50,43),(51,43),(52,43),(53,43),(54,43),(55,43),(56,43),(57,43),(58,43),(59,43),(60,99999),(61,43),(62,78),(63,99999),(64,78),(65,99999),(66,79),(70,99999),(71,80),(74,77),(75,48),(77,82),(78,99999),(79,49),(89,99999)],[(7,77),(8,42),(10,42),(12,42),(13,43),(14,43),(15,43),(16,43),(17,43),(18,43),(19,43),(20,44),(21,44),(22,44),(23,44),(25,45),(28,46),(29,99999),(30,47),(31,42),(32,42),(33,42),(34,42),(67,99999),(75,48),(78,99999),(79,49)],[(72,81),(73,77)],[(73,77)],[(7,77),(8,42),(10,42),(12,42),(13,43),(14,43),(15,43),(16,43),(17,43),(18,43),(19,43),(20,44),(21,44),(22,44),(23,44),(25,45),(28,46),(29,99999),(30,47),(31,42),(32,42),(33,42),(34,42),(36,43),(37,43),(38,99999),(39,43),(40,43),(41,43),(42,43),(43,43),(44,43),(45,43),(46,43),(47,43),(48,43),(49,43),(50,43),(51,43),(52,43),(53,43),(54,43),(55,43),(56,43),(57,43),(58,43),(59,43),(60,99999),(61,43),(62,78),(64,78),(65,99999),(66,79),(79,49),(89,99999)],[(72,84),(73,74)],[(73,74)],[(7,74),(8,17),(10,17),(12,17),(13,18),(14,18),(15,18),(16,18),(17,18),(18,18),(19,18),(20,19),(21,19),(22,19),(23,19),(25,20),(28,21),(29,99999),(30,22),(31,17),(32,17),(33,17),(34,17),(36,18),(37,18),(38,99999),(39,18),(40,18),(41,18),(42,18),(43,18),(44,18),(45,18),(46,18),(47,18),(48,18),(49,18),(50,18),(51,18),(52,18),(53,18),(54,18),(55,18),(56,18),(57,18),(58,18),(59,18),(60,99999),(61,18),(62,75),(64,75),(65,99999),(66,76),(79,24),(89,99999)],[(7,68),(8,67),(9,67),(10,67),(12,67),(13,69),(14,69),(15,69),(16,69),(17,69),(18,69),(19,69),(20,70),(21,70),(22,70),(23,70),(25,71),(28,72),(29,99999),(30,73),(31,67),(32,67),(33,67),(34,67),(35,18),(36,69),(37,69),(38,99999),(39,69),(40,69),(41,69),(42,69),(43,69),(44,69),(45,69),(46,69),(47,69),(48,69),(49,69),(50,69),(51,69),(52,69),(53,69),(54,69),(55,69),(56,69),(57,69),(58,69),(59,69),(60,99999),(61,69),(62,86),(63,99999),(64,86),(65,99999),(66,87),(69,88),(70,99999),(71,105),(74,68),(75,107),(77,108),(78,99999),(79,109),(89,99999)],[(7,68),(8,67),(10,67),(12,67),(13,69),(14,69),(15,69),(16,69),(17,69),(18,69),(19,69),(20,70),(21,70),(22,70),(23,70),(25,71),(28,72),(29,99999),(30,73),(31,67),(32,67),(33,67),(34,67),(67,99999),(75,107),(78,99999),(79,109)],[(7,89),(9,90),(33,90),(34,90),(35,43),(36,88),(37,88),(38,99999),(39,88),(40,88),(41,88),(42,88),(43,88),(44,88),(45,88),(46,88),(47,88),(48,88),(49,88),(50,88),(51,88),(52,88),(53,88),(54,88),(55,88),(56,88),(57,88),(58,88),(59,88),(60,99999),(61,88),(62,100),(64,100),(65,99999),(66,101),(70,99999),(71,102),(74,89),(77,104),(89,99999)],[(89,99999)],[(7,89),(8,90),(9,90),(10,90),(12,90),(13,88),(14,88),(15,88),(16,88),(17,88),(18,88),(19,88),(20,91),(21,91),(22,91),(23,91),(25,92),(28,93),(29,99999),(30,94),(31,90),(32,90),(33,90),(34,90),(35,43),(36,88),(37,88),(38,99999),(39,88),(40,88),(41,88),(42,88),(43,88),(44,88),(45,88),(46,88),(47,88),(48,88),(49,88),(50,88),(51,88),(52,88),(53,88),(54,88),(55,88),(56,88),(57,88),(58,88),(59,88),(60,99999),(61,88),(62,100),(64,100),(65,99999),(66,101),(70,99999),(71,102),(74,89),(75,95),(77,104),(78,99999),(79,96),(89,99999)],[(24,90)],[(26,88),(27,90)],[(7,89),(9,90),(13,88),(33,90),(34,90),(35,43),(36,88),(37,88),(38,99999),(39,88),(40,88),(41,88),(42,88),(43,88),(44,88),(45,88),(46,88),(47,88),(48,88),(49,88),(50,88),(51,88),(52,88),(53,88),(54,88),(55,88),(56,88),(57,88),(58,88),(59,88),(60,99999),(61,88),(62,100),(64,100),(65,99999),(66,101),(70,99999),(71,102),(74,89),(77,104),(89,99999)],[(7,89),(33,90),(34,90),(35,43),(36,88),(37,88),(38,99999),(39,88),(40,88),(41,88),(42,88),(43,88),(44,88),(45,88),(46,88),(47,88),(48,88),(49,88),(52,88),(53,88),(54,88),(57,88),(58,88),(59,88),(70,99999),(71,102),(74,89),(77,104),(89,99999)],[(7,89),(8,90),(9,90),(10,90),(12,90),(13,88),(14,88),(15,88),(16,88),(17,88),(18,88),(19,88),(20,91),(21,91),(22,91),(23,91),(25,92),(28,93),(29,99999),(30,94),(31,90),(32,90),(33,90),(34,90),(35,43),(36,88),(37,88),(38,99999),(39,88),(40,88),(41,88),(42,88),(43,88),(44,88),(45,88),(46,88),(47,88),(48,88),(49,88),(50,88),(51,88),(52,88),(53,88),(54,88),(55,88),(56,88),(57,88),(58,88),(59,88),(60,99999),(61,88),(62,100),(64,100),(65,99999),(66,101),(70,99999),(71,102),(74,89),(75,95),(76,88),(77,104),(78,99999),(79,96),(89,99999)],[(80,88),(81,97),(82,97),(83,97),(84,98),(85,99999),(86,99)],[(86,99)],[(85,99999)],[(87,90),(88,90)],[(7,89),(8,90),(9,90),(10,90),(12,90),(13,88),(14,88),(15,88),(16,88),(17,88),(18,88),(19,88),(20,91),(21,91),(22,91),(23,91),(25,92),(28,93),(29,99999),(30,94),(31,90),(32,90),(33,90),(34,90),(35,43),(36,88),(37,88),(38,99999),(39,88),(40,88),(41,88),(42,88),(43,88),(44,88),(45,88),(46,88),(47,88),(48,88),(49,88),(50,88),(51,88),(52,88),(53,88),(54,88),(55,88),(56,88),(57,88),(58,88),(59,88),(60,99999),(61,88),(62,100),(63,99999),(64,100),(65,99999),(66,101),(70,99999),(71,102),(74,89),(75,95),(77,104),(78,99999),(79,96),(89,99999)],[(7,89),(8,90),(10,90),(12,90),(13,88),(14,88),(15,88),(16,88),(17,88),(18,88),(19,88),(20,91),(21,91),(22,91),(23,91),(25,92),(28,93),(29,99999),(30,94),(31,90),(32,90),(33,90),(34,90),(67,99999),(75,95),(78,99999),(79,96)],[(72,103),(73,89)],[(73,89)],[(7,89),(8,90),(10,90),(12,90),(13,88),(14,88),(15,88),(16,88),(17,88),(18,88),(19,88),(20,91),(21,91),(22,91),(23,91),(25,92),(28,93),(29,99999),(30,94),(31,90),(32,90),(33,90),(34,90),(36,88),(37,88),(38,99999),(39,88),(40,88),(41,88),(42,88),(43,88),(44,88),(45,88),(46,88),(47,88),(48,88),(49,88),(50,88),(51,88),(52,88),(53,88),(54,88),(55,88),(56,88),(57,88),(58,88),(59,88),(60,99999),(61,88),(62,100),(64,100),(65,99999),(66,101),(79,96),(89,99999)],[(72,106),(73,68)],[(73,68)],[(7,68),(8,67),(9,67),(10,67),(12,67),(13,69),(14,69),(15,69),(16,69),(17,69),(18,69),(19,69),(20,70),(21,70),(22,70),(23,70),(25,71),(28,72),(29,99999),(30,73),(31,67),(32,67),(33,67),(34,67),(35,18),(36,69),(37,69),(38,99999),(39,69),(40,69),(41,69),(42,69),(43,69),(44,69),(45,69),(46,69),(47,69),(48,69),(49,69),(50,69),(51,69),(52,69),(53,69),(54,69),(55,69),(56,69),(57,69),(58,69),(59,69),(60,99999),(61,69),(62,86),(64,86),(65,99999),(66,87),(69,88),(70,99999),(71,105),(74,68),(75,107),(76,69),(77,108),(78,99999),(79,109),(89,99999)],[(7,68),(8,67),(10,67),(12,67),(13,69),(14,69),(15,69),(16,69),(17,69),(18,69),(19,69),(20,70),(21,70),(22,70),(23,70),(25,71),(28,72),(29,99999),(30,73),(31,67),(32,67),(33,67),(34,67),(36,69),(37,69),(38,99999),(39,69),(40,69),(41,69),(42,69),(43,69),(44,69),(45,69),(46,69),(47,69),(48,69),(49,69),(50,69),(51,69),(52,69),(53,69),(54,69),(55,69),(56,69),(57,69),(58,69),(59,69),(60,99999),(61,69),(62,86),(64,86),(65,99999),(66,87),(79,109),(89,99999)],[(80,69),(81,110),(82,110),(83,110),(84,111),(85,99999),(86,112)],[(86,112)],[(85,99999)],[(87,67),(88,67)],[(7,114),(9,115),(33,115),(34,115),(35,35),(36,113),(37,113),(38,99999),(39,113),(40,113),(41,113),(42,113),(43,113),(44,113),(45,113),(46,113),(47,113),(48,113),(49,113),(50,113),(51,113),(52,113),(53,113),(54,113),(55,113),(56,113),(57,113),(58,113),(59,113),(60,99999),(61,113),(62,125),(64,125),(65,99999),(66,126),(70,99999),(71,127),(74,114),(77,129),(89,99999)],[(89,99999)],[(7,114),(8,115),(9,115),(10,115),(12,115),(13,113),(14,113),(15,113),(16,113),(17,113),(18,113),(19,113),(20,116),(21,116),(22,116),(23,116),(25,117),(28,118),(29,99999),(30,119),(31,115),(32,115),(33,115),(34,115),(35,35),(36,113),(37,113),(38,99999),(39,113),(40,113),(41,113),(42,113),(43,113),(44,113),(45,113),(46,113),(47,113),(48,113),(49,113),(50,113),(51,113),(52,113),(53,113),(54,113),(55,113),(56,113),(57,113),(58,113),(59,113),(60,99999),(61,113),(62,125),(64,125),(65,99999),(66,126),(68,90),(70,99999),(71,127),(74,114),(75,120),(77,129),(78,99999),(79,121),(89,99999)],[(24,115)],[(26,113),(27,115)],[(7,114),(9,115),(13,113),(33,115),(34,115),(35,35),(36,113),(37,113),(38,99999),(39,113),(40,113),(41,113),(42,113),(43,113),(44,113),(45,113),(46,113),(47,113),(48,113),(49,113),(50,113),(51,113),(52,113),(53,113),(54,113),(55,113),(56,113),(57,113),(58,113),(59,113),(60,99999),(61,113),(62,125),(64,125),(65,99999),(66,126),(70,99999),(71,127),(74,114),(77,129),(89,99999)],[(7,114),(33,115),(34,115),(35,35),(36,113),(37,113),(38,99999),(39,113),(40,113),(41,113),(42,113),(43,113),(44,113),(45,113),(46,113),(47,113),(48,113),(49,113),(52,113),(53,113),(54,113),(57,113),(58,113),(59,113),(70,99999),(71,127),(74,114),(77,129),(89,99999)],[(7,114),(8,115),(9,115),(10,115),(12,115),(13,113),(14,113),(15,113),(16,113),(17,113),(18,113),(19,113),(20,116),(21,116),(22,116),(23,116),(25,117),(28,118),(29,99999),(30,119),(31,115),(32,115),(33,115),(34,115),(35,35),(36,113),(37,113),(38,99999),(39,113),(40,113),(41,113),(42,113),(43,113),(44,113),(45,113),(46,113),(47,113),(48,113),(49,113),(50,113),(51,113),(52,113),(53,113),(54,113),(55,113),(56,113),(57,113),(58,113),(59,113),(60,99999),(61,113),(62,125),(64,125),(65,99999),(66,126),(68,90),(70,99999),(71,127),(74,114),(75,120),(76,113),(77,129),(78,99999),(79,121),(89,99999)],[(80,113),(81,122),(82,122),(83,122),(84,123),(85,99999),(86,124)],[(86,124)],[(85,99999)],[(87,115),(88,115)],[(7,114),(8,115),(9,115),(10,115),(12,115),(13,113),(14,113),(15,113),(16,113),(17,113),(18,113),(19,113),(20,116),(21,116),(22,116),(23,116),(25,117),(28,118),(29,99999),(30,119),(31,115),(32,115),(33,115),(34,115),(35,35),(36,113),(37,113),(38,99999),(39,113),(40,113),(41,113),(42,113),(43,113),(44,113),(45,113),(46,113),(47,113),(48,113),(49,113),(50,113),(51,113),(52,113),(53,113),(54,113),(55,113),(56,113),(57,113),(58,113),(59,113),(60,99999),(61,113),(62,125),(63,99999),(64,125),(65,99999),(66,126),(68,90),(70,99999),(71,127),(74,114),(75,120),(77,129),(78,99999),(79,121),(89,99999)],[(7,114),(8,115),(10,115),(12,115),(13,113),(14,113),(15,113),(16,113),(17,113),(18,113),(19,113),(20,116),(21,116),(22,116),(23,116),(25,117),(28,118),(29,99999),(30,119),(31,115),(32,115),(33,115),(34,115),(67,99999),(68,90),(75,120),(78,99999),(79,121)],[(72,128),(73,114)],[(73,114)],[(7,114),(8,115),(10,115),(12,115),(13,113),(14,113),(15,113),(16,113),(17,113),(18,113),(19,113),(20,116),(21,116),(22,116),(23,116),(25,117),(28,118),(29,99999),(30,119),(31,115),(32,115),(33,115),(34,115),(36,113),(37,113),(38,99999),(39,113),(40,113),(41,113),(42,113),(43,113),(44,113),(45,113),(46,113),(47,113),(48,113),(49,113),(50,113),(51,113),(52,113),(53,113),(54,113),(55,113),(56,113),(57,113),(58,113),(59,113),(60,99999),(61,113),(62,125),(64,125),(65,99999),(66,126),(79,121),(89,99999)],[(72,131),(73,2)],[(73,2)],[(7,2),(8,4),(9,4),(10,4),(12,4),(13,5),(14,5),(15,5),(16,5),(17,5),(18,5),(19,5),(20,6),(21,6),(22,6),(23,6),(25,7),(28,8),(29,99999),(30,9),(31,4),(32,4),(33,4),(34,4),(35,10),(36,5),(37,5),(38,99999),(39,5),(40,5),(41,5),(42,5),(43,5),(44,5),(45,5),(46,5),(47,5),(48,5),(49,5),(50,5),(51,5),(52,5),(53,5),(54,5),(55,5),(56,5),(57,5),(58,5),(59,5),(60,99999),(61,5),(62,3),(64,3),(65,99999),(66,66),(68,67),(69,113),(70,99999),(71,130),(74,2),(75,132),(76,5),(77,133),(78,99999),(79,134),(89,99999)],[(7,2),(8,4),(10,4),(12,4),(13,5),(14,5),(15,5),(16,5),(17,5),(18,5),(19,5),(20,6),(21,6),(22,6),(23,6),(25,7),(28,8),(29,99999),(30,9),(31,4),(32,4),(33,4),(34,4),(36,5),(37,5),(38,99999),(39,5),(40,5),(41,5),(42,5),(43,5),(44,5),(45,5),(46,5),(47,5),(48,5),(49,5),(50,5),(51,5),(52,5),(53,5),(54,5),(55,5),(56,5),(57,5),(58,5),(59,5),(60,99999),(61,5),(62,3),(64,3),(65,99999),(66,66),(79,134),(89,99999)],[(80,5),(81,135),(82,135),(83,135),(84,136),(85,99999),(86,137)],[(86,137)],[(85,99999)],[(87,4),(88,4)],[]]



-- Bytestring conversion functions
s2b_escape = U.fromString . stringToHtmlString
stringToHtmlString = concatMap fixChar
    where
      fixChar '<' = "&lt;"
      fixChar '>' = "&gt;"
      fixChar '&' = "&amp;"
      fixChar '"' = "&quot;"
      fixChar c   = [c]
html_escape c   = c
s2b = U.fromString
lt_byte = s2b "<"
gt_byte = s2b ">"
gts_byte = s2b " />"

-- | HTML document root type
data Ent = Html [Att0] [Ent0]
    deriving (Show)

data Att59 = Id_Att_59 B.ByteString  | Class_Att_59 B.ByteString  | Style_Att_59 B.ByteString  | Title_Att_59 B.ByteString  | Lang_Att_59 B.ByteString  | Dir_Att_59 B.ByteString  | Onclick_Att_59 B.ByteString  | Ondblclick_Att_59 B.ByteString  | Onmousedown_Att_59 B.ByteString  | Onmouseup_Att_59 B.ByteString  | Onmouseover_Att_59 B.ByteString  | Onmousemove_Att_59 B.ByteString  | Onmouseout_Att_59 B.ByteString  | Onkeypress_Att_59 B.ByteString  | Onkeydown_Att_59 B.ByteString  | Onkeyup_Att_59 B.ByteString  | Abbr_Att_59 B.ByteString  | Axis_Att_59 B.ByteString  | Headers_Att_59 B.ByteString  | Scope_Att_59 B.ByteString  | Rowspan_Att_59 B.ByteString  | Colspan_Att_59 B.ByteString  | Align_Att_59 B.ByteString  | Char_Att_59 B.ByteString  | Charoff_Att_59 B.ByteString  | Valign_Att_59 B.ByteString  | Nowrap_Att_59 B.ByteString  | Bgcolor_Att_59 B.ByteString  | Width_Att_59 B.ByteString  | Height_Att_59 B.ByteString 
   deriving (Show)
data Att58 = Id_Att_58 B.ByteString  | Class_Att_58 B.ByteString  | Style_Att_58 B.ByteString  | Title_Att_58 B.ByteString  | Lang_Att_58 B.ByteString  | Dir_Att_58 B.ByteString  | Onclick_Att_58 B.ByteString  | Ondblclick_Att_58 B.ByteString  | Onmousedown_Att_58 B.ByteString  | Onmouseup_Att_58 B.ByteString  | Onmouseover_Att_58 B.ByteString  | Onmousemove_Att_58 B.ByteString  | Onmouseout_Att_58 B.ByteString  | Onkeypress_Att_58 B.ByteString  | Onkeydown_Att_58 B.ByteString  | Onkeyup_Att_58 B.ByteString  | Align_Att_58 B.ByteString  | Char_Att_58 B.ByteString  | Charoff_Att_58 B.ByteString  | Valign_Att_58 B.ByteString  | Bgcolor_Att_58 B.ByteString 
   deriving (Show)
data Att57 = Id_Att_57 B.ByteString  | Class_Att_57 B.ByteString  | Style_Att_57 B.ByteString  | Title_Att_57 B.ByteString  | Lang_Att_57 B.ByteString  | Dir_Att_57 B.ByteString  | Onclick_Att_57 B.ByteString  | Ondblclick_Att_57 B.ByteString  | Onmousedown_Att_57 B.ByteString  | Onmouseup_Att_57 B.ByteString  | Onmouseover_Att_57 B.ByteString  | Onmousemove_Att_57 B.ByteString  | Onmouseout_Att_57 B.ByteString  | Onkeypress_Att_57 B.ByteString  | Onkeydown_Att_57 B.ByteString  | Onkeyup_Att_57 B.ByteString  | Span_Att_57 B.ByteString  | Width_Att_57 B.ByteString  | Align_Att_57 B.ByteString  | Char_Att_57 B.ByteString  | Charoff_Att_57 B.ByteString  | Valign_Att_57 B.ByteString 
   deriving (Show)
data Att56 = Id_Att_56 B.ByteString  | Class_Att_56 B.ByteString  | Style_Att_56 B.ByteString  | Title_Att_56 B.ByteString  | Lang_Att_56 B.ByteString  | Dir_Att_56 B.ByteString  | Onclick_Att_56 B.ByteString  | Ondblclick_Att_56 B.ByteString  | Onmousedown_Att_56 B.ByteString  | Onmouseup_Att_56 B.ByteString  | Onmouseover_Att_56 B.ByteString  | Onmousemove_Att_56 B.ByteString  | Onmouseout_Att_56 B.ByteString  | Onkeypress_Att_56 B.ByteString  | Onkeydown_Att_56 B.ByteString  | Onkeyup_Att_56 B.ByteString  | Align_Att_56 B.ByteString  | Char_Att_56 B.ByteString  | Charoff_Att_56 B.ByteString  | Valign_Att_56 B.ByteString 
   deriving (Show)
data Att55 = Id_Att_55 B.ByteString  | Class_Att_55 B.ByteString  | Style_Att_55 B.ByteString  | Title_Att_55 B.ByteString  | Lang_Att_55 B.ByteString  | Dir_Att_55 B.ByteString  | Onclick_Att_55 B.ByteString  | Ondblclick_Att_55 B.ByteString  | Onmousedown_Att_55 B.ByteString  | Onmouseup_Att_55 B.ByteString  | Onmouseover_Att_55 B.ByteString  | Onmousemove_Att_55 B.ByteString  | Onmouseout_Att_55 B.ByteString  | Onkeypress_Att_55 B.ByteString  | Onkeydown_Att_55 B.ByteString  | Onkeyup_Att_55 B.ByteString  | Summary_Att_55 B.ByteString  | Width_Att_55 B.ByteString  | Border_Att_55 B.ByteString  | Frame_Att_55 B.ByteString  | Rules_Att_55 B.ByteString  | Cellspacing_Att_55 B.ByteString  | Cellpadding_Att_55 B.ByteString  | Align_Att_55 B.ByteString  | Bgcolor_Att_55 B.ByteString 
   deriving (Show)
data Att54 = Id_Att_54 B.ByteString  | Class_Att_54 B.ByteString  | Style_Att_54 B.ByteString  | Title_Att_54 B.ByteString  | Lang_Att_54 B.ByteString  | Dir_Att_54 B.ByteString  | Prompt_Att_54 B.ByteString 
   deriving (Show)
data Att53 = Id_Att_53 B.ByteString  | Class_Att_53 B.ByteString  | Style_Att_53 B.ByteString  | Title_Att_53 B.ByteString  | Lang_Att_53 B.ByteString  | Dir_Att_53 B.ByteString  | Onclick_Att_53 B.ByteString  | Ondblclick_Att_53 B.ByteString  | Onmousedown_Att_53 B.ByteString  | Onmouseup_Att_53 B.ByteString  | Onmouseover_Att_53 B.ByteString  | Onmousemove_Att_53 B.ByteString  | Onmouseout_Att_53 B.ByteString  | Onkeypress_Att_53 B.ByteString  | Onkeydown_Att_53 B.ByteString  | Onkeyup_Att_53 B.ByteString  | Accesskey_Att_53 B.ByteString  | Tabindex_Att_53 B.ByteString  | Onfocus_Att_53 B.ByteString  | Onblur_Att_53 B.ByteString  | Name_Att_53 B.ByteString  | Value_Att_53 B.ByteString  | Type_Att_53 B.ByteString  | Disabled_Att_53 B.ByteString 
   deriving (Show)
data Att52 = Id_Att_52 B.ByteString  | Class_Att_52 B.ByteString  | Style_Att_52 B.ByteString  | Title_Att_52 B.ByteString  | Lang_Att_52 B.ByteString  | Dir_Att_52 B.ByteString  | Onclick_Att_52 B.ByteString  | Ondblclick_Att_52 B.ByteString  | Onmousedown_Att_52 B.ByteString  | Onmouseup_Att_52 B.ByteString  | Onmouseover_Att_52 B.ByteString  | Onmousemove_Att_52 B.ByteString  | Onmouseout_Att_52 B.ByteString  | Onkeypress_Att_52 B.ByteString  | Onkeydown_Att_52 B.ByteString  | Onkeyup_Att_52 B.ByteString  | Accesskey_Att_52 B.ByteString  | Align_Att_52 B.ByteString 
   deriving (Show)
data Att51 = Cols_Att_51 B.ByteString 
   deriving (Show)
data Att50 = Rows_Att_50 B.ByteString 
   deriving (Show)
data Att49 = Id_Att_49 B.ByteString  | Class_Att_49 B.ByteString  | Style_Att_49 B.ByteString  | Title_Att_49 B.ByteString  | Lang_Att_49 B.ByteString  | Dir_Att_49 B.ByteString  | Onclick_Att_49 B.ByteString  | Ondblclick_Att_49 B.ByteString  | Onmousedown_Att_49 B.ByteString  | Onmouseup_Att_49 B.ByteString  | Onmouseover_Att_49 B.ByteString  | Onmousemove_Att_49 B.ByteString  | Onmouseout_Att_49 B.ByteString  | Onkeypress_Att_49 B.ByteString  | Onkeydown_Att_49 B.ByteString  | Onkeyup_Att_49 B.ByteString  | Accesskey_Att_49 B.ByteString  | Tabindex_Att_49 B.ByteString  | Onfocus_Att_49 B.ByteString  | Onblur_Att_49 B.ByteString  | Name_Att_49 B.ByteString  | Rows_Att_49 B.ByteString  | Cols_Att_49 B.ByteString  | Disabled_Att_49 B.ByteString  | Readonly_Att_49 B.ByteString  | Onselect_Att_49 B.ByteString  | Onchange_Att_49 B.ByteString 
   deriving (Show)
data Att48 = Id_Att_48 B.ByteString  | Class_Att_48 B.ByteString  | Style_Att_48 B.ByteString  | Title_Att_48 B.ByteString  | Lang_Att_48 B.ByteString  | Dir_Att_48 B.ByteString  | Onclick_Att_48 B.ByteString  | Ondblclick_Att_48 B.ByteString  | Onmousedown_Att_48 B.ByteString  | Onmouseup_Att_48 B.ByteString  | Onmouseover_Att_48 B.ByteString  | Onmousemove_Att_48 B.ByteString  | Onmouseout_Att_48 B.ByteString  | Onkeypress_Att_48 B.ByteString  | Onkeydown_Att_48 B.ByteString  | Onkeyup_Att_48 B.ByteString  | Selected_Att_48 B.ByteString  | Disabled_Att_48 B.ByteString  | Label_Att_48 B.ByteString  | Value_Att_48 B.ByteString 
   deriving (Show)
data Att47 = Label_Att_47 B.ByteString 
   deriving (Show)
data Att46 = Id_Att_46 B.ByteString  | Class_Att_46 B.ByteString  | Style_Att_46 B.ByteString  | Title_Att_46 B.ByteString  | Lang_Att_46 B.ByteString  | Dir_Att_46 B.ByteString  | Onclick_Att_46 B.ByteString  | Ondblclick_Att_46 B.ByteString  | Onmousedown_Att_46 B.ByteString  | Onmouseup_Att_46 B.ByteString  | Onmouseover_Att_46 B.ByteString  | Onmousemove_Att_46 B.ByteString  | Onmouseout_Att_46 B.ByteString  | Onkeypress_Att_46 B.ByteString  | Onkeydown_Att_46 B.ByteString  | Onkeyup_Att_46 B.ByteString  | Disabled_Att_46 B.ByteString  | Label_Att_46 B.ByteString 
   deriving (Show)
data Att45 = Id_Att_45 B.ByteString  | Class_Att_45 B.ByteString  | Style_Att_45 B.ByteString  | Title_Att_45 B.ByteString  | Lang_Att_45 B.ByteString  | Dir_Att_45 B.ByteString  | Onclick_Att_45 B.ByteString  | Ondblclick_Att_45 B.ByteString  | Onmousedown_Att_45 B.ByteString  | Onmouseup_Att_45 B.ByteString  | Onmouseover_Att_45 B.ByteString  | Onmousemove_Att_45 B.ByteString  | Onmouseout_Att_45 B.ByteString  | Onkeypress_Att_45 B.ByteString  | Onkeydown_Att_45 B.ByteString  | Onkeyup_Att_45 B.ByteString  | Name_Att_45 B.ByteString  | Size_Att_45 B.ByteString  | Multiple_Att_45 B.ByteString  | Disabled_Att_45 B.ByteString  | Tabindex_Att_45 B.ByteString  | Onfocus_Att_45 B.ByteString  | Onblur_Att_45 B.ByteString  | Onchange_Att_45 B.ByteString 
   deriving (Show)
data Att44 = Id_Att_44 B.ByteString  | Class_Att_44 B.ByteString  | Style_Att_44 B.ByteString  | Title_Att_44 B.ByteString  | Lang_Att_44 B.ByteString  | Dir_Att_44 B.ByteString  | Onclick_Att_44 B.ByteString  | Ondblclick_Att_44 B.ByteString  | Onmousedown_Att_44 B.ByteString  | Onmouseup_Att_44 B.ByteString  | Onmouseover_Att_44 B.ByteString  | Onmousemove_Att_44 B.ByteString  | Onmouseout_Att_44 B.ByteString  | Onkeypress_Att_44 B.ByteString  | Onkeydown_Att_44 B.ByteString  | Onkeyup_Att_44 B.ByteString  | Accesskey_Att_44 B.ByteString  | Tabindex_Att_44 B.ByteString  | Onfocus_Att_44 B.ByteString  | Onblur_Att_44 B.ByteString  | Type_Att_44 B.ByteString  | Name_Att_44 B.ByteString  | Value_Att_44 B.ByteString  | Checked_Att_44 B.ByteString  | Disabled_Att_44 B.ByteString  | Readonly_Att_44 B.ByteString  | Size_Att_44 B.ByteString  | Maxlength_Att_44 B.ByteString  | Src_Att_44 B.ByteString  | Alt_Att_44 B.ByteString  | Usemap_Att_44 B.ByteString  | Onselect_Att_44 B.ByteString  | Onchange_Att_44 B.ByteString  | Accept_Att_44 B.ByteString  | Align_Att_44 B.ByteString 
   deriving (Show)
data Att43 = Id_Att_43 B.ByteString  | Class_Att_43 B.ByteString  | Style_Att_43 B.ByteString  | Title_Att_43 B.ByteString  | Lang_Att_43 B.ByteString  | Dir_Att_43 B.ByteString  | Onclick_Att_43 B.ByteString  | Ondblclick_Att_43 B.ByteString  | Onmousedown_Att_43 B.ByteString  | Onmouseup_Att_43 B.ByteString  | Onmouseover_Att_43 B.ByteString  | Onmousemove_Att_43 B.ByteString  | Onmouseout_Att_43 B.ByteString  | Onkeypress_Att_43 B.ByteString  | Onkeydown_Att_43 B.ByteString  | Onkeyup_Att_43 B.ByteString  | For_Att_43 B.ByteString  | Accesskey_Att_43 B.ByteString  | Onfocus_Att_43 B.ByteString  | Onblur_Att_43 B.ByteString 
   deriving (Show)
data Att42 = Action_Att_42 B.ByteString 
   deriving (Show)
data Att41 = Id_Att_41 B.ByteString  | Class_Att_41 B.ByteString  | Style_Att_41 B.ByteString  | Title_Att_41 B.ByteString  | Lang_Att_41 B.ByteString  | Dir_Att_41 B.ByteString  | Onclick_Att_41 B.ByteString  | Ondblclick_Att_41 B.ByteString  | Onmousedown_Att_41 B.ByteString  | Onmouseup_Att_41 B.ByteString  | Onmouseover_Att_41 B.ByteString  | Onmousemove_Att_41 B.ByteString  | Onmouseout_Att_41 B.ByteString  | Onkeypress_Att_41 B.ByteString  | Onkeydown_Att_41 B.ByteString  | Onkeyup_Att_41 B.ByteString  | Action_Att_41 B.ByteString  | Method_Att_41 B.ByteString  | Name_Att_41 B.ByteString  | Enctype_Att_41 B.ByteString  | Onsubmit_Att_41 B.ByteString  | Onreset_Att_41 B.ByteString  | Accept_Att_41 B.ByteString  | Accept_charset_Att_41 B.ByteString  | Target_Att_41 B.ByteString 
   deriving (Show)
data Att40 = Id_Att_40 B.ByteString  | Class_Att_40 B.ByteString  | Style_Att_40 B.ByteString  | Title_Att_40 B.ByteString  | Lang_Att_40 B.ByteString  | Dir_Att_40 B.ByteString  | Onclick_Att_40 B.ByteString  | Ondblclick_Att_40 B.ByteString  | Onmousedown_Att_40 B.ByteString  | Onmouseup_Att_40 B.ByteString  | Onmouseover_Att_40 B.ByteString  | Onmousemove_Att_40 B.ByteString  | Onmouseout_Att_40 B.ByteString  | Onkeypress_Att_40 B.ByteString  | Onkeydown_Att_40 B.ByteString  | Onkeyup_Att_40 B.ByteString  | Accesskey_Att_40 B.ByteString  | Tabindex_Att_40 B.ByteString  | Onfocus_Att_40 B.ByteString  | Onblur_Att_40 B.ByteString  | Shape_Att_40 B.ByteString  | Coords_Att_40 B.ByteString  | Href_Att_40 B.ByteString  | Nohref_Att_40 B.ByteString  | Alt_Att_40 B.ByteString  | Target_Att_40 B.ByteString 
   deriving (Show)
data Att39 = Id_Att_39 B.ByteString 
   deriving (Show)
data Att38 = Lang_Att_38 B.ByteString  | Dir_Att_38 B.ByteString  | Onclick_Att_38 B.ByteString  | Ondblclick_Att_38 B.ByteString  | Onmousedown_Att_38 B.ByteString  | Onmouseup_Att_38 B.ByteString  | Onmouseover_Att_38 B.ByteString  | Onmousemove_Att_38 B.ByteString  | Onmouseout_Att_38 B.ByteString  | Onkeypress_Att_38 B.ByteString  | Onkeydown_Att_38 B.ByteString  | Onkeyup_Att_38 B.ByteString  | Id_Att_38 B.ByteString  | Class_Att_38 B.ByteString  | Style_Att_38 B.ByteString  | Title_Att_38 B.ByteString  | Name_Att_38 B.ByteString 
   deriving (Show)
data Att37 = Alt_Att_37 B.ByteString 
   deriving (Show)
data Att36 = Src_Att_36 B.ByteString 
   deriving (Show)
data Att35 = Id_Att_35 B.ByteString  | Class_Att_35 B.ByteString  | Style_Att_35 B.ByteString  | Title_Att_35 B.ByteString  | Lang_Att_35 B.ByteString  | Dir_Att_35 B.ByteString  | Onclick_Att_35 B.ByteString  | Ondblclick_Att_35 B.ByteString  | Onmousedown_Att_35 B.ByteString  | Onmouseup_Att_35 B.ByteString  | Onmouseover_Att_35 B.ByteString  | Onmousemove_Att_35 B.ByteString  | Onmouseout_Att_35 B.ByteString  | Onkeypress_Att_35 B.ByteString  | Onkeydown_Att_35 B.ByteString  | Onkeyup_Att_35 B.ByteString  | Src_Att_35 B.ByteString  | Alt_Att_35 B.ByteString  | Name_Att_35 B.ByteString  | Longdesc_Att_35 B.ByteString  | Height_Att_35 B.ByteString  | Width_Att_35 B.ByteString  | Usemap_Att_35 B.ByteString  | Ismap_Att_35 B.ByteString  | Align_Att_35 B.ByteString  | Border_Att_35 B.ByteString  | Hspace_Att_35 B.ByteString  | Vspace_Att_35 B.ByteString 
   deriving (Show)
data Att34 = Height_Att_34 B.ByteString 
   deriving (Show)
data Att33 = Width_Att_33 B.ByteString 
   deriving (Show)
data Att32 = Id_Att_32 B.ByteString  | Class_Att_32 B.ByteString  | Style_Att_32 B.ByteString  | Title_Att_32 B.ByteString  | Codebase_Att_32 B.ByteString  | Archive_Att_32 B.ByteString  | Code_Att_32 B.ByteString  | Object_Att_32 B.ByteString  | Alt_Att_32 B.ByteString  | Name_Att_32 B.ByteString  | Width_Att_32 B.ByteString  | Height_Att_32 B.ByteString  | Align_Att_32 B.ByteString  | Hspace_Att_32 B.ByteString  | Vspace_Att_32 B.ByteString 
   deriving (Show)
data Att31 = Name_Att_31 B.ByteString 
   deriving (Show)
data Att30 = Id_Att_30 B.ByteString  | Name_Att_30 B.ByteString  | Value_Att_30 B.ByteString  | Valuetype_Att_30 B.ByteString  | Type_Att_30 B.ByteString 
   deriving (Show)
data Att29 = Id_Att_29 B.ByteString  | Class_Att_29 B.ByteString  | Style_Att_29 B.ByteString  | Title_Att_29 B.ByteString  | Lang_Att_29 B.ByteString  | Dir_Att_29 B.ByteString  | Onclick_Att_29 B.ByteString  | Ondblclick_Att_29 B.ByteString  | Onmousedown_Att_29 B.ByteString  | Onmouseup_Att_29 B.ByteString  | Onmouseover_Att_29 B.ByteString  | Onmousemove_Att_29 B.ByteString  | Onmouseout_Att_29 B.ByteString  | Onkeypress_Att_29 B.ByteString  | Onkeydown_Att_29 B.ByteString  | Onkeyup_Att_29 B.ByteString  | Declare_Att_29 B.ByteString  | Classid_Att_29 B.ByteString  | Codebase_Att_29 B.ByteString  | Data_Att_29 B.ByteString  | Type_Att_29 B.ByteString  | Codetype_Att_29 B.ByteString  | Archive_Att_29 B.ByteString  | Standby_Att_29 B.ByteString  | Height_Att_29 B.ByteString  | Width_Att_29 B.ByteString  | Usemap_Att_29 B.ByteString  | Name_Att_29 B.ByteString  | Tabindex_Att_29 B.ByteString  | Align_Att_29 B.ByteString  | Border_Att_29 B.ByteString  | Hspace_Att_29 B.ByteString  | Vspace_Att_29 B.ByteString 
   deriving (Show)
data Att28 = Id_Att_28 B.ByteString  | Class_Att_28 B.ByteString  | Style_Att_28 B.ByteString  | Title_Att_28 B.ByteString  | Lang_Att_28 B.ByteString  | Dir_Att_28 B.ByteString  | Size_Att_28 B.ByteString  | Color_Att_28 B.ByteString  | Face_Att_28 B.ByteString 
   deriving (Show)
data Att27 = Size_Att_27 B.ByteString 
   deriving (Show)
data Att26 = Id_Att_26 B.ByteString  | Size_Att_26 B.ByteString  | Color_Att_26 B.ByteString  | Face_Att_26 B.ByteString 
   deriving (Show)
data Att25 = Id_Att_25 B.ByteString  | Class_Att_25 B.ByteString  | Style_Att_25 B.ByteString  | Title_Att_25 B.ByteString  | Clear_Att_25 B.ByteString 
   deriving (Show)
data Att24 = Dir_Att_24 B.ByteString 
   deriving (Show)
data Att23 = Id_Att_23 B.ByteString  | Class_Att_23 B.ByteString  | Style_Att_23 B.ByteString  | Title_Att_23 B.ByteString  | Onclick_Att_23 B.ByteString  | Ondblclick_Att_23 B.ByteString  | Onmousedown_Att_23 B.ByteString  | Onmouseup_Att_23 B.ByteString  | Onmouseover_Att_23 B.ByteString  | Onmousemove_Att_23 B.ByteString  | Onmouseout_Att_23 B.ByteString  | Onkeypress_Att_23 B.ByteString  | Onkeydown_Att_23 B.ByteString  | Onkeyup_Att_23 B.ByteString  | Lang_Att_23 B.ByteString  | Dir_Att_23 B.ByteString 
   deriving (Show)
data Att22 = Id_Att_22 B.ByteString  | Class_Att_22 B.ByteString  | Style_Att_22 B.ByteString  | Title_Att_22 B.ByteString  | Lang_Att_22 B.ByteString  | Dir_Att_22 B.ByteString  | Onclick_Att_22 B.ByteString  | Ondblclick_Att_22 B.ByteString  | Onmousedown_Att_22 B.ByteString  | Onmouseup_Att_22 B.ByteString  | Onmouseover_Att_22 B.ByteString  | Onmousemove_Att_22 B.ByteString  | Onmouseout_Att_22 B.ByteString  | Onkeypress_Att_22 B.ByteString  | Onkeydown_Att_22 B.ByteString  | Onkeyup_Att_22 B.ByteString  | Accesskey_Att_22 B.ByteString  | Tabindex_Att_22 B.ByteString  | Onfocus_Att_22 B.ByteString  | Onblur_Att_22 B.ByteString  | Charset_Att_22 B.ByteString  | Type_Att_22 B.ByteString  | Name_Att_22 B.ByteString  | Href_Att_22 B.ByteString  | Hreflang_Att_22 B.ByteString  | Rel_Att_22 B.ByteString  | Rev_Att_22 B.ByteString  | Shape_Att_22 B.ByteString  | Coords_Att_22 B.ByteString  | Target_Att_22 B.ByteString 
   deriving (Show)
data Att21 = Id_Att_21 B.ByteString  | Class_Att_21 B.ByteString  | Style_Att_21 B.ByteString  | Title_Att_21 B.ByteString  | Lang_Att_21 B.ByteString  | Dir_Att_21 B.ByteString  | Onclick_Att_21 B.ByteString  | Ondblclick_Att_21 B.ByteString  | Onmousedown_Att_21 B.ByteString  | Onmouseup_Att_21 B.ByteString  | Onmouseover_Att_21 B.ByteString  | Onmousemove_Att_21 B.ByteString  | Onmouseout_Att_21 B.ByteString  | Onkeypress_Att_21 B.ByteString  | Onkeydown_Att_21 B.ByteString  | Onkeyup_Att_21 B.ByteString  | Cite_Att_21 B.ByteString  | Datetime_Att_21 B.ByteString 
   deriving (Show)
data Att20 = Id_Att_20 B.ByteString  | Class_Att_20 B.ByteString  | Style_Att_20 B.ByteString  | Title_Att_20 B.ByteString  | Lang_Att_20 B.ByteString  | Dir_Att_20 B.ByteString  | Onclick_Att_20 B.ByteString  | Ondblclick_Att_20 B.ByteString  | Onmousedown_Att_20 B.ByteString  | Onmouseup_Att_20 B.ByteString  | Onmouseover_Att_20 B.ByteString  | Onmousemove_Att_20 B.ByteString  | Onmouseout_Att_20 B.ByteString  | Onkeypress_Att_20 B.ByteString  | Onkeydown_Att_20 B.ByteString  | Onkeyup_Att_20 B.ByteString  | Cite_Att_20 B.ByteString 
   deriving (Show)
data Att19 = Id_Att_19 B.ByteString  | Class_Att_19 B.ByteString  | Style_Att_19 B.ByteString  | Title_Att_19 B.ByteString  | Lang_Att_19 B.ByteString  | Dir_Att_19 B.ByteString  | Onclick_Att_19 B.ByteString  | Ondblclick_Att_19 B.ByteString  | Onmousedown_Att_19 B.ByteString  | Onmouseup_Att_19 B.ByteString  | Onmouseover_Att_19 B.ByteString  | Onmousemove_Att_19 B.ByteString  | Onmouseout_Att_19 B.ByteString  | Onkeypress_Att_19 B.ByteString  | Onkeydown_Att_19 B.ByteString  | Onkeyup_Att_19 B.ByteString  | Width_Att_19 B.ByteString 
   deriving (Show)
data Att18 = Id_Att_18 B.ByteString  | Class_Att_18 B.ByteString  | Style_Att_18 B.ByteString  | Title_Att_18 B.ByteString  | Lang_Att_18 B.ByteString  | Dir_Att_18 B.ByteString  | Onclick_Att_18 B.ByteString  | Ondblclick_Att_18 B.ByteString  | Onmousedown_Att_18 B.ByteString  | Onmouseup_Att_18 B.ByteString  | Onmouseover_Att_18 B.ByteString  | Onmousemove_Att_18 B.ByteString  | Onmouseout_Att_18 B.ByteString  | Onkeypress_Att_18 B.ByteString  | Onkeydown_Att_18 B.ByteString  | Onkeyup_Att_18 B.ByteString  | Align_Att_18 B.ByteString  | Noshade_Att_18 B.ByteString  | Size_Att_18 B.ByteString  | Width_Att_18 B.ByteString 
   deriving (Show)
data Att17 = Id_Att_17 B.ByteString  | Class_Att_17 B.ByteString  | Style_Att_17 B.ByteString  | Title_Att_17 B.ByteString  | Lang_Att_17 B.ByteString  | Dir_Att_17 B.ByteString  | Onclick_Att_17 B.ByteString  | Ondblclick_Att_17 B.ByteString  | Onmousedown_Att_17 B.ByteString  | Onmouseup_Att_17 B.ByteString  | Onmouseover_Att_17 B.ByteString  | Onmousemove_Att_17 B.ByteString  | Onmouseout_Att_17 B.ByteString  | Onkeypress_Att_17 B.ByteString  | Onkeydown_Att_17 B.ByteString  | Onkeyup_Att_17 B.ByteString  | Type_Att_17 B.ByteString  | Value_Att_17 B.ByteString 
   deriving (Show)
data Att16 = Id_Att_16 B.ByteString  | Class_Att_16 B.ByteString  | Style_Att_16 B.ByteString  | Title_Att_16 B.ByteString  | Lang_Att_16 B.ByteString  | Dir_Att_16 B.ByteString  | Onclick_Att_16 B.ByteString  | Ondblclick_Att_16 B.ByteString  | Onmousedown_Att_16 B.ByteString  | Onmouseup_Att_16 B.ByteString  | Onmouseover_Att_16 B.ByteString  | Onmousemove_Att_16 B.ByteString  | Onmouseout_Att_16 B.ByteString  | Onkeypress_Att_16 B.ByteString  | Onkeydown_Att_16 B.ByteString  | Onkeyup_Att_16 B.ByteString  | Compact_Att_16 B.ByteString 
   deriving (Show)
data Att15 = Id_Att_15 B.ByteString  | Class_Att_15 B.ByteString  | Style_Att_15 B.ByteString  | Title_Att_15 B.ByteString  | Lang_Att_15 B.ByteString  | Dir_Att_15 B.ByteString  | Onclick_Att_15 B.ByteString  | Ondblclick_Att_15 B.ByteString  | Onmousedown_Att_15 B.ByteString  | Onmouseup_Att_15 B.ByteString  | Onmouseover_Att_15 B.ByteString  | Onmousemove_Att_15 B.ByteString  | Onmouseout_Att_15 B.ByteString  | Onkeypress_Att_15 B.ByteString  | Onkeydown_Att_15 B.ByteString  | Onkeyup_Att_15 B.ByteString  | Type_Att_15 B.ByteString  | Compact_Att_15 B.ByteString  | Start_Att_15 B.ByteString 
   deriving (Show)
data Att14 = Id_Att_14 B.ByteString  | Class_Att_14 B.ByteString  | Style_Att_14 B.ByteString  | Title_Att_14 B.ByteString  | Lang_Att_14 B.ByteString  | Dir_Att_14 B.ByteString  | Onclick_Att_14 B.ByteString  | Ondblclick_Att_14 B.ByteString  | Onmousedown_Att_14 B.ByteString  | Onmouseup_Att_14 B.ByteString  | Onmouseover_Att_14 B.ByteString  | Onmousemove_Att_14 B.ByteString  | Onmouseout_Att_14 B.ByteString  | Onkeypress_Att_14 B.ByteString  | Onkeydown_Att_14 B.ByteString  | Onkeyup_Att_14 B.ByteString  | Type_Att_14 B.ByteString  | Compact_Att_14 B.ByteString 
   deriving (Show)
data Att13 = Id_Att_13 B.ByteString  | Class_Att_13 B.ByteString  | Style_Att_13 B.ByteString  | Title_Att_13 B.ByteString  | Lang_Att_13 B.ByteString  | Dir_Att_13 B.ByteString  | Onclick_Att_13 B.ByteString  | Ondblclick_Att_13 B.ByteString  | Onmousedown_Att_13 B.ByteString  | Onmouseup_Att_13 B.ByteString  | Onmouseover_Att_13 B.ByteString  | Onmousemove_Att_13 B.ByteString  | Onmouseout_Att_13 B.ByteString  | Onkeypress_Att_13 B.ByteString  | Onkeydown_Att_13 B.ByteString  | Onkeyup_Att_13 B.ByteString  | Align_Att_13 B.ByteString 
   deriving (Show)
data Att12 = Id_Att_12 B.ByteString  | Class_Att_12 B.ByteString  | Style_Att_12 B.ByteString  | Title_Att_12 B.ByteString  | Lang_Att_12 B.ByteString  | Dir_Att_12 B.ByteString  | Onclick_Att_12 B.ByteString  | Ondblclick_Att_12 B.ByteString  | Onmousedown_Att_12 B.ByteString  | Onmouseup_Att_12 B.ByteString  | Onmouseover_Att_12 B.ByteString  | Onmousemove_Att_12 B.ByteString  | Onmouseout_Att_12 B.ByteString  | Onkeypress_Att_12 B.ByteString  | Onkeydown_Att_12 B.ByteString  | Onkeyup_Att_12 B.ByteString  | Onload_Att_12 B.ByteString  | Onunload_Att_12 B.ByteString  | Background_Att_12 B.ByteString  | Bgcolor_Att_12 B.ByteString  | Text_Att_12 B.ByteString  | Link_Att_12 B.ByteString  | Vlink_Att_12 B.ByteString  | Alink_Att_12 B.ByteString 
   deriving (Show)
data Att11 = Id_Att_11 B.ByteString  | Class_Att_11 B.ByteString  | Style_Att_11 B.ByteString  | Title_Att_11 B.ByteString  | Longdesc_Att_11 B.ByteString  | Name_Att_11 B.ByteString  | Src_Att_11 B.ByteString  | Frameborder_Att_11 B.ByteString  | Marginwidth_Att_11 B.ByteString  | Marginheight_Att_11 B.ByteString  | Scrolling_Att_11 B.ByteString  | Align_Att_11 B.ByteString  | Height_Att_11 B.ByteString  | Width_Att_11 B.ByteString 
   deriving (Show)
data Att10 = Id_Att_10 B.ByteString  | Class_Att_10 B.ByteString  | Style_Att_10 B.ByteString  | Title_Att_10 B.ByteString  | Lang_Att_10 B.ByteString  | Dir_Att_10 B.ByteString  | Onclick_Att_10 B.ByteString  | Ondblclick_Att_10 B.ByteString  | Onmousedown_Att_10 B.ByteString  | Onmouseup_Att_10 B.ByteString  | Onmouseover_Att_10 B.ByteString  | Onmousemove_Att_10 B.ByteString  | Onmouseout_Att_10 B.ByteString  | Onkeypress_Att_10 B.ByteString  | Onkeydown_Att_10 B.ByteString  | Onkeyup_Att_10 B.ByteString 
   deriving (Show)
data Att9 = Id_Att_9 B.ByteString  | Charset_Att_9 B.ByteString  | Type_Att_9 B.ByteString  | Language_Att_9 B.ByteString  | Src_Att_9 B.ByteString  | Defer_Att_9 B.ByteString 
   deriving (Show)
data Att8 = Type_Att_8 B.ByteString 
   deriving (Show)
data Att7 = Lang_Att_7 B.ByteString  | Dir_Att_7 B.ByteString  | Id_Att_7 B.ByteString  | Type_Att_7 B.ByteString  | Media_Att_7 B.ByteString  | Title_Att_7 B.ByteString 
   deriving (Show)
data Att6 = Id_Att_6 B.ByteString  | Class_Att_6 B.ByteString  | Style_Att_6 B.ByteString  | Title_Att_6 B.ByteString  | Lang_Att_6 B.ByteString  | Dir_Att_6 B.ByteString  | Onclick_Att_6 B.ByteString  | Ondblclick_Att_6 B.ByteString  | Onmousedown_Att_6 B.ByteString  | Onmouseup_Att_6 B.ByteString  | Onmouseover_Att_6 B.ByteString  | Onmousemove_Att_6 B.ByteString  | Onmouseout_Att_6 B.ByteString  | Onkeypress_Att_6 B.ByteString  | Onkeydown_Att_6 B.ByteString  | Onkeyup_Att_6 B.ByteString  | Charset_Att_6 B.ByteString  | Href_Att_6 B.ByteString  | Hreflang_Att_6 B.ByteString  | Type_Att_6 B.ByteString  | Rel_Att_6 B.ByteString  | Rev_Att_6 B.ByteString  | Media_Att_6 B.ByteString  | Target_Att_6 B.ByteString 
   deriving (Show)
data Att5 = Content_Att_5 B.ByteString 
   deriving (Show)
data Att4 = Lang_Att_4 B.ByteString  | Dir_Att_4 B.ByteString  | Id_Att_4 B.ByteString  | Http_equiv_Att_4 B.ByteString  | Name_Att_4 B.ByteString  | Content_Att_4 B.ByteString  | Scheme_Att_4 B.ByteString 
   deriving (Show)
data Att3 = Id_Att_3 B.ByteString  | Href_Att_3 B.ByteString  | Target_Att_3 B.ByteString 
   deriving (Show)
data Att2 = Lang_Att_2 B.ByteString  | Dir_Att_2 B.ByteString  | Id_Att_2 B.ByteString 
   deriving (Show)
data Att1 = Lang_Att_1 B.ByteString  | Dir_Att_1 B.ByteString  | Id_Att_1 B.ByteString  | Profile_Att_1 B.ByteString 
   deriving (Show)
data Att0 = Lang_Att_0 B.ByteString  | Dir_Att_0 B.ByteString  | Id_Att_0 B.ByteString  | Xmlns_Att_0 B.ByteString 
   deriving (Show)

data ValuetypeEnum = Data | Ref | Object
instance Show ValuetypeEnum where
    show Text.CHXHtml.XHtml1_transitional.Data="data"
    show Text.CHXHtml.XHtml1_transitional.Ref="ref"
    show Text.CHXHtml.XHtml1_transitional.Object="object"
data RulesEnum = Rules_none | Groups | Rows | Cols | Rules_all
instance Show RulesEnum where
    show Text.CHXHtml.XHtml1_transitional.Rules_none="none"
    show Text.CHXHtml.XHtml1_transitional.Groups="groups"
    show Text.CHXHtml.XHtml1_transitional.Rows="rows"
    show Text.CHXHtml.XHtml1_transitional.Cols="cols"
    show Text.CHXHtml.XHtml1_transitional.Rules_all="all"
data ScrollingEnum = Yes | No | Auto
instance Show ScrollingEnum where
    show Text.CHXHtml.XHtml1_transitional.Yes="yes"
    show Text.CHXHtml.XHtml1_transitional.No="no"
    show Text.CHXHtml.XHtml1_transitional.Auto="auto"
data ShapeEnum = Rect | Circle | Poly | Default
instance Show ShapeEnum where
    show Text.CHXHtml.XHtml1_transitional.Rect="rect"
    show Text.CHXHtml.XHtml1_transitional.Circle="circle"
    show Text.CHXHtml.XHtml1_transitional.Poly="poly"
    show Text.CHXHtml.XHtml1_transitional.Default="default"
data MethodEnum = Get | Post
instance Show MethodEnum where
    show Text.CHXHtml.XHtml1_transitional.Get="get"
    show Text.CHXHtml.XHtml1_transitional.Post="post"
data DirEnum = Ltr | Rtl
instance Show DirEnum where
    show Text.CHXHtml.XHtml1_transitional.Ltr="ltr"
    show Text.CHXHtml.XHtml1_transitional.Rtl="rtl"
data FrameEnum = Void | Above | Below | Hsides | Lhs | Rhs | Vsides | Box | Border
instance Show FrameEnum where
    show Text.CHXHtml.XHtml1_transitional.Void="void"
    show Text.CHXHtml.XHtml1_transitional.Above="above"
    show Text.CHXHtml.XHtml1_transitional.Below="below"
    show Text.CHXHtml.XHtml1_transitional.Hsides="hsides"
    show Text.CHXHtml.XHtml1_transitional.Lhs="lhs"
    show Text.CHXHtml.XHtml1_transitional.Rhs="rhs"
    show Text.CHXHtml.XHtml1_transitional.Vsides="vsides"
    show Text.CHXHtml.XHtml1_transitional.Box="box"
    show Text.CHXHtml.XHtml1_transitional.Border="border"
data FrameborderEnum = D1 | D0
instance Show FrameborderEnum where
    show Text.CHXHtml.XHtml1_transitional.D1="1"
    show Text.CHXHtml.XHtml1_transitional.D0="0"
data ValignEnum = Top | Middle | Bottom | Baseline
instance Show ValignEnum where
    show Text.CHXHtml.XHtml1_transitional.Top="top"
    show Text.CHXHtml.XHtml1_transitional.Middle="middle"
    show Text.CHXHtml.XHtml1_transitional.Bottom="bottom"
    show Text.CHXHtml.XHtml1_transitional.Baseline="baseline"
data AlignEnum = Align_left | Center | Align_right | Justify
instance Show AlignEnum where
    show Text.CHXHtml.XHtml1_transitional.Align_left="left"
    show Text.CHXHtml.XHtml1_transitional.Center="center"
    show Text.CHXHtml.XHtml1_transitional.Align_right="right"
    show Text.CHXHtml.XHtml1_transitional.Justify="justify"
data ScopeEnum = Row | Col | Rowgroup | Colgroup
instance Show ScopeEnum where
    show Text.CHXHtml.XHtml1_transitional.Row="row"
    show Text.CHXHtml.XHtml1_transitional.Col="col"
    show Text.CHXHtml.XHtml1_transitional.Rowgroup="rowgroup"
    show Text.CHXHtml.XHtml1_transitional.Colgroup="colgroup"
data ClearEnum = Clear_left | Clear_all | Clear_right | Clear_none
instance Show ClearEnum where
    show Text.CHXHtml.XHtml1_transitional.Clear_left="left"
    show Text.CHXHtml.XHtml1_transitional.Clear_all="all"
    show Text.CHXHtml.XHtml1_transitional.Clear_right="right"
    show Text.CHXHtml.XHtml1_transitional.Clear_none="none"

class A_Http_equiv a where
    http_equiv_att :: String -> a
    http_equiv_att_bs :: B.ByteString -> a
instance A_Http_equiv Att4 where
    http_equiv_att s =  Http_equiv_Att_4 (s2b_escape s)
    http_equiv_att_bs =  Http_equiv_Att_4 

class A_Clear a where
    clear_att :: ClearEnum -> a
instance A_Clear Att25 where
    clear_att s =  Clear_Att_25 (s2b (show s))

class A_Content a where
    content_att :: String -> a
    content_att_bs :: B.ByteString -> a
instance A_Content Att5 where
    content_att s =  Content_Att_5 (s2b_escape s)
    content_att_bs =  Content_Att_5 
instance A_Content Att4 where
    content_att s =  Content_Att_4 (s2b_escape s)
    content_att_bs =  Content_Att_4 

class A_Nohref a where
    nohref_att :: String -> a
instance A_Nohref Att40 where
    nohref_att s =  Nohref_Att_40 (s2b (show s))

class A_Onkeydown a where
    onkeydown_att :: String -> a
    onkeydown_att_bs :: B.ByteString -> a
instance A_Onkeydown Att59 where
    onkeydown_att s =  Onkeydown_Att_59 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_59 
instance A_Onkeydown Att58 where
    onkeydown_att s =  Onkeydown_Att_58 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_58 
instance A_Onkeydown Att57 where
    onkeydown_att s =  Onkeydown_Att_57 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_57 
instance A_Onkeydown Att56 where
    onkeydown_att s =  Onkeydown_Att_56 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_56 
instance A_Onkeydown Att55 where
    onkeydown_att s =  Onkeydown_Att_55 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_55 
instance A_Onkeydown Att53 where
    onkeydown_att s =  Onkeydown_Att_53 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_53 
instance A_Onkeydown Att52 where
    onkeydown_att s =  Onkeydown_Att_52 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_52 
instance A_Onkeydown Att49 where
    onkeydown_att s =  Onkeydown_Att_49 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_49 
instance A_Onkeydown Att48 where
    onkeydown_att s =  Onkeydown_Att_48 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_48 
instance A_Onkeydown Att46 where
    onkeydown_att s =  Onkeydown_Att_46 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_46 
instance A_Onkeydown Att45 where
    onkeydown_att s =  Onkeydown_Att_45 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_45 
instance A_Onkeydown Att44 where
    onkeydown_att s =  Onkeydown_Att_44 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_44 
instance A_Onkeydown Att43 where
    onkeydown_att s =  Onkeydown_Att_43 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_43 
instance A_Onkeydown Att41 where
    onkeydown_att s =  Onkeydown_Att_41 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_41 
instance A_Onkeydown Att40 where
    onkeydown_att s =  Onkeydown_Att_40 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_40 
instance A_Onkeydown Att38 where
    onkeydown_att s =  Onkeydown_Att_38 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_38 
instance A_Onkeydown Att35 where
    onkeydown_att s =  Onkeydown_Att_35 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_35 
instance A_Onkeydown Att29 where
    onkeydown_att s =  Onkeydown_Att_29 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_29 
instance A_Onkeydown Att23 where
    onkeydown_att s =  Onkeydown_Att_23 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_23 
instance A_Onkeydown Att22 where
    onkeydown_att s =  Onkeydown_Att_22 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_22 
instance A_Onkeydown Att21 where
    onkeydown_att s =  Onkeydown_Att_21 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_21 
instance A_Onkeydown Att20 where
    onkeydown_att s =  Onkeydown_Att_20 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_20 
instance A_Onkeydown Att19 where
    onkeydown_att s =  Onkeydown_Att_19 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_19 
instance A_Onkeydown Att18 where
    onkeydown_att s =  Onkeydown_Att_18 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_18 
instance A_Onkeydown Att17 where
    onkeydown_att s =  Onkeydown_Att_17 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_17 
instance A_Onkeydown Att16 where
    onkeydown_att s =  Onkeydown_Att_16 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_16 
instance A_Onkeydown Att15 where
    onkeydown_att s =  Onkeydown_Att_15 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_15 
instance A_Onkeydown Att14 where
    onkeydown_att s =  Onkeydown_Att_14 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_14 
instance A_Onkeydown Att13 where
    onkeydown_att s =  Onkeydown_Att_13 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_13 
instance A_Onkeydown Att12 where
    onkeydown_att s =  Onkeydown_Att_12 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_12 
instance A_Onkeydown Att10 where
    onkeydown_att s =  Onkeydown_Att_10 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_10 
instance A_Onkeydown Att6 where
    onkeydown_att s =  Onkeydown_Att_6 (s2b_escape s)
    onkeydown_att_bs =  Onkeydown_Att_6 

class A_Target a where
    target_att :: String -> a
    target_att_bs :: B.ByteString -> a
instance A_Target Att41 where
    target_att s =  Target_Att_41 (s2b_escape s)
    target_att_bs =  Target_Att_41 
instance A_Target Att40 where
    target_att s =  Target_Att_40 (s2b_escape s)
    target_att_bs =  Target_Att_40 
instance A_Target Att22 where
    target_att s =  Target_Att_22 (s2b_escape s)
    target_att_bs =  Target_Att_22 
instance A_Target Att6 where
    target_att s =  Target_Att_6 (s2b_escape s)
    target_att_bs =  Target_Att_6 
instance A_Target Att3 where
    target_att s =  Target_Att_3 (s2b_escape s)
    target_att_bs =  Target_Att_3 

class A_Onkeyup a where
    onkeyup_att :: String -> a
    onkeyup_att_bs :: B.ByteString -> a
instance A_Onkeyup Att59 where
    onkeyup_att s =  Onkeyup_Att_59 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_59 
instance A_Onkeyup Att58 where
    onkeyup_att s =  Onkeyup_Att_58 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_58 
instance A_Onkeyup Att57 where
    onkeyup_att s =  Onkeyup_Att_57 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_57 
instance A_Onkeyup Att56 where
    onkeyup_att s =  Onkeyup_Att_56 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_56 
instance A_Onkeyup Att55 where
    onkeyup_att s =  Onkeyup_Att_55 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_55 
instance A_Onkeyup Att53 where
    onkeyup_att s =  Onkeyup_Att_53 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_53 
instance A_Onkeyup Att52 where
    onkeyup_att s =  Onkeyup_Att_52 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_52 
instance A_Onkeyup Att49 where
    onkeyup_att s =  Onkeyup_Att_49 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_49 
instance A_Onkeyup Att48 where
    onkeyup_att s =  Onkeyup_Att_48 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_48 
instance A_Onkeyup Att46 where
    onkeyup_att s =  Onkeyup_Att_46 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_46 
instance A_Onkeyup Att45 where
    onkeyup_att s =  Onkeyup_Att_45 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_45 
instance A_Onkeyup Att44 where
    onkeyup_att s =  Onkeyup_Att_44 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_44 
instance A_Onkeyup Att43 where
    onkeyup_att s =  Onkeyup_Att_43 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_43 
instance A_Onkeyup Att41 where
    onkeyup_att s =  Onkeyup_Att_41 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_41 
instance A_Onkeyup Att40 where
    onkeyup_att s =  Onkeyup_Att_40 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_40 
instance A_Onkeyup Att38 where
    onkeyup_att s =  Onkeyup_Att_38 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_38 
instance A_Onkeyup Att35 where
    onkeyup_att s =  Onkeyup_Att_35 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_35 
instance A_Onkeyup Att29 where
    onkeyup_att s =  Onkeyup_Att_29 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_29 
instance A_Onkeyup Att23 where
    onkeyup_att s =  Onkeyup_Att_23 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_23 
instance A_Onkeyup Att22 where
    onkeyup_att s =  Onkeyup_Att_22 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_22 
instance A_Onkeyup Att21 where
    onkeyup_att s =  Onkeyup_Att_21 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_21 
instance A_Onkeyup Att20 where
    onkeyup_att s =  Onkeyup_Att_20 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_20 
instance A_Onkeyup Att19 where
    onkeyup_att s =  Onkeyup_Att_19 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_19 
instance A_Onkeyup Att18 where
    onkeyup_att s =  Onkeyup_Att_18 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_18 
instance A_Onkeyup Att17 where
    onkeyup_att s =  Onkeyup_Att_17 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_17 
instance A_Onkeyup Att16 where
    onkeyup_att s =  Onkeyup_Att_16 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_16 
instance A_Onkeyup Att15 where
    onkeyup_att s =  Onkeyup_Att_15 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_15 
instance A_Onkeyup Att14 where
    onkeyup_att s =  Onkeyup_Att_14 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_14 
instance A_Onkeyup Att13 where
    onkeyup_att s =  Onkeyup_Att_13 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_13 
instance A_Onkeyup Att12 where
    onkeyup_att s =  Onkeyup_Att_12 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_12 
instance A_Onkeyup Att10 where
    onkeyup_att s =  Onkeyup_Att_10 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_10 
instance A_Onkeyup Att6 where
    onkeyup_att s =  Onkeyup_Att_6 (s2b_escape s)
    onkeyup_att_bs =  Onkeyup_Att_6 

class A_Onreset a where
    onreset_att :: String -> a
    onreset_att_bs :: B.ByteString -> a
instance A_Onreset Att41 where
    onreset_att s =  Onreset_Att_41 (s2b_escape s)
    onreset_att_bs =  Onreset_Att_41 

class A_Onmouseup a where
    onmouseup_att :: String -> a
    onmouseup_att_bs :: B.ByteString -> a
instance A_Onmouseup Att59 where
    onmouseup_att s =  Onmouseup_Att_59 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_59 
instance A_Onmouseup Att58 where
    onmouseup_att s =  Onmouseup_Att_58 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_58 
instance A_Onmouseup Att57 where
    onmouseup_att s =  Onmouseup_Att_57 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_57 
instance A_Onmouseup Att56 where
    onmouseup_att s =  Onmouseup_Att_56 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_56 
instance A_Onmouseup Att55 where
    onmouseup_att s =  Onmouseup_Att_55 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_55 
instance A_Onmouseup Att53 where
    onmouseup_att s =  Onmouseup_Att_53 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_53 
instance A_Onmouseup Att52 where
    onmouseup_att s =  Onmouseup_Att_52 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_52 
instance A_Onmouseup Att49 where
    onmouseup_att s =  Onmouseup_Att_49 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_49 
instance A_Onmouseup Att48 where
    onmouseup_att s =  Onmouseup_Att_48 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_48 
instance A_Onmouseup Att46 where
    onmouseup_att s =  Onmouseup_Att_46 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_46 
instance A_Onmouseup Att45 where
    onmouseup_att s =  Onmouseup_Att_45 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_45 
instance A_Onmouseup Att44 where
    onmouseup_att s =  Onmouseup_Att_44 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_44 
instance A_Onmouseup Att43 where
    onmouseup_att s =  Onmouseup_Att_43 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_43 
instance A_Onmouseup Att41 where
    onmouseup_att s =  Onmouseup_Att_41 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_41 
instance A_Onmouseup Att40 where
    onmouseup_att s =  Onmouseup_Att_40 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_40 
instance A_Onmouseup Att38 where
    onmouseup_att s =  Onmouseup_Att_38 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_38 
instance A_Onmouseup Att35 where
    onmouseup_att s =  Onmouseup_Att_35 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_35 
instance A_Onmouseup Att29 where
    onmouseup_att s =  Onmouseup_Att_29 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_29 
instance A_Onmouseup Att23 where
    onmouseup_att s =  Onmouseup_Att_23 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_23 
instance A_Onmouseup Att22 where
    onmouseup_att s =  Onmouseup_Att_22 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_22 
instance A_Onmouseup Att21 where
    onmouseup_att s =  Onmouseup_Att_21 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_21 
instance A_Onmouseup Att20 where
    onmouseup_att s =  Onmouseup_Att_20 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_20 
instance A_Onmouseup Att19 where
    onmouseup_att s =  Onmouseup_Att_19 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_19 
instance A_Onmouseup Att18 where
    onmouseup_att s =  Onmouseup_Att_18 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_18 
instance A_Onmouseup Att17 where
    onmouseup_att s =  Onmouseup_Att_17 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_17 
instance A_Onmouseup Att16 where
    onmouseup_att s =  Onmouseup_Att_16 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_16 
instance A_Onmouseup Att15 where
    onmouseup_att s =  Onmouseup_Att_15 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_15 
instance A_Onmouseup Att14 where
    onmouseup_att s =  Onmouseup_Att_14 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_14 
instance A_Onmouseup Att13 where
    onmouseup_att s =  Onmouseup_Att_13 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_13 
instance A_Onmouseup Att12 where
    onmouseup_att s =  Onmouseup_Att_12 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_12 
instance A_Onmouseup Att10 where
    onmouseup_att s =  Onmouseup_Att_10 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_10 
instance A_Onmouseup Att6 where
    onmouseup_att s =  Onmouseup_Att_6 (s2b_escape s)
    onmouseup_att_bs =  Onmouseup_Att_6 

class A_Scope a where
    scope_att :: ScopeEnum -> a
instance A_Scope Att59 where
    scope_att s =  Scope_Att_59 (s2b (show s))

class A_Code a where
    code_att :: String -> a
    code_att_bs :: B.ByteString -> a
instance A_Code Att32 where
    code_att s =  Code_Att_32 (s2b_escape s)
    code_att_bs =  Code_Att_32 

class A_Onmouseover a where
    onmouseover_att :: String -> a
    onmouseover_att_bs :: B.ByteString -> a
instance A_Onmouseover Att59 where
    onmouseover_att s =  Onmouseover_Att_59 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_59 
instance A_Onmouseover Att58 where
    onmouseover_att s =  Onmouseover_Att_58 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_58 
instance A_Onmouseover Att57 where
    onmouseover_att s =  Onmouseover_Att_57 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_57 
instance A_Onmouseover Att56 where
    onmouseover_att s =  Onmouseover_Att_56 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_56 
instance A_Onmouseover Att55 where
    onmouseover_att s =  Onmouseover_Att_55 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_55 
instance A_Onmouseover Att53 where
    onmouseover_att s =  Onmouseover_Att_53 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_53 
instance A_Onmouseover Att52 where
    onmouseover_att s =  Onmouseover_Att_52 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_52 
instance A_Onmouseover Att49 where
    onmouseover_att s =  Onmouseover_Att_49 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_49 
instance A_Onmouseover Att48 where
    onmouseover_att s =  Onmouseover_Att_48 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_48 
instance A_Onmouseover Att46 where
    onmouseover_att s =  Onmouseover_Att_46 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_46 
instance A_Onmouseover Att45 where
    onmouseover_att s =  Onmouseover_Att_45 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_45 
instance A_Onmouseover Att44 where
    onmouseover_att s =  Onmouseover_Att_44 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_44 
instance A_Onmouseover Att43 where
    onmouseover_att s =  Onmouseover_Att_43 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_43 
instance A_Onmouseover Att41 where
    onmouseover_att s =  Onmouseover_Att_41 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_41 
instance A_Onmouseover Att40 where
    onmouseover_att s =  Onmouseover_Att_40 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_40 
instance A_Onmouseover Att38 where
    onmouseover_att s =  Onmouseover_Att_38 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_38 
instance A_Onmouseover Att35 where
    onmouseover_att s =  Onmouseover_Att_35 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_35 
instance A_Onmouseover Att29 where
    onmouseover_att s =  Onmouseover_Att_29 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_29 
instance A_Onmouseover Att23 where
    onmouseover_att s =  Onmouseover_Att_23 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_23 
instance A_Onmouseover Att22 where
    onmouseover_att s =  Onmouseover_Att_22 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_22 
instance A_Onmouseover Att21 where
    onmouseover_att s =  Onmouseover_Att_21 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_21 
instance A_Onmouseover Att20 where
    onmouseover_att s =  Onmouseover_Att_20 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_20 
instance A_Onmouseover Att19 where
    onmouseover_att s =  Onmouseover_Att_19 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_19 
instance A_Onmouseover Att18 where
    onmouseover_att s =  Onmouseover_Att_18 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_18 
instance A_Onmouseover Att17 where
    onmouseover_att s =  Onmouseover_Att_17 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_17 
instance A_Onmouseover Att16 where
    onmouseover_att s =  Onmouseover_Att_16 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_16 
instance A_Onmouseover Att15 where
    onmouseover_att s =  Onmouseover_Att_15 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_15 
instance A_Onmouseover Att14 where
    onmouseover_att s =  Onmouseover_Att_14 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_14 
instance A_Onmouseover Att13 where
    onmouseover_att s =  Onmouseover_Att_13 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_13 
instance A_Onmouseover Att12 where
    onmouseover_att s =  Onmouseover_Att_12 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_12 
instance A_Onmouseover Att10 where
    onmouseover_att s =  Onmouseover_Att_10 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_10 
instance A_Onmouseover Att6 where
    onmouseover_att s =  Onmouseover_Att_6 (s2b_escape s)
    onmouseover_att_bs =  Onmouseover_Att_6 

class A_Align a where
    align_att :: AlignEnum -> a
instance A_Align Att59 where
    align_att s =  Align_Att_59 (s2b (show s))
instance A_Align Att58 where
    align_att s =  Align_Att_58 (s2b (show s))
instance A_Align Att57 where
    align_att s =  Align_Att_57 (s2b (show s))
instance A_Align Att56 where
    align_att s =  Align_Att_56 (s2b (show s))
instance A_Align Att55 where
    align_att s =  Align_Att_55 (s2b (show s))
instance A_Align Att52 where
    align_att s =  Align_Att_52 (s2b (show s))
instance A_Align Att44 where
    align_att s =  Align_Att_44 (s2b (show s))
instance A_Align Att35 where
    align_att s =  Align_Att_35 (s2b (show s))
instance A_Align Att32 where
    align_att s =  Align_Att_32 (s2b (show s))
instance A_Align Att29 where
    align_att s =  Align_Att_29 (s2b (show s))
instance A_Align Att18 where
    align_att s =  Align_Att_18 (s2b (show s))
instance A_Align Att13 where
    align_att s =  Align_Att_13 (s2b (show s))
instance A_Align Att11 where
    align_att s =  Align_Att_11 (s2b (show s))

class A_Lang a where
    lang_att :: String -> a
    lang_att_bs :: B.ByteString -> a
instance A_Lang Att59 where
    lang_att s =  Lang_Att_59 (s2b_escape s)
    lang_att_bs =  Lang_Att_59 
instance A_Lang Att58 where
    lang_att s =  Lang_Att_58 (s2b_escape s)
    lang_att_bs =  Lang_Att_58 
instance A_Lang Att57 where
    lang_att s =  Lang_Att_57 (s2b_escape s)
    lang_att_bs =  Lang_Att_57 
instance A_Lang Att56 where
    lang_att s =  Lang_Att_56 (s2b_escape s)
    lang_att_bs =  Lang_Att_56 
instance A_Lang Att55 where
    lang_att s =  Lang_Att_55 (s2b_escape s)
    lang_att_bs =  Lang_Att_55 
instance A_Lang Att54 where
    lang_att s =  Lang_Att_54 (s2b_escape s)
    lang_att_bs =  Lang_Att_54 
instance A_Lang Att53 where
    lang_att s =  Lang_Att_53 (s2b_escape s)
    lang_att_bs =  Lang_Att_53 
instance A_Lang Att52 where
    lang_att s =  Lang_Att_52 (s2b_escape s)
    lang_att_bs =  Lang_Att_52 
instance A_Lang Att49 where
    lang_att s =  Lang_Att_49 (s2b_escape s)
    lang_att_bs =  Lang_Att_49 
instance A_Lang Att48 where
    lang_att s =  Lang_Att_48 (s2b_escape s)
    lang_att_bs =  Lang_Att_48 
instance A_Lang Att46 where
    lang_att s =  Lang_Att_46 (s2b_escape s)
    lang_att_bs =  Lang_Att_46 
instance A_Lang Att45 where
    lang_att s =  Lang_Att_45 (s2b_escape s)
    lang_att_bs =  Lang_Att_45 
instance A_Lang Att44 where
    lang_att s =  Lang_Att_44 (s2b_escape s)
    lang_att_bs =  Lang_Att_44 
instance A_Lang Att43 where
    lang_att s =  Lang_Att_43 (s2b_escape s)
    lang_att_bs =  Lang_Att_43 
instance A_Lang Att41 where
    lang_att s =  Lang_Att_41 (s2b_escape s)
    lang_att_bs =  Lang_Att_41 
instance A_Lang Att40 where
    lang_att s =  Lang_Att_40 (s2b_escape s)
    lang_att_bs =  Lang_Att_40 
instance A_Lang Att38 where
    lang_att s =  Lang_Att_38 (s2b_escape s)
    lang_att_bs =  Lang_Att_38 
instance A_Lang Att35 where
    lang_att s =  Lang_Att_35 (s2b_escape s)
    lang_att_bs =  Lang_Att_35 
instance A_Lang Att29 where
    lang_att s =  Lang_Att_29 (s2b_escape s)
    lang_att_bs =  Lang_Att_29 
instance A_Lang Att28 where
    lang_att s =  Lang_Att_28 (s2b_escape s)
    lang_att_bs =  Lang_Att_28 
instance A_Lang Att23 where
    lang_att s =  Lang_Att_23 (s2b_escape s)
    lang_att_bs =  Lang_Att_23 
instance A_Lang Att22 where
    lang_att s =  Lang_Att_22 (s2b_escape s)
    lang_att_bs =  Lang_Att_22 
instance A_Lang Att21 where
    lang_att s =  Lang_Att_21 (s2b_escape s)
    lang_att_bs =  Lang_Att_21 
instance A_Lang Att20 where
    lang_att s =  Lang_Att_20 (s2b_escape s)
    lang_att_bs =  Lang_Att_20 
instance A_Lang Att19 where
    lang_att s =  Lang_Att_19 (s2b_escape s)
    lang_att_bs =  Lang_Att_19 
instance A_Lang Att18 where
    lang_att s =  Lang_Att_18 (s2b_escape s)
    lang_att_bs =  Lang_Att_18 
instance A_Lang Att17 where
    lang_att s =  Lang_Att_17 (s2b_escape s)
    lang_att_bs =  Lang_Att_17 
instance A_Lang Att16 where
    lang_att s =  Lang_Att_16 (s2b_escape s)
    lang_att_bs =  Lang_Att_16 
instance A_Lang Att15 where
    lang_att s =  Lang_Att_15 (s2b_escape s)
    lang_att_bs =  Lang_Att_15 
instance A_Lang Att14 where
    lang_att s =  Lang_Att_14 (s2b_escape s)
    lang_att_bs =  Lang_Att_14 
instance A_Lang Att13 where
    lang_att s =  Lang_Att_13 (s2b_escape s)
    lang_att_bs =  Lang_Att_13 
instance A_Lang Att12 where
    lang_att s =  Lang_Att_12 (s2b_escape s)
    lang_att_bs =  Lang_Att_12 
instance A_Lang Att10 where
    lang_att s =  Lang_Att_10 (s2b_escape s)
    lang_att_bs =  Lang_Att_10 
instance A_Lang Att7 where
    lang_att s =  Lang_Att_7 (s2b_escape s)
    lang_att_bs =  Lang_Att_7 
instance A_Lang Att6 where
    lang_att s =  Lang_Att_6 (s2b_escape s)
    lang_att_bs =  Lang_Att_6 
instance A_Lang Att4 where
    lang_att s =  Lang_Att_4 (s2b_escape s)
    lang_att_bs =  Lang_Att_4 
instance A_Lang Att2 where
    lang_att s =  Lang_Att_2 (s2b_escape s)
    lang_att_bs =  Lang_Att_2 
instance A_Lang Att1 where
    lang_att s =  Lang_Att_1 (s2b_escape s)
    lang_att_bs =  Lang_Att_1 
instance A_Lang Att0 where
    lang_att s =  Lang_Att_0 (s2b_escape s)
    lang_att_bs =  Lang_Att_0 

class A_Valign a where
    valign_att :: ValignEnum -> a
instance A_Valign Att59 where
    valign_att s =  Valign_Att_59 (s2b (show s))
instance A_Valign Att58 where
    valign_att s =  Valign_Att_58 (s2b (show s))
instance A_Valign Att57 where
    valign_att s =  Valign_Att_57 (s2b (show s))
instance A_Valign Att56 where
    valign_att s =  Valign_Att_56 (s2b (show s))

class A_Name a where
    name_att :: String -> a
    name_att_bs :: B.ByteString -> a
instance A_Name Att53 where
    name_att s =  Name_Att_53 (s2b_escape s)
    name_att_bs =  Name_Att_53 
instance A_Name Att49 where
    name_att s =  Name_Att_49 (s2b_escape s)
    name_att_bs =  Name_Att_49 
instance A_Name Att45 where
    name_att s =  Name_Att_45 (s2b_escape s)
    name_att_bs =  Name_Att_45 
instance A_Name Att44 where
    name_att s =  Name_Att_44 (s2b_escape s)
    name_att_bs =  Name_Att_44 
instance A_Name Att41 where
    name_att s =  Name_Att_41 (s2b_escape s)
    name_att_bs =  Name_Att_41 
instance A_Name Att38 where
    name_att s =  Name_Att_38 (s2b_escape s)
    name_att_bs =  Name_Att_38 
instance A_Name Att35 where
    name_att s =  Name_Att_35 (s2b_escape s)
    name_att_bs =  Name_Att_35 
instance A_Name Att32 where
    name_att s =  Name_Att_32 (s2b_escape s)
    name_att_bs =  Name_Att_32 
instance A_Name Att31 where
    name_att s =  Name_Att_31 (s2b_escape s)
    name_att_bs =  Name_Att_31 
instance A_Name Att30 where
    name_att s =  Name_Att_30 (s2b_escape s)
    name_att_bs =  Name_Att_30 
instance A_Name Att29 where
    name_att s =  Name_Att_29 (s2b_escape s)
    name_att_bs =  Name_Att_29 
instance A_Name Att22 where
    name_att s =  Name_Att_22 (s2b_escape s)
    name_att_bs =  Name_Att_22 
instance A_Name Att11 where
    name_att s =  Name_Att_11 (s2b_escape s)
    name_att_bs =  Name_Att_11 
instance A_Name Att4 where
    name_att s =  Name_Att_4 (s2b_escape s)
    name_att_bs =  Name_Att_4 

class A_Charset a where
    charset_att :: String -> a
    charset_att_bs :: B.ByteString -> a
instance A_Charset Att22 where
    charset_att s =  Charset_Att_22 (s2b_escape s)
    charset_att_bs =  Charset_Att_22 
instance A_Charset Att9 where
    charset_att s =  Charset_Att_9 (s2b_escape s)
    charset_att_bs =  Charset_Att_9 
instance A_Charset Att6 where
    charset_att s =  Charset_Att_6 (s2b_escape s)
    charset_att_bs =  Charset_Att_6 

class A_Scheme a where
    scheme_att :: String -> a
    scheme_att_bs :: B.ByteString -> a
instance A_Scheme Att4 where
    scheme_att s =  Scheme_Att_4 (s2b_escape s)
    scheme_att_bs =  Scheme_Att_4 

class A_Prompt a where
    prompt_att :: String -> a
    prompt_att_bs :: B.ByteString -> a
instance A_Prompt Att54 where
    prompt_att s =  Prompt_Att_54 (s2b_escape s)
    prompt_att_bs =  Prompt_Att_54 

class A_Accept_charset a where
    accept_charset_att :: String -> a
    accept_charset_att_bs :: B.ByteString -> a
instance A_Accept_charset Att41 where
    accept_charset_att s =  Accept_charset_Att_41 (s2b_escape s)
    accept_charset_att_bs =  Accept_charset_Att_41 

class A_Frameborder a where
    frameborder_att :: FrameborderEnum -> a
instance A_Frameborder Att11 where
    frameborder_att s =  Frameborder_Att_11 (s2b (show s))

class A_Onmousedown a where
    onmousedown_att :: String -> a
    onmousedown_att_bs :: B.ByteString -> a
instance A_Onmousedown Att59 where
    onmousedown_att s =  Onmousedown_Att_59 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_59 
instance A_Onmousedown Att58 where
    onmousedown_att s =  Onmousedown_Att_58 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_58 
instance A_Onmousedown Att57 where
    onmousedown_att s =  Onmousedown_Att_57 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_57 
instance A_Onmousedown Att56 where
    onmousedown_att s =  Onmousedown_Att_56 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_56 
instance A_Onmousedown Att55 where
    onmousedown_att s =  Onmousedown_Att_55 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_55 
instance A_Onmousedown Att53 where
    onmousedown_att s =  Onmousedown_Att_53 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_53 
instance A_Onmousedown Att52 where
    onmousedown_att s =  Onmousedown_Att_52 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_52 
instance A_Onmousedown Att49 where
    onmousedown_att s =  Onmousedown_Att_49 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_49 
instance A_Onmousedown Att48 where
    onmousedown_att s =  Onmousedown_Att_48 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_48 
instance A_Onmousedown Att46 where
    onmousedown_att s =  Onmousedown_Att_46 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_46 
instance A_Onmousedown Att45 where
    onmousedown_att s =  Onmousedown_Att_45 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_45 
instance A_Onmousedown Att44 where
    onmousedown_att s =  Onmousedown_Att_44 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_44 
instance A_Onmousedown Att43 where
    onmousedown_att s =  Onmousedown_Att_43 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_43 
instance A_Onmousedown Att41 where
    onmousedown_att s =  Onmousedown_Att_41 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_41 
instance A_Onmousedown Att40 where
    onmousedown_att s =  Onmousedown_Att_40 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_40 
instance A_Onmousedown Att38 where
    onmousedown_att s =  Onmousedown_Att_38 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_38 
instance A_Onmousedown Att35 where
    onmousedown_att s =  Onmousedown_Att_35 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_35 
instance A_Onmousedown Att29 where
    onmousedown_att s =  Onmousedown_Att_29 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_29 
instance A_Onmousedown Att23 where
    onmousedown_att s =  Onmousedown_Att_23 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_23 
instance A_Onmousedown Att22 where
    onmousedown_att s =  Onmousedown_Att_22 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_22 
instance A_Onmousedown Att21 where
    onmousedown_att s =  Onmousedown_Att_21 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_21 
instance A_Onmousedown Att20 where
    onmousedown_att s =  Onmousedown_Att_20 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_20 
instance A_Onmousedown Att19 where
    onmousedown_att s =  Onmousedown_Att_19 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_19 
instance A_Onmousedown Att18 where
    onmousedown_att s =  Onmousedown_Att_18 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_18 
instance A_Onmousedown Att17 where
    onmousedown_att s =  Onmousedown_Att_17 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_17 
instance A_Onmousedown Att16 where
    onmousedown_att s =  Onmousedown_Att_16 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_16 
instance A_Onmousedown Att15 where
    onmousedown_att s =  Onmousedown_Att_15 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_15 
instance A_Onmousedown Att14 where
    onmousedown_att s =  Onmousedown_Att_14 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_14 
instance A_Onmousedown Att13 where
    onmousedown_att s =  Onmousedown_Att_13 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_13 
instance A_Onmousedown Att12 where
    onmousedown_att s =  Onmousedown_Att_12 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_12 
instance A_Onmousedown Att10 where
    onmousedown_att s =  Onmousedown_Att_10 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_10 
instance A_Onmousedown Att6 where
    onmousedown_att s =  Onmousedown_Att_6 (s2b_escape s)
    onmousedown_att_bs =  Onmousedown_Att_6 

class A_Rev a where
    rev_att :: String -> a
    rev_att_bs :: B.ByteString -> a
instance A_Rev Att22 where
    rev_att s =  Rev_Att_22 (s2b_escape s)
    rev_att_bs =  Rev_Att_22 
instance A_Rev Att6 where
    rev_att s =  Rev_Att_6 (s2b_escape s)
    rev_att_bs =  Rev_Att_6 

class A_Span a where
    span_att :: String -> a
    span_att_bs :: B.ByteString -> a
instance A_Span Att57 where
    span_att s =  Span_Att_57 (s2b_escape s)
    span_att_bs =  Span_Att_57 

class A_Title a where
    title_att :: String -> a
    title_att_bs :: B.ByteString -> a
instance A_Title Att59 where
    title_att s =  Title_Att_59 (s2b_escape s)
    title_att_bs =  Title_Att_59 
instance A_Title Att58 where
    title_att s =  Title_Att_58 (s2b_escape s)
    title_att_bs =  Title_Att_58 
instance A_Title Att57 where
    title_att s =  Title_Att_57 (s2b_escape s)
    title_att_bs =  Title_Att_57 
instance A_Title Att56 where
    title_att s =  Title_Att_56 (s2b_escape s)
    title_att_bs =  Title_Att_56 
instance A_Title Att55 where
    title_att s =  Title_Att_55 (s2b_escape s)
    title_att_bs =  Title_Att_55 
instance A_Title Att54 where
    title_att s =  Title_Att_54 (s2b_escape s)
    title_att_bs =  Title_Att_54 
instance A_Title Att53 where
    title_att s =  Title_Att_53 (s2b_escape s)
    title_att_bs =  Title_Att_53 
instance A_Title Att52 where
    title_att s =  Title_Att_52 (s2b_escape s)
    title_att_bs =  Title_Att_52 
instance A_Title Att49 where
    title_att s =  Title_Att_49 (s2b_escape s)
    title_att_bs =  Title_Att_49 
instance A_Title Att48 where
    title_att s =  Title_Att_48 (s2b_escape s)
    title_att_bs =  Title_Att_48 
instance A_Title Att46 where
    title_att s =  Title_Att_46 (s2b_escape s)
    title_att_bs =  Title_Att_46 
instance A_Title Att45 where
    title_att s =  Title_Att_45 (s2b_escape s)
    title_att_bs =  Title_Att_45 
instance A_Title Att44 where
    title_att s =  Title_Att_44 (s2b_escape s)
    title_att_bs =  Title_Att_44 
instance A_Title Att43 where
    title_att s =  Title_Att_43 (s2b_escape s)
    title_att_bs =  Title_Att_43 
instance A_Title Att41 where
    title_att s =  Title_Att_41 (s2b_escape s)
    title_att_bs =  Title_Att_41 
instance A_Title Att40 where
    title_att s =  Title_Att_40 (s2b_escape s)
    title_att_bs =  Title_Att_40 
instance A_Title Att38 where
    title_att s =  Title_Att_38 (s2b_escape s)
    title_att_bs =  Title_Att_38 
instance A_Title Att35 where
    title_att s =  Title_Att_35 (s2b_escape s)
    title_att_bs =  Title_Att_35 
instance A_Title Att32 where
    title_att s =  Title_Att_32 (s2b_escape s)
    title_att_bs =  Title_Att_32 
instance A_Title Att29 where
    title_att s =  Title_Att_29 (s2b_escape s)
    title_att_bs =  Title_Att_29 
instance A_Title Att28 where
    title_att s =  Title_Att_28 (s2b_escape s)
    title_att_bs =  Title_Att_28 
instance A_Title Att25 where
    title_att s =  Title_Att_25 (s2b_escape s)
    title_att_bs =  Title_Att_25 
instance A_Title Att23 where
    title_att s =  Title_Att_23 (s2b_escape s)
    title_att_bs =  Title_Att_23 
instance A_Title Att22 where
    title_att s =  Title_Att_22 (s2b_escape s)
    title_att_bs =  Title_Att_22 
instance A_Title Att21 where
    title_att s =  Title_Att_21 (s2b_escape s)
    title_att_bs =  Title_Att_21 
instance A_Title Att20 where
    title_att s =  Title_Att_20 (s2b_escape s)
    title_att_bs =  Title_Att_20 
instance A_Title Att19 where
    title_att s =  Title_Att_19 (s2b_escape s)
    title_att_bs =  Title_Att_19 
instance A_Title Att18 where
    title_att s =  Title_Att_18 (s2b_escape s)
    title_att_bs =  Title_Att_18 
instance A_Title Att17 where
    title_att s =  Title_Att_17 (s2b_escape s)
    title_att_bs =  Title_Att_17 
instance A_Title Att16 where
    title_att s =  Title_Att_16 (s2b_escape s)
    title_att_bs =  Title_Att_16 
instance A_Title Att15 where
    title_att s =  Title_Att_15 (s2b_escape s)
    title_att_bs =  Title_Att_15 
instance A_Title Att14 where
    title_att s =  Title_Att_14 (s2b_escape s)
    title_att_bs =  Title_Att_14 
instance A_Title Att13 where
    title_att s =  Title_Att_13 (s2b_escape s)
    title_att_bs =  Title_Att_13 
instance A_Title Att12 where
    title_att s =  Title_Att_12 (s2b_escape s)
    title_att_bs =  Title_Att_12 
instance A_Title Att11 where
    title_att s =  Title_Att_11 (s2b_escape s)
    title_att_bs =  Title_Att_11 
instance A_Title Att10 where
    title_att s =  Title_Att_10 (s2b_escape s)
    title_att_bs =  Title_Att_10 
instance A_Title Att7 where
    title_att s =  Title_Att_7 (s2b_escape s)
    title_att_bs =  Title_Att_7 
instance A_Title Att6 where
    title_att s =  Title_Att_6 (s2b_escape s)
    title_att_bs =  Title_Att_6 

class A_Onclick a where
    onclick_att :: String -> a
    onclick_att_bs :: B.ByteString -> a
instance A_Onclick Att59 where
    onclick_att s =  Onclick_Att_59 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_59 
instance A_Onclick Att58 where
    onclick_att s =  Onclick_Att_58 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_58 
instance A_Onclick Att57 where
    onclick_att s =  Onclick_Att_57 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_57 
instance A_Onclick Att56 where
    onclick_att s =  Onclick_Att_56 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_56 
instance A_Onclick Att55 where
    onclick_att s =  Onclick_Att_55 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_55 
instance A_Onclick Att53 where
    onclick_att s =  Onclick_Att_53 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_53 
instance A_Onclick Att52 where
    onclick_att s =  Onclick_Att_52 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_52 
instance A_Onclick Att49 where
    onclick_att s =  Onclick_Att_49 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_49 
instance A_Onclick Att48 where
    onclick_att s =  Onclick_Att_48 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_48 
instance A_Onclick Att46 where
    onclick_att s =  Onclick_Att_46 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_46 
instance A_Onclick Att45 where
    onclick_att s =  Onclick_Att_45 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_45 
instance A_Onclick Att44 where
    onclick_att s =  Onclick_Att_44 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_44 
instance A_Onclick Att43 where
    onclick_att s =  Onclick_Att_43 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_43 
instance A_Onclick Att41 where
    onclick_att s =  Onclick_Att_41 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_41 
instance A_Onclick Att40 where
    onclick_att s =  Onclick_Att_40 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_40 
instance A_Onclick Att38 where
    onclick_att s =  Onclick_Att_38 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_38 
instance A_Onclick Att35 where
    onclick_att s =  Onclick_Att_35 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_35 
instance A_Onclick Att29 where
    onclick_att s =  Onclick_Att_29 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_29 
instance A_Onclick Att23 where
    onclick_att s =  Onclick_Att_23 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_23 
instance A_Onclick Att22 where
    onclick_att s =  Onclick_Att_22 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_22 
instance A_Onclick Att21 where
    onclick_att s =  Onclick_Att_21 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_21 
instance A_Onclick Att20 where
    onclick_att s =  Onclick_Att_20 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_20 
instance A_Onclick Att19 where
    onclick_att s =  Onclick_Att_19 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_19 
instance A_Onclick Att18 where
    onclick_att s =  Onclick_Att_18 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_18 
instance A_Onclick Att17 where
    onclick_att s =  Onclick_Att_17 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_17 
instance A_Onclick Att16 where
    onclick_att s =  Onclick_Att_16 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_16 
instance A_Onclick Att15 where
    onclick_att s =  Onclick_Att_15 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_15 
instance A_Onclick Att14 where
    onclick_att s =  Onclick_Att_14 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_14 
instance A_Onclick Att13 where
    onclick_att s =  Onclick_Att_13 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_13 
instance A_Onclick Att12 where
    onclick_att s =  Onclick_Att_12 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_12 
instance A_Onclick Att10 where
    onclick_att s =  Onclick_Att_10 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_10 
instance A_Onclick Att6 where
    onclick_att s =  Onclick_Att_6 (s2b_escape s)
    onclick_att_bs =  Onclick_Att_6 

class A_Start a where
    start_att :: String -> a
    start_att_bs :: B.ByteString -> a
instance A_Start Att15 where
    start_att s =  Start_Att_15 (s2b_escape s)
    start_att_bs =  Start_Att_15 

class A_Width a where
    width_att :: String -> a
    width_att_bs :: B.ByteString -> a
instance A_Width Att59 where
    width_att s =  Width_Att_59 (s2b_escape s)
    width_att_bs =  Width_Att_59 
instance A_Width Att57 where
    width_att s =  Width_Att_57 (s2b_escape s)
    width_att_bs =  Width_Att_57 
instance A_Width Att55 where
    width_att s =  Width_Att_55 (s2b_escape s)
    width_att_bs =  Width_Att_55 
instance A_Width Att35 where
    width_att s =  Width_Att_35 (s2b_escape s)
    width_att_bs =  Width_Att_35 
instance A_Width Att33 where
    width_att s =  Width_Att_33 (s2b_escape s)
    width_att_bs =  Width_Att_33 
instance A_Width Att32 where
    width_att s =  Width_Att_32 (s2b_escape s)
    width_att_bs =  Width_Att_32 
instance A_Width Att29 where
    width_att s =  Width_Att_29 (s2b_escape s)
    width_att_bs =  Width_Att_29 
instance A_Width Att19 where
    width_att s =  Width_Att_19 (s2b_escape s)
    width_att_bs =  Width_Att_19 
instance A_Width Att18 where
    width_att s =  Width_Att_18 (s2b_escape s)
    width_att_bs =  Width_Att_18 
instance A_Width Att11 where
    width_att s =  Width_Att_11 (s2b_escape s)
    width_att_bs =  Width_Att_11 

class A_Vlink a where
    vlink_att :: String -> a
    vlink_att_bs :: B.ByteString -> a
instance A_Vlink Att12 where
    vlink_att s =  Vlink_Att_12 (s2b_escape s)
    vlink_att_bs =  Vlink_Att_12 

class A_Enctype a where
    enctype_att :: String -> a
    enctype_att_bs :: B.ByteString -> a
instance A_Enctype Att41 where
    enctype_att s =  Enctype_Att_41 (s2b_escape s)
    enctype_att_bs =  Enctype_Att_41 

class A_Ismap a where
    ismap_att :: String -> a
instance A_Ismap Att35 where
    ismap_att s =  Ismap_Att_35 (s2b (show s))

class A_Usemap a where
    usemap_att :: String -> a
    usemap_att_bs :: B.ByteString -> a
instance A_Usemap Att44 where
    usemap_att s =  Usemap_Att_44 (s2b_escape s)
    usemap_att_bs =  Usemap_Att_44 
instance A_Usemap Att35 where
    usemap_att s =  Usemap_Att_35 (s2b_escape s)
    usemap_att_bs =  Usemap_Att_35 
instance A_Usemap Att29 where
    usemap_att s =  Usemap_Att_29 (s2b_escape s)
    usemap_att_bs =  Usemap_Att_29 

class A_Nowrap a where
    nowrap_att :: String -> a
instance A_Nowrap Att59 where
    nowrap_att s =  Nowrap_Att_59 (s2b (show s))

class A_Coords a where
    coords_att :: String -> a
    coords_att_bs :: B.ByteString -> a
instance A_Coords Att40 where
    coords_att s =  Coords_Att_40 (s2b_escape s)
    coords_att_bs =  Coords_Att_40 
instance A_Coords Att22 where
    coords_att s =  Coords_Att_22 (s2b_escape s)
    coords_att_bs =  Coords_Att_22 

class A_Frame a where
    frame_att :: FrameEnum -> a
instance A_Frame Att55 where
    frame_att s =  Frame_Att_55 (s2b (show s))

class A_Onblur a where
    onblur_att :: String -> a
    onblur_att_bs :: B.ByteString -> a
instance A_Onblur Att53 where
    onblur_att s =  Onblur_Att_53 (s2b_escape s)
    onblur_att_bs =  Onblur_Att_53 
instance A_Onblur Att49 where
    onblur_att s =  Onblur_Att_49 (s2b_escape s)
    onblur_att_bs =  Onblur_Att_49 
instance A_Onblur Att45 where
    onblur_att s =  Onblur_Att_45 (s2b_escape s)
    onblur_att_bs =  Onblur_Att_45 
instance A_Onblur Att44 where
    onblur_att s =  Onblur_Att_44 (s2b_escape s)
    onblur_att_bs =  Onblur_Att_44 
instance A_Onblur Att43 where
    onblur_att s =  Onblur_Att_43 (s2b_escape s)
    onblur_att_bs =  Onblur_Att_43 
instance A_Onblur Att40 where
    onblur_att s =  Onblur_Att_40 (s2b_escape s)
    onblur_att_bs =  Onblur_Att_40 
instance A_Onblur Att22 where
    onblur_att s =  Onblur_Att_22 (s2b_escape s)
    onblur_att_bs =  Onblur_Att_22 

class A_Datetime a where
    datetime_att :: String -> a
    datetime_att_bs :: B.ByteString -> a
instance A_Datetime Att21 where
    datetime_att s =  Datetime_Att_21 (s2b_escape s)
    datetime_att_bs =  Datetime_Att_21 

class A_Size a where
    size_att :: String -> a
    size_att_bs :: B.ByteString -> a
instance A_Size Att45 where
    size_att s =  Size_Att_45 (s2b_escape s)
    size_att_bs =  Size_Att_45 
instance A_Size Att44 where
    size_att s =  Size_Att_44 (s2b_escape s)
    size_att_bs =  Size_Att_44 
instance A_Size Att28 where
    size_att s =  Size_Att_28 (s2b_escape s)
    size_att_bs =  Size_Att_28 
instance A_Size Att27 where
    size_att s =  Size_Att_27 (s2b_escape s)
    size_att_bs =  Size_Att_27 
instance A_Size Att26 where
    size_att s =  Size_Att_26 (s2b_escape s)
    size_att_bs =  Size_Att_26 
instance A_Size Att18 where
    size_att s =  Size_Att_18 (s2b_escape s)
    size_att_bs =  Size_Att_18 

class A_Dir a where
    dir_att :: DirEnum -> a
instance A_Dir Att59 where
    dir_att s =  Dir_Att_59 (s2b (show s))
instance A_Dir Att58 where
    dir_att s =  Dir_Att_58 (s2b (show s))
instance A_Dir Att57 where
    dir_att s =  Dir_Att_57 (s2b (show s))
instance A_Dir Att56 where
    dir_att s =  Dir_Att_56 (s2b (show s))
instance A_Dir Att55 where
    dir_att s =  Dir_Att_55 (s2b (show s))
instance A_Dir Att54 where
    dir_att s =  Dir_Att_54 (s2b (show s))
instance A_Dir Att53 where
    dir_att s =  Dir_Att_53 (s2b (show s))
instance A_Dir Att52 where
    dir_att s =  Dir_Att_52 (s2b (show s))
instance A_Dir Att49 where
    dir_att s =  Dir_Att_49 (s2b (show s))
instance A_Dir Att48 where
    dir_att s =  Dir_Att_48 (s2b (show s))
instance A_Dir Att46 where
    dir_att s =  Dir_Att_46 (s2b (show s))
instance A_Dir Att45 where
    dir_att s =  Dir_Att_45 (s2b (show s))
instance A_Dir Att44 where
    dir_att s =  Dir_Att_44 (s2b (show s))
instance A_Dir Att43 where
    dir_att s =  Dir_Att_43 (s2b (show s))
instance A_Dir Att41 where
    dir_att s =  Dir_Att_41 (s2b (show s))
instance A_Dir Att40 where
    dir_att s =  Dir_Att_40 (s2b (show s))
instance A_Dir Att38 where
    dir_att s =  Dir_Att_38 (s2b (show s))
instance A_Dir Att35 where
    dir_att s =  Dir_Att_35 (s2b (show s))
instance A_Dir Att29 where
    dir_att s =  Dir_Att_29 (s2b (show s))
instance A_Dir Att28 where
    dir_att s =  Dir_Att_28 (s2b (show s))
instance A_Dir Att24 where
    dir_att s =  Dir_Att_24 (s2b (show s))
instance A_Dir Att23 where
    dir_att s =  Dir_Att_23 (s2b (show s))
instance A_Dir Att22 where
    dir_att s =  Dir_Att_22 (s2b (show s))
instance A_Dir Att21 where
    dir_att s =  Dir_Att_21 (s2b (show s))
instance A_Dir Att20 where
    dir_att s =  Dir_Att_20 (s2b (show s))
instance A_Dir Att19 where
    dir_att s =  Dir_Att_19 (s2b (show s))
instance A_Dir Att18 where
    dir_att s =  Dir_Att_18 (s2b (show s))
instance A_Dir Att17 where
    dir_att s =  Dir_Att_17 (s2b (show s))
instance A_Dir Att16 where
    dir_att s =  Dir_Att_16 (s2b (show s))
instance A_Dir Att15 where
    dir_att s =  Dir_Att_15 (s2b (show s))
instance A_Dir Att14 where
    dir_att s =  Dir_Att_14 (s2b (show s))
instance A_Dir Att13 where
    dir_att s =  Dir_Att_13 (s2b (show s))
instance A_Dir Att12 where
    dir_att s =  Dir_Att_12 (s2b (show s))
instance A_Dir Att10 where
    dir_att s =  Dir_Att_10 (s2b (show s))
instance A_Dir Att7 where
    dir_att s =  Dir_Att_7 (s2b (show s))
instance A_Dir Att6 where
    dir_att s =  Dir_Att_6 (s2b (show s))
instance A_Dir Att4 where
    dir_att s =  Dir_Att_4 (s2b (show s))
instance A_Dir Att2 where
    dir_att s =  Dir_Att_2 (s2b (show s))
instance A_Dir Att1 where
    dir_att s =  Dir_Att_1 (s2b (show s))
instance A_Dir Att0 where
    dir_att s =  Dir_Att_0 (s2b (show s))

class A_Face a where
    face_att :: String -> a
    face_att_bs :: B.ByteString -> a
instance A_Face Att28 where
    face_att s =  Face_Att_28 (s2b_escape s)
    face_att_bs =  Face_Att_28 
instance A_Face Att26 where
    face_att s =  Face_Att_26 (s2b_escape s)
    face_att_bs =  Face_Att_26 

class A_Color a where
    color_att :: String -> a
    color_att_bs :: B.ByteString -> a
instance A_Color Att28 where
    color_att s =  Color_Att_28 (s2b_escape s)
    color_att_bs =  Color_Att_28 
instance A_Color Att26 where
    color_att s =  Color_Att_26 (s2b_escape s)
    color_att_bs =  Color_Att_26 

class A_Summary a where
    summary_att :: String -> a
    summary_att_bs :: B.ByteString -> a
instance A_Summary Att55 where
    summary_att s =  Summary_Att_55 (s2b_escape s)
    summary_att_bs =  Summary_Att_55 

class A_Bgcolor a where
    bgcolor_att :: String -> a
    bgcolor_att_bs :: B.ByteString -> a
instance A_Bgcolor Att59 where
    bgcolor_att s =  Bgcolor_Att_59 (s2b_escape s)
    bgcolor_att_bs =  Bgcolor_Att_59 
instance A_Bgcolor Att58 where
    bgcolor_att s =  Bgcolor_Att_58 (s2b_escape s)
    bgcolor_att_bs =  Bgcolor_Att_58 
instance A_Bgcolor Att55 where
    bgcolor_att s =  Bgcolor_Att_55 (s2b_escape s)
    bgcolor_att_bs =  Bgcolor_Att_55 
instance A_Bgcolor Att12 where
    bgcolor_att s =  Bgcolor_Att_12 (s2b_escape s)
    bgcolor_att_bs =  Bgcolor_Att_12 

class A_Text a where
    text_att :: String -> a
    text_att_bs :: B.ByteString -> a
instance A_Text Att12 where
    text_att s =  Text_Att_12 (s2b_escape s)
    text_att_bs =  Text_Att_12 

class A_Method a where
    method_att :: MethodEnum -> a
instance A_Method Att41 where
    method_att s =  Method_Att_41 (s2b (show s))

class A_Vspace a where
    vspace_att :: String -> a
    vspace_att_bs :: B.ByteString -> a
instance A_Vspace Att35 where
    vspace_att s =  Vspace_Att_35 (s2b_escape s)
    vspace_att_bs =  Vspace_Att_35 
instance A_Vspace Att32 where
    vspace_att s =  Vspace_Att_32 (s2b_escape s)
    vspace_att_bs =  Vspace_Att_32 
instance A_Vspace Att29 where
    vspace_att s =  Vspace_Att_29 (s2b_escape s)
    vspace_att_bs =  Vspace_Att_29 

class A_Standby a where
    standby_att :: String -> a
    standby_att_bs :: B.ByteString -> a
instance A_Standby Att29 where
    standby_att s =  Standby_Att_29 (s2b_escape s)
    standby_att_bs =  Standby_Att_29 

class A_Tabindex a where
    tabindex_att :: String -> a
    tabindex_att_bs :: B.ByteString -> a
instance A_Tabindex Att53 where
    tabindex_att s =  Tabindex_Att_53 (s2b_escape s)
    tabindex_att_bs =  Tabindex_Att_53 
instance A_Tabindex Att49 where
    tabindex_att s =  Tabindex_Att_49 (s2b_escape s)
    tabindex_att_bs =  Tabindex_Att_49 
instance A_Tabindex Att45 where
    tabindex_att s =  Tabindex_Att_45 (s2b_escape s)
    tabindex_att_bs =  Tabindex_Att_45 
instance A_Tabindex Att44 where
    tabindex_att s =  Tabindex_Att_44 (s2b_escape s)
    tabindex_att_bs =  Tabindex_Att_44 
instance A_Tabindex Att40 where
    tabindex_att s =  Tabindex_Att_40 (s2b_escape s)
    tabindex_att_bs =  Tabindex_Att_40 
instance A_Tabindex Att29 where
    tabindex_att s =  Tabindex_Att_29 (s2b_escape s)
    tabindex_att_bs =  Tabindex_Att_29 
instance A_Tabindex Att22 where
    tabindex_att s =  Tabindex_Att_22 (s2b_escape s)
    tabindex_att_bs =  Tabindex_Att_22 

class A_Language a where
    language_att :: String -> a
    language_att_bs :: B.ByteString -> a
instance A_Language Att9 where
    language_att s =  Language_Att_9 (s2b_escape s)
    language_att_bs =  Language_Att_9 

class A_Background a where
    background_att :: String -> a
    background_att_bs :: B.ByteString -> a
instance A_Background Att12 where
    background_att s =  Background_Att_12 (s2b_escape s)
    background_att_bs =  Background_Att_12 

class A_Style a where
    style_att :: String -> a
    style_att_bs :: B.ByteString -> a
instance A_Style Att59 where
    style_att s =  Style_Att_59 (s2b_escape s)
    style_att_bs =  Style_Att_59 
instance A_Style Att58 where
    style_att s =  Style_Att_58 (s2b_escape s)
    style_att_bs =  Style_Att_58 
instance A_Style Att57 where
    style_att s =  Style_Att_57 (s2b_escape s)
    style_att_bs =  Style_Att_57 
instance A_Style Att56 where
    style_att s =  Style_Att_56 (s2b_escape s)
    style_att_bs =  Style_Att_56 
instance A_Style Att55 where
    style_att s =  Style_Att_55 (s2b_escape s)
    style_att_bs =  Style_Att_55 
instance A_Style Att54 where
    style_att s =  Style_Att_54 (s2b_escape s)
    style_att_bs =  Style_Att_54 
instance A_Style Att53 where
    style_att s =  Style_Att_53 (s2b_escape s)
    style_att_bs =  Style_Att_53 
instance A_Style Att52 where
    style_att s =  Style_Att_52 (s2b_escape s)
    style_att_bs =  Style_Att_52 
instance A_Style Att49 where
    style_att s =  Style_Att_49 (s2b_escape s)
    style_att_bs =  Style_Att_49 
instance A_Style Att48 where
    style_att s =  Style_Att_48 (s2b_escape s)
    style_att_bs =  Style_Att_48 
instance A_Style Att46 where
    style_att s =  Style_Att_46 (s2b_escape s)
    style_att_bs =  Style_Att_46 
instance A_Style Att45 where
    style_att s =  Style_Att_45 (s2b_escape s)
    style_att_bs =  Style_Att_45 
instance A_Style Att44 where
    style_att s =  Style_Att_44 (s2b_escape s)
    style_att_bs =  Style_Att_44 
instance A_Style Att43 where
    style_att s =  Style_Att_43 (s2b_escape s)
    style_att_bs =  Style_Att_43 
instance A_Style Att41 where
    style_att s =  Style_Att_41 (s2b_escape s)
    style_att_bs =  Style_Att_41 
instance A_Style Att40 where
    style_att s =  Style_Att_40 (s2b_escape s)
    style_att_bs =  Style_Att_40 
instance A_Style Att38 where
    style_att s =  Style_Att_38 (s2b_escape s)
    style_att_bs =  Style_Att_38 
instance A_Style Att35 where
    style_att s =  Style_Att_35 (s2b_escape s)
    style_att_bs =  Style_Att_35 
instance A_Style Att32 where
    style_att s =  Style_Att_32 (s2b_escape s)
    style_att_bs =  Style_Att_32 
instance A_Style Att29 where
    style_att s =  Style_Att_29 (s2b_escape s)
    style_att_bs =  Style_Att_29 
instance A_Style Att28 where
    style_att s =  Style_Att_28 (s2b_escape s)
    style_att_bs =  Style_Att_28 
instance A_Style Att25 where
    style_att s =  Style_Att_25 (s2b_escape s)
    style_att_bs =  Style_Att_25 
instance A_Style Att23 where
    style_att s =  Style_Att_23 (s2b_escape s)
    style_att_bs =  Style_Att_23 
instance A_Style Att22 where
    style_att s =  Style_Att_22 (s2b_escape s)
    style_att_bs =  Style_Att_22 
instance A_Style Att21 where
    style_att s =  Style_Att_21 (s2b_escape s)
    style_att_bs =  Style_Att_21 
instance A_Style Att20 where
    style_att s =  Style_Att_20 (s2b_escape s)
    style_att_bs =  Style_Att_20 
instance A_Style Att19 where
    style_att s =  Style_Att_19 (s2b_escape s)
    style_att_bs =  Style_Att_19 
instance A_Style Att18 where
    style_att s =  Style_Att_18 (s2b_escape s)
    style_att_bs =  Style_Att_18 
instance A_Style Att17 where
    style_att s =  Style_Att_17 (s2b_escape s)
    style_att_bs =  Style_Att_17 
instance A_Style Att16 where
    style_att s =  Style_Att_16 (s2b_escape s)
    style_att_bs =  Style_Att_16 
instance A_Style Att15 where
    style_att s =  Style_Att_15 (s2b_escape s)
    style_att_bs =  Style_Att_15 
instance A_Style Att14 where
    style_att s =  Style_Att_14 (s2b_escape s)
    style_att_bs =  Style_Att_14 
instance A_Style Att13 where
    style_att s =  Style_Att_13 (s2b_escape s)
    style_att_bs =  Style_Att_13 
instance A_Style Att12 where
    style_att s =  Style_Att_12 (s2b_escape s)
    style_att_bs =  Style_Att_12 
instance A_Style Att11 where
    style_att s =  Style_Att_11 (s2b_escape s)
    style_att_bs =  Style_Att_11 
instance A_Style Att10 where
    style_att s =  Style_Att_10 (s2b_escape s)
    style_att_bs =  Style_Att_10 
instance A_Style Att6 where
    style_att s =  Style_Att_6 (s2b_escape s)
    style_att_bs =  Style_Att_6 

class A_Onmousemove a where
    onmousemove_att :: String -> a
    onmousemove_att_bs :: B.ByteString -> a
instance A_Onmousemove Att59 where
    onmousemove_att s =  Onmousemove_Att_59 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_59 
instance A_Onmousemove Att58 where
    onmousemove_att s =  Onmousemove_Att_58 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_58 
instance A_Onmousemove Att57 where
    onmousemove_att s =  Onmousemove_Att_57 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_57 
instance A_Onmousemove Att56 where
    onmousemove_att s =  Onmousemove_Att_56 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_56 
instance A_Onmousemove Att55 where
    onmousemove_att s =  Onmousemove_Att_55 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_55 
instance A_Onmousemove Att53 where
    onmousemove_att s =  Onmousemove_Att_53 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_53 
instance A_Onmousemove Att52 where
    onmousemove_att s =  Onmousemove_Att_52 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_52 
instance A_Onmousemove Att49 where
    onmousemove_att s =  Onmousemove_Att_49 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_49 
instance A_Onmousemove Att48 where
    onmousemove_att s =  Onmousemove_Att_48 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_48 
instance A_Onmousemove Att46 where
    onmousemove_att s =  Onmousemove_Att_46 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_46 
instance A_Onmousemove Att45 where
    onmousemove_att s =  Onmousemove_Att_45 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_45 
instance A_Onmousemove Att44 where
    onmousemove_att s =  Onmousemove_Att_44 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_44 
instance A_Onmousemove Att43 where
    onmousemove_att s =  Onmousemove_Att_43 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_43 
instance A_Onmousemove Att41 where
    onmousemove_att s =  Onmousemove_Att_41 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_41 
instance A_Onmousemove Att40 where
    onmousemove_att s =  Onmousemove_Att_40 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_40 
instance A_Onmousemove Att38 where
    onmousemove_att s =  Onmousemove_Att_38 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_38 
instance A_Onmousemove Att35 where
    onmousemove_att s =  Onmousemove_Att_35 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_35 
instance A_Onmousemove Att29 where
    onmousemove_att s =  Onmousemove_Att_29 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_29 
instance A_Onmousemove Att23 where
    onmousemove_att s =  Onmousemove_Att_23 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_23 
instance A_Onmousemove Att22 where
    onmousemove_att s =  Onmousemove_Att_22 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_22 
instance A_Onmousemove Att21 where
    onmousemove_att s =  Onmousemove_Att_21 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_21 
instance A_Onmousemove Att20 where
    onmousemove_att s =  Onmousemove_Att_20 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_20 
instance A_Onmousemove Att19 where
    onmousemove_att s =  Onmousemove_Att_19 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_19 
instance A_Onmousemove Att18 where
    onmousemove_att s =  Onmousemove_Att_18 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_18 
instance A_Onmousemove Att17 where
    onmousemove_att s =  Onmousemove_Att_17 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_17 
instance A_Onmousemove Att16 where
    onmousemove_att s =  Onmousemove_Att_16 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_16 
instance A_Onmousemove Att15 where
    onmousemove_att s =  Onmousemove_Att_15 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_15 
instance A_Onmousemove Att14 where
    onmousemove_att s =  Onmousemove_Att_14 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_14 
instance A_Onmousemove Att13 where
    onmousemove_att s =  Onmousemove_Att_13 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_13 
instance A_Onmousemove Att12 where
    onmousemove_att s =  Onmousemove_Att_12 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_12 
instance A_Onmousemove Att10 where
    onmousemove_att s =  Onmousemove_Att_10 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_10 
instance A_Onmousemove Att6 where
    onmousemove_att s =  Onmousemove_Att_6 (s2b_escape s)
    onmousemove_att_bs =  Onmousemove_Att_6 

class A_Height a where
    height_att :: String -> a
    height_att_bs :: B.ByteString -> a
instance A_Height Att59 where
    height_att s =  Height_Att_59 (s2b_escape s)
    height_att_bs =  Height_Att_59 
instance A_Height Att35 where
    height_att s =  Height_Att_35 (s2b_escape s)
    height_att_bs =  Height_Att_35 
instance A_Height Att34 where
    height_att s =  Height_Att_34 (s2b_escape s)
    height_att_bs =  Height_Att_34 
instance A_Height Att32 where
    height_att s =  Height_Att_32 (s2b_escape s)
    height_att_bs =  Height_Att_32 
instance A_Height Att29 where
    height_att s =  Height_Att_29 (s2b_escape s)
    height_att_bs =  Height_Att_29 
instance A_Height Att11 where
    height_att s =  Height_Att_11 (s2b_escape s)
    height_att_bs =  Height_Att_11 

class A_Codetype a where
    codetype_att :: String -> a
    codetype_att_bs :: B.ByteString -> a
instance A_Codetype Att29 where
    codetype_att s =  Codetype_Att_29 (s2b_escape s)
    codetype_att_bs =  Codetype_Att_29 

class A_Char a where
    char_att :: String -> a
    char_att_bs :: B.ByteString -> a
instance A_Char Att59 where
    char_att s =  Char_Att_59 (s2b_escape s)
    char_att_bs =  Char_Att_59 
instance A_Char Att58 where
    char_att s =  Char_Att_58 (s2b_escape s)
    char_att_bs =  Char_Att_58 
instance A_Char Att57 where
    char_att s =  Char_Att_57 (s2b_escape s)
    char_att_bs =  Char_Att_57 
instance A_Char Att56 where
    char_att s =  Char_Att_56 (s2b_escape s)
    char_att_bs =  Char_Att_56 

class A_Multiple a where
    multiple_att :: String -> a
instance A_Multiple Att45 where
    multiple_att s =  Multiple_Att_45 (s2b (show s))

class A_Codebase a where
    codebase_att :: String -> a
    codebase_att_bs :: B.ByteString -> a
instance A_Codebase Att32 where
    codebase_att s =  Codebase_Att_32 (s2b_escape s)
    codebase_att_bs =  Codebase_Att_32 
instance A_Codebase Att29 where
    codebase_att s =  Codebase_Att_29 (s2b_escape s)
    codebase_att_bs =  Codebase_Att_29 

class A_Xmlns a where
    xmlns_att :: String -> a
    xmlns_att_bs :: B.ByteString -> a
instance A_Xmlns Att0 where
    xmlns_att s =  Xmlns_Att_0 (s2b_escape s)
    xmlns_att_bs =  Xmlns_Att_0 

class A_Profile a where
    profile_att :: String -> a
    profile_att_bs :: B.ByteString -> a
instance A_Profile Att1 where
    profile_att s =  Profile_Att_1 (s2b_escape s)
    profile_att_bs =  Profile_Att_1 

class A_Rel a where
    rel_att :: String -> a
    rel_att_bs :: B.ByteString -> a
instance A_Rel Att22 where
    rel_att s =  Rel_Att_22 (s2b_escape s)
    rel_att_bs =  Rel_Att_22 
instance A_Rel Att6 where
    rel_att s =  Rel_Att_6 (s2b_escape s)
    rel_att_bs =  Rel_Att_6 

class A_Onsubmit a where
    onsubmit_att :: String -> a
    onsubmit_att_bs :: B.ByteString -> a
instance A_Onsubmit Att41 where
    onsubmit_att s =  Onsubmit_Att_41 (s2b_escape s)
    onsubmit_att_bs =  Onsubmit_Att_41 

class A_Ondblclick a where
    ondblclick_att :: String -> a
    ondblclick_att_bs :: B.ByteString -> a
instance A_Ondblclick Att59 where
    ondblclick_att s =  Ondblclick_Att_59 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_59 
instance A_Ondblclick Att58 where
    ondblclick_att s =  Ondblclick_Att_58 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_58 
instance A_Ondblclick Att57 where
    ondblclick_att s =  Ondblclick_Att_57 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_57 
instance A_Ondblclick Att56 where
    ondblclick_att s =  Ondblclick_Att_56 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_56 
instance A_Ondblclick Att55 where
    ondblclick_att s =  Ondblclick_Att_55 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_55 
instance A_Ondblclick Att53 where
    ondblclick_att s =  Ondblclick_Att_53 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_53 
instance A_Ondblclick Att52 where
    ondblclick_att s =  Ondblclick_Att_52 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_52 
instance A_Ondblclick Att49 where
    ondblclick_att s =  Ondblclick_Att_49 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_49 
instance A_Ondblclick Att48 where
    ondblclick_att s =  Ondblclick_Att_48 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_48 
instance A_Ondblclick Att46 where
    ondblclick_att s =  Ondblclick_Att_46 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_46 
instance A_Ondblclick Att45 where
    ondblclick_att s =  Ondblclick_Att_45 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_45 
instance A_Ondblclick Att44 where
    ondblclick_att s =  Ondblclick_Att_44 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_44 
instance A_Ondblclick Att43 where
    ondblclick_att s =  Ondblclick_Att_43 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_43 
instance A_Ondblclick Att41 where
    ondblclick_att s =  Ondblclick_Att_41 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_41 
instance A_Ondblclick Att40 where
    ondblclick_att s =  Ondblclick_Att_40 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_40 
instance A_Ondblclick Att38 where
    ondblclick_att s =  Ondblclick_Att_38 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_38 
instance A_Ondblclick Att35 where
    ondblclick_att s =  Ondblclick_Att_35 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_35 
instance A_Ondblclick Att29 where
    ondblclick_att s =  Ondblclick_Att_29 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_29 
instance A_Ondblclick Att23 where
    ondblclick_att s =  Ondblclick_Att_23 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_23 
instance A_Ondblclick Att22 where
    ondblclick_att s =  Ondblclick_Att_22 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_22 
instance A_Ondblclick Att21 where
    ondblclick_att s =  Ondblclick_Att_21 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_21 
instance A_Ondblclick Att20 where
    ondblclick_att s =  Ondblclick_Att_20 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_20 
instance A_Ondblclick Att19 where
    ondblclick_att s =  Ondblclick_Att_19 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_19 
instance A_Ondblclick Att18 where
    ondblclick_att s =  Ondblclick_Att_18 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_18 
instance A_Ondblclick Att17 where
    ondblclick_att s =  Ondblclick_Att_17 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_17 
instance A_Ondblclick Att16 where
    ondblclick_att s =  Ondblclick_Att_16 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_16 
instance A_Ondblclick Att15 where
    ondblclick_att s =  Ondblclick_Att_15 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_15 
instance A_Ondblclick Att14 where
    ondblclick_att s =  Ondblclick_Att_14 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_14 
instance A_Ondblclick Att13 where
    ondblclick_att s =  Ondblclick_Att_13 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_13 
instance A_Ondblclick Att12 where
    ondblclick_att s =  Ondblclick_Att_12 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_12 
instance A_Ondblclick Att10 where
    ondblclick_att s =  Ondblclick_Att_10 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_10 
instance A_Ondblclick Att6 where
    ondblclick_att s =  Ondblclick_Att_6 (s2b_escape s)
    ondblclick_att_bs =  Ondblclick_Att_6 

class A_Axis a where
    axis_att :: String -> a
    axis_att_bs :: B.ByteString -> a
instance A_Axis Att59 where
    axis_att s =  Axis_Att_59 (s2b_escape s)
    axis_att_bs =  Axis_Att_59 

class A_Cols a where
    cols_att :: String -> a
    cols_att_bs :: B.ByteString -> a
instance A_Cols Att51 where
    cols_att s =  Cols_Att_51 (s2b_escape s)
    cols_att_bs =  Cols_Att_51 
instance A_Cols Att49 where
    cols_att s =  Cols_Att_49 (s2b_escape s)
    cols_att_bs =  Cols_Att_49 

class A_Marginwidth a where
    marginwidth_att :: String -> a
    marginwidth_att_bs :: B.ByteString -> a
instance A_Marginwidth Att11 where
    marginwidth_att s =  Marginwidth_Att_11 (s2b_escape s)
    marginwidth_att_bs =  Marginwidth_Att_11 

class A_Abbr a where
    abbr_att :: String -> a
    abbr_att_bs :: B.ByteString -> a
instance A_Abbr Att59 where
    abbr_att s =  Abbr_Att_59 (s2b_escape s)
    abbr_att_bs =  Abbr_Att_59 

class A_Onchange a where
    onchange_att :: String -> a
    onchange_att_bs :: B.ByteString -> a
instance A_Onchange Att49 where
    onchange_att s =  Onchange_Att_49 (s2b_escape s)
    onchange_att_bs =  Onchange_Att_49 
instance A_Onchange Att45 where
    onchange_att s =  Onchange_Att_45 (s2b_escape s)
    onchange_att_bs =  Onchange_Att_45 
instance A_Onchange Att44 where
    onchange_att s =  Onchange_Att_44 (s2b_escape s)
    onchange_att_bs =  Onchange_Att_44 

class A_Readonly a where
    readonly_att :: String -> a
instance A_Readonly Att49 where
    readonly_att s =  Readonly_Att_49 (s2b (show s))
instance A_Readonly Att44 where
    readonly_att s =  Readonly_Att_44 (s2b (show s))

class A_Href a where
    href_att :: String -> a
    href_att_bs :: B.ByteString -> a
instance A_Href Att40 where
    href_att s =  Href_Att_40 (s2b_escape s)
    href_att_bs =  Href_Att_40 
instance A_Href Att22 where
    href_att s =  Href_Att_22 (s2b_escape s)
    href_att_bs =  Href_Att_22 
instance A_Href Att6 where
    href_att s =  Href_Att_6 (s2b_escape s)
    href_att_bs =  Href_Att_6 
instance A_Href Att3 where
    href_att s =  Href_Att_3 (s2b_escape s)
    href_att_bs =  Href_Att_3 

class A_Media a where
    media_att :: String -> a
    media_att_bs :: B.ByteString -> a
instance A_Media Att7 where
    media_att s =  Media_Att_7 (s2b_escape s)
    media_att_bs =  Media_Att_7 
instance A_Media Att6 where
    media_att s =  Media_Att_6 (s2b_escape s)
    media_att_bs =  Media_Att_6 

class A_Id a where
    id_att :: String -> a
    id_att_bs :: B.ByteString -> a
instance A_Id Att59 where
    id_att s =  Id_Att_59 (s2b_escape s)
    id_att_bs =  Id_Att_59 
instance A_Id Att58 where
    id_att s =  Id_Att_58 (s2b_escape s)
    id_att_bs =  Id_Att_58 
instance A_Id Att57 where
    id_att s =  Id_Att_57 (s2b_escape s)
    id_att_bs =  Id_Att_57 
instance A_Id Att56 where
    id_att s =  Id_Att_56 (s2b_escape s)
    id_att_bs =  Id_Att_56 
instance A_Id Att55 where
    id_att s =  Id_Att_55 (s2b_escape s)
    id_att_bs =  Id_Att_55 
instance A_Id Att54 where
    id_att s =  Id_Att_54 (s2b_escape s)
    id_att_bs =  Id_Att_54 
instance A_Id Att53 where
    id_att s =  Id_Att_53 (s2b_escape s)
    id_att_bs =  Id_Att_53 
instance A_Id Att52 where
    id_att s =  Id_Att_52 (s2b_escape s)
    id_att_bs =  Id_Att_52 
instance A_Id Att49 where
    id_att s =  Id_Att_49 (s2b_escape s)
    id_att_bs =  Id_Att_49 
instance A_Id Att48 where
    id_att s =  Id_Att_48 (s2b_escape s)
    id_att_bs =  Id_Att_48 
instance A_Id Att46 where
    id_att s =  Id_Att_46 (s2b_escape s)
    id_att_bs =  Id_Att_46 
instance A_Id Att45 where
    id_att s =  Id_Att_45 (s2b_escape s)
    id_att_bs =  Id_Att_45 
instance A_Id Att44 where
    id_att s =  Id_Att_44 (s2b_escape s)
    id_att_bs =  Id_Att_44 
instance A_Id Att43 where
    id_att s =  Id_Att_43 (s2b_escape s)
    id_att_bs =  Id_Att_43 
instance A_Id Att41 where
    id_att s =  Id_Att_41 (s2b_escape s)
    id_att_bs =  Id_Att_41 
instance A_Id Att40 where
    id_att s =  Id_Att_40 (s2b_escape s)
    id_att_bs =  Id_Att_40 
instance A_Id Att39 where
    id_att s =  Id_Att_39 (s2b_escape s)
    id_att_bs =  Id_Att_39 
instance A_Id Att38 where
    id_att s =  Id_Att_38 (s2b_escape s)
    id_att_bs =  Id_Att_38 
instance A_Id Att35 where
    id_att s =  Id_Att_35 (s2b_escape s)
    id_att_bs =  Id_Att_35 
instance A_Id Att32 where
    id_att s =  Id_Att_32 (s2b_escape s)
    id_att_bs =  Id_Att_32 
instance A_Id Att30 where
    id_att s =  Id_Att_30 (s2b_escape s)
    id_att_bs =  Id_Att_30 
instance A_Id Att29 where
    id_att s =  Id_Att_29 (s2b_escape s)
    id_att_bs =  Id_Att_29 
instance A_Id Att28 where
    id_att s =  Id_Att_28 (s2b_escape s)
    id_att_bs =  Id_Att_28 
instance A_Id Att26 where
    id_att s =  Id_Att_26 (s2b_escape s)
    id_att_bs =  Id_Att_26 
instance A_Id Att25 where
    id_att s =  Id_Att_25 (s2b_escape s)
    id_att_bs =  Id_Att_25 
instance A_Id Att23 where
    id_att s =  Id_Att_23 (s2b_escape s)
    id_att_bs =  Id_Att_23 
instance A_Id Att22 where
    id_att s =  Id_Att_22 (s2b_escape s)
    id_att_bs =  Id_Att_22 
instance A_Id Att21 where
    id_att s =  Id_Att_21 (s2b_escape s)
    id_att_bs =  Id_Att_21 
instance A_Id Att20 where
    id_att s =  Id_Att_20 (s2b_escape s)
    id_att_bs =  Id_Att_20 
instance A_Id Att19 where
    id_att s =  Id_Att_19 (s2b_escape s)
    id_att_bs =  Id_Att_19 
instance A_Id Att18 where
    id_att s =  Id_Att_18 (s2b_escape s)
    id_att_bs =  Id_Att_18 
instance A_Id Att17 where
    id_att s =  Id_Att_17 (s2b_escape s)
    id_att_bs =  Id_Att_17 
instance A_Id Att16 where
    id_att s =  Id_Att_16 (s2b_escape s)
    id_att_bs =  Id_Att_16 
instance A_Id Att15 where
    id_att s =  Id_Att_15 (s2b_escape s)
    id_att_bs =  Id_Att_15 
instance A_Id Att14 where
    id_att s =  Id_Att_14 (s2b_escape s)
    id_att_bs =  Id_Att_14 
instance A_Id Att13 where
    id_att s =  Id_Att_13 (s2b_escape s)
    id_att_bs =  Id_Att_13 
instance A_Id Att12 where
    id_att s =  Id_Att_12 (s2b_escape s)
    id_att_bs =  Id_Att_12 
instance A_Id Att11 where
    id_att s =  Id_Att_11 (s2b_escape s)
    id_att_bs =  Id_Att_11 
instance A_Id Att10 where
    id_att s =  Id_Att_10 (s2b_escape s)
    id_att_bs =  Id_Att_10 
instance A_Id Att9 where
    id_att s =  Id_Att_9 (s2b_escape s)
    id_att_bs =  Id_Att_9 
instance A_Id Att7 where
    id_att s =  Id_Att_7 (s2b_escape s)
    id_att_bs =  Id_Att_7 
instance A_Id Att6 where
    id_att s =  Id_Att_6 (s2b_escape s)
    id_att_bs =  Id_Att_6 
instance A_Id Att4 where
    id_att s =  Id_Att_4 (s2b_escape s)
    id_att_bs =  Id_Att_4 
instance A_Id Att3 where
    id_att s =  Id_Att_3 (s2b_escape s)
    id_att_bs =  Id_Att_3 
instance A_Id Att2 where
    id_att s =  Id_Att_2 (s2b_escape s)
    id_att_bs =  Id_Att_2 
instance A_Id Att1 where
    id_att s =  Id_Att_1 (s2b_escape s)
    id_att_bs =  Id_Att_1 
instance A_Id Att0 where
    id_att s =  Id_Att_0 (s2b_escape s)
    id_att_bs =  Id_Att_0 

class A_Compact a where
    compact_att :: String -> a
instance A_Compact Att16 where
    compact_att s =  Compact_Att_16 (s2b (show s))
instance A_Compact Att15 where
    compact_att s =  Compact_Att_15 (s2b (show s))
instance A_Compact Att14 where
    compact_att s =  Compact_Att_14 (s2b (show s))

class A_For a where
    for_att :: String -> a
    for_att_bs :: B.ByteString -> a
instance A_For Att43 where
    for_att s =  For_Att_43 (s2b_escape s)
    for_att_bs =  For_Att_43 

class A_Src a where
    src_att :: String -> a
    src_att_bs :: B.ByteString -> a
instance A_Src Att44 where
    src_att s =  Src_Att_44 (s2b_escape s)
    src_att_bs =  Src_Att_44 
instance A_Src Att36 where
    src_att s =  Src_Att_36 (s2b_escape s)
    src_att_bs =  Src_Att_36 
instance A_Src Att35 where
    src_att s =  Src_Att_35 (s2b_escape s)
    src_att_bs =  Src_Att_35 
instance A_Src Att11 where
    src_att s =  Src_Att_11 (s2b_escape s)
    src_att_bs =  Src_Att_11 
instance A_Src Att9 where
    src_att s =  Src_Att_9 (s2b_escape s)
    src_att_bs =  Src_Att_9 

class A_Value a where
    value_att :: String -> a
    value_att_bs :: B.ByteString -> a
instance A_Value Att53 where
    value_att s =  Value_Att_53 (s2b_escape s)
    value_att_bs =  Value_Att_53 
instance A_Value Att48 where
    value_att s =  Value_Att_48 (s2b_escape s)
    value_att_bs =  Value_Att_48 
instance A_Value Att44 where
    value_att s =  Value_Att_44 (s2b_escape s)
    value_att_bs =  Value_Att_44 
instance A_Value Att30 where
    value_att s =  Value_Att_30 (s2b_escape s)
    value_att_bs =  Value_Att_30 
instance A_Value Att17 where
    value_att s =  Value_Att_17 (s2b_escape s)
    value_att_bs =  Value_Att_17 

class A_Data a where
    data_att :: String -> a
    data_att_bs :: B.ByteString -> a
instance A_Data Att29 where
    data_att s =  Data_Att_29 (s2b_escape s)
    data_att_bs =  Data_Att_29 

class A_Hreflang a where
    hreflang_att :: String -> a
    hreflang_att_bs :: B.ByteString -> a
instance A_Hreflang Att22 where
    hreflang_att s =  Hreflang_Att_22 (s2b_escape s)
    hreflang_att_bs =  Hreflang_Att_22 
instance A_Hreflang Att6 where
    hreflang_att s =  Hreflang_Att_6 (s2b_escape s)
    hreflang_att_bs =  Hreflang_Att_6 

class A_Checked a where
    checked_att :: String -> a
instance A_Checked Att44 where
    checked_att s =  Checked_Att_44 (s2b (show s))

class A_Declare a where
    declare_att :: String -> a
instance A_Declare Att29 where
    declare_att s =  Declare_Att_29 (s2b (show s))

class A_Onkeypress a where
    onkeypress_att :: String -> a
    onkeypress_att_bs :: B.ByteString -> a
instance A_Onkeypress Att59 where
    onkeypress_att s =  Onkeypress_Att_59 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_59 
instance A_Onkeypress Att58 where
    onkeypress_att s =  Onkeypress_Att_58 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_58 
instance A_Onkeypress Att57 where
    onkeypress_att s =  Onkeypress_Att_57 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_57 
instance A_Onkeypress Att56 where
    onkeypress_att s =  Onkeypress_Att_56 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_56 
instance A_Onkeypress Att55 where
    onkeypress_att s =  Onkeypress_Att_55 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_55 
instance A_Onkeypress Att53 where
    onkeypress_att s =  Onkeypress_Att_53 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_53 
instance A_Onkeypress Att52 where
    onkeypress_att s =  Onkeypress_Att_52 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_52 
instance A_Onkeypress Att49 where
    onkeypress_att s =  Onkeypress_Att_49 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_49 
instance A_Onkeypress Att48 where
    onkeypress_att s =  Onkeypress_Att_48 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_48 
instance A_Onkeypress Att46 where
    onkeypress_att s =  Onkeypress_Att_46 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_46 
instance A_Onkeypress Att45 where
    onkeypress_att s =  Onkeypress_Att_45 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_45 
instance A_Onkeypress Att44 where
    onkeypress_att s =  Onkeypress_Att_44 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_44 
instance A_Onkeypress Att43 where
    onkeypress_att s =  Onkeypress_Att_43 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_43 
instance A_Onkeypress Att41 where
    onkeypress_att s =  Onkeypress_Att_41 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_41 
instance A_Onkeypress Att40 where
    onkeypress_att s =  Onkeypress_Att_40 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_40 
instance A_Onkeypress Att38 where
    onkeypress_att s =  Onkeypress_Att_38 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_38 
instance A_Onkeypress Att35 where
    onkeypress_att s =  Onkeypress_Att_35 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_35 
instance A_Onkeypress Att29 where
    onkeypress_att s =  Onkeypress_Att_29 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_29 
instance A_Onkeypress Att23 where
    onkeypress_att s =  Onkeypress_Att_23 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_23 
instance A_Onkeypress Att22 where
    onkeypress_att s =  Onkeypress_Att_22 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_22 
instance A_Onkeypress Att21 where
    onkeypress_att s =  Onkeypress_Att_21 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_21 
instance A_Onkeypress Att20 where
    onkeypress_att s =  Onkeypress_Att_20 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_20 
instance A_Onkeypress Att19 where
    onkeypress_att s =  Onkeypress_Att_19 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_19 
instance A_Onkeypress Att18 where
    onkeypress_att s =  Onkeypress_Att_18 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_18 
instance A_Onkeypress Att17 where
    onkeypress_att s =  Onkeypress_Att_17 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_17 
instance A_Onkeypress Att16 where
    onkeypress_att s =  Onkeypress_Att_16 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_16 
instance A_Onkeypress Att15 where
    onkeypress_att s =  Onkeypress_Att_15 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_15 
instance A_Onkeypress Att14 where
    onkeypress_att s =  Onkeypress_Att_14 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_14 
instance A_Onkeypress Att13 where
    onkeypress_att s =  Onkeypress_Att_13 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_13 
instance A_Onkeypress Att12 where
    onkeypress_att s =  Onkeypress_Att_12 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_12 
instance A_Onkeypress Att10 where
    onkeypress_att s =  Onkeypress_Att_10 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_10 
instance A_Onkeypress Att6 where
    onkeypress_att s =  Onkeypress_Att_6 (s2b_escape s)
    onkeypress_att_bs =  Onkeypress_Att_6 

class A_Label a where
    label_att :: String -> a
    label_att_bs :: B.ByteString -> a
instance A_Label Att48 where
    label_att s =  Label_Att_48 (s2b_escape s)
    label_att_bs =  Label_Att_48 
instance A_Label Att47 where
    label_att s =  Label_Att_47 (s2b_escape s)
    label_att_bs =  Label_Att_47 
instance A_Label Att46 where
    label_att s =  Label_Att_46 (s2b_escape s)
    label_att_bs =  Label_Att_46 

class A_Class a where
    class_att :: String -> a
    class_att_bs :: B.ByteString -> a
instance A_Class Att59 where
    class_att s =  Class_Att_59 (s2b_escape s)
    class_att_bs =  Class_Att_59 
instance A_Class Att58 where
    class_att s =  Class_Att_58 (s2b_escape s)
    class_att_bs =  Class_Att_58 
instance A_Class Att57 where
    class_att s =  Class_Att_57 (s2b_escape s)
    class_att_bs =  Class_Att_57 
instance A_Class Att56 where
    class_att s =  Class_Att_56 (s2b_escape s)
    class_att_bs =  Class_Att_56 
instance A_Class Att55 where
    class_att s =  Class_Att_55 (s2b_escape s)
    class_att_bs =  Class_Att_55 
instance A_Class Att54 where
    class_att s =  Class_Att_54 (s2b_escape s)
    class_att_bs =  Class_Att_54 
instance A_Class Att53 where
    class_att s =  Class_Att_53 (s2b_escape s)
    class_att_bs =  Class_Att_53 
instance A_Class Att52 where
    class_att s =  Class_Att_52 (s2b_escape s)
    class_att_bs =  Class_Att_52 
instance A_Class Att49 where
    class_att s =  Class_Att_49 (s2b_escape s)
    class_att_bs =  Class_Att_49 
instance A_Class Att48 where
    class_att s =  Class_Att_48 (s2b_escape s)
    class_att_bs =  Class_Att_48 
instance A_Class Att46 where
    class_att s =  Class_Att_46 (s2b_escape s)
    class_att_bs =  Class_Att_46 
instance A_Class Att45 where
    class_att s =  Class_Att_45 (s2b_escape s)
    class_att_bs =  Class_Att_45 
instance A_Class Att44 where
    class_att s =  Class_Att_44 (s2b_escape s)
    class_att_bs =  Class_Att_44 
instance A_Class Att43 where
    class_att s =  Class_Att_43 (s2b_escape s)
    class_att_bs =  Class_Att_43 
instance A_Class Att41 where
    class_att s =  Class_Att_41 (s2b_escape s)
    class_att_bs =  Class_Att_41 
instance A_Class Att40 where
    class_att s =  Class_Att_40 (s2b_escape s)
    class_att_bs =  Class_Att_40 
instance A_Class Att38 where
    class_att s =  Class_Att_38 (s2b_escape s)
    class_att_bs =  Class_Att_38 
instance A_Class Att35 where
    class_att s =  Class_Att_35 (s2b_escape s)
    class_att_bs =  Class_Att_35 
instance A_Class Att32 where
    class_att s =  Class_Att_32 (s2b_escape s)
    class_att_bs =  Class_Att_32 
instance A_Class Att29 where
    class_att s =  Class_Att_29 (s2b_escape s)
    class_att_bs =  Class_Att_29 
instance A_Class Att28 where
    class_att s =  Class_Att_28 (s2b_escape s)
    class_att_bs =  Class_Att_28 
instance A_Class Att25 where
    class_att s =  Class_Att_25 (s2b_escape s)
    class_att_bs =  Class_Att_25 
instance A_Class Att23 where
    class_att s =  Class_Att_23 (s2b_escape s)
    class_att_bs =  Class_Att_23 
instance A_Class Att22 where
    class_att s =  Class_Att_22 (s2b_escape s)
    class_att_bs =  Class_Att_22 
instance A_Class Att21 where
    class_att s =  Class_Att_21 (s2b_escape s)
    class_att_bs =  Class_Att_21 
instance A_Class Att20 where
    class_att s =  Class_Att_20 (s2b_escape s)
    class_att_bs =  Class_Att_20 
instance A_Class Att19 where
    class_att s =  Class_Att_19 (s2b_escape s)
    class_att_bs =  Class_Att_19 
instance A_Class Att18 where
    class_att s =  Class_Att_18 (s2b_escape s)
    class_att_bs =  Class_Att_18 
instance A_Class Att17 where
    class_att s =  Class_Att_17 (s2b_escape s)
    class_att_bs =  Class_Att_17 
instance A_Class Att16 where
    class_att s =  Class_Att_16 (s2b_escape s)
    class_att_bs =  Class_Att_16 
instance A_Class Att15 where
    class_att s =  Class_Att_15 (s2b_escape s)
    class_att_bs =  Class_Att_15 
instance A_Class Att14 where
    class_att s =  Class_Att_14 (s2b_escape s)
    class_att_bs =  Class_Att_14 
instance A_Class Att13 where
    class_att s =  Class_Att_13 (s2b_escape s)
    class_att_bs =  Class_Att_13 
instance A_Class Att12 where
    class_att s =  Class_Att_12 (s2b_escape s)
    class_att_bs =  Class_Att_12 
instance A_Class Att11 where
    class_att s =  Class_Att_11 (s2b_escape s)
    class_att_bs =  Class_Att_11 
instance A_Class Att10 where
    class_att s =  Class_Att_10 (s2b_escape s)
    class_att_bs =  Class_Att_10 
instance A_Class Att6 where
    class_att s =  Class_Att_6 (s2b_escape s)
    class_att_bs =  Class_Att_6 

class A_Type a where
    type_att :: String -> a
    type_att_bs :: B.ByteString -> a
instance A_Type Att53 where
    type_att s =  Type_Att_53 (s2b_escape s)
    type_att_bs =  Type_Att_53 
instance A_Type Att44 where
    type_att s =  Type_Att_44 (s2b_escape s)
    type_att_bs =  Type_Att_44 
instance A_Type Att30 where
    type_att s =  Type_Att_30 (s2b_escape s)
    type_att_bs =  Type_Att_30 
instance A_Type Att29 where
    type_att s =  Type_Att_29 (s2b_escape s)
    type_att_bs =  Type_Att_29 
instance A_Type Att22 where
    type_att s =  Type_Att_22 (s2b_escape s)
    type_att_bs =  Type_Att_22 
instance A_Type Att17 where
    type_att s =  Type_Att_17 (s2b_escape s)
    type_att_bs =  Type_Att_17 
instance A_Type Att15 where
    type_att s =  Type_Att_15 (s2b_escape s)
    type_att_bs =  Type_Att_15 
instance A_Type Att14 where
    type_att s =  Type_Att_14 (s2b_escape s)
    type_att_bs =  Type_Att_14 
instance A_Type Att9 where
    type_att s =  Type_Att_9 (s2b_escape s)
    type_att_bs =  Type_Att_9 
instance A_Type Att8 where
    type_att s =  Type_Att_8 (s2b_escape s)
    type_att_bs =  Type_Att_8 
instance A_Type Att7 where
    type_att s =  Type_Att_7 (s2b_escape s)
    type_att_bs =  Type_Att_7 
instance A_Type Att6 where
    type_att s =  Type_Att_6 (s2b_escape s)
    type_att_bs =  Type_Att_6 

class A_Shape a where
    shape_att :: ShapeEnum -> a
instance A_Shape Att40 where
    shape_att s =  Shape_Att_40 (s2b (show s))
instance A_Shape Att22 where
    shape_att s =  Shape_Att_22 (s2b (show s))

class A_Accesskey a where
    accesskey_att :: String -> a
    accesskey_att_bs :: B.ByteString -> a
instance A_Accesskey Att53 where
    accesskey_att s =  Accesskey_Att_53 (s2b_escape s)
    accesskey_att_bs =  Accesskey_Att_53 
instance A_Accesskey Att52 where
    accesskey_att s =  Accesskey_Att_52 (s2b_escape s)
    accesskey_att_bs =  Accesskey_Att_52 
instance A_Accesskey Att49 where
    accesskey_att s =  Accesskey_Att_49 (s2b_escape s)
    accesskey_att_bs =  Accesskey_Att_49 
instance A_Accesskey Att44 where
    accesskey_att s =  Accesskey_Att_44 (s2b_escape s)
    accesskey_att_bs =  Accesskey_Att_44 
instance A_Accesskey Att43 where
    accesskey_att s =  Accesskey_Att_43 (s2b_escape s)
    accesskey_att_bs =  Accesskey_Att_43 
instance A_Accesskey Att40 where
    accesskey_att s =  Accesskey_Att_40 (s2b_escape s)
    accesskey_att_bs =  Accesskey_Att_40 
instance A_Accesskey Att22 where
    accesskey_att s =  Accesskey_Att_22 (s2b_escape s)
    accesskey_att_bs =  Accesskey_Att_22 

class A_Headers a where
    headers_att :: String -> a
    headers_att_bs :: B.ByteString -> a
instance A_Headers Att59 where
    headers_att s =  Headers_Att_59 (s2b_escape s)
    headers_att_bs =  Headers_Att_59 

class A_Disabled a where
    disabled_att :: String -> a
instance A_Disabled Att53 where
    disabled_att s =  Disabled_Att_53 (s2b (show s))
instance A_Disabled Att49 where
    disabled_att s =  Disabled_Att_49 (s2b (show s))
instance A_Disabled Att48 where
    disabled_att s =  Disabled_Att_48 (s2b (show s))
instance A_Disabled Att46 where
    disabled_att s =  Disabled_Att_46 (s2b (show s))
instance A_Disabled Att45 where
    disabled_att s =  Disabled_Att_45 (s2b (show s))
instance A_Disabled Att44 where
    disabled_att s =  Disabled_Att_44 (s2b (show s))

class A_Object a where
    object_att :: String -> a
    object_att_bs :: B.ByteString -> a
instance A_Object Att32 where
    object_att s =  Object_Att_32 (s2b_escape s)
    object_att_bs =  Object_Att_32 

class A_Scrolling a where
    scrolling_att :: ScrollingEnum -> a
instance A_Scrolling Att11 where
    scrolling_att s =  Scrolling_Att_11 (s2b (show s))

class A_Rules a where
    rules_att :: RulesEnum -> a
instance A_Rules Att55 where
    rules_att s =  Rules_Att_55 (s2b (show s))

class A_Rows a where
    rows_att :: String -> a
    rows_att_bs :: B.ByteString -> a
instance A_Rows Att50 where
    rows_att s =  Rows_Att_50 (s2b_escape s)
    rows_att_bs =  Rows_Att_50 
instance A_Rows Att49 where
    rows_att s =  Rows_Att_49 (s2b_escape s)
    rows_att_bs =  Rows_Att_49 

class A_Alink a where
    alink_att :: String -> a
    alink_att_bs :: B.ByteString -> a
instance A_Alink Att12 where
    alink_att s =  Alink_Att_12 (s2b_escape s)
    alink_att_bs =  Alink_Att_12 

class A_Onfocus a where
    onfocus_att :: String -> a
    onfocus_att_bs :: B.ByteString -> a
instance A_Onfocus Att53 where
    onfocus_att s =  Onfocus_Att_53 (s2b_escape s)
    onfocus_att_bs =  Onfocus_Att_53 
instance A_Onfocus Att49 where
    onfocus_att s =  Onfocus_Att_49 (s2b_escape s)
    onfocus_att_bs =  Onfocus_Att_49 
instance A_Onfocus Att45 where
    onfocus_att s =  Onfocus_Att_45 (s2b_escape s)
    onfocus_att_bs =  Onfocus_Att_45 
instance A_Onfocus Att44 where
    onfocus_att s =  Onfocus_Att_44 (s2b_escape s)
    onfocus_att_bs =  Onfocus_Att_44 
instance A_Onfocus Att43 where
    onfocus_att s =  Onfocus_Att_43 (s2b_escape s)
    onfocus_att_bs =  Onfocus_Att_43 
instance A_Onfocus Att40 where
    onfocus_att s =  Onfocus_Att_40 (s2b_escape s)
    onfocus_att_bs =  Onfocus_Att_40 
instance A_Onfocus Att22 where
    onfocus_att s =  Onfocus_Att_22 (s2b_escape s)
    onfocus_att_bs =  Onfocus_Att_22 

class A_Colspan a where
    colspan_att :: String -> a
    colspan_att_bs :: B.ByteString -> a
instance A_Colspan Att59 where
    colspan_att s =  Colspan_Att_59 (s2b_escape s)
    colspan_att_bs =  Colspan_Att_59 

class A_Rowspan a where
    rowspan_att :: String -> a
    rowspan_att_bs :: B.ByteString -> a
instance A_Rowspan Att59 where
    rowspan_att s =  Rowspan_Att_59 (s2b_escape s)
    rowspan_att_bs =  Rowspan_Att_59 

class A_Defer a where
    defer_att :: String -> a
instance A_Defer Att9 where
    defer_att s =  Defer_Att_9 (s2b (show s))

class A_Cellspacing a where
    cellspacing_att :: String -> a
    cellspacing_att_bs :: B.ByteString -> a
instance A_Cellspacing Att55 where
    cellspacing_att s =  Cellspacing_Att_55 (s2b_escape s)
    cellspacing_att_bs =  Cellspacing_Att_55 

class A_Charoff a where
    charoff_att :: String -> a
    charoff_att_bs :: B.ByteString -> a
instance A_Charoff Att59 where
    charoff_att s =  Charoff_Att_59 (s2b_escape s)
    charoff_att_bs =  Charoff_Att_59 
instance A_Charoff Att58 where
    charoff_att s =  Charoff_Att_58 (s2b_escape s)
    charoff_att_bs =  Charoff_Att_58 
instance A_Charoff Att57 where
    charoff_att s =  Charoff_Att_57 (s2b_escape s)
    charoff_att_bs =  Charoff_Att_57 
instance A_Charoff Att56 where
    charoff_att s =  Charoff_Att_56 (s2b_escape s)
    charoff_att_bs =  Charoff_Att_56 

class A_Cite a where
    cite_att :: String -> a
    cite_att_bs :: B.ByteString -> a
instance A_Cite Att21 where
    cite_att s =  Cite_Att_21 (s2b_escape s)
    cite_att_bs =  Cite_Att_21 
instance A_Cite Att20 where
    cite_att s =  Cite_Att_20 (s2b_escape s)
    cite_att_bs =  Cite_Att_20 

class A_Marginheight a where
    marginheight_att :: String -> a
    marginheight_att_bs :: B.ByteString -> a
instance A_Marginheight Att11 where
    marginheight_att s =  Marginheight_Att_11 (s2b_escape s)
    marginheight_att_bs =  Marginheight_Att_11 

class A_Maxlength a where
    maxlength_att :: String -> a
    maxlength_att_bs :: B.ByteString -> a
instance A_Maxlength Att44 where
    maxlength_att s =  Maxlength_Att_44 (s2b_escape s)
    maxlength_att_bs =  Maxlength_Att_44 

class A_Link a where
    link_att :: String -> a
    link_att_bs :: B.ByteString -> a
instance A_Link Att12 where
    link_att s =  Link_Att_12 (s2b_escape s)
    link_att_bs =  Link_Att_12 

class A_Onselect a where
    onselect_att :: String -> a
    onselect_att_bs :: B.ByteString -> a
instance A_Onselect Att49 where
    onselect_att s =  Onselect_Att_49 (s2b_escape s)
    onselect_att_bs =  Onselect_Att_49 
instance A_Onselect Att44 where
    onselect_att s =  Onselect_Att_44 (s2b_escape s)
    onselect_att_bs =  Onselect_Att_44 

class A_Accept a where
    accept_att :: String -> a
    accept_att_bs :: B.ByteString -> a
instance A_Accept Att44 where
    accept_att s =  Accept_Att_44 (s2b_escape s)
    accept_att_bs =  Accept_Att_44 
instance A_Accept Att41 where
    accept_att s =  Accept_Att_41 (s2b_escape s)
    accept_att_bs =  Accept_Att_41 

class A_Alt a where
    alt_att :: String -> a
    alt_att_bs :: B.ByteString -> a
instance A_Alt Att44 where
    alt_att s =  Alt_Att_44 (s2b_escape s)
    alt_att_bs =  Alt_Att_44 
instance A_Alt Att40 where
    alt_att s =  Alt_Att_40 (s2b_escape s)
    alt_att_bs =  Alt_Att_40 
instance A_Alt Att37 where
    alt_att s =  Alt_Att_37 (s2b_escape s)
    alt_att_bs =  Alt_Att_37 
instance A_Alt Att35 where
    alt_att s =  Alt_Att_35 (s2b_escape s)
    alt_att_bs =  Alt_Att_35 
instance A_Alt Att32 where
    alt_att s =  Alt_Att_32 (s2b_escape s)
    alt_att_bs =  Alt_Att_32 

class A_Archive a where
    archive_att :: String -> a
    archive_att_bs :: B.ByteString -> a
instance A_Archive Att32 where
    archive_att s =  Archive_Att_32 (s2b_escape s)
    archive_att_bs =  Archive_Att_32 
instance A_Archive Att29 where
    archive_att s =  Archive_Att_29 (s2b_escape s)
    archive_att_bs =  Archive_Att_29 

class A_Classid a where
    classid_att :: String -> a
    classid_att_bs :: B.ByteString -> a
instance A_Classid Att29 where
    classid_att s =  Classid_Att_29 (s2b_escape s)
    classid_att_bs =  Classid_Att_29 

class A_Longdesc a where
    longdesc_att :: String -> a
    longdesc_att_bs :: B.ByteString -> a
instance A_Longdesc Att35 where
    longdesc_att s =  Longdesc_Att_35 (s2b_escape s)
    longdesc_att_bs =  Longdesc_Att_35 
instance A_Longdesc Att11 where
    longdesc_att s =  Longdesc_Att_11 (s2b_escape s)
    longdesc_att_bs =  Longdesc_Att_11 

class A_Onmouseout a where
    onmouseout_att :: String -> a
    onmouseout_att_bs :: B.ByteString -> a
instance A_Onmouseout Att59 where
    onmouseout_att s =  Onmouseout_Att_59 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_59 
instance A_Onmouseout Att58 where
    onmouseout_att s =  Onmouseout_Att_58 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_58 
instance A_Onmouseout Att57 where
    onmouseout_att s =  Onmouseout_Att_57 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_57 
instance A_Onmouseout Att56 where
    onmouseout_att s =  Onmouseout_Att_56 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_56 
instance A_Onmouseout Att55 where
    onmouseout_att s =  Onmouseout_Att_55 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_55 
instance A_Onmouseout Att53 where
    onmouseout_att s =  Onmouseout_Att_53 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_53 
instance A_Onmouseout Att52 where
    onmouseout_att s =  Onmouseout_Att_52 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_52 
instance A_Onmouseout Att49 where
    onmouseout_att s =  Onmouseout_Att_49 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_49 
instance A_Onmouseout Att48 where
    onmouseout_att s =  Onmouseout_Att_48 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_48 
instance A_Onmouseout Att46 where
    onmouseout_att s =  Onmouseout_Att_46 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_46 
instance A_Onmouseout Att45 where
    onmouseout_att s =  Onmouseout_Att_45 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_45 
instance A_Onmouseout Att44 where
    onmouseout_att s =  Onmouseout_Att_44 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_44 
instance A_Onmouseout Att43 where
    onmouseout_att s =  Onmouseout_Att_43 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_43 
instance A_Onmouseout Att41 where
    onmouseout_att s =  Onmouseout_Att_41 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_41 
instance A_Onmouseout Att40 where
    onmouseout_att s =  Onmouseout_Att_40 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_40 
instance A_Onmouseout Att38 where
    onmouseout_att s =  Onmouseout_Att_38 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_38 
instance A_Onmouseout Att35 where
    onmouseout_att s =  Onmouseout_Att_35 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_35 
instance A_Onmouseout Att29 where
    onmouseout_att s =  Onmouseout_Att_29 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_29 
instance A_Onmouseout Att23 where
    onmouseout_att s =  Onmouseout_Att_23 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_23 
instance A_Onmouseout Att22 where
    onmouseout_att s =  Onmouseout_Att_22 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_22 
instance A_Onmouseout Att21 where
    onmouseout_att s =  Onmouseout_Att_21 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_21 
instance A_Onmouseout Att20 where
    onmouseout_att s =  Onmouseout_Att_20 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_20 
instance A_Onmouseout Att19 where
    onmouseout_att s =  Onmouseout_Att_19 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_19 
instance A_Onmouseout Att18 where
    onmouseout_att s =  Onmouseout_Att_18 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_18 
instance A_Onmouseout Att17 where
    onmouseout_att s =  Onmouseout_Att_17 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_17 
instance A_Onmouseout Att16 where
    onmouseout_att s =  Onmouseout_Att_16 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_16 
instance A_Onmouseout Att15 where
    onmouseout_att s =  Onmouseout_Att_15 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_15 
instance A_Onmouseout Att14 where
    onmouseout_att s =  Onmouseout_Att_14 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_14 
instance A_Onmouseout Att13 where
    onmouseout_att s =  Onmouseout_Att_13 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_13 
instance A_Onmouseout Att12 where
    onmouseout_att s =  Onmouseout_Att_12 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_12 
instance A_Onmouseout Att10 where
    onmouseout_att s =  Onmouseout_Att_10 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_10 
instance A_Onmouseout Att6 where
    onmouseout_att s =  Onmouseout_Att_6 (s2b_escape s)
    onmouseout_att_bs =  Onmouseout_Att_6 

class A_Border a where
    border_att :: String -> a
    border_att_bs :: B.ByteString -> a
instance A_Border Att55 where
    border_att s =  Border_Att_55 (s2b_escape s)
    border_att_bs =  Border_Att_55 
instance A_Border Att35 where
    border_att s =  Border_Att_35 (s2b_escape s)
    border_att_bs =  Border_Att_35 
instance A_Border Att29 where
    border_att s =  Border_Att_29 (s2b_escape s)
    border_att_bs =  Border_Att_29 

class A_Noshade a where
    noshade_att :: String -> a
instance A_Noshade Att18 where
    noshade_att s =  Noshade_Att_18 (s2b (show s))

class A_Onunload a where
    onunload_att :: String -> a
    onunload_att_bs :: B.ByteString -> a
instance A_Onunload Att12 where
    onunload_att s =  Onunload_Att_12 (s2b_escape s)
    onunload_att_bs =  Onunload_Att_12 

class A_Hspace a where
    hspace_att :: String -> a
    hspace_att_bs :: B.ByteString -> a
instance A_Hspace Att35 where
    hspace_att s =  Hspace_Att_35 (s2b_escape s)
    hspace_att_bs =  Hspace_Att_35 
instance A_Hspace Att32 where
    hspace_att s =  Hspace_Att_32 (s2b_escape s)
    hspace_att_bs =  Hspace_Att_32 
instance A_Hspace Att29 where
    hspace_att s =  Hspace_Att_29 (s2b_escape s)
    hspace_att_bs =  Hspace_Att_29 

class A_Action a where
    action_att :: String -> a
    action_att_bs :: B.ByteString -> a
instance A_Action Att42 where
    action_att s =  Action_Att_42 (s2b_escape s)
    action_att_bs =  Action_Att_42 
instance A_Action Att41 where
    action_att s =  Action_Att_41 (s2b_escape s)
    action_att_bs =  Action_Att_41 

class A_Onload a where
    onload_att :: String -> a
    onload_att_bs :: B.ByteString -> a
instance A_Onload Att12 where
    onload_att s =  Onload_Att_12 (s2b_escape s)
    onload_att_bs =  Onload_Att_12 

class A_Cellpadding a where
    cellpadding_att :: String -> a
    cellpadding_att_bs :: B.ByteString -> a
instance A_Cellpadding Att55 where
    cellpadding_att s =  Cellpadding_Att_55 (s2b_escape s)
    cellpadding_att_bs =  Cellpadding_Att_55 

class A_Valuetype a where
    valuetype_att :: ValuetypeEnum -> a
instance A_Valuetype Att30 where
    valuetype_att s =  Valuetype_Att_30 (s2b (show s))

class A_Selected a where
    selected_att :: String -> a
instance A_Selected Att48 where
    selected_att s =  Selected_Att_48 (s2b (show s))

class RenderAttribute a where
    renderAtt :: a -> (B.ByteString,B.ByteString)
instance RenderAttribute Att59 where
    renderAtt (Id_Att_59 b) = (id_byte,b)
    renderAtt (Class_Att_59 b) = (class_byte,b)
    renderAtt (Style_Att_59 b) = (style_byte,b)
    renderAtt (Title_Att_59 b) = (title_byte,b)
    renderAtt (Lang_Att_59 b) = (lang_byte,b)
    renderAtt (Dir_Att_59 b) = (dir_byte,b)
    renderAtt (Onclick_Att_59 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_59 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_59 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_59 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_59 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_59 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_59 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_59 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_59 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_59 b) = (onkeyup_byte,b)
    renderAtt (Abbr_Att_59 b) = (abbr_byte,b)
    renderAtt (Axis_Att_59 b) = (axis_byte,b)
    renderAtt (Headers_Att_59 b) = (headers_byte,b)
    renderAtt (Scope_Att_59 b) = (scope_byte,b)
    renderAtt (Rowspan_Att_59 b) = (rowspan_byte,b)
    renderAtt (Colspan_Att_59 b) = (colspan_byte,b)
    renderAtt (Align_Att_59 b) = (align_byte,b)
    renderAtt (Char_Att_59 b) = (char_byte,b)
    renderAtt (Charoff_Att_59 b) = (charoff_byte,b)
    renderAtt (Valign_Att_59 b) = (valign_byte,b)
    renderAtt (Nowrap_Att_59 b) = (nowrap_byte,b)
    renderAtt (Bgcolor_Att_59 b) = (bgcolor_byte,b)
    renderAtt (Width_Att_59 b) = (width_byte,b)
    renderAtt (Height_Att_59 b) = (height_byte,b)

instance RenderAttribute Att58 where
    renderAtt (Id_Att_58 b) = (id_byte,b)
    renderAtt (Class_Att_58 b) = (class_byte,b)
    renderAtt (Style_Att_58 b) = (style_byte,b)
    renderAtt (Title_Att_58 b) = (title_byte,b)
    renderAtt (Lang_Att_58 b) = (lang_byte,b)
    renderAtt (Dir_Att_58 b) = (dir_byte,b)
    renderAtt (Onclick_Att_58 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_58 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_58 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_58 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_58 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_58 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_58 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_58 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_58 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_58 b) = (onkeyup_byte,b)
    renderAtt (Align_Att_58 b) = (align_byte,b)
    renderAtt (Char_Att_58 b) = (char_byte,b)
    renderAtt (Charoff_Att_58 b) = (charoff_byte,b)
    renderAtt (Valign_Att_58 b) = (valign_byte,b)
    renderAtt (Bgcolor_Att_58 b) = (bgcolor_byte,b)

instance RenderAttribute Att57 where
    renderAtt (Id_Att_57 b) = (id_byte,b)
    renderAtt (Class_Att_57 b) = (class_byte,b)
    renderAtt (Style_Att_57 b) = (style_byte,b)
    renderAtt (Title_Att_57 b) = (title_byte,b)
    renderAtt (Lang_Att_57 b) = (lang_byte,b)
    renderAtt (Dir_Att_57 b) = (dir_byte,b)
    renderAtt (Onclick_Att_57 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_57 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_57 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_57 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_57 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_57 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_57 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_57 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_57 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_57 b) = (onkeyup_byte,b)
    renderAtt (Span_Att_57 b) = (span_byte,b)
    renderAtt (Width_Att_57 b) = (width_byte,b)
    renderAtt (Align_Att_57 b) = (align_byte,b)
    renderAtt (Char_Att_57 b) = (char_byte,b)
    renderAtt (Charoff_Att_57 b) = (charoff_byte,b)
    renderAtt (Valign_Att_57 b) = (valign_byte,b)

instance RenderAttribute Att56 where
    renderAtt (Id_Att_56 b) = (id_byte,b)
    renderAtt (Class_Att_56 b) = (class_byte,b)
    renderAtt (Style_Att_56 b) = (style_byte,b)
    renderAtt (Title_Att_56 b) = (title_byte,b)
    renderAtt (Lang_Att_56 b) = (lang_byte,b)
    renderAtt (Dir_Att_56 b) = (dir_byte,b)
    renderAtt (Onclick_Att_56 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_56 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_56 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_56 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_56 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_56 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_56 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_56 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_56 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_56 b) = (onkeyup_byte,b)
    renderAtt (Align_Att_56 b) = (align_byte,b)
    renderAtt (Char_Att_56 b) = (char_byte,b)
    renderAtt (Charoff_Att_56 b) = (charoff_byte,b)
    renderAtt (Valign_Att_56 b) = (valign_byte,b)

instance RenderAttribute Att55 where
    renderAtt (Id_Att_55 b) = (id_byte,b)
    renderAtt (Class_Att_55 b) = (class_byte,b)
    renderAtt (Style_Att_55 b) = (style_byte,b)
    renderAtt (Title_Att_55 b) = (title_byte,b)
    renderAtt (Lang_Att_55 b) = (lang_byte,b)
    renderAtt (Dir_Att_55 b) = (dir_byte,b)
    renderAtt (Onclick_Att_55 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_55 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_55 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_55 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_55 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_55 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_55 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_55 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_55 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_55 b) = (onkeyup_byte,b)
    renderAtt (Summary_Att_55 b) = (summary_byte,b)
    renderAtt (Width_Att_55 b) = (width_byte,b)
    renderAtt (Border_Att_55 b) = (border_byte,b)
    renderAtt (Frame_Att_55 b) = (frame_byte,b)
    renderAtt (Rules_Att_55 b) = (rules_byte,b)
    renderAtt (Cellspacing_Att_55 b) = (cellspacing_byte,b)
    renderAtt (Cellpadding_Att_55 b) = (cellpadding_byte,b)
    renderAtt (Align_Att_55 b) = (align_byte,b)
    renderAtt (Bgcolor_Att_55 b) = (bgcolor_byte,b)

instance RenderAttribute Att54 where
    renderAtt (Id_Att_54 b) = (id_byte,b)
    renderAtt (Class_Att_54 b) = (class_byte,b)
    renderAtt (Style_Att_54 b) = (style_byte,b)
    renderAtt (Title_Att_54 b) = (title_byte,b)
    renderAtt (Lang_Att_54 b) = (lang_byte,b)
    renderAtt (Dir_Att_54 b) = (dir_byte,b)
    renderAtt (Prompt_Att_54 b) = (prompt_byte,b)

instance RenderAttribute Att53 where
    renderAtt (Id_Att_53 b) = (id_byte,b)
    renderAtt (Class_Att_53 b) = (class_byte,b)
    renderAtt (Style_Att_53 b) = (style_byte,b)
    renderAtt (Title_Att_53 b) = (title_byte,b)
    renderAtt (Lang_Att_53 b) = (lang_byte,b)
    renderAtt (Dir_Att_53 b) = (dir_byte,b)
    renderAtt (Onclick_Att_53 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_53 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_53 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_53 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_53 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_53 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_53 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_53 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_53 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_53 b) = (onkeyup_byte,b)
    renderAtt (Accesskey_Att_53 b) = (accesskey_byte,b)
    renderAtt (Tabindex_Att_53 b) = (tabindex_byte,b)
    renderAtt (Onfocus_Att_53 b) = (onfocus_byte,b)
    renderAtt (Onblur_Att_53 b) = (onblur_byte,b)
    renderAtt (Name_Att_53 b) = (name_byte,b)
    renderAtt (Value_Att_53 b) = (value_byte,b)
    renderAtt (Type_Att_53 b) = (type_byte,b)
    renderAtt (Disabled_Att_53 b) = (disabled_byte,b)

instance RenderAttribute Att52 where
    renderAtt (Id_Att_52 b) = (id_byte,b)
    renderAtt (Class_Att_52 b) = (class_byte,b)
    renderAtt (Style_Att_52 b) = (style_byte,b)
    renderAtt (Title_Att_52 b) = (title_byte,b)
    renderAtt (Lang_Att_52 b) = (lang_byte,b)
    renderAtt (Dir_Att_52 b) = (dir_byte,b)
    renderAtt (Onclick_Att_52 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_52 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_52 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_52 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_52 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_52 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_52 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_52 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_52 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_52 b) = (onkeyup_byte,b)
    renderAtt (Accesskey_Att_52 b) = (accesskey_byte,b)
    renderAtt (Align_Att_52 b) = (align_byte,b)

instance RenderAttribute Att51 where
    renderAtt (Cols_Att_51 b) = (cols_byte,b)

instance RenderAttribute Att50 where
    renderAtt (Rows_Att_50 b) = (rows_byte,b)

instance RenderAttribute Att49 where
    renderAtt (Id_Att_49 b) = (id_byte,b)
    renderAtt (Class_Att_49 b) = (class_byte,b)
    renderAtt (Style_Att_49 b) = (style_byte,b)
    renderAtt (Title_Att_49 b) = (title_byte,b)
    renderAtt (Lang_Att_49 b) = (lang_byte,b)
    renderAtt (Dir_Att_49 b) = (dir_byte,b)
    renderAtt (Onclick_Att_49 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_49 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_49 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_49 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_49 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_49 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_49 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_49 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_49 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_49 b) = (onkeyup_byte,b)
    renderAtt (Accesskey_Att_49 b) = (accesskey_byte,b)
    renderAtt (Tabindex_Att_49 b) = (tabindex_byte,b)
    renderAtt (Onfocus_Att_49 b) = (onfocus_byte,b)
    renderAtt (Onblur_Att_49 b) = (onblur_byte,b)
    renderAtt (Name_Att_49 b) = (name_byte,b)
    renderAtt (Rows_Att_49 b) = (rows_byte,b)
    renderAtt (Cols_Att_49 b) = (cols_byte,b)
    renderAtt (Disabled_Att_49 b) = (disabled_byte,b)
    renderAtt (Readonly_Att_49 b) = (readonly_byte,b)
    renderAtt (Onselect_Att_49 b) = (onselect_byte,b)
    renderAtt (Onchange_Att_49 b) = (onchange_byte,b)

instance RenderAttribute Att48 where
    renderAtt (Id_Att_48 b) = (id_byte,b)
    renderAtt (Class_Att_48 b) = (class_byte,b)
    renderAtt (Style_Att_48 b) = (style_byte,b)
    renderAtt (Title_Att_48 b) = (title_byte,b)
    renderAtt (Lang_Att_48 b) = (lang_byte,b)
    renderAtt (Dir_Att_48 b) = (dir_byte,b)
    renderAtt (Onclick_Att_48 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_48 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_48 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_48 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_48 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_48 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_48 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_48 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_48 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_48 b) = (onkeyup_byte,b)
    renderAtt (Selected_Att_48 b) = (selected_byte,b)
    renderAtt (Disabled_Att_48 b) = (disabled_byte,b)
    renderAtt (Label_Att_48 b) = (label_byte,b)
    renderAtt (Value_Att_48 b) = (value_byte,b)

instance RenderAttribute Att47 where
    renderAtt (Label_Att_47 b) = (label_byte,b)

instance RenderAttribute Att46 where
    renderAtt (Id_Att_46 b) = (id_byte,b)
    renderAtt (Class_Att_46 b) = (class_byte,b)
    renderAtt (Style_Att_46 b) = (style_byte,b)
    renderAtt (Title_Att_46 b) = (title_byte,b)
    renderAtt (Lang_Att_46 b) = (lang_byte,b)
    renderAtt (Dir_Att_46 b) = (dir_byte,b)
    renderAtt (Onclick_Att_46 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_46 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_46 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_46 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_46 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_46 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_46 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_46 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_46 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_46 b) = (onkeyup_byte,b)
    renderAtt (Disabled_Att_46 b) = (disabled_byte,b)
    renderAtt (Label_Att_46 b) = (label_byte,b)

instance RenderAttribute Att45 where
    renderAtt (Id_Att_45 b) = (id_byte,b)
    renderAtt (Class_Att_45 b) = (class_byte,b)
    renderAtt (Style_Att_45 b) = (style_byte,b)
    renderAtt (Title_Att_45 b) = (title_byte,b)
    renderAtt (Lang_Att_45 b) = (lang_byte,b)
    renderAtt (Dir_Att_45 b) = (dir_byte,b)
    renderAtt (Onclick_Att_45 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_45 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_45 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_45 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_45 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_45 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_45 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_45 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_45 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_45 b) = (onkeyup_byte,b)
    renderAtt (Name_Att_45 b) = (name_byte,b)
    renderAtt (Size_Att_45 b) = (size_byte,b)
    renderAtt (Multiple_Att_45 b) = (multiple_byte,b)
    renderAtt (Disabled_Att_45 b) = (disabled_byte,b)
    renderAtt (Tabindex_Att_45 b) = (tabindex_byte,b)
    renderAtt (Onfocus_Att_45 b) = (onfocus_byte,b)
    renderAtt (Onblur_Att_45 b) = (onblur_byte,b)
    renderAtt (Onchange_Att_45 b) = (onchange_byte,b)

instance RenderAttribute Att44 where
    renderAtt (Id_Att_44 b) = (id_byte,b)
    renderAtt (Class_Att_44 b) = (class_byte,b)
    renderAtt (Style_Att_44 b) = (style_byte,b)
    renderAtt (Title_Att_44 b) = (title_byte,b)
    renderAtt (Lang_Att_44 b) = (lang_byte,b)
    renderAtt (Dir_Att_44 b) = (dir_byte,b)
    renderAtt (Onclick_Att_44 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_44 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_44 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_44 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_44 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_44 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_44 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_44 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_44 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_44 b) = (onkeyup_byte,b)
    renderAtt (Accesskey_Att_44 b) = (accesskey_byte,b)
    renderAtt (Tabindex_Att_44 b) = (tabindex_byte,b)
    renderAtt (Onfocus_Att_44 b) = (onfocus_byte,b)
    renderAtt (Onblur_Att_44 b) = (onblur_byte,b)
    renderAtt (Type_Att_44 b) = (type_byte,b)
    renderAtt (Name_Att_44 b) = (name_byte,b)
    renderAtt (Value_Att_44 b) = (value_byte,b)
    renderAtt (Checked_Att_44 b) = (checked_byte,b)
    renderAtt (Disabled_Att_44 b) = (disabled_byte,b)
    renderAtt (Readonly_Att_44 b) = (readonly_byte,b)
    renderAtt (Size_Att_44 b) = (size_byte,b)
    renderAtt (Maxlength_Att_44 b) = (maxlength_byte,b)
    renderAtt (Src_Att_44 b) = (src_byte,b)
    renderAtt (Alt_Att_44 b) = (alt_byte,b)
    renderAtt (Usemap_Att_44 b) = (usemap_byte,b)
    renderAtt (Onselect_Att_44 b) = (onselect_byte,b)
    renderAtt (Onchange_Att_44 b) = (onchange_byte,b)
    renderAtt (Accept_Att_44 b) = (accept_byte,b)
    renderAtt (Align_Att_44 b) = (align_byte,b)

instance RenderAttribute Att43 where
    renderAtt (Id_Att_43 b) = (id_byte,b)
    renderAtt (Class_Att_43 b) = (class_byte,b)
    renderAtt (Style_Att_43 b) = (style_byte,b)
    renderAtt (Title_Att_43 b) = (title_byte,b)
    renderAtt (Lang_Att_43 b) = (lang_byte,b)
    renderAtt (Dir_Att_43 b) = (dir_byte,b)
    renderAtt (Onclick_Att_43 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_43 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_43 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_43 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_43 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_43 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_43 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_43 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_43 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_43 b) = (onkeyup_byte,b)
    renderAtt (For_Att_43 b) = (for_byte,b)
    renderAtt (Accesskey_Att_43 b) = (accesskey_byte,b)
    renderAtt (Onfocus_Att_43 b) = (onfocus_byte,b)
    renderAtt (Onblur_Att_43 b) = (onblur_byte,b)

instance RenderAttribute Att42 where
    renderAtt (Action_Att_42 b) = (action_byte,b)

instance RenderAttribute Att41 where
    renderAtt (Id_Att_41 b) = (id_byte,b)
    renderAtt (Class_Att_41 b) = (class_byte,b)
    renderAtt (Style_Att_41 b) = (style_byte,b)
    renderAtt (Title_Att_41 b) = (title_byte,b)
    renderAtt (Lang_Att_41 b) = (lang_byte,b)
    renderAtt (Dir_Att_41 b) = (dir_byte,b)
    renderAtt (Onclick_Att_41 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_41 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_41 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_41 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_41 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_41 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_41 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_41 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_41 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_41 b) = (onkeyup_byte,b)
    renderAtt (Action_Att_41 b) = (action_byte,b)
    renderAtt (Method_Att_41 b) = (method_byte,b)
    renderAtt (Name_Att_41 b) = (name_byte,b)
    renderAtt (Enctype_Att_41 b) = (enctype_byte,b)
    renderAtt (Onsubmit_Att_41 b) = (onsubmit_byte,b)
    renderAtt (Onreset_Att_41 b) = (onreset_byte,b)
    renderAtt (Accept_Att_41 b) = (accept_byte,b)
    renderAtt (Accept_charset_Att_41 b) = (accept_charset_byte,b)
    renderAtt (Target_Att_41 b) = (target_byte,b)

instance RenderAttribute Att40 where
    renderAtt (Id_Att_40 b) = (id_byte,b)
    renderAtt (Class_Att_40 b) = (class_byte,b)
    renderAtt (Style_Att_40 b) = (style_byte,b)
    renderAtt (Title_Att_40 b) = (title_byte,b)
    renderAtt (Lang_Att_40 b) = (lang_byte,b)
    renderAtt (Dir_Att_40 b) = (dir_byte,b)
    renderAtt (Onclick_Att_40 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_40 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_40 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_40 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_40 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_40 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_40 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_40 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_40 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_40 b) = (onkeyup_byte,b)
    renderAtt (Accesskey_Att_40 b) = (accesskey_byte,b)
    renderAtt (Tabindex_Att_40 b) = (tabindex_byte,b)
    renderAtt (Onfocus_Att_40 b) = (onfocus_byte,b)
    renderAtt (Onblur_Att_40 b) = (onblur_byte,b)
    renderAtt (Shape_Att_40 b) = (shape_byte,b)
    renderAtt (Coords_Att_40 b) = (coords_byte,b)
    renderAtt (Href_Att_40 b) = (href_byte,b)
    renderAtt (Nohref_Att_40 b) = (nohref_byte,b)
    renderAtt (Alt_Att_40 b) = (alt_byte,b)
    renderAtt (Target_Att_40 b) = (target_byte,b)

instance RenderAttribute Att39 where
    renderAtt (Id_Att_39 b) = (id_byte,b)

instance RenderAttribute Att38 where
    renderAtt (Lang_Att_38 b) = (lang_byte,b)
    renderAtt (Dir_Att_38 b) = (dir_byte,b)
    renderAtt (Onclick_Att_38 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_38 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_38 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_38 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_38 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_38 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_38 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_38 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_38 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_38 b) = (onkeyup_byte,b)
    renderAtt (Id_Att_38 b) = (id_byte,b)
    renderAtt (Class_Att_38 b) = (class_byte,b)
    renderAtt (Style_Att_38 b) = (style_byte,b)
    renderAtt (Title_Att_38 b) = (title_byte,b)
    renderAtt (Name_Att_38 b) = (name_byte,b)

instance RenderAttribute Att37 where
    renderAtt (Alt_Att_37 b) = (alt_byte,b)

instance RenderAttribute Att36 where
    renderAtt (Src_Att_36 b) = (src_byte,b)

instance RenderAttribute Att35 where
    renderAtt (Id_Att_35 b) = (id_byte,b)
    renderAtt (Class_Att_35 b) = (class_byte,b)
    renderAtt (Style_Att_35 b) = (style_byte,b)
    renderAtt (Title_Att_35 b) = (title_byte,b)
    renderAtt (Lang_Att_35 b) = (lang_byte,b)
    renderAtt (Dir_Att_35 b) = (dir_byte,b)
    renderAtt (Onclick_Att_35 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_35 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_35 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_35 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_35 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_35 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_35 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_35 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_35 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_35 b) = (onkeyup_byte,b)
    renderAtt (Src_Att_35 b) = (src_byte,b)
    renderAtt (Alt_Att_35 b) = (alt_byte,b)
    renderAtt (Name_Att_35 b) = (name_byte,b)
    renderAtt (Longdesc_Att_35 b) = (longdesc_byte,b)
    renderAtt (Height_Att_35 b) = (height_byte,b)
    renderAtt (Width_Att_35 b) = (width_byte,b)
    renderAtt (Usemap_Att_35 b) = (usemap_byte,b)
    renderAtt (Ismap_Att_35 b) = (ismap_byte,b)
    renderAtt (Align_Att_35 b) = (align_byte,b)
    renderAtt (Border_Att_35 b) = (border_byte,b)
    renderAtt (Hspace_Att_35 b) = (hspace_byte,b)
    renderAtt (Vspace_Att_35 b) = (vspace_byte,b)

instance RenderAttribute Att34 where
    renderAtt (Height_Att_34 b) = (height_byte,b)

instance RenderAttribute Att33 where
    renderAtt (Width_Att_33 b) = (width_byte,b)

instance RenderAttribute Att32 where
    renderAtt (Id_Att_32 b) = (id_byte,b)
    renderAtt (Class_Att_32 b) = (class_byte,b)
    renderAtt (Style_Att_32 b) = (style_byte,b)
    renderAtt (Title_Att_32 b) = (title_byte,b)
    renderAtt (Codebase_Att_32 b) = (codebase_byte,b)
    renderAtt (Archive_Att_32 b) = (archive_byte,b)
    renderAtt (Code_Att_32 b) = (code_byte,b)
    renderAtt (Object_Att_32 b) = (object_byte,b)
    renderAtt (Alt_Att_32 b) = (alt_byte,b)
    renderAtt (Name_Att_32 b) = (name_byte,b)
    renderAtt (Width_Att_32 b) = (width_byte,b)
    renderAtt (Height_Att_32 b) = (height_byte,b)
    renderAtt (Align_Att_32 b) = (align_byte,b)
    renderAtt (Hspace_Att_32 b) = (hspace_byte,b)
    renderAtt (Vspace_Att_32 b) = (vspace_byte,b)

instance RenderAttribute Att31 where
    renderAtt (Name_Att_31 b) = (name_byte,b)

instance RenderAttribute Att30 where
    renderAtt (Id_Att_30 b) = (id_byte,b)
    renderAtt (Name_Att_30 b) = (name_byte,b)
    renderAtt (Value_Att_30 b) = (value_byte,b)
    renderAtt (Valuetype_Att_30 b) = (valuetype_byte,b)
    renderAtt (Type_Att_30 b) = (type_byte,b)

instance RenderAttribute Att29 where
    renderAtt (Id_Att_29 b) = (id_byte,b)
    renderAtt (Class_Att_29 b) = (class_byte,b)
    renderAtt (Style_Att_29 b) = (style_byte,b)
    renderAtt (Title_Att_29 b) = (title_byte,b)
    renderAtt (Lang_Att_29 b) = (lang_byte,b)
    renderAtt (Dir_Att_29 b) = (dir_byte,b)
    renderAtt (Onclick_Att_29 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_29 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_29 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_29 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_29 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_29 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_29 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_29 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_29 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_29 b) = (onkeyup_byte,b)
    renderAtt (Declare_Att_29 b) = (declare_byte,b)
    renderAtt (Classid_Att_29 b) = (classid_byte,b)
    renderAtt (Codebase_Att_29 b) = (codebase_byte,b)
    renderAtt (Data_Att_29 b) = (data_byte,b)
    renderAtt (Type_Att_29 b) = (type_byte,b)
    renderAtt (Codetype_Att_29 b) = (codetype_byte,b)
    renderAtt (Archive_Att_29 b) = (archive_byte,b)
    renderAtt (Standby_Att_29 b) = (standby_byte,b)
    renderAtt (Height_Att_29 b) = (height_byte,b)
    renderAtt (Width_Att_29 b) = (width_byte,b)
    renderAtt (Usemap_Att_29 b) = (usemap_byte,b)
    renderAtt (Name_Att_29 b) = (name_byte,b)
    renderAtt (Tabindex_Att_29 b) = (tabindex_byte,b)
    renderAtt (Align_Att_29 b) = (align_byte,b)
    renderAtt (Border_Att_29 b) = (border_byte,b)
    renderAtt (Hspace_Att_29 b) = (hspace_byte,b)
    renderAtt (Vspace_Att_29 b) = (vspace_byte,b)

instance RenderAttribute Att28 where
    renderAtt (Id_Att_28 b) = (id_byte,b)
    renderAtt (Class_Att_28 b) = (class_byte,b)
    renderAtt (Style_Att_28 b) = (style_byte,b)
    renderAtt (Title_Att_28 b) = (title_byte,b)
    renderAtt (Lang_Att_28 b) = (lang_byte,b)
    renderAtt (Dir_Att_28 b) = (dir_byte,b)
    renderAtt (Size_Att_28 b) = (size_byte,b)
    renderAtt (Color_Att_28 b) = (color_byte,b)
    renderAtt (Face_Att_28 b) = (face_byte,b)

instance RenderAttribute Att27 where
    renderAtt (Size_Att_27 b) = (size_byte,b)

instance RenderAttribute Att26 where
    renderAtt (Id_Att_26 b) = (id_byte,b)
    renderAtt (Size_Att_26 b) = (size_byte,b)
    renderAtt (Color_Att_26 b) = (color_byte,b)
    renderAtt (Face_Att_26 b) = (face_byte,b)

instance RenderAttribute Att25 where
    renderAtt (Id_Att_25 b) = (id_byte,b)
    renderAtt (Class_Att_25 b) = (class_byte,b)
    renderAtt (Style_Att_25 b) = (style_byte,b)
    renderAtt (Title_Att_25 b) = (title_byte,b)
    renderAtt (Clear_Att_25 b) = (clear_byte,b)

instance RenderAttribute Att24 where
    renderAtt (Dir_Att_24 b) = (dir_byte,b)

instance RenderAttribute Att23 where
    renderAtt (Id_Att_23 b) = (id_byte,b)
    renderAtt (Class_Att_23 b) = (class_byte,b)
    renderAtt (Style_Att_23 b) = (style_byte,b)
    renderAtt (Title_Att_23 b) = (title_byte,b)
    renderAtt (Onclick_Att_23 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_23 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_23 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_23 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_23 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_23 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_23 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_23 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_23 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_23 b) = (onkeyup_byte,b)
    renderAtt (Lang_Att_23 b) = (lang_byte,b)
    renderAtt (Dir_Att_23 b) = (dir_byte,b)

instance RenderAttribute Att22 where
    renderAtt (Id_Att_22 b) = (id_byte,b)
    renderAtt (Class_Att_22 b) = (class_byte,b)
    renderAtt (Style_Att_22 b) = (style_byte,b)
    renderAtt (Title_Att_22 b) = (title_byte,b)
    renderAtt (Lang_Att_22 b) = (lang_byte,b)
    renderAtt (Dir_Att_22 b) = (dir_byte,b)
    renderAtt (Onclick_Att_22 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_22 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_22 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_22 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_22 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_22 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_22 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_22 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_22 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_22 b) = (onkeyup_byte,b)
    renderAtt (Accesskey_Att_22 b) = (accesskey_byte,b)
    renderAtt (Tabindex_Att_22 b) = (tabindex_byte,b)
    renderAtt (Onfocus_Att_22 b) = (onfocus_byte,b)
    renderAtt (Onblur_Att_22 b) = (onblur_byte,b)
    renderAtt (Charset_Att_22 b) = (charset_byte,b)
    renderAtt (Type_Att_22 b) = (type_byte,b)
    renderAtt (Name_Att_22 b) = (name_byte,b)
    renderAtt (Href_Att_22 b) = (href_byte,b)
    renderAtt (Hreflang_Att_22 b) = (hreflang_byte,b)
    renderAtt (Rel_Att_22 b) = (rel_byte,b)
    renderAtt (Rev_Att_22 b) = (rev_byte,b)
    renderAtt (Shape_Att_22 b) = (shape_byte,b)
    renderAtt (Coords_Att_22 b) = (coords_byte,b)
    renderAtt (Target_Att_22 b) = (target_byte,b)

instance RenderAttribute Att21 where
    renderAtt (Id_Att_21 b) = (id_byte,b)
    renderAtt (Class_Att_21 b) = (class_byte,b)
    renderAtt (Style_Att_21 b) = (style_byte,b)
    renderAtt (Title_Att_21 b) = (title_byte,b)
    renderAtt (Lang_Att_21 b) = (lang_byte,b)
    renderAtt (Dir_Att_21 b) = (dir_byte,b)
    renderAtt (Onclick_Att_21 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_21 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_21 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_21 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_21 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_21 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_21 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_21 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_21 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_21 b) = (onkeyup_byte,b)
    renderAtt (Cite_Att_21 b) = (cite_byte,b)
    renderAtt (Datetime_Att_21 b) = (datetime_byte,b)

instance RenderAttribute Att20 where
    renderAtt (Id_Att_20 b) = (id_byte,b)
    renderAtt (Class_Att_20 b) = (class_byte,b)
    renderAtt (Style_Att_20 b) = (style_byte,b)
    renderAtt (Title_Att_20 b) = (title_byte,b)
    renderAtt (Lang_Att_20 b) = (lang_byte,b)
    renderAtt (Dir_Att_20 b) = (dir_byte,b)
    renderAtt (Onclick_Att_20 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_20 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_20 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_20 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_20 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_20 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_20 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_20 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_20 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_20 b) = (onkeyup_byte,b)
    renderAtt (Cite_Att_20 b) = (cite_byte,b)

instance RenderAttribute Att19 where
    renderAtt (Id_Att_19 b) = (id_byte,b)
    renderAtt (Class_Att_19 b) = (class_byte,b)
    renderAtt (Style_Att_19 b) = (style_byte,b)
    renderAtt (Title_Att_19 b) = (title_byte,b)
    renderAtt (Lang_Att_19 b) = (lang_byte,b)
    renderAtt (Dir_Att_19 b) = (dir_byte,b)
    renderAtt (Onclick_Att_19 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_19 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_19 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_19 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_19 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_19 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_19 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_19 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_19 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_19 b) = (onkeyup_byte,b)
    renderAtt (Width_Att_19 b) = (width_byte,b)

instance RenderAttribute Att18 where
    renderAtt (Id_Att_18 b) = (id_byte,b)
    renderAtt (Class_Att_18 b) = (class_byte,b)
    renderAtt (Style_Att_18 b) = (style_byte,b)
    renderAtt (Title_Att_18 b) = (title_byte,b)
    renderAtt (Lang_Att_18 b) = (lang_byte,b)
    renderAtt (Dir_Att_18 b) = (dir_byte,b)
    renderAtt (Onclick_Att_18 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_18 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_18 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_18 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_18 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_18 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_18 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_18 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_18 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_18 b) = (onkeyup_byte,b)
    renderAtt (Align_Att_18 b) = (align_byte,b)
    renderAtt (Noshade_Att_18 b) = (noshade_byte,b)
    renderAtt (Size_Att_18 b) = (size_byte,b)
    renderAtt (Width_Att_18 b) = (width_byte,b)

instance RenderAttribute Att17 where
    renderAtt (Id_Att_17 b) = (id_byte,b)
    renderAtt (Class_Att_17 b) = (class_byte,b)
    renderAtt (Style_Att_17 b) = (style_byte,b)
    renderAtt (Title_Att_17 b) = (title_byte,b)
    renderAtt (Lang_Att_17 b) = (lang_byte,b)
    renderAtt (Dir_Att_17 b) = (dir_byte,b)
    renderAtt (Onclick_Att_17 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_17 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_17 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_17 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_17 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_17 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_17 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_17 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_17 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_17 b) = (onkeyup_byte,b)
    renderAtt (Type_Att_17 b) = (type_byte,b)
    renderAtt (Value_Att_17 b) = (value_byte,b)

instance RenderAttribute Att16 where
    renderAtt (Id_Att_16 b) = (id_byte,b)
    renderAtt (Class_Att_16 b) = (class_byte,b)
    renderAtt (Style_Att_16 b) = (style_byte,b)
    renderAtt (Title_Att_16 b) = (title_byte,b)
    renderAtt (Lang_Att_16 b) = (lang_byte,b)
    renderAtt (Dir_Att_16 b) = (dir_byte,b)
    renderAtt (Onclick_Att_16 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_16 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_16 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_16 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_16 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_16 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_16 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_16 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_16 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_16 b) = (onkeyup_byte,b)
    renderAtt (Compact_Att_16 b) = (compact_byte,b)

instance RenderAttribute Att15 where
    renderAtt (Id_Att_15 b) = (id_byte,b)
    renderAtt (Class_Att_15 b) = (class_byte,b)
    renderAtt (Style_Att_15 b) = (style_byte,b)
    renderAtt (Title_Att_15 b) = (title_byte,b)
    renderAtt (Lang_Att_15 b) = (lang_byte,b)
    renderAtt (Dir_Att_15 b) = (dir_byte,b)
    renderAtt (Onclick_Att_15 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_15 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_15 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_15 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_15 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_15 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_15 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_15 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_15 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_15 b) = (onkeyup_byte,b)
    renderAtt (Type_Att_15 b) = (type_byte,b)
    renderAtt (Compact_Att_15 b) = (compact_byte,b)
    renderAtt (Start_Att_15 b) = (start_byte,b)

instance RenderAttribute Att14 where
    renderAtt (Id_Att_14 b) = (id_byte,b)
    renderAtt (Class_Att_14 b) = (class_byte,b)
    renderAtt (Style_Att_14 b) = (style_byte,b)
    renderAtt (Title_Att_14 b) = (title_byte,b)
    renderAtt (Lang_Att_14 b) = (lang_byte,b)
    renderAtt (Dir_Att_14 b) = (dir_byte,b)
    renderAtt (Onclick_Att_14 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_14 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_14 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_14 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_14 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_14 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_14 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_14 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_14 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_14 b) = (onkeyup_byte,b)
    renderAtt (Type_Att_14 b) = (type_byte,b)
    renderAtt (Compact_Att_14 b) = (compact_byte,b)

instance RenderAttribute Att13 where
    renderAtt (Id_Att_13 b) = (id_byte,b)
    renderAtt (Class_Att_13 b) = (class_byte,b)
    renderAtt (Style_Att_13 b) = (style_byte,b)
    renderAtt (Title_Att_13 b) = (title_byte,b)
    renderAtt (Lang_Att_13 b) = (lang_byte,b)
    renderAtt (Dir_Att_13 b) = (dir_byte,b)
    renderAtt (Onclick_Att_13 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_13 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_13 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_13 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_13 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_13 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_13 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_13 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_13 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_13 b) = (onkeyup_byte,b)
    renderAtt (Align_Att_13 b) = (align_byte,b)

instance RenderAttribute Att12 where
    renderAtt (Id_Att_12 b) = (id_byte,b)
    renderAtt (Class_Att_12 b) = (class_byte,b)
    renderAtt (Style_Att_12 b) = (style_byte,b)
    renderAtt (Title_Att_12 b) = (title_byte,b)
    renderAtt (Lang_Att_12 b) = (lang_byte,b)
    renderAtt (Dir_Att_12 b) = (dir_byte,b)
    renderAtt (Onclick_Att_12 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_12 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_12 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_12 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_12 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_12 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_12 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_12 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_12 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_12 b) = (onkeyup_byte,b)
    renderAtt (Onload_Att_12 b) = (onload_byte,b)
    renderAtt (Onunload_Att_12 b) = (onunload_byte,b)
    renderAtt (Background_Att_12 b) = (background_byte,b)
    renderAtt (Bgcolor_Att_12 b) = (bgcolor_byte,b)
    renderAtt (Text_Att_12 b) = (text_byte,b)
    renderAtt (Link_Att_12 b) = (link_byte,b)
    renderAtt (Vlink_Att_12 b) = (vlink_byte,b)
    renderAtt (Alink_Att_12 b) = (alink_byte,b)

instance RenderAttribute Att11 where
    renderAtt (Id_Att_11 b) = (id_byte,b)
    renderAtt (Class_Att_11 b) = (class_byte,b)
    renderAtt (Style_Att_11 b) = (style_byte,b)
    renderAtt (Title_Att_11 b) = (title_byte,b)
    renderAtt (Longdesc_Att_11 b) = (longdesc_byte,b)
    renderAtt (Name_Att_11 b) = (name_byte,b)
    renderAtt (Src_Att_11 b) = (src_byte,b)
    renderAtt (Frameborder_Att_11 b) = (frameborder_byte,b)
    renderAtt (Marginwidth_Att_11 b) = (marginwidth_byte,b)
    renderAtt (Marginheight_Att_11 b) = (marginheight_byte,b)
    renderAtt (Scrolling_Att_11 b) = (scrolling_byte,b)
    renderAtt (Align_Att_11 b) = (align_byte,b)
    renderAtt (Height_Att_11 b) = (height_byte,b)
    renderAtt (Width_Att_11 b) = (width_byte,b)

instance RenderAttribute Att10 where
    renderAtt (Id_Att_10 b) = (id_byte,b)
    renderAtt (Class_Att_10 b) = (class_byte,b)
    renderAtt (Style_Att_10 b) = (style_byte,b)
    renderAtt (Title_Att_10 b) = (title_byte,b)
    renderAtt (Lang_Att_10 b) = (lang_byte,b)
    renderAtt (Dir_Att_10 b) = (dir_byte,b)
    renderAtt (Onclick_Att_10 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_10 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_10 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_10 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_10 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_10 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_10 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_10 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_10 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_10 b) = (onkeyup_byte,b)

instance RenderAttribute Att9 where
    renderAtt (Id_Att_9 b) = (id_byte,b)
    renderAtt (Charset_Att_9 b) = (charset_byte,b)
    renderAtt (Type_Att_9 b) = (type_byte,b)
    renderAtt (Language_Att_9 b) = (language_byte,b)
    renderAtt (Src_Att_9 b) = (src_byte,b)
    renderAtt (Defer_Att_9 b) = (defer_byte,b)

instance RenderAttribute Att8 where
    renderAtt (Type_Att_8 b) = (type_byte,b)

instance RenderAttribute Att7 where
    renderAtt (Lang_Att_7 b) = (lang_byte,b)
    renderAtt (Dir_Att_7 b) = (dir_byte,b)
    renderAtt (Id_Att_7 b) = (id_byte,b)
    renderAtt (Type_Att_7 b) = (type_byte,b)
    renderAtt (Media_Att_7 b) = (media_byte,b)
    renderAtt (Title_Att_7 b) = (title_byte,b)

instance RenderAttribute Att6 where
    renderAtt (Id_Att_6 b) = (id_byte,b)
    renderAtt (Class_Att_6 b) = (class_byte,b)
    renderAtt (Style_Att_6 b) = (style_byte,b)
    renderAtt (Title_Att_6 b) = (title_byte,b)
    renderAtt (Lang_Att_6 b) = (lang_byte,b)
    renderAtt (Dir_Att_6 b) = (dir_byte,b)
    renderAtt (Onclick_Att_6 b) = (onclick_byte,b)
    renderAtt (Ondblclick_Att_6 b) = (ondblclick_byte,b)
    renderAtt (Onmousedown_Att_6 b) = (onmousedown_byte,b)
    renderAtt (Onmouseup_Att_6 b) = (onmouseup_byte,b)
    renderAtt (Onmouseover_Att_6 b) = (onmouseover_byte,b)
    renderAtt (Onmousemove_Att_6 b) = (onmousemove_byte,b)
    renderAtt (Onmouseout_Att_6 b) = (onmouseout_byte,b)
    renderAtt (Onkeypress_Att_6 b) = (onkeypress_byte,b)
    renderAtt (Onkeydown_Att_6 b) = (onkeydown_byte,b)
    renderAtt (Onkeyup_Att_6 b) = (onkeyup_byte,b)
    renderAtt (Charset_Att_6 b) = (charset_byte,b)
    renderAtt (Href_Att_6 b) = (href_byte,b)
    renderAtt (Hreflang_Att_6 b) = (hreflang_byte,b)
    renderAtt (Type_Att_6 b) = (type_byte,b)
    renderAtt (Rel_Att_6 b) = (rel_byte,b)
    renderAtt (Rev_Att_6 b) = (rev_byte,b)
    renderAtt (Media_Att_6 b) = (media_byte,b)
    renderAtt (Target_Att_6 b) = (target_byte,b)

instance RenderAttribute Att5 where
    renderAtt (Content_Att_5 b) = (content_byte,b)

instance RenderAttribute Att4 where
    renderAtt (Lang_Att_4 b) = (lang_byte,b)
    renderAtt (Dir_Att_4 b) = (dir_byte,b)
    renderAtt (Id_Att_4 b) = (id_byte,b)
    renderAtt (Http_equiv_Att_4 b) = (http_equiv_byte,b)
    renderAtt (Name_Att_4 b) = (name_byte,b)
    renderAtt (Content_Att_4 b) = (content_byte,b)
    renderAtt (Scheme_Att_4 b) = (scheme_byte,b)

instance RenderAttribute Att3 where
    renderAtt (Id_Att_3 b) = (id_byte,b)
    renderAtt (Href_Att_3 b) = (href_byte,b)
    renderAtt (Target_Att_3 b) = (target_byte,b)

instance RenderAttribute Att2 where
    renderAtt (Lang_Att_2 b) = (lang_byte,b)
    renderAtt (Dir_Att_2 b) = (dir_byte,b)
    renderAtt (Id_Att_2 b) = (id_byte,b)

instance RenderAttribute Att1 where
    renderAtt (Lang_Att_1 b) = (lang_byte,b)
    renderAtt (Dir_Att_1 b) = (dir_byte,b)
    renderAtt (Id_Att_1 b) = (id_byte,b)
    renderAtt (Profile_Att_1 b) = (profile_byte,b)

instance RenderAttribute Att0 where
    renderAtt (Lang_Att_0 b) = (lang_byte,b)
    renderAtt (Dir_Att_0 b) = (dir_byte,b)
    renderAtt (Id_Att_0 b) = (id_byte,b)
    renderAtt (Xmlns_Att_0 b) = (xmlns_byte,b)

--renderAtts :: [Attributes] -> B.ByteString
sp_byte = s2b " "
eqq_byte = s2b "=\""
q_byte = s2b "\""
renderAtts [] = B.empty
renderAtts (at:[]) = B.concat [sp_byte, a, eqq_byte, b, q_byte]
   where (a,b) = renderAtt at
renderAtts at = B.concat (map (\(a,b)->B.concat [sp_byte, a, eqq_byte, b, q_byte]) (nubBy (\(a,b) (c,d)-> a==c) ats))
   where ats = map renderAtt at

data Ent0 = Head_0 [Att1]  [Ent1]  | Body_0 [Att12]  [Ent4] 
    deriving (Show)

data Ent1 = Title_1 [Att2]  [Ent2]  | Base_1 [Att3]  | Meta_1 [Att4]  | Link_1 [Att6]  | Style_1 [Att7]  [Ent2]  | Script_1 [Att9]  [Ent2]  | Object_1 [Att29]  [Ent3]  | Isindex_1 [Att54] 
    deriving (Show)

data Ent2 = PCDATA_2 [Att0] B.ByteString
    deriving (Show)

data Ent3 = Script_3 [Att9]  [Ent2]  | Noscript_3 [Att10]  [Ent4]  | Iframe_3 [Att11]  [Ent4]  | Noframes_3 [Att10]  [Ent4]  | Div_3 [Att13]  [Ent4]  | P_3 [Att13]  [Ent5]  | H1_3 [Att13]  [Ent5]  | H2_3 [Att13]  [Ent5]  | H3_3 [Att13]  [Ent5]  | H4_3 [Att13]  [Ent5]  | H5_3 [Att13]  [Ent5]  | H6_3 [Att13]  [Ent5]  | Ul_3 [Att14]  [Ent6]  | Ol_3 [Att15]  [Ent6]  | Menu_3 [Att16]  [Ent6]  | Dir_3 [Att16]  [Ent6]  | Dl_3 [Att16]  [Ent7]  | Address_3 [Att10]  [Ent8]  | Hr_3 [Att18]  | Pre_3 [Att19]  [Ent9]  | Blockquote_3 [Att20]  [Ent4]  | Center_3 [Att10]  [Ent4]  | Ins_3 [Att21]  [Ent4]  | Del_3 [Att21]  [Ent4]  | A_3 [Att22]  [Ent10]  | Span_3 [Att10]  [Ent5]  | Bdo_3 [Att10]  [Ent5]  | Br_3 [Att25]  | Em_3 [Att10]  [Ent5]  | Strong_3 [Att10]  [Ent5]  | Dfn_3 [Att10]  [Ent5]  | Code_3 [Att10]  [Ent5]  | Samp_3 [Att10]  [Ent5]  | Kbd_3 [Att10]  [Ent5]  | Var_3 [Att10]  [Ent5]  | Cite_3 [Att10]  [Ent5]  | Abbr_3 [Att10]  [Ent5]  | Acronym_3 [Att10]  [Ent5]  | Q_3 [Att20]  [Ent5]  | Sub_3 [Att10]  [Ent5]  | Sup_3 [Att10]  [Ent5]  | Tt_3 [Att10]  [Ent5]  | I_3 [Att10]  [Ent5]  | B_3 [Att10]  [Ent5]  | Big_3 [Att10]  [Ent5]  | Small_3 [Att10]  [Ent5]  | U_3 [Att10]  [Ent5]  | S_3 [Att10]  [Ent5]  | Strike_3 [Att10]  [Ent5]  | Basefont_3 [Att26]  | Font_3 [Att28]  [Ent5]  | Object_3 [Att29]  [Ent3]  | Param_3 [Att30]  | Applet_3 [Att32]  [Ent3]  | Img_3 [Att35]  | Map_3 [Att38]  [Ent66]  | Form_3 [Att41]  [Ent67]  | Label_3 [Att43]  [Ent113]  | Input_3 [Att44]  | Select_3 [Att45]  [Ent130]  | Textarea_3 [Att49]  [Ent2]  | Fieldset_3 [Att10]  [Ent132]  | Button_3 [Att53]  [Ent133]  | Isindex_3 [Att54]  | Table_3 [Att55]  [Ent134]  | PCDATA_3 [Att0] B.ByteString
    deriving (Show)

data Ent4 = Script_4 [Att9]  [Ent2]  | Noscript_4 [Att10]  [Ent4]  | Iframe_4 [Att11]  [Ent4]  | Noframes_4 [Att10]  [Ent4]  | Div_4 [Att13]  [Ent4]  | P_4 [Att13]  [Ent5]  | H1_4 [Att13]  [Ent5]  | H2_4 [Att13]  [Ent5]  | H3_4 [Att13]  [Ent5]  | H4_4 [Att13]  [Ent5]  | H5_4 [Att13]  [Ent5]  | H6_4 [Att13]  [Ent5]  | Ul_4 [Att14]  [Ent6]  | Ol_4 [Att15]  [Ent6]  | Menu_4 [Att16]  [Ent6]  | Dir_4 [Att16]  [Ent6]  | Dl_4 [Att16]  [Ent7]  | Address_4 [Att10]  [Ent8]  | Hr_4 [Att18]  | Pre_4 [Att19]  [Ent9]  | Blockquote_4 [Att20]  [Ent4]  | Center_4 [Att10]  [Ent4]  | Ins_4 [Att21]  [Ent4]  | Del_4 [Att21]  [Ent4]  | A_4 [Att22]  [Ent10]  | Span_4 [Att10]  [Ent5]  | Bdo_4 [Att10]  [Ent5]  | Br_4 [Att25]  | Em_4 [Att10]  [Ent5]  | Strong_4 [Att10]  [Ent5]  | Dfn_4 [Att10]  [Ent5]  | Code_4 [Att10]  [Ent5]  | Samp_4 [Att10]  [Ent5]  | Kbd_4 [Att10]  [Ent5]  | Var_4 [Att10]  [Ent5]  | Cite_4 [Att10]  [Ent5]  | Abbr_4 [Att10]  [Ent5]  | Acronym_4 [Att10]  [Ent5]  | Q_4 [Att20]  [Ent5]  | Sub_4 [Att10]  [Ent5]  | Sup_4 [Att10]  [Ent5]  | Tt_4 [Att10]  [Ent5]  | I_4 [Att10]  [Ent5]  | B_4 [Att10]  [Ent5]  | Big_4 [Att10]  [Ent5]  | Small_4 [Att10]  [Ent5]  | U_4 [Att10]  [Ent5]  | S_4 [Att10]  [Ent5]  | Strike_4 [Att10]  [Ent5]  | Basefont_4 [Att26]  | Font_4 [Att28]  [Ent5]  | Object_4 [Att29]  [Ent3]  | Applet_4 [Att32]  [Ent3]  | Img_4 [Att35]  | Map_4 [Att38]  [Ent66]  | Form_4 [Att41]  [Ent67]  | Label_4 [Att43]  [Ent113]  | Input_4 [Att44]  | Select_4 [Att45]  [Ent130]  | Textarea_4 [Att49]  [Ent2]  | Fieldset_4 [Att10]  [Ent132]  | Button_4 [Att53]  [Ent133]  | Isindex_4 [Att54]  | Table_4 [Att55]  [Ent134]  | PCDATA_4 [Att0] B.ByteString
    deriving (Show)

data Ent5 = Script_5 [Att9]  [Ent2]  | Iframe_5 [Att11]  [Ent4]  | Ins_5 [Att21]  [Ent4]  | Del_5 [Att21]  [Ent4]  | A_5 [Att22]  [Ent10]  | Span_5 [Att10]  [Ent5]  | Bdo_5 [Att10]  [Ent5]  | Br_5 [Att25]  | Em_5 [Att10]  [Ent5]  | Strong_5 [Att10]  [Ent5]  | Dfn_5 [Att10]  [Ent5]  | Code_5 [Att10]  [Ent5]  | Samp_5 [Att10]  [Ent5]  | Kbd_5 [Att10]  [Ent5]  | Var_5 [Att10]  [Ent5]  | Cite_5 [Att10]  [Ent5]  | Abbr_5 [Att10]  [Ent5]  | Acronym_5 [Att10]  [Ent5]  | Q_5 [Att20]  [Ent5]  | Sub_5 [Att10]  [Ent5]  | Sup_5 [Att10]  [Ent5]  | Tt_5 [Att10]  [Ent5]  | I_5 [Att10]  [Ent5]  | B_5 [Att10]  [Ent5]  | Big_5 [Att10]  [Ent5]  | Small_5 [Att10]  [Ent5]  | U_5 [Att10]  [Ent5]  | S_5 [Att10]  [Ent5]  | Strike_5 [Att10]  [Ent5]  | Basefont_5 [Att26]  | Font_5 [Att28]  [Ent5]  | Object_5 [Att29]  [Ent3]  | Applet_5 [Att32]  [Ent3]  | Img_5 [Att35]  | Map_5 [Att38]  [Ent66]  | Label_5 [Att43]  [Ent113]  | Input_5 [Att44]  | Select_5 [Att45]  [Ent130]  | Textarea_5 [Att49]  [Ent2]  | Button_5 [Att53]  [Ent133]  | PCDATA_5 [Att0] B.ByteString
    deriving (Show)

data Ent6 = Li_6 [Att17]  [Ent4] 
    deriving (Show)

data Ent7 = Dt_7 [Att10]  [Ent5]  | Dd_7 [Att10]  [Ent4] 
    deriving (Show)

data Ent8 = Script_8 [Att9]  [Ent2]  | Iframe_8 [Att11]  [Ent4]  | P_8 [Att13]  [Ent5]  | Ins_8 [Att21]  [Ent4]  | Del_8 [Att21]  [Ent4]  | A_8 [Att22]  [Ent10]  | Span_8 [Att10]  [Ent5]  | Bdo_8 [Att10]  [Ent5]  | Br_8 [Att25]  | Em_8 [Att10]  [Ent5]  | Strong_8 [Att10]  [Ent5]  | Dfn_8 [Att10]  [Ent5]  | Code_8 [Att10]  [Ent5]  | Samp_8 [Att10]  [Ent5]  | Kbd_8 [Att10]  [Ent5]  | Var_8 [Att10]  [Ent5]  | Cite_8 [Att10]  [Ent5]  | Abbr_8 [Att10]  [Ent5]  | Acronym_8 [Att10]  [Ent5]  | Q_8 [Att20]  [Ent5]  | Sub_8 [Att10]  [Ent5]  | Sup_8 [Att10]  [Ent5]  | Tt_8 [Att10]  [Ent5]  | I_8 [Att10]  [Ent5]  | B_8 [Att10]  [Ent5]  | Big_8 [Att10]  [Ent5]  | Small_8 [Att10]  [Ent5]  | U_8 [Att10]  [Ent5]  | S_8 [Att10]  [Ent5]  | Strike_8 [Att10]  [Ent5]  | Basefont_8 [Att26]  | Font_8 [Att28]  [Ent5]  | Object_8 [Att29]  [Ent3]  | Applet_8 [Att32]  [Ent3]  | Img_8 [Att35]  | Map_8 [Att38]  [Ent66]  | Label_8 [Att43]  [Ent113]  | Input_8 [Att44]  | Select_8 [Att45]  [Ent130]  | Textarea_8 [Att49]  [Ent2]  | Button_8 [Att53]  [Ent133]  | PCDATA_8 [Att0] B.ByteString
    deriving (Show)

data Ent9 = Script_9 [Att9]  [Ent2]  | Ins_9 [Att21]  [Ent4]  | Del_9 [Att21]  [Ent4]  | A_9 [Att22]  [Ent10]  | Span_9 [Att10]  [Ent5]  | Bdo_9 [Att10]  [Ent5]  | Br_9 [Att25]  | Em_9 [Att10]  [Ent5]  | Strong_9 [Att10]  [Ent5]  | Dfn_9 [Att10]  [Ent5]  | Code_9 [Att10]  [Ent5]  | Samp_9 [Att10]  [Ent5]  | Kbd_9 [Att10]  [Ent5]  | Var_9 [Att10]  [Ent5]  | Cite_9 [Att10]  [Ent5]  | Abbr_9 [Att10]  [Ent5]  | Acronym_9 [Att10]  [Ent5]  | Q_9 [Att20]  [Ent5]  | Tt_9 [Att10]  [Ent5]  | I_9 [Att10]  [Ent5]  | B_9 [Att10]  [Ent5]  | U_9 [Att10]  [Ent5]  | S_9 [Att10]  [Ent5]  | Strike_9 [Att10]  [Ent5]  | Label_9 [Att43]  [Ent113]  | Input_9 [Att44]  | Select_9 [Att45]  [Ent130]  | Textarea_9 [Att49]  [Ent2]  | Button_9 [Att53]  [Ent133]  | PCDATA_9 [Att0] B.ByteString
    deriving (Show)

data Ent10 = Script_10 [Att9]  [Ent11]  | Iframe_10 [Att11]  [Ent12]  | Ins_10 [Att21]  [Ent12]  | Del_10 [Att21]  [Ent12]  | Span_10 [Att10]  [Ent10]  | Bdo_10 [Att10]  [Ent10]  | Br_10 [Att25]  | Em_10 [Att10]  [Ent10]  | Strong_10 [Att10]  [Ent10]  | Dfn_10 [Att10]  [Ent10]  | Code_10 [Att10]  [Ent10]  | Samp_10 [Att10]  [Ent10]  | Kbd_10 [Att10]  [Ent10]  | Var_10 [Att10]  [Ent10]  | Cite_10 [Att10]  [Ent10]  | Abbr_10 [Att10]  [Ent10]  | Acronym_10 [Att10]  [Ent10]  | Q_10 [Att20]  [Ent10]  | Sub_10 [Att10]  [Ent10]  | Sup_10 [Att10]  [Ent10]  | Tt_10 [Att10]  [Ent10]  | I_10 [Att10]  [Ent10]  | B_10 [Att10]  [Ent10]  | Big_10 [Att10]  [Ent10]  | Small_10 [Att10]  [Ent10]  | U_10 [Att10]  [Ent10]  | S_10 [Att10]  [Ent10]  | Strike_10 [Att10]  [Ent10]  | Basefont_10 [Att26]  | Font_10 [Att28]  [Ent10]  | Object_10 [Att29]  [Ent33]  | Applet_10 [Att32]  [Ent33]  | Img_10 [Att35]  | Map_10 [Att38]  [Ent34]  | Label_10 [Att43]  [Ent35]  | Input_10 [Att44]  | Select_10 [Att45]  [Ent63]  | Textarea_10 [Att49]  [Ent11]  | Button_10 [Att53]  [Ent65]  | PCDATA_10 [Att0] B.ByteString
    deriving (Show)

data Ent11 = PCDATA_11 [Att0] B.ByteString
    deriving (Show)

data Ent12 = Script_12 [Att9]  [Ent11]  | Noscript_12 [Att10]  [Ent12]  | Iframe_12 [Att11]  [Ent12]  | Noframes_12 [Att10]  [Ent12]  | Div_12 [Att13]  [Ent12]  | P_12 [Att13]  [Ent10]  | H1_12 [Att13]  [Ent10]  | H2_12 [Att13]  [Ent10]  | H3_12 [Att13]  [Ent10]  | H4_12 [Att13]  [Ent10]  | H5_12 [Att13]  [Ent10]  | H6_12 [Att13]  [Ent10]  | Ul_12 [Att14]  [Ent13]  | Ol_12 [Att15]  [Ent13]  | Menu_12 [Att16]  [Ent13]  | Dir_12 [Att16]  [Ent13]  | Dl_12 [Att16]  [Ent14]  | Address_12 [Att10]  [Ent15]  | Hr_12 [Att18]  | Pre_12 [Att19]  [Ent16]  | Blockquote_12 [Att20]  [Ent12]  | Center_12 [Att10]  [Ent12]  | Ins_12 [Att21]  [Ent12]  | Del_12 [Att21]  [Ent12]  | Span_12 [Att10]  [Ent10]  | Bdo_12 [Att10]  [Ent10]  | Br_12 [Att25]  | Em_12 [Att10]  [Ent10]  | Strong_12 [Att10]  [Ent10]  | Dfn_12 [Att10]  [Ent10]  | Code_12 [Att10]  [Ent10]  | Samp_12 [Att10]  [Ent10]  | Kbd_12 [Att10]  [Ent10]  | Var_12 [Att10]  [Ent10]  | Cite_12 [Att10]  [Ent10]  | Abbr_12 [Att10]  [Ent10]  | Acronym_12 [Att10]  [Ent10]  | Q_12 [Att20]  [Ent10]  | Sub_12 [Att10]  [Ent10]  | Sup_12 [Att10]  [Ent10]  | Tt_12 [Att10]  [Ent10]  | I_12 [Att10]  [Ent10]  | B_12 [Att10]  [Ent10]  | Big_12 [Att10]  [Ent10]  | Small_12 [Att10]  [Ent10]  | U_12 [Att10]  [Ent10]  | S_12 [Att10]  [Ent10]  | Strike_12 [Att10]  [Ent10]  | Basefont_12 [Att26]  | Font_12 [Att28]  [Ent10]  | Object_12 [Att29]  [Ent33]  | Applet_12 [Att32]  [Ent33]  | Img_12 [Att35]  | Map_12 [Att38]  [Ent34]  | Form_12 [Att41]  [Ent17]  | Label_12 [Att43]  [Ent35]  | Input_12 [Att44]  | Select_12 [Att45]  [Ent63]  | Textarea_12 [Att49]  [Ent11]  | Fieldset_12 [Att10]  [Ent28]  | Button_12 [Att53]  [Ent65]  | Isindex_12 [Att54]  | Table_12 [Att55]  [Ent29]  | PCDATA_12 [Att0] B.ByteString
    deriving (Show)

data Ent13 = Li_13 [Att17]  [Ent12] 
    deriving (Show)

data Ent14 = Dt_14 [Att10]  [Ent10]  | Dd_14 [Att10]  [Ent12] 
    deriving (Show)

data Ent15 = Script_15 [Att9]  [Ent11]  | Iframe_15 [Att11]  [Ent12]  | P_15 [Att13]  [Ent10]  | Ins_15 [Att21]  [Ent12]  | Del_15 [Att21]  [Ent12]  | Span_15 [Att10]  [Ent10]  | Bdo_15 [Att10]  [Ent10]  | Br_15 [Att25]  | Em_15 [Att10]  [Ent10]  | Strong_15 [Att10]  [Ent10]  | Dfn_15 [Att10]  [Ent10]  | Code_15 [Att10]  [Ent10]  | Samp_15 [Att10]  [Ent10]  | Kbd_15 [Att10]  [Ent10]  | Var_15 [Att10]  [Ent10]  | Cite_15 [Att10]  [Ent10]  | Abbr_15 [Att10]  [Ent10]  | Acronym_15 [Att10]  [Ent10]  | Q_15 [Att20]  [Ent10]  | Sub_15 [Att10]  [Ent10]  | Sup_15 [Att10]  [Ent10]  | Tt_15 [Att10]  [Ent10]  | I_15 [Att10]  [Ent10]  | B_15 [Att10]  [Ent10]  | Big_15 [Att10]  [Ent10]  | Small_15 [Att10]  [Ent10]  | U_15 [Att10]  [Ent10]  | S_15 [Att10]  [Ent10]  | Strike_15 [Att10]  [Ent10]  | Basefont_15 [Att26]  | Font_15 [Att28]  [Ent10]  | Object_15 [Att29]  [Ent33]  | Applet_15 [Att32]  [Ent33]  | Img_15 [Att35]  | Map_15 [Att38]  [Ent34]  | Label_15 [Att43]  [Ent35]  | Input_15 [Att44]  | Select_15 [Att45]  [Ent63]  | Textarea_15 [Att49]  [Ent11]  | Button_15 [Att53]  [Ent65]  | PCDATA_15 [Att0] B.ByteString
    deriving (Show)

data Ent16 = Script_16 [Att9]  [Ent11]  | Ins_16 [Att21]  [Ent12]  | Del_16 [Att21]  [Ent12]  | Span_16 [Att10]  [Ent10]  | Bdo_16 [Att10]  [Ent10]  | Br_16 [Att25]  | Em_16 [Att10]  [Ent10]  | Strong_16 [Att10]  [Ent10]  | Dfn_16 [Att10]  [Ent10]  | Code_16 [Att10]  [Ent10]  | Samp_16 [Att10]  [Ent10]  | Kbd_16 [Att10]  [Ent10]  | Var_16 [Att10]  [Ent10]  | Cite_16 [Att10]  [Ent10]  | Abbr_16 [Att10]  [Ent10]  | Acronym_16 [Att10]  [Ent10]  | Q_16 [Att20]  [Ent10]  | Tt_16 [Att10]  [Ent10]  | I_16 [Att10]  [Ent10]  | B_16 [Att10]  [Ent10]  | U_16 [Att10]  [Ent10]  | S_16 [Att10]  [Ent10]  | Strike_16 [Att10]  [Ent10]  | Label_16 [Att43]  [Ent35]  | Input_16 [Att44]  | Select_16 [Att45]  [Ent63]  | Textarea_16 [Att49]  [Ent11]  | Button_16 [Att53]  [Ent65]  | PCDATA_16 [Att0] B.ByteString
    deriving (Show)

data Ent17 = Script_17 [Att9]  [Ent74]  | Noscript_17 [Att10]  [Ent17]  | Iframe_17 [Att11]  [Ent17]  | Noframes_17 [Att10]  [Ent17]  | Div_17 [Att13]  [Ent17]  | P_17 [Att13]  [Ent18]  | H1_17 [Att13]  [Ent18]  | H2_17 [Att13]  [Ent18]  | H3_17 [Att13]  [Ent18]  | H4_17 [Att13]  [Ent18]  | H5_17 [Att13]  [Ent18]  | H6_17 [Att13]  [Ent18]  | Ul_17 [Att14]  [Ent19]  | Ol_17 [Att15]  [Ent19]  | Menu_17 [Att16]  [Ent19]  | Dir_17 [Att16]  [Ent19]  | Dl_17 [Att16]  [Ent20]  | Address_17 [Att10]  [Ent21]  | Hr_17 [Att18]  | Pre_17 [Att19]  [Ent22]  | Blockquote_17 [Att20]  [Ent17]  | Center_17 [Att10]  [Ent17]  | Ins_17 [Att21]  [Ent17]  | Del_17 [Att21]  [Ent17]  | Span_17 [Att10]  [Ent18]  | Bdo_17 [Att10]  [Ent18]  | Br_17 [Att25]  | Em_17 [Att10]  [Ent18]  | Strong_17 [Att10]  [Ent18]  | Dfn_17 [Att10]  [Ent18]  | Code_17 [Att10]  [Ent18]  | Samp_17 [Att10]  [Ent18]  | Kbd_17 [Att10]  [Ent18]  | Var_17 [Att10]  [Ent18]  | Cite_17 [Att10]  [Ent18]  | Abbr_17 [Att10]  [Ent18]  | Acronym_17 [Att10]  [Ent18]  | Q_17 [Att20]  [Ent18]  | Sub_17 [Att10]  [Ent18]  | Sup_17 [Att10]  [Ent18]  | Tt_17 [Att10]  [Ent18]  | I_17 [Att10]  [Ent18]  | B_17 [Att10]  [Ent18]  | Big_17 [Att10]  [Ent18]  | Small_17 [Att10]  [Ent18]  | U_17 [Att10]  [Ent18]  | S_17 [Att10]  [Ent18]  | Strike_17 [Att10]  [Ent18]  | Basefont_17 [Att26]  | Font_17 [Att28]  [Ent18]  | Object_17 [Att29]  [Ent75]  | Applet_17 [Att32]  [Ent75]  | Img_17 [Att35]  | Map_17 [Att38]  [Ent76]  | Label_17 [Att43]  [Ent43]  | Input_17 [Att44]  | Select_17 [Att45]  [Ent83]  | Textarea_17 [Att49]  [Ent74]  | Fieldset_17 [Att10]  [Ent23]  | Button_17 [Att53]  [Ent85]  | Isindex_17 [Att54]  | Table_17 [Att55]  [Ent24]  | PCDATA_17 [Att0] B.ByteString
    deriving (Show)

data Ent18 = Script_18 [Att9]  [Ent74]  | Iframe_18 [Att11]  [Ent17]  | Ins_18 [Att21]  [Ent17]  | Del_18 [Att21]  [Ent17]  | Span_18 [Att10]  [Ent18]  | Bdo_18 [Att10]  [Ent18]  | Br_18 [Att25]  | Em_18 [Att10]  [Ent18]  | Strong_18 [Att10]  [Ent18]  | Dfn_18 [Att10]  [Ent18]  | Code_18 [Att10]  [Ent18]  | Samp_18 [Att10]  [Ent18]  | Kbd_18 [Att10]  [Ent18]  | Var_18 [Att10]  [Ent18]  | Cite_18 [Att10]  [Ent18]  | Abbr_18 [Att10]  [Ent18]  | Acronym_18 [Att10]  [Ent18]  | Q_18 [Att20]  [Ent18]  | Sub_18 [Att10]  [Ent18]  | Sup_18 [Att10]  [Ent18]  | Tt_18 [Att10]  [Ent18]  | I_18 [Att10]  [Ent18]  | B_18 [Att10]  [Ent18]  | Big_18 [Att10]  [Ent18]  | Small_18 [Att10]  [Ent18]  | U_18 [Att10]  [Ent18]  | S_18 [Att10]  [Ent18]  | Strike_18 [Att10]  [Ent18]  | Basefont_18 [Att26]  | Font_18 [Att28]  [Ent18]  | Object_18 [Att29]  [Ent75]  | Applet_18 [Att32]  [Ent75]  | Img_18 [Att35]  | Map_18 [Att38]  [Ent76]  | Label_18 [Att43]  [Ent43]  | Input_18 [Att44]  | Select_18 [Att45]  [Ent83]  | Textarea_18 [Att49]  [Ent74]  | Button_18 [Att53]  [Ent85]  | PCDATA_18 [Att0] B.ByteString
    deriving (Show)

data Ent19 = Li_19 [Att17]  [Ent17] 
    deriving (Show)

data Ent20 = Dt_20 [Att10]  [Ent18]  | Dd_20 [Att10]  [Ent17] 
    deriving (Show)

data Ent21 = Script_21 [Att9]  [Ent74]  | Iframe_21 [Att11]  [Ent17]  | P_21 [Att13]  [Ent18]  | Ins_21 [Att21]  [Ent17]  | Del_21 [Att21]  [Ent17]  | Span_21 [Att10]  [Ent18]  | Bdo_21 [Att10]  [Ent18]  | Br_21 [Att25]  | Em_21 [Att10]  [Ent18]  | Strong_21 [Att10]  [Ent18]  | Dfn_21 [Att10]  [Ent18]  | Code_21 [Att10]  [Ent18]  | Samp_21 [Att10]  [Ent18]  | Kbd_21 [Att10]  [Ent18]  | Var_21 [Att10]  [Ent18]  | Cite_21 [Att10]  [Ent18]  | Abbr_21 [Att10]  [Ent18]  | Acronym_21 [Att10]  [Ent18]  | Q_21 [Att20]  [Ent18]  | Sub_21 [Att10]  [Ent18]  | Sup_21 [Att10]  [Ent18]  | Tt_21 [Att10]  [Ent18]  | I_21 [Att10]  [Ent18]  | B_21 [Att10]  [Ent18]  | Big_21 [Att10]  [Ent18]  | Small_21 [Att10]  [Ent18]  | U_21 [Att10]  [Ent18]  | S_21 [Att10]  [Ent18]  | Strike_21 [Att10]  [Ent18]  | Basefont_21 [Att26]  | Font_21 [Att28]  [Ent18]  | Object_21 [Att29]  [Ent75]  | Applet_21 [Att32]  [Ent75]  | Img_21 [Att35]  | Map_21 [Att38]  [Ent76]  | Label_21 [Att43]  [Ent43]  | Input_21 [Att44]  | Select_21 [Att45]  [Ent83]  | Textarea_21 [Att49]  [Ent74]  | Button_21 [Att53]  [Ent85]  | PCDATA_21 [Att0] B.ByteString
    deriving (Show)

data Ent22 = Script_22 [Att9]  [Ent74]  | Ins_22 [Att21]  [Ent17]  | Del_22 [Att21]  [Ent17]  | Span_22 [Att10]  [Ent18]  | Bdo_22 [Att10]  [Ent18]  | Br_22 [Att25]  | Em_22 [Att10]  [Ent18]  | Strong_22 [Att10]  [Ent18]  | Dfn_22 [Att10]  [Ent18]  | Code_22 [Att10]  [Ent18]  | Samp_22 [Att10]  [Ent18]  | Kbd_22 [Att10]  [Ent18]  | Var_22 [Att10]  [Ent18]  | Cite_22 [Att10]  [Ent18]  | Abbr_22 [Att10]  [Ent18]  | Acronym_22 [Att10]  [Ent18]  | Q_22 [Att20]  [Ent18]  | Tt_22 [Att10]  [Ent18]  | I_22 [Att10]  [Ent18]  | B_22 [Att10]  [Ent18]  | U_22 [Att10]  [Ent18]  | S_22 [Att10]  [Ent18]  | Strike_22 [Att10]  [Ent18]  | Label_22 [Att43]  [Ent43]  | Input_22 [Att44]  | Select_22 [Att45]  [Ent83]  | Textarea_22 [Att49]  [Ent74]  | Button_22 [Att53]  [Ent85]  | PCDATA_22 [Att0] B.ByteString
    deriving (Show)

data Ent23 = Script_23 [Att9]  [Ent74]  | Noscript_23 [Att10]  [Ent17]  | Iframe_23 [Att11]  [Ent17]  | Noframes_23 [Att10]  [Ent17]  | Div_23 [Att13]  [Ent17]  | P_23 [Att13]  [Ent18]  | H1_23 [Att13]  [Ent18]  | H2_23 [Att13]  [Ent18]  | H3_23 [Att13]  [Ent18]  | H4_23 [Att13]  [Ent18]  | H5_23 [Att13]  [Ent18]  | H6_23 [Att13]  [Ent18]  | Ul_23 [Att14]  [Ent19]  | Ol_23 [Att15]  [Ent19]  | Menu_23 [Att16]  [Ent19]  | Dir_23 [Att16]  [Ent19]  | Dl_23 [Att16]  [Ent20]  | Address_23 [Att10]  [Ent21]  | Hr_23 [Att18]  | Pre_23 [Att19]  [Ent22]  | Blockquote_23 [Att20]  [Ent17]  | Center_23 [Att10]  [Ent17]  | Ins_23 [Att21]  [Ent17]  | Del_23 [Att21]  [Ent17]  | Span_23 [Att10]  [Ent18]  | Bdo_23 [Att10]  [Ent18]  | Br_23 [Att25]  | Em_23 [Att10]  [Ent18]  | Strong_23 [Att10]  [Ent18]  | Dfn_23 [Att10]  [Ent18]  | Code_23 [Att10]  [Ent18]  | Samp_23 [Att10]  [Ent18]  | Kbd_23 [Att10]  [Ent18]  | Var_23 [Att10]  [Ent18]  | Cite_23 [Att10]  [Ent18]  | Abbr_23 [Att10]  [Ent18]  | Acronym_23 [Att10]  [Ent18]  | Q_23 [Att20]  [Ent18]  | Sub_23 [Att10]  [Ent18]  | Sup_23 [Att10]  [Ent18]  | Tt_23 [Att10]  [Ent18]  | I_23 [Att10]  [Ent18]  | B_23 [Att10]  [Ent18]  | Big_23 [Att10]  [Ent18]  | Small_23 [Att10]  [Ent18]  | U_23 [Att10]  [Ent18]  | S_23 [Att10]  [Ent18]  | Strike_23 [Att10]  [Ent18]  | Basefont_23 [Att26]  | Font_23 [Att28]  [Ent18]  | Object_23 [Att29]  [Ent75]  | Applet_23 [Att32]  [Ent75]  | Img_23 [Att35]  | Map_23 [Att38]  [Ent76]  | Label_23 [Att43]  [Ent43]  | Input_23 [Att44]  | Select_23 [Att45]  [Ent83]  | Textarea_23 [Att49]  [Ent74]  | Fieldset_23 [Att10]  [Ent23]  | Legend_23 [Att52]  [Ent18]  | Button_23 [Att53]  [Ent85]  | Isindex_23 [Att54]  | Table_23 [Att55]  [Ent24]  | PCDATA_23 [Att0] B.ByteString
    deriving (Show)

data Ent24 = Caption_24 [Att13]  [Ent18]  | Thead_24 [Att56]  [Ent25]  | Tfoot_24 [Att56]  [Ent25]  | Tbody_24 [Att56]  [Ent25]  | Colgroup_24 [Att57]  [Ent26]  | Col_24 [Att57]  | Tr_24 [Att58]  [Ent27] 
    deriving (Show)

data Ent25 = Tr_25 [Att58]  [Ent27] 
    deriving (Show)

data Ent26 = Col_26 [Att57] 
    deriving (Show)

data Ent27 = Th_27 [Att59]  [Ent17]  | Td_27 [Att59]  [Ent17] 
    deriving (Show)

data Ent28 = Script_28 [Att9]  [Ent11]  | Noscript_28 [Att10]  [Ent12]  | Iframe_28 [Att11]  [Ent12]  | Noframes_28 [Att10]  [Ent12]  | Div_28 [Att13]  [Ent12]  | P_28 [Att13]  [Ent10]  | H1_28 [Att13]  [Ent10]  | H2_28 [Att13]  [Ent10]  | H3_28 [Att13]  [Ent10]  | H4_28 [Att13]  [Ent10]  | H5_28 [Att13]  [Ent10]  | H6_28 [Att13]  [Ent10]  | Ul_28 [Att14]  [Ent13]  | Ol_28 [Att15]  [Ent13]  | Menu_28 [Att16]  [Ent13]  | Dir_28 [Att16]  [Ent13]  | Dl_28 [Att16]  [Ent14]  | Address_28 [Att10]  [Ent15]  | Hr_28 [Att18]  | Pre_28 [Att19]  [Ent16]  | Blockquote_28 [Att20]  [Ent12]  | Center_28 [Att10]  [Ent12]  | Ins_28 [Att21]  [Ent12]  | Del_28 [Att21]  [Ent12]  | Span_28 [Att10]  [Ent10]  | Bdo_28 [Att10]  [Ent10]  | Br_28 [Att25]  | Em_28 [Att10]  [Ent10]  | Strong_28 [Att10]  [Ent10]  | Dfn_28 [Att10]  [Ent10]  | Code_28 [Att10]  [Ent10]  | Samp_28 [Att10]  [Ent10]  | Kbd_28 [Att10]  [Ent10]  | Var_28 [Att10]  [Ent10]  | Cite_28 [Att10]  [Ent10]  | Abbr_28 [Att10]  [Ent10]  | Acronym_28 [Att10]  [Ent10]  | Q_28 [Att20]  [Ent10]  | Sub_28 [Att10]  [Ent10]  | Sup_28 [Att10]  [Ent10]  | Tt_28 [Att10]  [Ent10]  | I_28 [Att10]  [Ent10]  | B_28 [Att10]  [Ent10]  | Big_28 [Att10]  [Ent10]  | Small_28 [Att10]  [Ent10]  | U_28 [Att10]  [Ent10]  | S_28 [Att10]  [Ent10]  | Strike_28 [Att10]  [Ent10]  | Basefont_28 [Att26]  | Font_28 [Att28]  [Ent10]  | Object_28 [Att29]  [Ent33]  | Applet_28 [Att32]  [Ent33]  | Img_28 [Att35]  | Map_28 [Att38]  [Ent34]  | Form_28 [Att41]  [Ent17]  | Label_28 [Att43]  [Ent35]  | Input_28 [Att44]  | Select_28 [Att45]  [Ent63]  | Textarea_28 [Att49]  [Ent11]  | Fieldset_28 [Att10]  [Ent28]  | Legend_28 [Att52]  [Ent10]  | Button_28 [Att53]  [Ent65]  | Isindex_28 [Att54]  | Table_28 [Att55]  [Ent29]  | PCDATA_28 [Att0] B.ByteString
    deriving (Show)

data Ent29 = Caption_29 [Att13]  [Ent10]  | Thead_29 [Att56]  [Ent30]  | Tfoot_29 [Att56]  [Ent30]  | Tbody_29 [Att56]  [Ent30]  | Colgroup_29 [Att57]  [Ent31]  | Col_29 [Att57]  | Tr_29 [Att58]  [Ent32] 
    deriving (Show)

data Ent30 = Tr_30 [Att58]  [Ent32] 
    deriving (Show)

data Ent31 = Col_31 [Att57] 
    deriving (Show)

data Ent32 = Th_32 [Att59]  [Ent12]  | Td_32 [Att59]  [Ent12] 
    deriving (Show)

data Ent33 = Script_33 [Att9]  [Ent11]  | Noscript_33 [Att10]  [Ent12]  | Iframe_33 [Att11]  [Ent12]  | Noframes_33 [Att10]  [Ent12]  | Div_33 [Att13]  [Ent12]  | P_33 [Att13]  [Ent10]  | H1_33 [Att13]  [Ent10]  | H2_33 [Att13]  [Ent10]  | H3_33 [Att13]  [Ent10]  | H4_33 [Att13]  [Ent10]  | H5_33 [Att13]  [Ent10]  | H6_33 [Att13]  [Ent10]  | Ul_33 [Att14]  [Ent13]  | Ol_33 [Att15]  [Ent13]  | Menu_33 [Att16]  [Ent13]  | Dir_33 [Att16]  [Ent13]  | Dl_33 [Att16]  [Ent14]  | Address_33 [Att10]  [Ent15]  | Hr_33 [Att18]  | Pre_33 [Att19]  [Ent16]  | Blockquote_33 [Att20]  [Ent12]  | Center_33 [Att10]  [Ent12]  | Ins_33 [Att21]  [Ent12]  | Del_33 [Att21]  [Ent12]  | Span_33 [Att10]  [Ent10]  | Bdo_33 [Att10]  [Ent10]  | Br_33 [Att25]  | Em_33 [Att10]  [Ent10]  | Strong_33 [Att10]  [Ent10]  | Dfn_33 [Att10]  [Ent10]  | Code_33 [Att10]  [Ent10]  | Samp_33 [Att10]  [Ent10]  | Kbd_33 [Att10]  [Ent10]  | Var_33 [Att10]  [Ent10]  | Cite_33 [Att10]  [Ent10]  | Abbr_33 [Att10]  [Ent10]  | Acronym_33 [Att10]  [Ent10]  | Q_33 [Att20]  [Ent10]  | Sub_33 [Att10]  [Ent10]  | Sup_33 [Att10]  [Ent10]  | Tt_33 [Att10]  [Ent10]  | I_33 [Att10]  [Ent10]  | B_33 [Att10]  [Ent10]  | Big_33 [Att10]  [Ent10]  | Small_33 [Att10]  [Ent10]  | U_33 [Att10]  [Ent10]  | S_33 [Att10]  [Ent10]  | Strike_33 [Att10]  [Ent10]  | Basefont_33 [Att26]  | Font_33 [Att28]  [Ent10]  | Object_33 [Att29]  [Ent33]  | Param_33 [Att30]  | Applet_33 [Att32]  [Ent33]  | Img_33 [Att35]  | Map_33 [Att38]  [Ent34]  | Form_33 [Att41]  [Ent17]  | Label_33 [Att43]  [Ent35]  | Input_33 [Att44]  | Select_33 [Att45]  [Ent63]  | Textarea_33 [Att49]  [Ent11]  | Fieldset_33 [Att10]  [Ent28]  | Button_33 [Att53]  [Ent65]  | Isindex_33 [Att54]  | Table_33 [Att55]  [Ent29]  | PCDATA_33 [Att0] B.ByteString
    deriving (Show)

data Ent34 = Script_34 [Att9]  [Ent11]  | Noscript_34 [Att10]  [Ent12]  | Noframes_34 [Att10]  [Ent12]  | Div_34 [Att13]  [Ent12]  | P_34 [Att13]  [Ent10]  | H1_34 [Att13]  [Ent10]  | H2_34 [Att13]  [Ent10]  | H3_34 [Att13]  [Ent10]  | H4_34 [Att13]  [Ent10]  | H5_34 [Att13]  [Ent10]  | H6_34 [Att13]  [Ent10]  | Ul_34 [Att14]  [Ent13]  | Ol_34 [Att15]  [Ent13]  | Menu_34 [Att16]  [Ent13]  | Dir_34 [Att16]  [Ent13]  | Dl_34 [Att16]  [Ent14]  | Address_34 [Att10]  [Ent15]  | Hr_34 [Att18]  | Pre_34 [Att19]  [Ent16]  | Blockquote_34 [Att20]  [Ent12]  | Center_34 [Att10]  [Ent12]  | Ins_34 [Att21]  [Ent12]  | Del_34 [Att21]  [Ent12]  | Area_34 [Att40]  | Form_34 [Att41]  [Ent17]  | Fieldset_34 [Att10]  [Ent28]  | Isindex_34 [Att54]  | Table_34 [Att55]  [Ent29] 
    deriving (Show)

data Ent35 = Script_35 [Att9]  [Ent36]  | Iframe_35 [Att11]  [Ent37]  | Ins_35 [Att21]  [Ent37]  | Del_35 [Att21]  [Ent37]  | Span_35 [Att10]  [Ent35]  | Bdo_35 [Att10]  [Ent35]  | Br_35 [Att25]  | Em_35 [Att10]  [Ent35]  | Strong_35 [Att10]  [Ent35]  | Dfn_35 [Att10]  [Ent35]  | Code_35 [Att10]  [Ent35]  | Samp_35 [Att10]  [Ent35]  | Kbd_35 [Att10]  [Ent35]  | Var_35 [Att10]  [Ent35]  | Cite_35 [Att10]  [Ent35]  | Abbr_35 [Att10]  [Ent35]  | Acronym_35 [Att10]  [Ent35]  | Q_35 [Att20]  [Ent35]  | Sub_35 [Att10]  [Ent35]  | Sup_35 [Att10]  [Ent35]  | Tt_35 [Att10]  [Ent35]  | I_35 [Att10]  [Ent35]  | B_35 [Att10]  [Ent35]  | Big_35 [Att10]  [Ent35]  | Small_35 [Att10]  [Ent35]  | U_35 [Att10]  [Ent35]  | S_35 [Att10]  [Ent35]  | Strike_35 [Att10]  [Ent35]  | Basefont_35 [Att26]  | Font_35 [Att28]  [Ent35]  | Object_35 [Att29]  [Ent58]  | Applet_35 [Att32]  [Ent58]  | Img_35 [Att35]  | Map_35 [Att38]  [Ent59]  | Input_35 [Att44]  | Select_35 [Att45]  [Ent60]  | Textarea_35 [Att49]  [Ent36]  | Button_35 [Att53]  [Ent62]  | PCDATA_35 [Att0] B.ByteString
    deriving (Show)

data Ent36 = PCDATA_36 [Att0] B.ByteString
    deriving (Show)

data Ent37 = Script_37 [Att9]  [Ent36]  | Noscript_37 [Att10]  [Ent37]  | Iframe_37 [Att11]  [Ent37]  | Noframes_37 [Att10]  [Ent37]  | Div_37 [Att13]  [Ent37]  | P_37 [Att13]  [Ent35]  | H1_37 [Att13]  [Ent35]  | H2_37 [Att13]  [Ent35]  | H3_37 [Att13]  [Ent35]  | H4_37 [Att13]  [Ent35]  | H5_37 [Att13]  [Ent35]  | H6_37 [Att13]  [Ent35]  | Ul_37 [Att14]  [Ent38]  | Ol_37 [Att15]  [Ent38]  | Menu_37 [Att16]  [Ent38]  | Dir_37 [Att16]  [Ent38]  | Dl_37 [Att16]  [Ent39]  | Address_37 [Att10]  [Ent40]  | Hr_37 [Att18]  | Pre_37 [Att19]  [Ent41]  | Blockquote_37 [Att20]  [Ent37]  | Center_37 [Att10]  [Ent37]  | Ins_37 [Att21]  [Ent37]  | Del_37 [Att21]  [Ent37]  | Span_37 [Att10]  [Ent35]  | Bdo_37 [Att10]  [Ent35]  | Br_37 [Att25]  | Em_37 [Att10]  [Ent35]  | Strong_37 [Att10]  [Ent35]  | Dfn_37 [Att10]  [Ent35]  | Code_37 [Att10]  [Ent35]  | Samp_37 [Att10]  [Ent35]  | Kbd_37 [Att10]  [Ent35]  | Var_37 [Att10]  [Ent35]  | Cite_37 [Att10]  [Ent35]  | Abbr_37 [Att10]  [Ent35]  | Acronym_37 [Att10]  [Ent35]  | Q_37 [Att20]  [Ent35]  | Sub_37 [Att10]  [Ent35]  | Sup_37 [Att10]  [Ent35]  | Tt_37 [Att10]  [Ent35]  | I_37 [Att10]  [Ent35]  | B_37 [Att10]  [Ent35]  | Big_37 [Att10]  [Ent35]  | Small_37 [Att10]  [Ent35]  | U_37 [Att10]  [Ent35]  | S_37 [Att10]  [Ent35]  | Strike_37 [Att10]  [Ent35]  | Basefont_37 [Att26]  | Font_37 [Att28]  [Ent35]  | Object_37 [Att29]  [Ent58]  | Applet_37 [Att32]  [Ent58]  | Img_37 [Att35]  | Map_37 [Att38]  [Ent59]  | Form_37 [Att41]  [Ent42]  | Input_37 [Att44]  | Select_37 [Att45]  [Ent60]  | Textarea_37 [Att49]  [Ent36]  | Fieldset_37 [Att10]  [Ent53]  | Button_37 [Att53]  [Ent62]  | Isindex_37 [Att54]  | Table_37 [Att55]  [Ent54]  | PCDATA_37 [Att0] B.ByteString
    deriving (Show)

data Ent38 = Li_38 [Att17]  [Ent37] 
    deriving (Show)

data Ent39 = Dt_39 [Att10]  [Ent35]  | Dd_39 [Att10]  [Ent37] 
    deriving (Show)

data Ent40 = Script_40 [Att9]  [Ent36]  | Iframe_40 [Att11]  [Ent37]  | P_40 [Att13]  [Ent35]  | Ins_40 [Att21]  [Ent37]  | Del_40 [Att21]  [Ent37]  | Span_40 [Att10]  [Ent35]  | Bdo_40 [Att10]  [Ent35]  | Br_40 [Att25]  | Em_40 [Att10]  [Ent35]  | Strong_40 [Att10]  [Ent35]  | Dfn_40 [Att10]  [Ent35]  | Code_40 [Att10]  [Ent35]  | Samp_40 [Att10]  [Ent35]  | Kbd_40 [Att10]  [Ent35]  | Var_40 [Att10]  [Ent35]  | Cite_40 [Att10]  [Ent35]  | Abbr_40 [Att10]  [Ent35]  | Acronym_40 [Att10]  [Ent35]  | Q_40 [Att20]  [Ent35]  | Sub_40 [Att10]  [Ent35]  | Sup_40 [Att10]  [Ent35]  | Tt_40 [Att10]  [Ent35]  | I_40 [Att10]  [Ent35]  | B_40 [Att10]  [Ent35]  | Big_40 [Att10]  [Ent35]  | Small_40 [Att10]  [Ent35]  | U_40 [Att10]  [Ent35]  | S_40 [Att10]  [Ent35]  | Strike_40 [Att10]  [Ent35]  | Basefont_40 [Att26]  | Font_40 [Att28]  [Ent35]  | Object_40 [Att29]  [Ent58]  | Applet_40 [Att32]  [Ent58]  | Img_40 [Att35]  | Map_40 [Att38]  [Ent59]  | Input_40 [Att44]  | Select_40 [Att45]  [Ent60]  | Textarea_40 [Att49]  [Ent36]  | Button_40 [Att53]  [Ent62]  | PCDATA_40 [Att0] B.ByteString
    deriving (Show)

data Ent41 = Script_41 [Att9]  [Ent36]  | Ins_41 [Att21]  [Ent37]  | Del_41 [Att21]  [Ent37]  | Span_41 [Att10]  [Ent35]  | Bdo_41 [Att10]  [Ent35]  | Br_41 [Att25]  | Em_41 [Att10]  [Ent35]  | Strong_41 [Att10]  [Ent35]  | Dfn_41 [Att10]  [Ent35]  | Code_41 [Att10]  [Ent35]  | Samp_41 [Att10]  [Ent35]  | Kbd_41 [Att10]  [Ent35]  | Var_41 [Att10]  [Ent35]  | Cite_41 [Att10]  [Ent35]  | Abbr_41 [Att10]  [Ent35]  | Acronym_41 [Att10]  [Ent35]  | Q_41 [Att20]  [Ent35]  | Tt_41 [Att10]  [Ent35]  | I_41 [Att10]  [Ent35]  | B_41 [Att10]  [Ent35]  | U_41 [Att10]  [Ent35]  | S_41 [Att10]  [Ent35]  | Strike_41 [Att10]  [Ent35]  | Input_41 [Att44]  | Select_41 [Att45]  [Ent60]  | Textarea_41 [Att49]  [Ent36]  | Button_41 [Att53]  [Ent62]  | PCDATA_41 [Att0] B.ByteString
    deriving (Show)

data Ent42 = Script_42 [Att9]  [Ent77]  | Noscript_42 [Att10]  [Ent42]  | Iframe_42 [Att11]  [Ent42]  | Noframes_42 [Att10]  [Ent42]  | Div_42 [Att13]  [Ent42]  | P_42 [Att13]  [Ent43]  | H1_42 [Att13]  [Ent43]  | H2_42 [Att13]  [Ent43]  | H3_42 [Att13]  [Ent43]  | H4_42 [Att13]  [Ent43]  | H5_42 [Att13]  [Ent43]  | H6_42 [Att13]  [Ent43]  | Ul_42 [Att14]  [Ent44]  | Ol_42 [Att15]  [Ent44]  | Menu_42 [Att16]  [Ent44]  | Dir_42 [Att16]  [Ent44]  | Dl_42 [Att16]  [Ent45]  | Address_42 [Att10]  [Ent46]  | Hr_42 [Att18]  | Pre_42 [Att19]  [Ent47]  | Blockquote_42 [Att20]  [Ent42]  | Center_42 [Att10]  [Ent42]  | Ins_42 [Att21]  [Ent42]  | Del_42 [Att21]  [Ent42]  | Span_42 [Att10]  [Ent43]  | Bdo_42 [Att10]  [Ent43]  | Br_42 [Att25]  | Em_42 [Att10]  [Ent43]  | Strong_42 [Att10]  [Ent43]  | Dfn_42 [Att10]  [Ent43]  | Code_42 [Att10]  [Ent43]  | Samp_42 [Att10]  [Ent43]  | Kbd_42 [Att10]  [Ent43]  | Var_42 [Att10]  [Ent43]  | Cite_42 [Att10]  [Ent43]  | Abbr_42 [Att10]  [Ent43]  | Acronym_42 [Att10]  [Ent43]  | Q_42 [Att20]  [Ent43]  | Sub_42 [Att10]  [Ent43]  | Sup_42 [Att10]  [Ent43]  | Tt_42 [Att10]  [Ent43]  | I_42 [Att10]  [Ent43]  | B_42 [Att10]  [Ent43]  | Big_42 [Att10]  [Ent43]  | Small_42 [Att10]  [Ent43]  | U_42 [Att10]  [Ent43]  | S_42 [Att10]  [Ent43]  | Strike_42 [Att10]  [Ent43]  | Basefont_42 [Att26]  | Font_42 [Att28]  [Ent43]  | Object_42 [Att29]  [Ent78]  | Applet_42 [Att32]  [Ent78]  | Img_42 [Att35]  | Map_42 [Att38]  [Ent79]  | Input_42 [Att44]  | Select_42 [Att45]  [Ent80]  | Textarea_42 [Att49]  [Ent77]  | Fieldset_42 [Att10]  [Ent48]  | Button_42 [Att53]  [Ent82]  | Isindex_42 [Att54]  | Table_42 [Att55]  [Ent49]  | PCDATA_42 [Att0] B.ByteString
    deriving (Show)

data Ent43 = Script_43 [Att9]  [Ent77]  | Iframe_43 [Att11]  [Ent42]  | Ins_43 [Att21]  [Ent42]  | Del_43 [Att21]  [Ent42]  | Span_43 [Att10]  [Ent43]  | Bdo_43 [Att10]  [Ent43]  | Br_43 [Att25]  | Em_43 [Att10]  [Ent43]  | Strong_43 [Att10]  [Ent43]  | Dfn_43 [Att10]  [Ent43]  | Code_43 [Att10]  [Ent43]  | Samp_43 [Att10]  [Ent43]  | Kbd_43 [Att10]  [Ent43]  | Var_43 [Att10]  [Ent43]  | Cite_43 [Att10]  [Ent43]  | Abbr_43 [Att10]  [Ent43]  | Acronym_43 [Att10]  [Ent43]  | Q_43 [Att20]  [Ent43]  | Sub_43 [Att10]  [Ent43]  | Sup_43 [Att10]  [Ent43]  | Tt_43 [Att10]  [Ent43]  | I_43 [Att10]  [Ent43]  | B_43 [Att10]  [Ent43]  | Big_43 [Att10]  [Ent43]  | Small_43 [Att10]  [Ent43]  | U_43 [Att10]  [Ent43]  | S_43 [Att10]  [Ent43]  | Strike_43 [Att10]  [Ent43]  | Basefont_43 [Att26]  | Font_43 [Att28]  [Ent43]  | Object_43 [Att29]  [Ent78]  | Applet_43 [Att32]  [Ent78]  | Img_43 [Att35]  | Map_43 [Att38]  [Ent79]  | Input_43 [Att44]  | Select_43 [Att45]  [Ent80]  | Textarea_43 [Att49]  [Ent77]  | Button_43 [Att53]  [Ent82]  | PCDATA_43 [Att0] B.ByteString
    deriving (Show)

data Ent44 = Li_44 [Att17]  [Ent42] 
    deriving (Show)

data Ent45 = Dt_45 [Att10]  [Ent43]  | Dd_45 [Att10]  [Ent42] 
    deriving (Show)

data Ent46 = Script_46 [Att9]  [Ent77]  | Iframe_46 [Att11]  [Ent42]  | P_46 [Att13]  [Ent43]  | Ins_46 [Att21]  [Ent42]  | Del_46 [Att21]  [Ent42]  | Span_46 [Att10]  [Ent43]  | Bdo_46 [Att10]  [Ent43]  | Br_46 [Att25]  | Em_46 [Att10]  [Ent43]  | Strong_46 [Att10]  [Ent43]  | Dfn_46 [Att10]  [Ent43]  | Code_46 [Att10]  [Ent43]  | Samp_46 [Att10]  [Ent43]  | Kbd_46 [Att10]  [Ent43]  | Var_46 [Att10]  [Ent43]  | Cite_46 [Att10]  [Ent43]  | Abbr_46 [Att10]  [Ent43]  | Acronym_46 [Att10]  [Ent43]  | Q_46 [Att20]  [Ent43]  | Sub_46 [Att10]  [Ent43]  | Sup_46 [Att10]  [Ent43]  | Tt_46 [Att10]  [Ent43]  | I_46 [Att10]  [Ent43]  | B_46 [Att10]  [Ent43]  | Big_46 [Att10]  [Ent43]  | Small_46 [Att10]  [Ent43]  | U_46 [Att10]  [Ent43]  | S_46 [Att10]  [Ent43]  | Strike_46 [Att10]  [Ent43]  | Basefont_46 [Att26]  | Font_46 [Att28]  [Ent43]  | Object_46 [Att29]  [Ent78]  | Applet_46 [Att32]  [Ent78]  | Img_46 [Att35]  | Map_46 [Att38]  [Ent79]  | Input_46 [Att44]  | Select_46 [Att45]  [Ent80]  | Textarea_46 [Att49]  [Ent77]  | Button_46 [Att53]  [Ent82]  | PCDATA_46 [Att0] B.ByteString
    deriving (Show)

data Ent47 = Script_47 [Att9]  [Ent77]  | Ins_47 [Att21]  [Ent42]  | Del_47 [Att21]  [Ent42]  | Span_47 [Att10]  [Ent43]  | Bdo_47 [Att10]  [Ent43]  | Br_47 [Att25]  | Em_47 [Att10]  [Ent43]  | Strong_47 [Att10]  [Ent43]  | Dfn_47 [Att10]  [Ent43]  | Code_47 [Att10]  [Ent43]  | Samp_47 [Att10]  [Ent43]  | Kbd_47 [Att10]  [Ent43]  | Var_47 [Att10]  [Ent43]  | Cite_47 [Att10]  [Ent43]  | Abbr_47 [Att10]  [Ent43]  | Acronym_47 [Att10]  [Ent43]  | Q_47 [Att20]  [Ent43]  | Tt_47 [Att10]  [Ent43]  | I_47 [Att10]  [Ent43]  | B_47 [Att10]  [Ent43]  | U_47 [Att10]  [Ent43]  | S_47 [Att10]  [Ent43]  | Strike_47 [Att10]  [Ent43]  | Input_47 [Att44]  | Select_47 [Att45]  [Ent80]  | Textarea_47 [Att49]  [Ent77]  | Button_47 [Att53]  [Ent82]  | PCDATA_47 [Att0] B.ByteString
    deriving (Show)

data Ent48 = Script_48 [Att9]  [Ent77]  | Noscript_48 [Att10]  [Ent42]  | Iframe_48 [Att11]  [Ent42]  | Noframes_48 [Att10]  [Ent42]  | Div_48 [Att13]  [Ent42]  | P_48 [Att13]  [Ent43]  | H1_48 [Att13]  [Ent43]  | H2_48 [Att13]  [Ent43]  | H3_48 [Att13]  [Ent43]  | H4_48 [Att13]  [Ent43]  | H5_48 [Att13]  [Ent43]  | H6_48 [Att13]  [Ent43]  | Ul_48 [Att14]  [Ent44]  | Ol_48 [Att15]  [Ent44]  | Menu_48 [Att16]  [Ent44]  | Dir_48 [Att16]  [Ent44]  | Dl_48 [Att16]  [Ent45]  | Address_48 [Att10]  [Ent46]  | Hr_48 [Att18]  | Pre_48 [Att19]  [Ent47]  | Blockquote_48 [Att20]  [Ent42]  | Center_48 [Att10]  [Ent42]  | Ins_48 [Att21]  [Ent42]  | Del_48 [Att21]  [Ent42]  | Span_48 [Att10]  [Ent43]  | Bdo_48 [Att10]  [Ent43]  | Br_48 [Att25]  | Em_48 [Att10]  [Ent43]  | Strong_48 [Att10]  [Ent43]  | Dfn_48 [Att10]  [Ent43]  | Code_48 [Att10]  [Ent43]  | Samp_48 [Att10]  [Ent43]  | Kbd_48 [Att10]  [Ent43]  | Var_48 [Att10]  [Ent43]  | Cite_48 [Att10]  [Ent43]  | Abbr_48 [Att10]  [Ent43]  | Acronym_48 [Att10]  [Ent43]  | Q_48 [Att20]  [Ent43]  | Sub_48 [Att10]  [Ent43]  | Sup_48 [Att10]  [Ent43]  | Tt_48 [Att10]  [Ent43]  | I_48 [Att10]  [Ent43]  | B_48 [Att10]  [Ent43]  | Big_48 [Att10]  [Ent43]  | Small_48 [Att10]  [Ent43]  | U_48 [Att10]  [Ent43]  | S_48 [Att10]  [Ent43]  | Strike_48 [Att10]  [Ent43]  | Basefont_48 [Att26]  | Font_48 [Att28]  [Ent43]  | Object_48 [Att29]  [Ent78]  | Applet_48 [Att32]  [Ent78]  | Img_48 [Att35]  | Map_48 [Att38]  [Ent79]  | Input_48 [Att44]  | Select_48 [Att45]  [Ent80]  | Textarea_48 [Att49]  [Ent77]  | Fieldset_48 [Att10]  [Ent48]  | Legend_48 [Att52]  [Ent43]  | Button_48 [Att53]  [Ent82]  | Isindex_48 [Att54]  | Table_48 [Att55]  [Ent49]  | PCDATA_48 [Att0] B.ByteString
    deriving (Show)

data Ent49 = Caption_49 [Att13]  [Ent43]  | Thead_49 [Att56]  [Ent50]  | Tfoot_49 [Att56]  [Ent50]  | Tbody_49 [Att56]  [Ent50]  | Colgroup_49 [Att57]  [Ent51]  | Col_49 [Att57]  | Tr_49 [Att58]  [Ent52] 
    deriving (Show)

data Ent50 = Tr_50 [Att58]  [Ent52] 
    deriving (Show)

data Ent51 = Col_51 [Att57] 
    deriving (Show)

data Ent52 = Th_52 [Att59]  [Ent42]  | Td_52 [Att59]  [Ent42] 
    deriving (Show)

data Ent53 = Script_53 [Att9]  [Ent36]  | Noscript_53 [Att10]  [Ent37]  | Iframe_53 [Att11]  [Ent37]  | Noframes_53 [Att10]  [Ent37]  | Div_53 [Att13]  [Ent37]  | P_53 [Att13]  [Ent35]  | H1_53 [Att13]  [Ent35]  | H2_53 [Att13]  [Ent35]  | H3_53 [Att13]  [Ent35]  | H4_53 [Att13]  [Ent35]  | H5_53 [Att13]  [Ent35]  | H6_53 [Att13]  [Ent35]  | Ul_53 [Att14]  [Ent38]  | Ol_53 [Att15]  [Ent38]  | Menu_53 [Att16]  [Ent38]  | Dir_53 [Att16]  [Ent38]  | Dl_53 [Att16]  [Ent39]  | Address_53 [Att10]  [Ent40]  | Hr_53 [Att18]  | Pre_53 [Att19]  [Ent41]  | Blockquote_53 [Att20]  [Ent37]  | Center_53 [Att10]  [Ent37]  | Ins_53 [Att21]  [Ent37]  | Del_53 [Att21]  [Ent37]  | Span_53 [Att10]  [Ent35]  | Bdo_53 [Att10]  [Ent35]  | Br_53 [Att25]  | Em_53 [Att10]  [Ent35]  | Strong_53 [Att10]  [Ent35]  | Dfn_53 [Att10]  [Ent35]  | Code_53 [Att10]  [Ent35]  | Samp_53 [Att10]  [Ent35]  | Kbd_53 [Att10]  [Ent35]  | Var_53 [Att10]  [Ent35]  | Cite_53 [Att10]  [Ent35]  | Abbr_53 [Att10]  [Ent35]  | Acronym_53 [Att10]  [Ent35]  | Q_53 [Att20]  [Ent35]  | Sub_53 [Att10]  [Ent35]  | Sup_53 [Att10]  [Ent35]  | Tt_53 [Att10]  [Ent35]  | I_53 [Att10]  [Ent35]  | B_53 [Att10]  [Ent35]  | Big_53 [Att10]  [Ent35]  | Small_53 [Att10]  [Ent35]  | U_53 [Att10]  [Ent35]  | S_53 [Att10]  [Ent35]  | Strike_53 [Att10]  [Ent35]  | Basefont_53 [Att26]  | Font_53 [Att28]  [Ent35]  | Object_53 [Att29]  [Ent58]  | Applet_53 [Att32]  [Ent58]  | Img_53 [Att35]  | Map_53 [Att38]  [Ent59]  | Form_53 [Att41]  [Ent42]  | Input_53 [Att44]  | Select_53 [Att45]  [Ent60]  | Textarea_53 [Att49]  [Ent36]  | Fieldset_53 [Att10]  [Ent53]  | Legend_53 [Att52]  [Ent35]  | Button_53 [Att53]  [Ent62]  | Isindex_53 [Att54]  | Table_53 [Att55]  [Ent54]  | PCDATA_53 [Att0] B.ByteString
    deriving (Show)

data Ent54 = Caption_54 [Att13]  [Ent35]  | Thead_54 [Att56]  [Ent55]  | Tfoot_54 [Att56]  [Ent55]  | Tbody_54 [Att56]  [Ent55]  | Colgroup_54 [Att57]  [Ent56]  | Col_54 [Att57]  | Tr_54 [Att58]  [Ent57] 
    deriving (Show)

data Ent55 = Tr_55 [Att58]  [Ent57] 
    deriving (Show)

data Ent56 = Col_56 [Att57] 
    deriving (Show)

data Ent57 = Th_57 [Att59]  [Ent37]  | Td_57 [Att59]  [Ent37] 
    deriving (Show)

data Ent58 = Script_58 [Att9]  [Ent36]  | Noscript_58 [Att10]  [Ent37]  | Iframe_58 [Att11]  [Ent37]  | Noframes_58 [Att10]  [Ent37]  | Div_58 [Att13]  [Ent37]  | P_58 [Att13]  [Ent35]  | H1_58 [Att13]  [Ent35]  | H2_58 [Att13]  [Ent35]  | H3_58 [Att13]  [Ent35]  | H4_58 [Att13]  [Ent35]  | H5_58 [Att13]  [Ent35]  | H6_58 [Att13]  [Ent35]  | Ul_58 [Att14]  [Ent38]  | Ol_58 [Att15]  [Ent38]  | Menu_58 [Att16]  [Ent38]  | Dir_58 [Att16]  [Ent38]  | Dl_58 [Att16]  [Ent39]  | Address_58 [Att10]  [Ent40]  | Hr_58 [Att18]  | Pre_58 [Att19]  [Ent41]  | Blockquote_58 [Att20]  [Ent37]  | Center_58 [Att10]  [Ent37]  | Ins_58 [Att21]  [Ent37]  | Del_58 [Att21]  [Ent37]  | Span_58 [Att10]  [Ent35]  | Bdo_58 [Att10]  [Ent35]  | Br_58 [Att25]  | Em_58 [Att10]  [Ent35]  | Strong_58 [Att10]  [Ent35]  | Dfn_58 [Att10]  [Ent35]  | Code_58 [Att10]  [Ent35]  | Samp_58 [Att10]  [Ent35]  | Kbd_58 [Att10]  [Ent35]  | Var_58 [Att10]  [Ent35]  | Cite_58 [Att10]  [Ent35]  | Abbr_58 [Att10]  [Ent35]  | Acronym_58 [Att10]  [Ent35]  | Q_58 [Att20]  [Ent35]  | Sub_58 [Att10]  [Ent35]  | Sup_58 [Att10]  [Ent35]  | Tt_58 [Att10]  [Ent35]  | I_58 [Att10]  [Ent35]  | B_58 [Att10]  [Ent35]  | Big_58 [Att10]  [Ent35]  | Small_58 [Att10]  [Ent35]  | U_58 [Att10]  [Ent35]  | S_58 [Att10]  [Ent35]  | Strike_58 [Att10]  [Ent35]  | Basefont_58 [Att26]  | Font_58 [Att28]  [Ent35]  | Object_58 [Att29]  [Ent58]  | Param_58 [Att30]  | Applet_58 [Att32]  [Ent58]  | Img_58 [Att35]  | Map_58 [Att38]  [Ent59]  | Form_58 [Att41]  [Ent42]  | Input_58 [Att44]  | Select_58 [Att45]  [Ent60]  | Textarea_58 [Att49]  [Ent36]  | Fieldset_58 [Att10]  [Ent53]  | Button_58 [Att53]  [Ent62]  | Isindex_58 [Att54]  | Table_58 [Att55]  [Ent54]  | PCDATA_58 [Att0] B.ByteString
    deriving (Show)

data Ent59 = Script_59 [Att9]  [Ent36]  | Noscript_59 [Att10]  [Ent37]  | Noframes_59 [Att10]  [Ent37]  | Div_59 [Att13]  [Ent37]  | P_59 [Att13]  [Ent35]  | H1_59 [Att13]  [Ent35]  | H2_59 [Att13]  [Ent35]  | H3_59 [Att13]  [Ent35]  | H4_59 [Att13]  [Ent35]  | H5_59 [Att13]  [Ent35]  | H6_59 [Att13]  [Ent35]  | Ul_59 [Att14]  [Ent38]  | Ol_59 [Att15]  [Ent38]  | Menu_59 [Att16]  [Ent38]  | Dir_59 [Att16]  [Ent38]  | Dl_59 [Att16]  [Ent39]  | Address_59 [Att10]  [Ent40]  | Hr_59 [Att18]  | Pre_59 [Att19]  [Ent41]  | Blockquote_59 [Att20]  [Ent37]  | Center_59 [Att10]  [Ent37]  | Ins_59 [Att21]  [Ent37]  | Del_59 [Att21]  [Ent37]  | Area_59 [Att40]  | Form_59 [Att41]  [Ent42]  | Fieldset_59 [Att10]  [Ent53]  | Isindex_59 [Att54]  | Table_59 [Att55]  [Ent54] 
    deriving (Show)

data Ent60 = Optgroup_60 [Att46]  [Ent61]  | Option_60 [Att48]  [Ent36] 
    deriving (Show)

data Ent61 = Option_61 [Att48]  [Ent36] 
    deriving (Show)

data Ent62 = Script_62 [Att9]  [Ent36]  | Noscript_62 [Att10]  [Ent37]  | Noframes_62 [Att10]  [Ent37]  | Div_62 [Att13]  [Ent37]  | P_62 [Att13]  [Ent35]  | H1_62 [Att13]  [Ent35]  | H2_62 [Att13]  [Ent35]  | H3_62 [Att13]  [Ent35]  | H4_62 [Att13]  [Ent35]  | H5_62 [Att13]  [Ent35]  | H6_62 [Att13]  [Ent35]  | Ul_62 [Att14]  [Ent38]  | Ol_62 [Att15]  [Ent38]  | Menu_62 [Att16]  [Ent38]  | Dir_62 [Att16]  [Ent38]  | Dl_62 [Att16]  [Ent39]  | Address_62 [Att10]  [Ent40]  | Hr_62 [Att18]  | Pre_62 [Att19]  [Ent41]  | Blockquote_62 [Att20]  [Ent37]  | Center_62 [Att10]  [Ent37]  | Ins_62 [Att21]  [Ent37]  | Del_62 [Att21]  [Ent37]  | Span_62 [Att10]  [Ent35]  | Bdo_62 [Att10]  [Ent35]  | Br_62 [Att25]  | Em_62 [Att10]  [Ent35]  | Strong_62 [Att10]  [Ent35]  | Dfn_62 [Att10]  [Ent35]  | Code_62 [Att10]  [Ent35]  | Samp_62 [Att10]  [Ent35]  | Kbd_62 [Att10]  [Ent35]  | Var_62 [Att10]  [Ent35]  | Cite_62 [Att10]  [Ent35]  | Abbr_62 [Att10]  [Ent35]  | Acronym_62 [Att10]  [Ent35]  | Q_62 [Att20]  [Ent35]  | Sub_62 [Att10]  [Ent35]  | Sup_62 [Att10]  [Ent35]  | Tt_62 [Att10]  [Ent35]  | I_62 [Att10]  [Ent35]  | B_62 [Att10]  [Ent35]  | Big_62 [Att10]  [Ent35]  | Small_62 [Att10]  [Ent35]  | U_62 [Att10]  [Ent35]  | S_62 [Att10]  [Ent35]  | Strike_62 [Att10]  [Ent35]  | Basefont_62 [Att26]  | Font_62 [Att28]  [Ent35]  | Object_62 [Att29]  [Ent58]  | Applet_62 [Att32]  [Ent58]  | Img_62 [Att35]  | Map_62 [Att38]  [Ent59]  | Table_62 [Att55]  [Ent54]  | PCDATA_62 [Att0] B.ByteString
    deriving (Show)

data Ent63 = Optgroup_63 [Att46]  [Ent64]  | Option_63 [Att48]  [Ent11] 
    deriving (Show)

data Ent64 = Option_64 [Att48]  [Ent11] 
    deriving (Show)

data Ent65 = Script_65 [Att9]  [Ent11]  | Noscript_65 [Att10]  [Ent12]  | Noframes_65 [Att10]  [Ent12]  | Div_65 [Att13]  [Ent12]  | P_65 [Att13]  [Ent10]  | H1_65 [Att13]  [Ent10]  | H2_65 [Att13]  [Ent10]  | H3_65 [Att13]  [Ent10]  | H4_65 [Att13]  [Ent10]  | H5_65 [Att13]  [Ent10]  | H6_65 [Att13]  [Ent10]  | Ul_65 [Att14]  [Ent13]  | Ol_65 [Att15]  [Ent13]  | Menu_65 [Att16]  [Ent13]  | Dir_65 [Att16]  [Ent13]  | Dl_65 [Att16]  [Ent14]  | Address_65 [Att10]  [Ent15]  | Hr_65 [Att18]  | Pre_65 [Att19]  [Ent16]  | Blockquote_65 [Att20]  [Ent12]  | Center_65 [Att10]  [Ent12]  | Ins_65 [Att21]  [Ent12]  | Del_65 [Att21]  [Ent12]  | Span_65 [Att10]  [Ent10]  | Bdo_65 [Att10]  [Ent10]  | Br_65 [Att25]  | Em_65 [Att10]  [Ent10]  | Strong_65 [Att10]  [Ent10]  | Dfn_65 [Att10]  [Ent10]  | Code_65 [Att10]  [Ent10]  | Samp_65 [Att10]  [Ent10]  | Kbd_65 [Att10]  [Ent10]  | Var_65 [Att10]  [Ent10]  | Cite_65 [Att10]  [Ent10]  | Abbr_65 [Att10]  [Ent10]  | Acronym_65 [Att10]  [Ent10]  | Q_65 [Att20]  [Ent10]  | Sub_65 [Att10]  [Ent10]  | Sup_65 [Att10]  [Ent10]  | Tt_65 [Att10]  [Ent10]  | I_65 [Att10]  [Ent10]  | B_65 [Att10]  [Ent10]  | Big_65 [Att10]  [Ent10]  | Small_65 [Att10]  [Ent10]  | U_65 [Att10]  [Ent10]  | S_65 [Att10]  [Ent10]  | Strike_65 [Att10]  [Ent10]  | Basefont_65 [Att26]  | Font_65 [Att28]  [Ent10]  | Object_65 [Att29]  [Ent33]  | Applet_65 [Att32]  [Ent33]  | Img_65 [Att35]  | Map_65 [Att38]  [Ent34]  | Table_65 [Att55]  [Ent29]  | PCDATA_65 [Att0] B.ByteString
    deriving (Show)

data Ent66 = Script_66 [Att9]  [Ent2]  | Noscript_66 [Att10]  [Ent4]  | Noframes_66 [Att10]  [Ent4]  | Div_66 [Att13]  [Ent4]  | P_66 [Att13]  [Ent5]  | H1_66 [Att13]  [Ent5]  | H2_66 [Att13]  [Ent5]  | H3_66 [Att13]  [Ent5]  | H4_66 [Att13]  [Ent5]  | H5_66 [Att13]  [Ent5]  | H6_66 [Att13]  [Ent5]  | Ul_66 [Att14]  [Ent6]  | Ol_66 [Att15]  [Ent6]  | Menu_66 [Att16]  [Ent6]  | Dir_66 [Att16]  [Ent6]  | Dl_66 [Att16]  [Ent7]  | Address_66 [Att10]  [Ent8]  | Hr_66 [Att18]  | Pre_66 [Att19]  [Ent9]  | Blockquote_66 [Att20]  [Ent4]  | Center_66 [Att10]  [Ent4]  | Ins_66 [Att21]  [Ent4]  | Del_66 [Att21]  [Ent4]  | Area_66 [Att40]  | Form_66 [Att41]  [Ent67]  | Fieldset_66 [Att10]  [Ent132]  | Isindex_66 [Att54]  | Table_66 [Att55]  [Ent134] 
    deriving (Show)

data Ent67 = Script_67 [Att9]  [Ent68]  | Noscript_67 [Att10]  [Ent67]  | Iframe_67 [Att11]  [Ent67]  | Noframes_67 [Att10]  [Ent67]  | Div_67 [Att13]  [Ent67]  | P_67 [Att13]  [Ent69]  | H1_67 [Att13]  [Ent69]  | H2_67 [Att13]  [Ent69]  | H3_67 [Att13]  [Ent69]  | H4_67 [Att13]  [Ent69]  | H5_67 [Att13]  [Ent69]  | H6_67 [Att13]  [Ent69]  | Ul_67 [Att14]  [Ent70]  | Ol_67 [Att15]  [Ent70]  | Menu_67 [Att16]  [Ent70]  | Dir_67 [Att16]  [Ent70]  | Dl_67 [Att16]  [Ent71]  | Address_67 [Att10]  [Ent72]  | Hr_67 [Att18]  | Pre_67 [Att19]  [Ent73]  | Blockquote_67 [Att20]  [Ent67]  | Center_67 [Att10]  [Ent67]  | Ins_67 [Att21]  [Ent67]  | Del_67 [Att21]  [Ent67]  | A_67 [Att22]  [Ent18]  | Span_67 [Att10]  [Ent69]  | Bdo_67 [Att10]  [Ent69]  | Br_67 [Att25]  | Em_67 [Att10]  [Ent69]  | Strong_67 [Att10]  [Ent69]  | Dfn_67 [Att10]  [Ent69]  | Code_67 [Att10]  [Ent69]  | Samp_67 [Att10]  [Ent69]  | Kbd_67 [Att10]  [Ent69]  | Var_67 [Att10]  [Ent69]  | Cite_67 [Att10]  [Ent69]  | Abbr_67 [Att10]  [Ent69]  | Acronym_67 [Att10]  [Ent69]  | Q_67 [Att20]  [Ent69]  | Sub_67 [Att10]  [Ent69]  | Sup_67 [Att10]  [Ent69]  | Tt_67 [Att10]  [Ent69]  | I_67 [Att10]  [Ent69]  | B_67 [Att10]  [Ent69]  | Big_67 [Att10]  [Ent69]  | Small_67 [Att10]  [Ent69]  | U_67 [Att10]  [Ent69]  | S_67 [Att10]  [Ent69]  | Strike_67 [Att10]  [Ent69]  | Basefont_67 [Att26]  | Font_67 [Att28]  [Ent69]  | Object_67 [Att29]  [Ent86]  | Applet_67 [Att32]  [Ent86]  | Img_67 [Att35]  | Map_67 [Att38]  [Ent87]  | Label_67 [Att43]  [Ent88]  | Input_67 [Att44]  | Select_67 [Att45]  [Ent105]  | Textarea_67 [Att49]  [Ent68]  | Fieldset_67 [Att10]  [Ent107]  | Button_67 [Att53]  [Ent108]  | Isindex_67 [Att54]  | Table_67 [Att55]  [Ent109]  | PCDATA_67 [Att0] B.ByteString
    deriving (Show)

data Ent68 = PCDATA_68 [Att0] B.ByteString
    deriving (Show)

data Ent69 = Script_69 [Att9]  [Ent68]  | Iframe_69 [Att11]  [Ent67]  | Ins_69 [Att21]  [Ent67]  | Del_69 [Att21]  [Ent67]  | A_69 [Att22]  [Ent18]  | Span_69 [Att10]  [Ent69]  | Bdo_69 [Att10]  [Ent69]  | Br_69 [Att25]  | Em_69 [Att10]  [Ent69]  | Strong_69 [Att10]  [Ent69]  | Dfn_69 [Att10]  [Ent69]  | Code_69 [Att10]  [Ent69]  | Samp_69 [Att10]  [Ent69]  | Kbd_69 [Att10]  [Ent69]  | Var_69 [Att10]  [Ent69]  | Cite_69 [Att10]  [Ent69]  | Abbr_69 [Att10]  [Ent69]  | Acronym_69 [Att10]  [Ent69]  | Q_69 [Att20]  [Ent69]  | Sub_69 [Att10]  [Ent69]  | Sup_69 [Att10]  [Ent69]  | Tt_69 [Att10]  [Ent69]  | I_69 [Att10]  [Ent69]  | B_69 [Att10]  [Ent69]  | Big_69 [Att10]  [Ent69]  | Small_69 [Att10]  [Ent69]  | U_69 [Att10]  [Ent69]  | S_69 [Att10]  [Ent69]  | Strike_69 [Att10]  [Ent69]  | Basefont_69 [Att26]  | Font_69 [Att28]  [Ent69]  | Object_69 [Att29]  [Ent86]  | Applet_69 [Att32]  [Ent86]  | Img_69 [Att35]  | Map_69 [Att38]  [Ent87]  | Label_69 [Att43]  [Ent88]  | Input_69 [Att44]  | Select_69 [Att45]  [Ent105]  | Textarea_69 [Att49]  [Ent68]  | Button_69 [Att53]  [Ent108]  | PCDATA_69 [Att0] B.ByteString
    deriving (Show)

data Ent70 = Li_70 [Att17]  [Ent67] 
    deriving (Show)

data Ent71 = Dt_71 [Att10]  [Ent69]  | Dd_71 [Att10]  [Ent67] 
    deriving (Show)

data Ent72 = Script_72 [Att9]  [Ent68]  | Iframe_72 [Att11]  [Ent67]  | P_72 [Att13]  [Ent69]  | Ins_72 [Att21]  [Ent67]  | Del_72 [Att21]  [Ent67]  | A_72 [Att22]  [Ent18]  | Span_72 [Att10]  [Ent69]  | Bdo_72 [Att10]  [Ent69]  | Br_72 [Att25]  | Em_72 [Att10]  [Ent69]  | Strong_72 [Att10]  [Ent69]  | Dfn_72 [Att10]  [Ent69]  | Code_72 [Att10]  [Ent69]  | Samp_72 [Att10]  [Ent69]  | Kbd_72 [Att10]  [Ent69]  | Var_72 [Att10]  [Ent69]  | Cite_72 [Att10]  [Ent69]  | Abbr_72 [Att10]  [Ent69]  | Acronym_72 [Att10]  [Ent69]  | Q_72 [Att20]  [Ent69]  | Sub_72 [Att10]  [Ent69]  | Sup_72 [Att10]  [Ent69]  | Tt_72 [Att10]  [Ent69]  | I_72 [Att10]  [Ent69]  | B_72 [Att10]  [Ent69]  | Big_72 [Att10]  [Ent69]  | Small_72 [Att10]  [Ent69]  | U_72 [Att10]  [Ent69]  | S_72 [Att10]  [Ent69]  | Strike_72 [Att10]  [Ent69]  | Basefont_72 [Att26]  | Font_72 [Att28]  [Ent69]  | Object_72 [Att29]  [Ent86]  | Applet_72 [Att32]  [Ent86]  | Img_72 [Att35]  | Map_72 [Att38]  [Ent87]  | Label_72 [Att43]  [Ent88]  | Input_72 [Att44]  | Select_72 [Att45]  [Ent105]  | Textarea_72 [Att49]  [Ent68]  | Button_72 [Att53]  [Ent108]  | PCDATA_72 [Att0] B.ByteString
    deriving (Show)

data Ent73 = Script_73 [Att9]  [Ent68]  | Ins_73 [Att21]  [Ent67]  | Del_73 [Att21]  [Ent67]  | A_73 [Att22]  [Ent18]  | Span_73 [Att10]  [Ent69]  | Bdo_73 [Att10]  [Ent69]  | Br_73 [Att25]  | Em_73 [Att10]  [Ent69]  | Strong_73 [Att10]  [Ent69]  | Dfn_73 [Att10]  [Ent69]  | Code_73 [Att10]  [Ent69]  | Samp_73 [Att10]  [Ent69]  | Kbd_73 [Att10]  [Ent69]  | Var_73 [Att10]  [Ent69]  | Cite_73 [Att10]  [Ent69]  | Abbr_73 [Att10]  [Ent69]  | Acronym_73 [Att10]  [Ent69]  | Q_73 [Att20]  [Ent69]  | Tt_73 [Att10]  [Ent69]  | I_73 [Att10]  [Ent69]  | B_73 [Att10]  [Ent69]  | U_73 [Att10]  [Ent69]  | S_73 [Att10]  [Ent69]  | Strike_73 [Att10]  [Ent69]  | Label_73 [Att43]  [Ent88]  | Input_73 [Att44]  | Select_73 [Att45]  [Ent105]  | Textarea_73 [Att49]  [Ent68]  | Button_73 [Att53]  [Ent108]  | PCDATA_73 [Att0] B.ByteString
    deriving (Show)

data Ent74 = PCDATA_74 [Att0] B.ByteString
    deriving (Show)

data Ent75 = Script_75 [Att9]  [Ent74]  | Noscript_75 [Att10]  [Ent17]  | Iframe_75 [Att11]  [Ent17]  | Noframes_75 [Att10]  [Ent17]  | Div_75 [Att13]  [Ent17]  | P_75 [Att13]  [Ent18]  | H1_75 [Att13]  [Ent18]  | H2_75 [Att13]  [Ent18]  | H3_75 [Att13]  [Ent18]  | H4_75 [Att13]  [Ent18]  | H5_75 [Att13]  [Ent18]  | H6_75 [Att13]  [Ent18]  | Ul_75 [Att14]  [Ent19]  | Ol_75 [Att15]  [Ent19]  | Menu_75 [Att16]  [Ent19]  | Dir_75 [Att16]  [Ent19]  | Dl_75 [Att16]  [Ent20]  | Address_75 [Att10]  [Ent21]  | Hr_75 [Att18]  | Pre_75 [Att19]  [Ent22]  | Blockquote_75 [Att20]  [Ent17]  | Center_75 [Att10]  [Ent17]  | Ins_75 [Att21]  [Ent17]  | Del_75 [Att21]  [Ent17]  | Span_75 [Att10]  [Ent18]  | Bdo_75 [Att10]  [Ent18]  | Br_75 [Att25]  | Em_75 [Att10]  [Ent18]  | Strong_75 [Att10]  [Ent18]  | Dfn_75 [Att10]  [Ent18]  | Code_75 [Att10]  [Ent18]  | Samp_75 [Att10]  [Ent18]  | Kbd_75 [Att10]  [Ent18]  | Var_75 [Att10]  [Ent18]  | Cite_75 [Att10]  [Ent18]  | Abbr_75 [Att10]  [Ent18]  | Acronym_75 [Att10]  [Ent18]  | Q_75 [Att20]  [Ent18]  | Sub_75 [Att10]  [Ent18]  | Sup_75 [Att10]  [Ent18]  | Tt_75 [Att10]  [Ent18]  | I_75 [Att10]  [Ent18]  | B_75 [Att10]  [Ent18]  | Big_75 [Att10]  [Ent18]  | Small_75 [Att10]  [Ent18]  | U_75 [Att10]  [Ent18]  | S_75 [Att10]  [Ent18]  | Strike_75 [Att10]  [Ent18]  | Basefont_75 [Att26]  | Font_75 [Att28]  [Ent18]  | Object_75 [Att29]  [Ent75]  | Param_75 [Att30]  | Applet_75 [Att32]  [Ent75]  | Img_75 [Att35]  | Map_75 [Att38]  [Ent76]  | Label_75 [Att43]  [Ent43]  | Input_75 [Att44]  | Select_75 [Att45]  [Ent83]  | Textarea_75 [Att49]  [Ent74]  | Fieldset_75 [Att10]  [Ent23]  | Button_75 [Att53]  [Ent85]  | Isindex_75 [Att54]  | Table_75 [Att55]  [Ent24]  | PCDATA_75 [Att0] B.ByteString
    deriving (Show)

data Ent76 = Script_76 [Att9]  [Ent74]  | Noscript_76 [Att10]  [Ent17]  | Noframes_76 [Att10]  [Ent17]  | Div_76 [Att13]  [Ent17]  | P_76 [Att13]  [Ent18]  | H1_76 [Att13]  [Ent18]  | H2_76 [Att13]  [Ent18]  | H3_76 [Att13]  [Ent18]  | H4_76 [Att13]  [Ent18]  | H5_76 [Att13]  [Ent18]  | H6_76 [Att13]  [Ent18]  | Ul_76 [Att14]  [Ent19]  | Ol_76 [Att15]  [Ent19]  | Menu_76 [Att16]  [Ent19]  | Dir_76 [Att16]  [Ent19]  | Dl_76 [Att16]  [Ent20]  | Address_76 [Att10]  [Ent21]  | Hr_76 [Att18]  | Pre_76 [Att19]  [Ent22]  | Blockquote_76 [Att20]  [Ent17]  | Center_76 [Att10]  [Ent17]  | Ins_76 [Att21]  [Ent17]  | Del_76 [Att21]  [Ent17]  | Area_76 [Att40]  | Fieldset_76 [Att10]  [Ent23]  | Isindex_76 [Att54]  | Table_76 [Att55]  [Ent24] 
    deriving (Show)

data Ent77 = PCDATA_77 [Att0] B.ByteString
    deriving (Show)

data Ent78 = Script_78 [Att9]  [Ent77]  | Noscript_78 [Att10]  [Ent42]  | Iframe_78 [Att11]  [Ent42]  | Noframes_78 [Att10]  [Ent42]  | Div_78 [Att13]  [Ent42]  | P_78 [Att13]  [Ent43]  | H1_78 [Att13]  [Ent43]  | H2_78 [Att13]  [Ent43]  | H3_78 [Att13]  [Ent43]  | H4_78 [Att13]  [Ent43]  | H5_78 [Att13]  [Ent43]  | H6_78 [Att13]  [Ent43]  | Ul_78 [Att14]  [Ent44]  | Ol_78 [Att15]  [Ent44]  | Menu_78 [Att16]  [Ent44]  | Dir_78 [Att16]  [Ent44]  | Dl_78 [Att16]  [Ent45]  | Address_78 [Att10]  [Ent46]  | Hr_78 [Att18]  | Pre_78 [Att19]  [Ent47]  | Blockquote_78 [Att20]  [Ent42]  | Center_78 [Att10]  [Ent42]  | Ins_78 [Att21]  [Ent42]  | Del_78 [Att21]  [Ent42]  | Span_78 [Att10]  [Ent43]  | Bdo_78 [Att10]  [Ent43]  | Br_78 [Att25]  | Em_78 [Att10]  [Ent43]  | Strong_78 [Att10]  [Ent43]  | Dfn_78 [Att10]  [Ent43]  | Code_78 [Att10]  [Ent43]  | Samp_78 [Att10]  [Ent43]  | Kbd_78 [Att10]  [Ent43]  | Var_78 [Att10]  [Ent43]  | Cite_78 [Att10]  [Ent43]  | Abbr_78 [Att10]  [Ent43]  | Acronym_78 [Att10]  [Ent43]  | Q_78 [Att20]  [Ent43]  | Sub_78 [Att10]  [Ent43]  | Sup_78 [Att10]  [Ent43]  | Tt_78 [Att10]  [Ent43]  | I_78 [Att10]  [Ent43]  | B_78 [Att10]  [Ent43]  | Big_78 [Att10]  [Ent43]  | Small_78 [Att10]  [Ent43]  | U_78 [Att10]  [Ent43]  | S_78 [Att10]  [Ent43]  | Strike_78 [Att10]  [Ent43]  | Basefont_78 [Att26]  | Font_78 [Att28]  [Ent43]  | Object_78 [Att29]  [Ent78]  | Param_78 [Att30]  | Applet_78 [Att32]  [Ent78]  | Img_78 [Att35]  | Map_78 [Att38]  [Ent79]  | Input_78 [Att44]  | Select_78 [Att45]  [Ent80]  | Textarea_78 [Att49]  [Ent77]  | Fieldset_78 [Att10]  [Ent48]  | Button_78 [Att53]  [Ent82]  | Isindex_78 [Att54]  | Table_78 [Att55]  [Ent49]  | PCDATA_78 [Att0] B.ByteString
    deriving (Show)

data Ent79 = Script_79 [Att9]  [Ent77]  | Noscript_79 [Att10]  [Ent42]  | Noframes_79 [Att10]  [Ent42]  | Div_79 [Att13]  [Ent42]  | P_79 [Att13]  [Ent43]  | H1_79 [Att13]  [Ent43]  | H2_79 [Att13]  [Ent43]  | H3_79 [Att13]  [Ent43]  | H4_79 [Att13]  [Ent43]  | H5_79 [Att13]  [Ent43]  | H6_79 [Att13]  [Ent43]  | Ul_79 [Att14]  [Ent44]  | Ol_79 [Att15]  [Ent44]  | Menu_79 [Att16]  [Ent44]  | Dir_79 [Att16]  [Ent44]  | Dl_79 [Att16]  [Ent45]  | Address_79 [Att10]  [Ent46]  | Hr_79 [Att18]  | Pre_79 [Att19]  [Ent47]  | Blockquote_79 [Att20]  [Ent42]  | Center_79 [Att10]  [Ent42]  | Ins_79 [Att21]  [Ent42]  | Del_79 [Att21]  [Ent42]  | Area_79 [Att40]  | Fieldset_79 [Att10]  [Ent48]  | Isindex_79 [Att54]  | Table_79 [Att55]  [Ent49] 
    deriving (Show)

data Ent80 = Optgroup_80 [Att46]  [Ent81]  | Option_80 [Att48]  [Ent77] 
    deriving (Show)

data Ent81 = Option_81 [Att48]  [Ent77] 
    deriving (Show)

data Ent82 = Script_82 [Att9]  [Ent77]  | Noscript_82 [Att10]  [Ent42]  | Noframes_82 [Att10]  [Ent42]  | Div_82 [Att13]  [Ent42]  | P_82 [Att13]  [Ent43]  | H1_82 [Att13]  [Ent43]  | H2_82 [Att13]  [Ent43]  | H3_82 [Att13]  [Ent43]  | H4_82 [Att13]  [Ent43]  | H5_82 [Att13]  [Ent43]  | H6_82 [Att13]  [Ent43]  | Ul_82 [Att14]  [Ent44]  | Ol_82 [Att15]  [Ent44]  | Menu_82 [Att16]  [Ent44]  | Dir_82 [Att16]  [Ent44]  | Dl_82 [Att16]  [Ent45]  | Address_82 [Att10]  [Ent46]  | Hr_82 [Att18]  | Pre_82 [Att19]  [Ent47]  | Blockquote_82 [Att20]  [Ent42]  | Center_82 [Att10]  [Ent42]  | Ins_82 [Att21]  [Ent42]  | Del_82 [Att21]  [Ent42]  | Span_82 [Att10]  [Ent43]  | Bdo_82 [Att10]  [Ent43]  | Br_82 [Att25]  | Em_82 [Att10]  [Ent43]  | Strong_82 [Att10]  [Ent43]  | Dfn_82 [Att10]  [Ent43]  | Code_82 [Att10]  [Ent43]  | Samp_82 [Att10]  [Ent43]  | Kbd_82 [Att10]  [Ent43]  | Var_82 [Att10]  [Ent43]  | Cite_82 [Att10]  [Ent43]  | Abbr_82 [Att10]  [Ent43]  | Acronym_82 [Att10]  [Ent43]  | Q_82 [Att20]  [Ent43]  | Sub_82 [Att10]  [Ent43]  | Sup_82 [Att10]  [Ent43]  | Tt_82 [Att10]  [Ent43]  | I_82 [Att10]  [Ent43]  | B_82 [Att10]  [Ent43]  | Big_82 [Att10]  [Ent43]  | Small_82 [Att10]  [Ent43]  | U_82 [Att10]  [Ent43]  | S_82 [Att10]  [Ent43]  | Strike_82 [Att10]  [Ent43]  | Basefont_82 [Att26]  | Font_82 [Att28]  [Ent43]  | Object_82 [Att29]  [Ent78]  | Applet_82 [Att32]  [Ent78]  | Img_82 [Att35]  | Map_82 [Att38]  [Ent79]  | Table_82 [Att55]  [Ent49]  | PCDATA_82 [Att0] B.ByteString
    deriving (Show)

data Ent83 = Optgroup_83 [Att46]  [Ent84]  | Option_83 [Att48]  [Ent74] 
    deriving (Show)

data Ent84 = Option_84 [Att48]  [Ent74] 
    deriving (Show)

data Ent85 = Script_85 [Att9]  [Ent74]  | Noscript_85 [Att10]  [Ent17]  | Noframes_85 [Att10]  [Ent17]  | Div_85 [Att13]  [Ent17]  | P_85 [Att13]  [Ent18]  | H1_85 [Att13]  [Ent18]  | H2_85 [Att13]  [Ent18]  | H3_85 [Att13]  [Ent18]  | H4_85 [Att13]  [Ent18]  | H5_85 [Att13]  [Ent18]  | H6_85 [Att13]  [Ent18]  | Ul_85 [Att14]  [Ent19]  | Ol_85 [Att15]  [Ent19]  | Menu_85 [Att16]  [Ent19]  | Dir_85 [Att16]  [Ent19]  | Dl_85 [Att16]  [Ent20]  | Address_85 [Att10]  [Ent21]  | Hr_85 [Att18]  | Pre_85 [Att19]  [Ent22]  | Blockquote_85 [Att20]  [Ent17]  | Center_85 [Att10]  [Ent17]  | Ins_85 [Att21]  [Ent17]  | Del_85 [Att21]  [Ent17]  | Span_85 [Att10]  [Ent18]  | Bdo_85 [Att10]  [Ent18]  | Br_85 [Att25]  | Em_85 [Att10]  [Ent18]  | Strong_85 [Att10]  [Ent18]  | Dfn_85 [Att10]  [Ent18]  | Code_85 [Att10]  [Ent18]  | Samp_85 [Att10]  [Ent18]  | Kbd_85 [Att10]  [Ent18]  | Var_85 [Att10]  [Ent18]  | Cite_85 [Att10]  [Ent18]  | Abbr_85 [Att10]  [Ent18]  | Acronym_85 [Att10]  [Ent18]  | Q_85 [Att20]  [Ent18]  | Sub_85 [Att10]  [Ent18]  | Sup_85 [Att10]  [Ent18]  | Tt_85 [Att10]  [Ent18]  | I_85 [Att10]  [Ent18]  | B_85 [Att10]  [Ent18]  | Big_85 [Att10]  [Ent18]  | Small_85 [Att10]  [Ent18]  | U_85 [Att10]  [Ent18]  | S_85 [Att10]  [Ent18]  | Strike_85 [Att10]  [Ent18]  | Basefont_85 [Att26]  | Font_85 [Att28]  [Ent18]  | Object_85 [Att29]  [Ent75]  | Applet_85 [Att32]  [Ent75]  | Img_85 [Att35]  | Map_85 [Att38]  [Ent76]  | Table_85 [Att55]  [Ent24]  | PCDATA_85 [Att0] B.ByteString
    deriving (Show)

data Ent86 = Script_86 [Att9]  [Ent68]  | Noscript_86 [Att10]  [Ent67]  | Iframe_86 [Att11]  [Ent67]  | Noframes_86 [Att10]  [Ent67]  | Div_86 [Att13]  [Ent67]  | P_86 [Att13]  [Ent69]  | H1_86 [Att13]  [Ent69]  | H2_86 [Att13]  [Ent69]  | H3_86 [Att13]  [Ent69]  | H4_86 [Att13]  [Ent69]  | H5_86 [Att13]  [Ent69]  | H6_86 [Att13]  [Ent69]  | Ul_86 [Att14]  [Ent70]  | Ol_86 [Att15]  [Ent70]  | Menu_86 [Att16]  [Ent70]  | Dir_86 [Att16]  [Ent70]  | Dl_86 [Att16]  [Ent71]  | Address_86 [Att10]  [Ent72]  | Hr_86 [Att18]  | Pre_86 [Att19]  [Ent73]  | Blockquote_86 [Att20]  [Ent67]  | Center_86 [Att10]  [Ent67]  | Ins_86 [Att21]  [Ent67]  | Del_86 [Att21]  [Ent67]  | A_86 [Att22]  [Ent18]  | Span_86 [Att10]  [Ent69]  | Bdo_86 [Att10]  [Ent69]  | Br_86 [Att25]  | Em_86 [Att10]  [Ent69]  | Strong_86 [Att10]  [Ent69]  | Dfn_86 [Att10]  [Ent69]  | Code_86 [Att10]  [Ent69]  | Samp_86 [Att10]  [Ent69]  | Kbd_86 [Att10]  [Ent69]  | Var_86 [Att10]  [Ent69]  | Cite_86 [Att10]  [Ent69]  | Abbr_86 [Att10]  [Ent69]  | Acronym_86 [Att10]  [Ent69]  | Q_86 [Att20]  [Ent69]  | Sub_86 [Att10]  [Ent69]  | Sup_86 [Att10]  [Ent69]  | Tt_86 [Att10]  [Ent69]  | I_86 [Att10]  [Ent69]  | B_86 [Att10]  [Ent69]  | Big_86 [Att10]  [Ent69]  | Small_86 [Att10]  [Ent69]  | U_86 [Att10]  [Ent69]  | S_86 [Att10]  [Ent69]  | Strike_86 [Att10]  [Ent69]  | Basefont_86 [Att26]  | Font_86 [Att28]  [Ent69]  | Object_86 [Att29]  [Ent86]  | Param_86 [Att30]  | Applet_86 [Att32]  [Ent86]  | Img_86 [Att35]  | Map_86 [Att38]  [Ent87]  | Label_86 [Att43]  [Ent88]  | Input_86 [Att44]  | Select_86 [Att45]  [Ent105]  | Textarea_86 [Att49]  [Ent68]  | Fieldset_86 [Att10]  [Ent107]  | Button_86 [Att53]  [Ent108]  | Isindex_86 [Att54]  | Table_86 [Att55]  [Ent109]  | PCDATA_86 [Att0] B.ByteString
    deriving (Show)

data Ent87 = Script_87 [Att9]  [Ent68]  | Noscript_87 [Att10]  [Ent67]  | Noframes_87 [Att10]  [Ent67]  | Div_87 [Att13]  [Ent67]  | P_87 [Att13]  [Ent69]  | H1_87 [Att13]  [Ent69]  | H2_87 [Att13]  [Ent69]  | H3_87 [Att13]  [Ent69]  | H4_87 [Att13]  [Ent69]  | H5_87 [Att13]  [Ent69]  | H6_87 [Att13]  [Ent69]  | Ul_87 [Att14]  [Ent70]  | Ol_87 [Att15]  [Ent70]  | Menu_87 [Att16]  [Ent70]  | Dir_87 [Att16]  [Ent70]  | Dl_87 [Att16]  [Ent71]  | Address_87 [Att10]  [Ent72]  | Hr_87 [Att18]  | Pre_87 [Att19]  [Ent73]  | Blockquote_87 [Att20]  [Ent67]  | Center_87 [Att10]  [Ent67]  | Ins_87 [Att21]  [Ent67]  | Del_87 [Att21]  [Ent67]  | Area_87 [Att40]  | Fieldset_87 [Att10]  [Ent107]  | Isindex_87 [Att54]  | Table_87 [Att55]  [Ent109] 
    deriving (Show)

data Ent88 = Script_88 [Att9]  [Ent89]  | Iframe_88 [Att11]  [Ent90]  | Ins_88 [Att21]  [Ent90]  | Del_88 [Att21]  [Ent90]  | A_88 [Att22]  [Ent43]  | Span_88 [Att10]  [Ent88]  | Bdo_88 [Att10]  [Ent88]  | Br_88 [Att25]  | Em_88 [Att10]  [Ent88]  | Strong_88 [Att10]  [Ent88]  | Dfn_88 [Att10]  [Ent88]  | Code_88 [Att10]  [Ent88]  | Samp_88 [Att10]  [Ent88]  | Kbd_88 [Att10]  [Ent88]  | Var_88 [Att10]  [Ent88]  | Cite_88 [Att10]  [Ent88]  | Abbr_88 [Att10]  [Ent88]  | Acronym_88 [Att10]  [Ent88]  | Q_88 [Att20]  [Ent88]  | Sub_88 [Att10]  [Ent88]  | Sup_88 [Att10]  [Ent88]  | Tt_88 [Att10]  [Ent88]  | I_88 [Att10]  [Ent88]  | B_88 [Att10]  [Ent88]  | Big_88 [Att10]  [Ent88]  | Small_88 [Att10]  [Ent88]  | U_88 [Att10]  [Ent88]  | S_88 [Att10]  [Ent88]  | Strike_88 [Att10]  [Ent88]  | Basefont_88 [Att26]  | Font_88 [Att28]  [Ent88]  | Object_88 [Att29]  [Ent100]  | Applet_88 [Att32]  [Ent100]  | Img_88 [Att35]  | Map_88 [Att38]  [Ent101]  | Input_88 [Att44]  | Select_88 [Att45]  [Ent102]  | Textarea_88 [Att49]  [Ent89]  | Button_88 [Att53]  [Ent104]  | PCDATA_88 [Att0] B.ByteString
    deriving (Show)

data Ent89 = PCDATA_89 [Att0] B.ByteString
    deriving (Show)

data Ent90 = Script_90 [Att9]  [Ent89]  | Noscript_90 [Att10]  [Ent90]  | Iframe_90 [Att11]  [Ent90]  | Noframes_90 [Att10]  [Ent90]  | Div_90 [Att13]  [Ent90]  | P_90 [Att13]  [Ent88]  | H1_90 [Att13]  [Ent88]  | H2_90 [Att13]  [Ent88]  | H3_90 [Att13]  [Ent88]  | H4_90 [Att13]  [Ent88]  | H5_90 [Att13]  [Ent88]  | H6_90 [Att13]  [Ent88]  | Ul_90 [Att14]  [Ent91]  | Ol_90 [Att15]  [Ent91]  | Menu_90 [Att16]  [Ent91]  | Dir_90 [Att16]  [Ent91]  | Dl_90 [Att16]  [Ent92]  | Address_90 [Att10]  [Ent93]  | Hr_90 [Att18]  | Pre_90 [Att19]  [Ent94]  | Blockquote_90 [Att20]  [Ent90]  | Center_90 [Att10]  [Ent90]  | Ins_90 [Att21]  [Ent90]  | Del_90 [Att21]  [Ent90]  | A_90 [Att22]  [Ent43]  | Span_90 [Att10]  [Ent88]  | Bdo_90 [Att10]  [Ent88]  | Br_90 [Att25]  | Em_90 [Att10]  [Ent88]  | Strong_90 [Att10]  [Ent88]  | Dfn_90 [Att10]  [Ent88]  | Code_90 [Att10]  [Ent88]  | Samp_90 [Att10]  [Ent88]  | Kbd_90 [Att10]  [Ent88]  | Var_90 [Att10]  [Ent88]  | Cite_90 [Att10]  [Ent88]  | Abbr_90 [Att10]  [Ent88]  | Acronym_90 [Att10]  [Ent88]  | Q_90 [Att20]  [Ent88]  | Sub_90 [Att10]  [Ent88]  | Sup_90 [Att10]  [Ent88]  | Tt_90 [Att10]  [Ent88]  | I_90 [Att10]  [Ent88]  | B_90 [Att10]  [Ent88]  | Big_90 [Att10]  [Ent88]  | Small_90 [Att10]  [Ent88]  | U_90 [Att10]  [Ent88]  | S_90 [Att10]  [Ent88]  | Strike_90 [Att10]  [Ent88]  | Basefont_90 [Att26]  | Font_90 [Att28]  [Ent88]  | Object_90 [Att29]  [Ent100]  | Applet_90 [Att32]  [Ent100]  | Img_90 [Att35]  | Map_90 [Att38]  [Ent101]  | Input_90 [Att44]  | Select_90 [Att45]  [Ent102]  | Textarea_90 [Att49]  [Ent89]  | Fieldset_90 [Att10]  [Ent95]  | Button_90 [Att53]  [Ent104]  | Isindex_90 [Att54]  | Table_90 [Att55]  [Ent96]  | PCDATA_90 [Att0] B.ByteString
    deriving (Show)

data Ent91 = Li_91 [Att17]  [Ent90] 
    deriving (Show)

data Ent92 = Dt_92 [Att10]  [Ent88]  | Dd_92 [Att10]  [Ent90] 
    deriving (Show)

data Ent93 = Script_93 [Att9]  [Ent89]  | Iframe_93 [Att11]  [Ent90]  | P_93 [Att13]  [Ent88]  | Ins_93 [Att21]  [Ent90]  | Del_93 [Att21]  [Ent90]  | A_93 [Att22]  [Ent43]  | Span_93 [Att10]  [Ent88]  | Bdo_93 [Att10]  [Ent88]  | Br_93 [Att25]  | Em_93 [Att10]  [Ent88]  | Strong_93 [Att10]  [Ent88]  | Dfn_93 [Att10]  [Ent88]  | Code_93 [Att10]  [Ent88]  | Samp_93 [Att10]  [Ent88]  | Kbd_93 [Att10]  [Ent88]  | Var_93 [Att10]  [Ent88]  | Cite_93 [Att10]  [Ent88]  | Abbr_93 [Att10]  [Ent88]  | Acronym_93 [Att10]  [Ent88]  | Q_93 [Att20]  [Ent88]  | Sub_93 [Att10]  [Ent88]  | Sup_93 [Att10]  [Ent88]  | Tt_93 [Att10]  [Ent88]  | I_93 [Att10]  [Ent88]  | B_93 [Att10]  [Ent88]  | Big_93 [Att10]  [Ent88]  | Small_93 [Att10]  [Ent88]  | U_93 [Att10]  [Ent88]  | S_93 [Att10]  [Ent88]  | Strike_93 [Att10]  [Ent88]  | Basefont_93 [Att26]  | Font_93 [Att28]  [Ent88]  | Object_93 [Att29]  [Ent100]  | Applet_93 [Att32]  [Ent100]  | Img_93 [Att35]  | Map_93 [Att38]  [Ent101]  | Input_93 [Att44]  | Select_93 [Att45]  [Ent102]  | Textarea_93 [Att49]  [Ent89]  | Button_93 [Att53]  [Ent104]  | PCDATA_93 [Att0] B.ByteString
    deriving (Show)

data Ent94 = Script_94 [Att9]  [Ent89]  | Ins_94 [Att21]  [Ent90]  | Del_94 [Att21]  [Ent90]  | A_94 [Att22]  [Ent43]  | Span_94 [Att10]  [Ent88]  | Bdo_94 [Att10]  [Ent88]  | Br_94 [Att25]  | Em_94 [Att10]  [Ent88]  | Strong_94 [Att10]  [Ent88]  | Dfn_94 [Att10]  [Ent88]  | Code_94 [Att10]  [Ent88]  | Samp_94 [Att10]  [Ent88]  | Kbd_94 [Att10]  [Ent88]  | Var_94 [Att10]  [Ent88]  | Cite_94 [Att10]  [Ent88]  | Abbr_94 [Att10]  [Ent88]  | Acronym_94 [Att10]  [Ent88]  | Q_94 [Att20]  [Ent88]  | Tt_94 [Att10]  [Ent88]  | I_94 [Att10]  [Ent88]  | B_94 [Att10]  [Ent88]  | U_94 [Att10]  [Ent88]  | S_94 [Att10]  [Ent88]  | Strike_94 [Att10]  [Ent88]  | Input_94 [Att44]  | Select_94 [Att45]  [Ent102]  | Textarea_94 [Att49]  [Ent89]  | Button_94 [Att53]  [Ent104]  | PCDATA_94 [Att0] B.ByteString
    deriving (Show)

data Ent95 = Script_95 [Att9]  [Ent89]  | Noscript_95 [Att10]  [Ent90]  | Iframe_95 [Att11]  [Ent90]  | Noframes_95 [Att10]  [Ent90]  | Div_95 [Att13]  [Ent90]  | P_95 [Att13]  [Ent88]  | H1_95 [Att13]  [Ent88]  | H2_95 [Att13]  [Ent88]  | H3_95 [Att13]  [Ent88]  | H4_95 [Att13]  [Ent88]  | H5_95 [Att13]  [Ent88]  | H6_95 [Att13]  [Ent88]  | Ul_95 [Att14]  [Ent91]  | Ol_95 [Att15]  [Ent91]  | Menu_95 [Att16]  [Ent91]  | Dir_95 [Att16]  [Ent91]  | Dl_95 [Att16]  [Ent92]  | Address_95 [Att10]  [Ent93]  | Hr_95 [Att18]  | Pre_95 [Att19]  [Ent94]  | Blockquote_95 [Att20]  [Ent90]  | Center_95 [Att10]  [Ent90]  | Ins_95 [Att21]  [Ent90]  | Del_95 [Att21]  [Ent90]  | A_95 [Att22]  [Ent43]  | Span_95 [Att10]  [Ent88]  | Bdo_95 [Att10]  [Ent88]  | Br_95 [Att25]  | Em_95 [Att10]  [Ent88]  | Strong_95 [Att10]  [Ent88]  | Dfn_95 [Att10]  [Ent88]  | Code_95 [Att10]  [Ent88]  | Samp_95 [Att10]  [Ent88]  | Kbd_95 [Att10]  [Ent88]  | Var_95 [Att10]  [Ent88]  | Cite_95 [Att10]  [Ent88]  | Abbr_95 [Att10]  [Ent88]  | Acronym_95 [Att10]  [Ent88]  | Q_95 [Att20]  [Ent88]  | Sub_95 [Att10]  [Ent88]  | Sup_95 [Att10]  [Ent88]  | Tt_95 [Att10]  [Ent88]  | I_95 [Att10]  [Ent88]  | B_95 [Att10]  [Ent88]  | Big_95 [Att10]  [Ent88]  | Small_95 [Att10]  [Ent88]  | U_95 [Att10]  [Ent88]  | S_95 [Att10]  [Ent88]  | Strike_95 [Att10]  [Ent88]  | Basefont_95 [Att26]  | Font_95 [Att28]  [Ent88]  | Object_95 [Att29]  [Ent100]  | Applet_95 [Att32]  [Ent100]  | Img_95 [Att35]  | Map_95 [Att38]  [Ent101]  | Input_95 [Att44]  | Select_95 [Att45]  [Ent102]  | Textarea_95 [Att49]  [Ent89]  | Fieldset_95 [Att10]  [Ent95]  | Legend_95 [Att52]  [Ent88]  | Button_95 [Att53]  [Ent104]  | Isindex_95 [Att54]  | Table_95 [Att55]  [Ent96]  | PCDATA_95 [Att0] B.ByteString
    deriving (Show)

data Ent96 = Caption_96 [Att13]  [Ent88]  | Thead_96 [Att56]  [Ent97]  | Tfoot_96 [Att56]  [Ent97]  | Tbody_96 [Att56]  [Ent97]  | Colgroup_96 [Att57]  [Ent98]  | Col_96 [Att57]  | Tr_96 [Att58]  [Ent99] 
    deriving (Show)

data Ent97 = Tr_97 [Att58]  [Ent99] 
    deriving (Show)

data Ent98 = Col_98 [Att57] 
    deriving (Show)

data Ent99 = Th_99 [Att59]  [Ent90]  | Td_99 [Att59]  [Ent90] 
    deriving (Show)

data Ent100 = Script_100 [Att9]  [Ent89]  | Noscript_100 [Att10]  [Ent90]  | Iframe_100 [Att11]  [Ent90]  | Noframes_100 [Att10]  [Ent90]  | Div_100 [Att13]  [Ent90]  | P_100 [Att13]  [Ent88]  | H1_100 [Att13]  [Ent88]  | H2_100 [Att13]  [Ent88]  | H3_100 [Att13]  [Ent88]  | H4_100 [Att13]  [Ent88]  | H5_100 [Att13]  [Ent88]  | H6_100 [Att13]  [Ent88]  | Ul_100 [Att14]  [Ent91]  | Ol_100 [Att15]  [Ent91]  | Menu_100 [Att16]  [Ent91]  | Dir_100 [Att16]  [Ent91]  | Dl_100 [Att16]  [Ent92]  | Address_100 [Att10]  [Ent93]  | Hr_100 [Att18]  | Pre_100 [Att19]  [Ent94]  | Blockquote_100 [Att20]  [Ent90]  | Center_100 [Att10]  [Ent90]  | Ins_100 [Att21]  [Ent90]  | Del_100 [Att21]  [Ent90]  | A_100 [Att22]  [Ent43]  | Span_100 [Att10]  [Ent88]  | Bdo_100 [Att10]  [Ent88]  | Br_100 [Att25]  | Em_100 [Att10]  [Ent88]  | Strong_100 [Att10]  [Ent88]  | Dfn_100 [Att10]  [Ent88]  | Code_100 [Att10]  [Ent88]  | Samp_100 [Att10]  [Ent88]  | Kbd_100 [Att10]  [Ent88]  | Var_100 [Att10]  [Ent88]  | Cite_100 [Att10]  [Ent88]  | Abbr_100 [Att10]  [Ent88]  | Acronym_100 [Att10]  [Ent88]  | Q_100 [Att20]  [Ent88]  | Sub_100 [Att10]  [Ent88]  | Sup_100 [Att10]  [Ent88]  | Tt_100 [Att10]  [Ent88]  | I_100 [Att10]  [Ent88]  | B_100 [Att10]  [Ent88]  | Big_100 [Att10]  [Ent88]  | Small_100 [Att10]  [Ent88]  | U_100 [Att10]  [Ent88]  | S_100 [Att10]  [Ent88]  | Strike_100 [Att10]  [Ent88]  | Basefont_100 [Att26]  | Font_100 [Att28]  [Ent88]  | Object_100 [Att29]  [Ent100]  | Param_100 [Att30]  | Applet_100 [Att32]  [Ent100]  | Img_100 [Att35]  | Map_100 [Att38]  [Ent101]  | Input_100 [Att44]  | Select_100 [Att45]  [Ent102]  | Textarea_100 [Att49]  [Ent89]  | Fieldset_100 [Att10]  [Ent95]  | Button_100 [Att53]  [Ent104]  | Isindex_100 [Att54]  | Table_100 [Att55]  [Ent96]  | PCDATA_100 [Att0] B.ByteString
    deriving (Show)

data Ent101 = Script_101 [Att9]  [Ent89]  | Noscript_101 [Att10]  [Ent90]  | Noframes_101 [Att10]  [Ent90]  | Div_101 [Att13]  [Ent90]  | P_101 [Att13]  [Ent88]  | H1_101 [Att13]  [Ent88]  | H2_101 [Att13]  [Ent88]  | H3_101 [Att13]  [Ent88]  | H4_101 [Att13]  [Ent88]  | H5_101 [Att13]  [Ent88]  | H6_101 [Att13]  [Ent88]  | Ul_101 [Att14]  [Ent91]  | Ol_101 [Att15]  [Ent91]  | Menu_101 [Att16]  [Ent91]  | Dir_101 [Att16]  [Ent91]  | Dl_101 [Att16]  [Ent92]  | Address_101 [Att10]  [Ent93]  | Hr_101 [Att18]  | Pre_101 [Att19]  [Ent94]  | Blockquote_101 [Att20]  [Ent90]  | Center_101 [Att10]  [Ent90]  | Ins_101 [Att21]  [Ent90]  | Del_101 [Att21]  [Ent90]  | Area_101 [Att40]  | Fieldset_101 [Att10]  [Ent95]  | Isindex_101 [Att54]  | Table_101 [Att55]  [Ent96] 
    deriving (Show)

data Ent102 = Optgroup_102 [Att46]  [Ent103]  | Option_102 [Att48]  [Ent89] 
    deriving (Show)

data Ent103 = Option_103 [Att48]  [Ent89] 
    deriving (Show)

data Ent104 = Script_104 [Att9]  [Ent89]  | Noscript_104 [Att10]  [Ent90]  | Noframes_104 [Att10]  [Ent90]  | Div_104 [Att13]  [Ent90]  | P_104 [Att13]  [Ent88]  | H1_104 [Att13]  [Ent88]  | H2_104 [Att13]  [Ent88]  | H3_104 [Att13]  [Ent88]  | H4_104 [Att13]  [Ent88]  | H5_104 [Att13]  [Ent88]  | H6_104 [Att13]  [Ent88]  | Ul_104 [Att14]  [Ent91]  | Ol_104 [Att15]  [Ent91]  | Menu_104 [Att16]  [Ent91]  | Dir_104 [Att16]  [Ent91]  | Dl_104 [Att16]  [Ent92]  | Address_104 [Att10]  [Ent93]  | Hr_104 [Att18]  | Pre_104 [Att19]  [Ent94]  | Blockquote_104 [Att20]  [Ent90]  | Center_104 [Att10]  [Ent90]  | Ins_104 [Att21]  [Ent90]  | Del_104 [Att21]  [Ent90]  | Span_104 [Att10]  [Ent88]  | Bdo_104 [Att10]  [Ent88]  | Br_104 [Att25]  | Em_104 [Att10]  [Ent88]  | Strong_104 [Att10]  [Ent88]  | Dfn_104 [Att10]  [Ent88]  | Code_104 [Att10]  [Ent88]  | Samp_104 [Att10]  [Ent88]  | Kbd_104 [Att10]  [Ent88]  | Var_104 [Att10]  [Ent88]  | Cite_104 [Att10]  [Ent88]  | Abbr_104 [Att10]  [Ent88]  | Acronym_104 [Att10]  [Ent88]  | Q_104 [Att20]  [Ent88]  | Sub_104 [Att10]  [Ent88]  | Sup_104 [Att10]  [Ent88]  | Tt_104 [Att10]  [Ent88]  | I_104 [Att10]  [Ent88]  | B_104 [Att10]  [Ent88]  | Big_104 [Att10]  [Ent88]  | Small_104 [Att10]  [Ent88]  | U_104 [Att10]  [Ent88]  | S_104 [Att10]  [Ent88]  | Strike_104 [Att10]  [Ent88]  | Basefont_104 [Att26]  | Font_104 [Att28]  [Ent88]  | Object_104 [Att29]  [Ent100]  | Applet_104 [Att32]  [Ent100]  | Img_104 [Att35]  | Map_104 [Att38]  [Ent101]  | Table_104 [Att55]  [Ent96]  | PCDATA_104 [Att0] B.ByteString
    deriving (Show)

data Ent105 = Optgroup_105 [Att46]  [Ent106]  | Option_105 [Att48]  [Ent68] 
    deriving (Show)

data Ent106 = Option_106 [Att48]  [Ent68] 
    deriving (Show)

data Ent107 = Script_107 [Att9]  [Ent68]  | Noscript_107 [Att10]  [Ent67]  | Iframe_107 [Att11]  [Ent67]  | Noframes_107 [Att10]  [Ent67]  | Div_107 [Att13]  [Ent67]  | P_107 [Att13]  [Ent69]  | H1_107 [Att13]  [Ent69]  | H2_107 [Att13]  [Ent69]  | H3_107 [Att13]  [Ent69]  | H4_107 [Att13]  [Ent69]  | H5_107 [Att13]  [Ent69]  | H6_107 [Att13]  [Ent69]  | Ul_107 [Att14]  [Ent70]  | Ol_107 [Att15]  [Ent70]  | Menu_107 [Att16]  [Ent70]  | Dir_107 [Att16]  [Ent70]  | Dl_107 [Att16]  [Ent71]  | Address_107 [Att10]  [Ent72]  | Hr_107 [Att18]  | Pre_107 [Att19]  [Ent73]  | Blockquote_107 [Att20]  [Ent67]  | Center_107 [Att10]  [Ent67]  | Ins_107 [Att21]  [Ent67]  | Del_107 [Att21]  [Ent67]  | A_107 [Att22]  [Ent18]  | Span_107 [Att10]  [Ent69]  | Bdo_107 [Att10]  [Ent69]  | Br_107 [Att25]  | Em_107 [Att10]  [Ent69]  | Strong_107 [Att10]  [Ent69]  | Dfn_107 [Att10]  [Ent69]  | Code_107 [Att10]  [Ent69]  | Samp_107 [Att10]  [Ent69]  | Kbd_107 [Att10]  [Ent69]  | Var_107 [Att10]  [Ent69]  | Cite_107 [Att10]  [Ent69]  | Abbr_107 [Att10]  [Ent69]  | Acronym_107 [Att10]  [Ent69]  | Q_107 [Att20]  [Ent69]  | Sub_107 [Att10]  [Ent69]  | Sup_107 [Att10]  [Ent69]  | Tt_107 [Att10]  [Ent69]  | I_107 [Att10]  [Ent69]  | B_107 [Att10]  [Ent69]  | Big_107 [Att10]  [Ent69]  | Small_107 [Att10]  [Ent69]  | U_107 [Att10]  [Ent69]  | S_107 [Att10]  [Ent69]  | Strike_107 [Att10]  [Ent69]  | Basefont_107 [Att26]  | Font_107 [Att28]  [Ent69]  | Object_107 [Att29]  [Ent86]  | Applet_107 [Att32]  [Ent86]  | Img_107 [Att35]  | Map_107 [Att38]  [Ent87]  | Label_107 [Att43]  [Ent88]  | Input_107 [Att44]  | Select_107 [Att45]  [Ent105]  | Textarea_107 [Att49]  [Ent68]  | Fieldset_107 [Att10]  [Ent107]  | Legend_107 [Att52]  [Ent69]  | Button_107 [Att53]  [Ent108]  | Isindex_107 [Att54]  | Table_107 [Att55]  [Ent109]  | PCDATA_107 [Att0] B.ByteString
    deriving (Show)

data Ent108 = Script_108 [Att9]  [Ent68]  | Noscript_108 [Att10]  [Ent67]  | Noframes_108 [Att10]  [Ent67]  | Div_108 [Att13]  [Ent67]  | P_108 [Att13]  [Ent69]  | H1_108 [Att13]  [Ent69]  | H2_108 [Att13]  [Ent69]  | H3_108 [Att13]  [Ent69]  | H4_108 [Att13]  [Ent69]  | H5_108 [Att13]  [Ent69]  | H6_108 [Att13]  [Ent69]  | Ul_108 [Att14]  [Ent70]  | Ol_108 [Att15]  [Ent70]  | Menu_108 [Att16]  [Ent70]  | Dir_108 [Att16]  [Ent70]  | Dl_108 [Att16]  [Ent71]  | Address_108 [Att10]  [Ent72]  | Hr_108 [Att18]  | Pre_108 [Att19]  [Ent73]  | Blockquote_108 [Att20]  [Ent67]  | Center_108 [Att10]  [Ent67]  | Ins_108 [Att21]  [Ent67]  | Del_108 [Att21]  [Ent67]  | Span_108 [Att10]  [Ent69]  | Bdo_108 [Att10]  [Ent69]  | Br_108 [Att25]  | Em_108 [Att10]  [Ent69]  | Strong_108 [Att10]  [Ent69]  | Dfn_108 [Att10]  [Ent69]  | Code_108 [Att10]  [Ent69]  | Samp_108 [Att10]  [Ent69]  | Kbd_108 [Att10]  [Ent69]  | Var_108 [Att10]  [Ent69]  | Cite_108 [Att10]  [Ent69]  | Abbr_108 [Att10]  [Ent69]  | Acronym_108 [Att10]  [Ent69]  | Q_108 [Att20]  [Ent69]  | Sub_108 [Att10]  [Ent69]  | Sup_108 [Att10]  [Ent69]  | Tt_108 [Att10]  [Ent69]  | I_108 [Att10]  [Ent69]  | B_108 [Att10]  [Ent69]  | Big_108 [Att10]  [Ent69]  | Small_108 [Att10]  [Ent69]  | U_108 [Att10]  [Ent69]  | S_108 [Att10]  [Ent69]  | Strike_108 [Att10]  [Ent69]  | Basefont_108 [Att26]  | Font_108 [Att28]  [Ent69]  | Object_108 [Att29]  [Ent86]  | Applet_108 [Att32]  [Ent86]  | Img_108 [Att35]  | Map_108 [Att38]  [Ent87]  | Table_108 [Att55]  [Ent109]  | PCDATA_108 [Att0] B.ByteString
    deriving (Show)

data Ent109 = Caption_109 [Att13]  [Ent69]  | Thead_109 [Att56]  [Ent110]  | Tfoot_109 [Att56]  [Ent110]  | Tbody_109 [Att56]  [Ent110]  | Colgroup_109 [Att57]  [Ent111]  | Col_109 [Att57]  | Tr_109 [Att58]  [Ent112] 
    deriving (Show)

data Ent110 = Tr_110 [Att58]  [Ent112] 
    deriving (Show)

data Ent111 = Col_111 [Att57] 
    deriving (Show)

data Ent112 = Th_112 [Att59]  [Ent67]  | Td_112 [Att59]  [Ent67] 
    deriving (Show)

data Ent113 = Script_113 [Att9]  [Ent114]  | Iframe_113 [Att11]  [Ent115]  | Ins_113 [Att21]  [Ent115]  | Del_113 [Att21]  [Ent115]  | A_113 [Att22]  [Ent35]  | Span_113 [Att10]  [Ent113]  | Bdo_113 [Att10]  [Ent113]  | Br_113 [Att25]  | Em_113 [Att10]  [Ent113]  | Strong_113 [Att10]  [Ent113]  | Dfn_113 [Att10]  [Ent113]  | Code_113 [Att10]  [Ent113]  | Samp_113 [Att10]  [Ent113]  | Kbd_113 [Att10]  [Ent113]  | Var_113 [Att10]  [Ent113]  | Cite_113 [Att10]  [Ent113]  | Abbr_113 [Att10]  [Ent113]  | Acronym_113 [Att10]  [Ent113]  | Q_113 [Att20]  [Ent113]  | Sub_113 [Att10]  [Ent113]  | Sup_113 [Att10]  [Ent113]  | Tt_113 [Att10]  [Ent113]  | I_113 [Att10]  [Ent113]  | B_113 [Att10]  [Ent113]  | Big_113 [Att10]  [Ent113]  | Small_113 [Att10]  [Ent113]  | U_113 [Att10]  [Ent113]  | S_113 [Att10]  [Ent113]  | Strike_113 [Att10]  [Ent113]  | Basefont_113 [Att26]  | Font_113 [Att28]  [Ent113]  | Object_113 [Att29]  [Ent125]  | Applet_113 [Att32]  [Ent125]  | Img_113 [Att35]  | Map_113 [Att38]  [Ent126]  | Input_113 [Att44]  | Select_113 [Att45]  [Ent127]  | Textarea_113 [Att49]  [Ent114]  | Button_113 [Att53]  [Ent129]  | PCDATA_113 [Att0] B.ByteString
    deriving (Show)

data Ent114 = PCDATA_114 [Att0] B.ByteString
    deriving (Show)

data Ent115 = Script_115 [Att9]  [Ent114]  | Noscript_115 [Att10]  [Ent115]  | Iframe_115 [Att11]  [Ent115]  | Noframes_115 [Att10]  [Ent115]  | Div_115 [Att13]  [Ent115]  | P_115 [Att13]  [Ent113]  | H1_115 [Att13]  [Ent113]  | H2_115 [Att13]  [Ent113]  | H3_115 [Att13]  [Ent113]  | H4_115 [Att13]  [Ent113]  | H5_115 [Att13]  [Ent113]  | H6_115 [Att13]  [Ent113]  | Ul_115 [Att14]  [Ent116]  | Ol_115 [Att15]  [Ent116]  | Menu_115 [Att16]  [Ent116]  | Dir_115 [Att16]  [Ent116]  | Dl_115 [Att16]  [Ent117]  | Address_115 [Att10]  [Ent118]  | Hr_115 [Att18]  | Pre_115 [Att19]  [Ent119]  | Blockquote_115 [Att20]  [Ent115]  | Center_115 [Att10]  [Ent115]  | Ins_115 [Att21]  [Ent115]  | Del_115 [Att21]  [Ent115]  | A_115 [Att22]  [Ent35]  | Span_115 [Att10]  [Ent113]  | Bdo_115 [Att10]  [Ent113]  | Br_115 [Att25]  | Em_115 [Att10]  [Ent113]  | Strong_115 [Att10]  [Ent113]  | Dfn_115 [Att10]  [Ent113]  | Code_115 [Att10]  [Ent113]  | Samp_115 [Att10]  [Ent113]  | Kbd_115 [Att10]  [Ent113]  | Var_115 [Att10]  [Ent113]  | Cite_115 [Att10]  [Ent113]  | Abbr_115 [Att10]  [Ent113]  | Acronym_115 [Att10]  [Ent113]  | Q_115 [Att20]  [Ent113]  | Sub_115 [Att10]  [Ent113]  | Sup_115 [Att10]  [Ent113]  | Tt_115 [Att10]  [Ent113]  | I_115 [Att10]  [Ent113]  | B_115 [Att10]  [Ent113]  | Big_115 [Att10]  [Ent113]  | Small_115 [Att10]  [Ent113]  | U_115 [Att10]  [Ent113]  | S_115 [Att10]  [Ent113]  | Strike_115 [Att10]  [Ent113]  | Basefont_115 [Att26]  | Font_115 [Att28]  [Ent113]  | Object_115 [Att29]  [Ent125]  | Applet_115 [Att32]  [Ent125]  | Img_115 [Att35]  | Map_115 [Att38]  [Ent126]  | Form_115 [Att41]  [Ent90]  | Input_115 [Att44]  | Select_115 [Att45]  [Ent127]  | Textarea_115 [Att49]  [Ent114]  | Fieldset_115 [Att10]  [Ent120]  | Button_115 [Att53]  [Ent129]  | Isindex_115 [Att54]  | Table_115 [Att55]  [Ent121]  | PCDATA_115 [Att0] B.ByteString
    deriving (Show)

data Ent116 = Li_116 [Att17]  [Ent115] 
    deriving (Show)

data Ent117 = Dt_117 [Att10]  [Ent113]  | Dd_117 [Att10]  [Ent115] 
    deriving (Show)

data Ent118 = Script_118 [Att9]  [Ent114]  | Iframe_118 [Att11]  [Ent115]  | P_118 [Att13]  [Ent113]  | Ins_118 [Att21]  [Ent115]  | Del_118 [Att21]  [Ent115]  | A_118 [Att22]  [Ent35]  | Span_118 [Att10]  [Ent113]  | Bdo_118 [Att10]  [Ent113]  | Br_118 [Att25]  | Em_118 [Att10]  [Ent113]  | Strong_118 [Att10]  [Ent113]  | Dfn_118 [Att10]  [Ent113]  | Code_118 [Att10]  [Ent113]  | Samp_118 [Att10]  [Ent113]  | Kbd_118 [Att10]  [Ent113]  | Var_118 [Att10]  [Ent113]  | Cite_118 [Att10]  [Ent113]  | Abbr_118 [Att10]  [Ent113]  | Acronym_118 [Att10]  [Ent113]  | Q_118 [Att20]  [Ent113]  | Sub_118 [Att10]  [Ent113]  | Sup_118 [Att10]  [Ent113]  | Tt_118 [Att10]  [Ent113]  | I_118 [Att10]  [Ent113]  | B_118 [Att10]  [Ent113]  | Big_118 [Att10]  [Ent113]  | Small_118 [Att10]  [Ent113]  | U_118 [Att10]  [Ent113]  | S_118 [Att10]  [Ent113]  | Strike_118 [Att10]  [Ent113]  | Basefont_118 [Att26]  | Font_118 [Att28]  [Ent113]  | Object_118 [Att29]  [Ent125]  | Applet_118 [Att32]  [Ent125]  | Img_118 [Att35]  | Map_118 [Att38]  [Ent126]  | Input_118 [Att44]  | Select_118 [Att45]  [Ent127]  | Textarea_118 [Att49]  [Ent114]  | Button_118 [Att53]  [Ent129]  | PCDATA_118 [Att0] B.ByteString
    deriving (Show)

data Ent119 = Script_119 [Att9]  [Ent114]  | Ins_119 [Att21]  [Ent115]  | Del_119 [Att21]  [Ent115]  | A_119 [Att22]  [Ent35]  | Span_119 [Att10]  [Ent113]  | Bdo_119 [Att10]  [Ent113]  | Br_119 [Att25]  | Em_119 [Att10]  [Ent113]  | Strong_119 [Att10]  [Ent113]  | Dfn_119 [Att10]  [Ent113]  | Code_119 [Att10]  [Ent113]  | Samp_119 [Att10]  [Ent113]  | Kbd_119 [Att10]  [Ent113]  | Var_119 [Att10]  [Ent113]  | Cite_119 [Att10]  [Ent113]  | Abbr_119 [Att10]  [Ent113]  | Acronym_119 [Att10]  [Ent113]  | Q_119 [Att20]  [Ent113]  | Tt_119 [Att10]  [Ent113]  | I_119 [Att10]  [Ent113]  | B_119 [Att10]  [Ent113]  | U_119 [Att10]  [Ent113]  | S_119 [Att10]  [Ent113]  | Strike_119 [Att10]  [Ent113]  | Input_119 [Att44]  | Select_119 [Att45]  [Ent127]  | Textarea_119 [Att49]  [Ent114]  | Button_119 [Att53]  [Ent129]  | PCDATA_119 [Att0] B.ByteString
    deriving (Show)

data Ent120 = Script_120 [Att9]  [Ent114]  | Noscript_120 [Att10]  [Ent115]  | Iframe_120 [Att11]  [Ent115]  | Noframes_120 [Att10]  [Ent115]  | Div_120 [Att13]  [Ent115]  | P_120 [Att13]  [Ent113]  | H1_120 [Att13]  [Ent113]  | H2_120 [Att13]  [Ent113]  | H3_120 [Att13]  [Ent113]  | H4_120 [Att13]  [Ent113]  | H5_120 [Att13]  [Ent113]  | H6_120 [Att13]  [Ent113]  | Ul_120 [Att14]  [Ent116]  | Ol_120 [Att15]  [Ent116]  | Menu_120 [Att16]  [Ent116]  | Dir_120 [Att16]  [Ent116]  | Dl_120 [Att16]  [Ent117]  | Address_120 [Att10]  [Ent118]  | Hr_120 [Att18]  | Pre_120 [Att19]  [Ent119]  | Blockquote_120 [Att20]  [Ent115]  | Center_120 [Att10]  [Ent115]  | Ins_120 [Att21]  [Ent115]  | Del_120 [Att21]  [Ent115]  | A_120 [Att22]  [Ent35]  | Span_120 [Att10]  [Ent113]  | Bdo_120 [Att10]  [Ent113]  | Br_120 [Att25]  | Em_120 [Att10]  [Ent113]  | Strong_120 [Att10]  [Ent113]  | Dfn_120 [Att10]  [Ent113]  | Code_120 [Att10]  [Ent113]  | Samp_120 [Att10]  [Ent113]  | Kbd_120 [Att10]  [Ent113]  | Var_120 [Att10]  [Ent113]  | Cite_120 [Att10]  [Ent113]  | Abbr_120 [Att10]  [Ent113]  | Acronym_120 [Att10]  [Ent113]  | Q_120 [Att20]  [Ent113]  | Sub_120 [Att10]  [Ent113]  | Sup_120 [Att10]  [Ent113]  | Tt_120 [Att10]  [Ent113]  | I_120 [Att10]  [Ent113]  | B_120 [Att10]  [Ent113]  | Big_120 [Att10]  [Ent113]  | Small_120 [Att10]  [Ent113]  | U_120 [Att10]  [Ent113]  | S_120 [Att10]  [Ent113]  | Strike_120 [Att10]  [Ent113]  | Basefont_120 [Att26]  | Font_120 [Att28]  [Ent113]  | Object_120 [Att29]  [Ent125]  | Applet_120 [Att32]  [Ent125]  | Img_120 [Att35]  | Map_120 [Att38]  [Ent126]  | Form_120 [Att41]  [Ent90]  | Input_120 [Att44]  | Select_120 [Att45]  [Ent127]  | Textarea_120 [Att49]  [Ent114]  | Fieldset_120 [Att10]  [Ent120]  | Legend_120 [Att52]  [Ent113]  | Button_120 [Att53]  [Ent129]  | Isindex_120 [Att54]  | Table_120 [Att55]  [Ent121]  | PCDATA_120 [Att0] B.ByteString
    deriving (Show)

data Ent121 = Caption_121 [Att13]  [Ent113]  | Thead_121 [Att56]  [Ent122]  | Tfoot_121 [Att56]  [Ent122]  | Tbody_121 [Att56]  [Ent122]  | Colgroup_121 [Att57]  [Ent123]  | Col_121 [Att57]  | Tr_121 [Att58]  [Ent124] 
    deriving (Show)

data Ent122 = Tr_122 [Att58]  [Ent124] 
    deriving (Show)

data Ent123 = Col_123 [Att57] 
    deriving (Show)

data Ent124 = Th_124 [Att59]  [Ent115]  | Td_124 [Att59]  [Ent115] 
    deriving (Show)

data Ent125 = Script_125 [Att9]  [Ent114]  | Noscript_125 [Att10]  [Ent115]  | Iframe_125 [Att11]  [Ent115]  | Noframes_125 [Att10]  [Ent115]  | Div_125 [Att13]  [Ent115]  | P_125 [Att13]  [Ent113]  | H1_125 [Att13]  [Ent113]  | H2_125 [Att13]  [Ent113]  | H3_125 [Att13]  [Ent113]  | H4_125 [Att13]  [Ent113]  | H5_125 [Att13]  [Ent113]  | H6_125 [Att13]  [Ent113]  | Ul_125 [Att14]  [Ent116]  | Ol_125 [Att15]  [Ent116]  | Menu_125 [Att16]  [Ent116]  | Dir_125 [Att16]  [Ent116]  | Dl_125 [Att16]  [Ent117]  | Address_125 [Att10]  [Ent118]  | Hr_125 [Att18]  | Pre_125 [Att19]  [Ent119]  | Blockquote_125 [Att20]  [Ent115]  | Center_125 [Att10]  [Ent115]  | Ins_125 [Att21]  [Ent115]  | Del_125 [Att21]  [Ent115]  | A_125 [Att22]  [Ent35]  | Span_125 [Att10]  [Ent113]  | Bdo_125 [Att10]  [Ent113]  | Br_125 [Att25]  | Em_125 [Att10]  [Ent113]  | Strong_125 [Att10]  [Ent113]  | Dfn_125 [Att10]  [Ent113]  | Code_125 [Att10]  [Ent113]  | Samp_125 [Att10]  [Ent113]  | Kbd_125 [Att10]  [Ent113]  | Var_125 [Att10]  [Ent113]  | Cite_125 [Att10]  [Ent113]  | Abbr_125 [Att10]  [Ent113]  | Acronym_125 [Att10]  [Ent113]  | Q_125 [Att20]  [Ent113]  | Sub_125 [Att10]  [Ent113]  | Sup_125 [Att10]  [Ent113]  | Tt_125 [Att10]  [Ent113]  | I_125 [Att10]  [Ent113]  | B_125 [Att10]  [Ent113]  | Big_125 [Att10]  [Ent113]  | Small_125 [Att10]  [Ent113]  | U_125 [Att10]  [Ent113]  | S_125 [Att10]  [Ent113]  | Strike_125 [Att10]  [Ent113]  | Basefont_125 [Att26]  | Font_125 [Att28]  [Ent113]  | Object_125 [Att29]  [Ent125]  | Param_125 [Att30]  | Applet_125 [Att32]  [Ent125]  | Img_125 [Att35]  | Map_125 [Att38]  [Ent126]  | Form_125 [Att41]  [Ent90]  | Input_125 [Att44]  | Select_125 [Att45]  [Ent127]  | Textarea_125 [Att49]  [Ent114]  | Fieldset_125 [Att10]  [Ent120]  | Button_125 [Att53]  [Ent129]  | Isindex_125 [Att54]  | Table_125 [Att55]  [Ent121]  | PCDATA_125 [Att0] B.ByteString
    deriving (Show)

data Ent126 = Script_126 [Att9]  [Ent114]  | Noscript_126 [Att10]  [Ent115]  | Noframes_126 [Att10]  [Ent115]  | Div_126 [Att13]  [Ent115]  | P_126 [Att13]  [Ent113]  | H1_126 [Att13]  [Ent113]  | H2_126 [Att13]  [Ent113]  | H3_126 [Att13]  [Ent113]  | H4_126 [Att13]  [Ent113]  | H5_126 [Att13]  [Ent113]  | H6_126 [Att13]  [Ent113]  | Ul_126 [Att14]  [Ent116]  | Ol_126 [Att15]  [Ent116]  | Menu_126 [Att16]  [Ent116]  | Dir_126 [Att16]  [Ent116]  | Dl_126 [Att16]  [Ent117]  | Address_126 [Att10]  [Ent118]  | Hr_126 [Att18]  | Pre_126 [Att19]  [Ent119]  | Blockquote_126 [Att20]  [Ent115]  | Center_126 [Att10]  [Ent115]  | Ins_126 [Att21]  [Ent115]  | Del_126 [Att21]  [Ent115]  | Area_126 [Att40]  | Form_126 [Att41]  [Ent90]  | Fieldset_126 [Att10]  [Ent120]  | Isindex_126 [Att54]  | Table_126 [Att55]  [Ent121] 
    deriving (Show)

data Ent127 = Optgroup_127 [Att46]  [Ent128]  | Option_127 [Att48]  [Ent114] 
    deriving (Show)

data Ent128 = Option_128 [Att48]  [Ent114] 
    deriving (Show)

data Ent129 = Script_129 [Att9]  [Ent114]  | Noscript_129 [Att10]  [Ent115]  | Noframes_129 [Att10]  [Ent115]  | Div_129 [Att13]  [Ent115]  | P_129 [Att13]  [Ent113]  | H1_129 [Att13]  [Ent113]  | H2_129 [Att13]  [Ent113]  | H3_129 [Att13]  [Ent113]  | H4_129 [Att13]  [Ent113]  | H5_129 [Att13]  [Ent113]  | H6_129 [Att13]  [Ent113]  | Ul_129 [Att14]  [Ent116]  | Ol_129 [Att15]  [Ent116]  | Menu_129 [Att16]  [Ent116]  | Dir_129 [Att16]  [Ent116]  | Dl_129 [Att16]  [Ent117]  | Address_129 [Att10]  [Ent118]  | Hr_129 [Att18]  | Pre_129 [Att19]  [Ent119]  | Blockquote_129 [Att20]  [Ent115]  | Center_129 [Att10]  [Ent115]  | Ins_129 [Att21]  [Ent115]  | Del_129 [Att21]  [Ent115]  | Span_129 [Att10]  [Ent113]  | Bdo_129 [Att10]  [Ent113]  | Br_129 [Att25]  | Em_129 [Att10]  [Ent113]  | Strong_129 [Att10]  [Ent113]  | Dfn_129 [Att10]  [Ent113]  | Code_129 [Att10]  [Ent113]  | Samp_129 [Att10]  [Ent113]  | Kbd_129 [Att10]  [Ent113]  | Var_129 [Att10]  [Ent113]  | Cite_129 [Att10]  [Ent113]  | Abbr_129 [Att10]  [Ent113]  | Acronym_129 [Att10]  [Ent113]  | Q_129 [Att20]  [Ent113]  | Sub_129 [Att10]  [Ent113]  | Sup_129 [Att10]  [Ent113]  | Tt_129 [Att10]  [Ent113]  | I_129 [Att10]  [Ent113]  | B_129 [Att10]  [Ent113]  | Big_129 [Att10]  [Ent113]  | Small_129 [Att10]  [Ent113]  | U_129 [Att10]  [Ent113]  | S_129 [Att10]  [Ent113]  | Strike_129 [Att10]  [Ent113]  | Basefont_129 [Att26]  | Font_129 [Att28]  [Ent113]  | Object_129 [Att29]  [Ent125]  | Applet_129 [Att32]  [Ent125]  | Img_129 [Att35]  | Map_129 [Att38]  [Ent126]  | Table_129 [Att55]  [Ent121]  | PCDATA_129 [Att0] B.ByteString
    deriving (Show)

data Ent130 = Optgroup_130 [Att46]  [Ent131]  | Option_130 [Att48]  [Ent2] 
    deriving (Show)

data Ent131 = Option_131 [Att48]  [Ent2] 
    deriving (Show)

data Ent132 = Script_132 [Att9]  [Ent2]  | Noscript_132 [Att10]  [Ent4]  | Iframe_132 [Att11]  [Ent4]  | Noframes_132 [Att10]  [Ent4]  | Div_132 [Att13]  [Ent4]  | P_132 [Att13]  [Ent5]  | H1_132 [Att13]  [Ent5]  | H2_132 [Att13]  [Ent5]  | H3_132 [Att13]  [Ent5]  | H4_132 [Att13]  [Ent5]  | H5_132 [Att13]  [Ent5]  | H6_132 [Att13]  [Ent5]  | Ul_132 [Att14]  [Ent6]  | Ol_132 [Att15]  [Ent6]  | Menu_132 [Att16]  [Ent6]  | Dir_132 [Att16]  [Ent6]  | Dl_132 [Att16]  [Ent7]  | Address_132 [Att10]  [Ent8]  | Hr_132 [Att18]  | Pre_132 [Att19]  [Ent9]  | Blockquote_132 [Att20]  [Ent4]  | Center_132 [Att10]  [Ent4]  | Ins_132 [Att21]  [Ent4]  | Del_132 [Att21]  [Ent4]  | A_132 [Att22]  [Ent10]  | Span_132 [Att10]  [Ent5]  | Bdo_132 [Att10]  [Ent5]  | Br_132 [Att25]  | Em_132 [Att10]  [Ent5]  | Strong_132 [Att10]  [Ent5]  | Dfn_132 [Att10]  [Ent5]  | Code_132 [Att10]  [Ent5]  | Samp_132 [Att10]  [Ent5]  | Kbd_132 [Att10]  [Ent5]  | Var_132 [Att10]  [Ent5]  | Cite_132 [Att10]  [Ent5]  | Abbr_132 [Att10]  [Ent5]  | Acronym_132 [Att10]  [Ent5]  | Q_132 [Att20]  [Ent5]  | Sub_132 [Att10]  [Ent5]  | Sup_132 [Att10]  [Ent5]  | Tt_132 [Att10]  [Ent5]  | I_132 [Att10]  [Ent5]  | B_132 [Att10]  [Ent5]  | Big_132 [Att10]  [Ent5]  | Small_132 [Att10]  [Ent5]  | U_132 [Att10]  [Ent5]  | S_132 [Att10]  [Ent5]  | Strike_132 [Att10]  [Ent5]  | Basefont_132 [Att26]  | Font_132 [Att28]  [Ent5]  | Object_132 [Att29]  [Ent3]  | Applet_132 [Att32]  [Ent3]  | Img_132 [Att35]  | Map_132 [Att38]  [Ent66]  | Form_132 [Att41]  [Ent67]  | Label_132 [Att43]  [Ent113]  | Input_132 [Att44]  | Select_132 [Att45]  [Ent130]  | Textarea_132 [Att49]  [Ent2]  | Fieldset_132 [Att10]  [Ent132]  | Legend_132 [Att52]  [Ent5]  | Button_132 [Att53]  [Ent133]  | Isindex_132 [Att54]  | Table_132 [Att55]  [Ent134]  | PCDATA_132 [Att0] B.ByteString
    deriving (Show)

data Ent133 = Script_133 [Att9]  [Ent2]  | Noscript_133 [Att10]  [Ent4]  | Noframes_133 [Att10]  [Ent4]  | Div_133 [Att13]  [Ent4]  | P_133 [Att13]  [Ent5]  | H1_133 [Att13]  [Ent5]  | H2_133 [Att13]  [Ent5]  | H3_133 [Att13]  [Ent5]  | H4_133 [Att13]  [Ent5]  | H5_133 [Att13]  [Ent5]  | H6_133 [Att13]  [Ent5]  | Ul_133 [Att14]  [Ent6]  | Ol_133 [Att15]  [Ent6]  | Menu_133 [Att16]  [Ent6]  | Dir_133 [Att16]  [Ent6]  | Dl_133 [Att16]  [Ent7]  | Address_133 [Att10]  [Ent8]  | Hr_133 [Att18]  | Pre_133 [Att19]  [Ent9]  | Blockquote_133 [Att20]  [Ent4]  | Center_133 [Att10]  [Ent4]  | Ins_133 [Att21]  [Ent4]  | Del_133 [Att21]  [Ent4]  | Span_133 [Att10]  [Ent5]  | Bdo_133 [Att10]  [Ent5]  | Br_133 [Att25]  | Em_133 [Att10]  [Ent5]  | Strong_133 [Att10]  [Ent5]  | Dfn_133 [Att10]  [Ent5]  | Code_133 [Att10]  [Ent5]  | Samp_133 [Att10]  [Ent5]  | Kbd_133 [Att10]  [Ent5]  | Var_133 [Att10]  [Ent5]  | Cite_133 [Att10]  [Ent5]  | Abbr_133 [Att10]  [Ent5]  | Acronym_133 [Att10]  [Ent5]  | Q_133 [Att20]  [Ent5]  | Sub_133 [Att10]  [Ent5]  | Sup_133 [Att10]  [Ent5]  | Tt_133 [Att10]  [Ent5]  | I_133 [Att10]  [Ent5]  | B_133 [Att10]  [Ent5]  | Big_133 [Att10]  [Ent5]  | Small_133 [Att10]  [Ent5]  | U_133 [Att10]  [Ent5]  | S_133 [Att10]  [Ent5]  | Strike_133 [Att10]  [Ent5]  | Basefont_133 [Att26]  | Font_133 [Att28]  [Ent5]  | Object_133 [Att29]  [Ent3]  | Applet_133 [Att32]  [Ent3]  | Img_133 [Att35]  | Map_133 [Att38]  [Ent66]  | Table_133 [Att55]  [Ent134]  | PCDATA_133 [Att0] B.ByteString
    deriving (Show)

data Ent134 = Caption_134 [Att13]  [Ent5]  | Thead_134 [Att56]  [Ent135]  | Tfoot_134 [Att56]  [Ent135]  | Tbody_134 [Att56]  [Ent135]  | Colgroup_134 [Att57]  [Ent136]  | Col_134 [Att57]  | Tr_134 [Att58]  [Ent137] 
    deriving (Show)

data Ent135 = Tr_135 [Att58]  [Ent137] 
    deriving (Show)

data Ent136 = Col_136 [Att57] 
    deriving (Show)

data Ent137 = Th_137 [Att59]  [Ent4]  | Td_137 [Att59]  [Ent4] 
    deriving (Show)


-------------------------

_html :: [Ent0] -> Ent
_html  = Html [xmlns_att "http://www.w3.org/1999/xhtml"] 
html_ :: [Att0] -> [Ent0] -> Ent
html_ at  = Html (xmlns_att "http://www.w3.org/1999/xhtml" :at) 

class C_Head a b | a -> b where
    _head :: [b] -> a
    head_ :: [Att1] -> [b] -> a
instance C_Head Ent0 Ent1 where
    _head = Head_0 []
    head_  = Head_0 

class C_Title a b | a -> b where
    _title :: [b] -> a
    title_ :: [Att2] -> [b] -> a
instance C_Title Ent1 Ent2 where
    _title = Title_1 []
    title_  = Title_1 

class C_Base a where
    _base :: a
    base_ :: [Att3] -> a
instance C_Base Ent1 where
    _base = Base_1 []
    base_ = Base_1 

class C_Meta a where
    _meta :: a
    meta_ :: [Att4] -> a
instance C_Meta Ent1 where
    _meta = Meta_1 []
    meta_ = Meta_1 

class C_Link a where
    _link :: a
    link_ :: [Att6] -> a
instance C_Link Ent1 where
    _link = Link_1 []
    link_ = Link_1 

class C_Style a b | a -> b where
    _style :: [b] -> a
    style_ :: [Att7] -> [b] -> a
instance C_Style Ent1 Ent2 where
    _style = Style_1 []
    style_  = Style_1 

class C_Script a b | a -> b where
    _script :: [b] -> a
    script_ :: [Att9] -> [b] -> a
instance C_Script Ent1 Ent2 where
    _script = Script_1 []
    script_  = Script_1 
instance C_Script Ent3 Ent2 where
    _script = Script_3 []
    script_  = Script_3 
instance C_Script Ent4 Ent2 where
    _script = Script_4 []
    script_  = Script_4 
instance C_Script Ent5 Ent2 where
    _script = Script_5 []
    script_  = Script_5 
instance C_Script Ent8 Ent2 where
    _script = Script_8 []
    script_  = Script_8 
instance C_Script Ent9 Ent2 where
    _script = Script_9 []
    script_  = Script_9 
instance C_Script Ent10 Ent11 where
    _script = Script_10 []
    script_  = Script_10 
instance C_Script Ent12 Ent11 where
    _script = Script_12 []
    script_  = Script_12 
instance C_Script Ent15 Ent11 where
    _script = Script_15 []
    script_  = Script_15 
instance C_Script Ent16 Ent11 where
    _script = Script_16 []
    script_  = Script_16 
instance C_Script Ent17 Ent74 where
    _script = Script_17 []
    script_  = Script_17 
instance C_Script Ent18 Ent74 where
    _script = Script_18 []
    script_  = Script_18 
instance C_Script Ent21 Ent74 where
    _script = Script_21 []
    script_  = Script_21 
instance C_Script Ent22 Ent74 where
    _script = Script_22 []
    script_  = Script_22 
instance C_Script Ent23 Ent74 where
    _script = Script_23 []
    script_  = Script_23 
instance C_Script Ent28 Ent11 where
    _script = Script_28 []
    script_  = Script_28 
instance C_Script Ent33 Ent11 where
    _script = Script_33 []
    script_  = Script_33 
instance C_Script Ent34 Ent11 where
    _script = Script_34 []
    script_  = Script_34 
instance C_Script Ent35 Ent36 where
    _script = Script_35 []
    script_  = Script_35 
instance C_Script Ent37 Ent36 where
    _script = Script_37 []
    script_  = Script_37 
instance C_Script Ent40 Ent36 where
    _script = Script_40 []
    script_  = Script_40 
instance C_Script Ent41 Ent36 where
    _script = Script_41 []
    script_  = Script_41 
instance C_Script Ent42 Ent77 where
    _script = Script_42 []
    script_  = Script_42 
instance C_Script Ent43 Ent77 where
    _script = Script_43 []
    script_  = Script_43 
instance C_Script Ent46 Ent77 where
    _script = Script_46 []
    script_  = Script_46 
instance C_Script Ent47 Ent77 where
    _script = Script_47 []
    script_  = Script_47 
instance C_Script Ent48 Ent77 where
    _script = Script_48 []
    script_  = Script_48 
instance C_Script Ent53 Ent36 where
    _script = Script_53 []
    script_  = Script_53 
instance C_Script Ent58 Ent36 where
    _script = Script_58 []
    script_  = Script_58 
instance C_Script Ent59 Ent36 where
    _script = Script_59 []
    script_  = Script_59 
instance C_Script Ent62 Ent36 where
    _script = Script_62 []
    script_  = Script_62 
instance C_Script Ent65 Ent11 where
    _script = Script_65 []
    script_  = Script_65 
instance C_Script Ent66 Ent2 where
    _script = Script_66 []
    script_  = Script_66 
instance C_Script Ent67 Ent68 where
    _script = Script_67 []
    script_  = Script_67 
instance C_Script Ent69 Ent68 where
    _script = Script_69 []
    script_  = Script_69 
instance C_Script Ent72 Ent68 where
    _script = Script_72 []
    script_  = Script_72 
instance C_Script Ent73 Ent68 where
    _script = Script_73 []
    script_  = Script_73 
instance C_Script Ent75 Ent74 where
    _script = Script_75 []
    script_  = Script_75 
instance C_Script Ent76 Ent74 where
    _script = Script_76 []
    script_  = Script_76 
instance C_Script Ent78 Ent77 where
    _script = Script_78 []
    script_  = Script_78 
instance C_Script Ent79 Ent77 where
    _script = Script_79 []
    script_  = Script_79 
instance C_Script Ent82 Ent77 where
    _script = Script_82 []
    script_  = Script_82 
instance C_Script Ent85 Ent74 where
    _script = Script_85 []
    script_  = Script_85 
instance C_Script Ent86 Ent68 where
    _script = Script_86 []
    script_  = Script_86 
instance C_Script Ent87 Ent68 where
    _script = Script_87 []
    script_  = Script_87 
instance C_Script Ent88 Ent89 where
    _script = Script_88 []
    script_  = Script_88 
instance C_Script Ent90 Ent89 where
    _script = Script_90 []
    script_  = Script_90 
instance C_Script Ent93 Ent89 where
    _script = Script_93 []
    script_  = Script_93 
instance C_Script Ent94 Ent89 where
    _script = Script_94 []
    script_  = Script_94 
instance C_Script Ent95 Ent89 where
    _script = Script_95 []
    script_  = Script_95 
instance C_Script Ent100 Ent89 where
    _script = Script_100 []
    script_  = Script_100 
instance C_Script Ent101 Ent89 where
    _script = Script_101 []
    script_  = Script_101 
instance C_Script Ent104 Ent89 where
    _script = Script_104 []
    script_  = Script_104 
instance C_Script Ent107 Ent68 where
    _script = Script_107 []
    script_  = Script_107 
instance C_Script Ent108 Ent68 where
    _script = Script_108 []
    script_  = Script_108 
instance C_Script Ent113 Ent114 where
    _script = Script_113 []
    script_  = Script_113 
instance C_Script Ent115 Ent114 where
    _script = Script_115 []
    script_  = Script_115 
instance C_Script Ent118 Ent114 where
    _script = Script_118 []
    script_  = Script_118 
instance C_Script Ent119 Ent114 where
    _script = Script_119 []
    script_  = Script_119 
instance C_Script Ent120 Ent114 where
    _script = Script_120 []
    script_  = Script_120 
instance C_Script Ent125 Ent114 where
    _script = Script_125 []
    script_  = Script_125 
instance C_Script Ent126 Ent114 where
    _script = Script_126 []
    script_  = Script_126 
instance C_Script Ent129 Ent114 where
    _script = Script_129 []
    script_  = Script_129 
instance C_Script Ent132 Ent2 where
    _script = Script_132 []
    script_  = Script_132 
instance C_Script Ent133 Ent2 where
    _script = Script_133 []
    script_  = Script_133 

class C_Noscript a b | a -> b where
    _noscript :: [b] -> a
    noscript_ :: [Att10] -> [b] -> a
instance C_Noscript Ent3 Ent4 where
    _noscript = Noscript_3 []
    noscript_  = Noscript_3 
instance C_Noscript Ent4 Ent4 where
    _noscript = Noscript_4 []
    noscript_  = Noscript_4 
instance C_Noscript Ent12 Ent12 where
    _noscript = Noscript_12 []
    noscript_  = Noscript_12 
instance C_Noscript Ent17 Ent17 where
    _noscript = Noscript_17 []
    noscript_  = Noscript_17 
instance C_Noscript Ent23 Ent17 where
    _noscript = Noscript_23 []
    noscript_  = Noscript_23 
instance C_Noscript Ent28 Ent12 where
    _noscript = Noscript_28 []
    noscript_  = Noscript_28 
instance C_Noscript Ent33 Ent12 where
    _noscript = Noscript_33 []
    noscript_  = Noscript_33 
instance C_Noscript Ent34 Ent12 where
    _noscript = Noscript_34 []
    noscript_  = Noscript_34 
instance C_Noscript Ent37 Ent37 where
    _noscript = Noscript_37 []
    noscript_  = Noscript_37 
instance C_Noscript Ent42 Ent42 where
    _noscript = Noscript_42 []
    noscript_  = Noscript_42 
instance C_Noscript Ent48 Ent42 where
    _noscript = Noscript_48 []
    noscript_  = Noscript_48 
instance C_Noscript Ent53 Ent37 where
    _noscript = Noscript_53 []
    noscript_  = Noscript_53 
instance C_Noscript Ent58 Ent37 where
    _noscript = Noscript_58 []
    noscript_  = Noscript_58 
instance C_Noscript Ent59 Ent37 where
    _noscript = Noscript_59 []
    noscript_  = Noscript_59 
instance C_Noscript Ent62 Ent37 where
    _noscript = Noscript_62 []
    noscript_  = Noscript_62 
instance C_Noscript Ent65 Ent12 where
    _noscript = Noscript_65 []
    noscript_  = Noscript_65 
instance C_Noscript Ent66 Ent4 where
    _noscript = Noscript_66 []
    noscript_  = Noscript_66 
instance C_Noscript Ent67 Ent67 where
    _noscript = Noscript_67 []
    noscript_  = Noscript_67 
instance C_Noscript Ent75 Ent17 where
    _noscript = Noscript_75 []
    noscript_  = Noscript_75 
instance C_Noscript Ent76 Ent17 where
    _noscript = Noscript_76 []
    noscript_  = Noscript_76 
instance C_Noscript Ent78 Ent42 where
    _noscript = Noscript_78 []
    noscript_  = Noscript_78 
instance C_Noscript Ent79 Ent42 where
    _noscript = Noscript_79 []
    noscript_  = Noscript_79 
instance C_Noscript Ent82 Ent42 where
    _noscript = Noscript_82 []
    noscript_  = Noscript_82 
instance C_Noscript Ent85 Ent17 where
    _noscript = Noscript_85 []
    noscript_  = Noscript_85 
instance C_Noscript Ent86 Ent67 where
    _noscript = Noscript_86 []
    noscript_  = Noscript_86 
instance C_Noscript Ent87 Ent67 where
    _noscript = Noscript_87 []
    noscript_  = Noscript_87 
instance C_Noscript Ent90 Ent90 where
    _noscript = Noscript_90 []
    noscript_  = Noscript_90 
instance C_Noscript Ent95 Ent90 where
    _noscript = Noscript_95 []
    noscript_  = Noscript_95 
instance C_Noscript Ent100 Ent90 where
    _noscript = Noscript_100 []
    noscript_  = Noscript_100 
instance C_Noscript Ent101 Ent90 where
    _noscript = Noscript_101 []
    noscript_  = Noscript_101 
instance C_Noscript Ent104 Ent90 where
    _noscript = Noscript_104 []
    noscript_  = Noscript_104 
instance C_Noscript Ent107 Ent67 where
    _noscript = Noscript_107 []
    noscript_  = Noscript_107 
instance C_Noscript Ent108 Ent67 where
    _noscript = Noscript_108 []
    noscript_  = Noscript_108 
instance C_Noscript Ent115 Ent115 where
    _noscript = Noscript_115 []
    noscript_  = Noscript_115 
instance C_Noscript Ent120 Ent115 where
    _noscript = Noscript_120 []
    noscript_  = Noscript_120 
instance C_Noscript Ent125 Ent115 where
    _noscript = Noscript_125 []
    noscript_  = Noscript_125 
instance C_Noscript Ent126 Ent115 where
    _noscript = Noscript_126 []
    noscript_  = Noscript_126 
instance C_Noscript Ent129 Ent115 where
    _noscript = Noscript_129 []
    noscript_  = Noscript_129 
instance C_Noscript Ent132 Ent4 where
    _noscript = Noscript_132 []
    noscript_  = Noscript_132 
instance C_Noscript Ent133 Ent4 where
    _noscript = Noscript_133 []
    noscript_  = Noscript_133 

class C_Iframe a b | a -> b where
    _iframe :: [b] -> a
    iframe_ :: [Att11] -> [b] -> a
instance C_Iframe Ent3 Ent4 where
    _iframe = Iframe_3 []
    iframe_  = Iframe_3 
instance C_Iframe Ent4 Ent4 where
    _iframe = Iframe_4 []
    iframe_  = Iframe_4 
instance C_Iframe Ent5 Ent4 where
    _iframe = Iframe_5 []
    iframe_  = Iframe_5 
instance C_Iframe Ent8 Ent4 where
    _iframe = Iframe_8 []
    iframe_  = Iframe_8 
instance C_Iframe Ent10 Ent12 where
    _iframe = Iframe_10 []
    iframe_  = Iframe_10 
instance C_Iframe Ent12 Ent12 where
    _iframe = Iframe_12 []
    iframe_  = Iframe_12 
instance C_Iframe Ent15 Ent12 where
    _iframe = Iframe_15 []
    iframe_  = Iframe_15 
instance C_Iframe Ent17 Ent17 where
    _iframe = Iframe_17 []
    iframe_  = Iframe_17 
instance C_Iframe Ent18 Ent17 where
    _iframe = Iframe_18 []
    iframe_  = Iframe_18 
instance C_Iframe Ent21 Ent17 where
    _iframe = Iframe_21 []
    iframe_  = Iframe_21 
instance C_Iframe Ent23 Ent17 where
    _iframe = Iframe_23 []
    iframe_  = Iframe_23 
instance C_Iframe Ent28 Ent12 where
    _iframe = Iframe_28 []
    iframe_  = Iframe_28 
instance C_Iframe Ent33 Ent12 where
    _iframe = Iframe_33 []
    iframe_  = Iframe_33 
instance C_Iframe Ent35 Ent37 where
    _iframe = Iframe_35 []
    iframe_  = Iframe_35 
instance C_Iframe Ent37 Ent37 where
    _iframe = Iframe_37 []
    iframe_  = Iframe_37 
instance C_Iframe Ent40 Ent37 where
    _iframe = Iframe_40 []
    iframe_  = Iframe_40 
instance C_Iframe Ent42 Ent42 where
    _iframe = Iframe_42 []
    iframe_  = Iframe_42 
instance C_Iframe Ent43 Ent42 where
    _iframe = Iframe_43 []
    iframe_  = Iframe_43 
instance C_Iframe Ent46 Ent42 where
    _iframe = Iframe_46 []
    iframe_  = Iframe_46 
instance C_Iframe Ent48 Ent42 where
    _iframe = Iframe_48 []
    iframe_  = Iframe_48 
instance C_Iframe Ent53 Ent37 where
    _iframe = Iframe_53 []
    iframe_  = Iframe_53 
instance C_Iframe Ent58 Ent37 where
    _iframe = Iframe_58 []
    iframe_  = Iframe_58 
instance C_Iframe Ent67 Ent67 where
    _iframe = Iframe_67 []
    iframe_  = Iframe_67 
instance C_Iframe Ent69 Ent67 where
    _iframe = Iframe_69 []
    iframe_  = Iframe_69 
instance C_Iframe Ent72 Ent67 where
    _iframe = Iframe_72 []
    iframe_  = Iframe_72 
instance C_Iframe Ent75 Ent17 where
    _iframe = Iframe_75 []
    iframe_  = Iframe_75 
instance C_Iframe Ent78 Ent42 where
    _iframe = Iframe_78 []
    iframe_  = Iframe_78 
instance C_Iframe Ent86 Ent67 where
    _iframe = Iframe_86 []
    iframe_  = Iframe_86 
instance C_Iframe Ent88 Ent90 where
    _iframe = Iframe_88 []
    iframe_  = Iframe_88 
instance C_Iframe Ent90 Ent90 where
    _iframe = Iframe_90 []
    iframe_  = Iframe_90 
instance C_Iframe Ent93 Ent90 where
    _iframe = Iframe_93 []
    iframe_  = Iframe_93 
instance C_Iframe Ent95 Ent90 where
    _iframe = Iframe_95 []
    iframe_  = Iframe_95 
instance C_Iframe Ent100 Ent90 where
    _iframe = Iframe_100 []
    iframe_  = Iframe_100 
instance C_Iframe Ent107 Ent67 where
    _iframe = Iframe_107 []
    iframe_  = Iframe_107 
instance C_Iframe Ent113 Ent115 where
    _iframe = Iframe_113 []
    iframe_  = Iframe_113 
instance C_Iframe Ent115 Ent115 where
    _iframe = Iframe_115 []
    iframe_  = Iframe_115 
instance C_Iframe Ent118 Ent115 where
    _iframe = Iframe_118 []
    iframe_  = Iframe_118 
instance C_Iframe Ent120 Ent115 where
    _iframe = Iframe_120 []
    iframe_  = Iframe_120 
instance C_Iframe Ent125 Ent115 where
    _iframe = Iframe_125 []
    iframe_  = Iframe_125 
instance C_Iframe Ent132 Ent4 where
    _iframe = Iframe_132 []
    iframe_  = Iframe_132 

class C_Noframes a b | a -> b where
    _noframes :: [b] -> a
    noframes_ :: [Att10] -> [b] -> a
instance C_Noframes Ent3 Ent4 where
    _noframes = Noframes_3 []
    noframes_  = Noframes_3 
instance C_Noframes Ent4 Ent4 where
    _noframes = Noframes_4 []
    noframes_  = Noframes_4 
instance C_Noframes Ent12 Ent12 where
    _noframes = Noframes_12 []
    noframes_  = Noframes_12 
instance C_Noframes Ent17 Ent17 where
    _noframes = Noframes_17 []
    noframes_  = Noframes_17 
instance C_Noframes Ent23 Ent17 where
    _noframes = Noframes_23 []
    noframes_  = Noframes_23 
instance C_Noframes Ent28 Ent12 where
    _noframes = Noframes_28 []
    noframes_  = Noframes_28 
instance C_Noframes Ent33 Ent12 where
    _noframes = Noframes_33 []
    noframes_  = Noframes_33 
instance C_Noframes Ent34 Ent12 where
    _noframes = Noframes_34 []
    noframes_  = Noframes_34 
instance C_Noframes Ent37 Ent37 where
    _noframes = Noframes_37 []
    noframes_  = Noframes_37 
instance C_Noframes Ent42 Ent42 where
    _noframes = Noframes_42 []
    noframes_  = Noframes_42 
instance C_Noframes Ent48 Ent42 where
    _noframes = Noframes_48 []
    noframes_  = Noframes_48 
instance C_Noframes Ent53 Ent37 where
    _noframes = Noframes_53 []
    noframes_  = Noframes_53 
instance C_Noframes Ent58 Ent37 where
    _noframes = Noframes_58 []
    noframes_  = Noframes_58 
instance C_Noframes Ent59 Ent37 where
    _noframes = Noframes_59 []
    noframes_  = Noframes_59 
instance C_Noframes Ent62 Ent37 where
    _noframes = Noframes_62 []
    noframes_  = Noframes_62 
instance C_Noframes Ent65 Ent12 where
    _noframes = Noframes_65 []
    noframes_  = Noframes_65 
instance C_Noframes Ent66 Ent4 where
    _noframes = Noframes_66 []
    noframes_  = Noframes_66 
instance C_Noframes Ent67 Ent67 where
    _noframes = Noframes_67 []
    noframes_  = Noframes_67 
instance C_Noframes Ent75 Ent17 where
    _noframes = Noframes_75 []
    noframes_  = Noframes_75 
instance C_Noframes Ent76 Ent17 where
    _noframes = Noframes_76 []
    noframes_  = Noframes_76 
instance C_Noframes Ent78 Ent42 where
    _noframes = Noframes_78 []
    noframes_  = Noframes_78 
instance C_Noframes Ent79 Ent42 where
    _noframes = Noframes_79 []
    noframes_  = Noframes_79 
instance C_Noframes Ent82 Ent42 where
    _noframes = Noframes_82 []
    noframes_  = Noframes_82 
instance C_Noframes Ent85 Ent17 where
    _noframes = Noframes_85 []
    noframes_  = Noframes_85 
instance C_Noframes Ent86 Ent67 where
    _noframes = Noframes_86 []
    noframes_  = Noframes_86 
instance C_Noframes Ent87 Ent67 where
    _noframes = Noframes_87 []
    noframes_  = Noframes_87 
instance C_Noframes Ent90 Ent90 where
    _noframes = Noframes_90 []
    noframes_  = Noframes_90 
instance C_Noframes Ent95 Ent90 where
    _noframes = Noframes_95 []
    noframes_  = Noframes_95 
instance C_Noframes Ent100 Ent90 where
    _noframes = Noframes_100 []
    noframes_  = Noframes_100 
instance C_Noframes Ent101 Ent90 where
    _noframes = Noframes_101 []
    noframes_  = Noframes_101 
instance C_Noframes Ent104 Ent90 where
    _noframes = Noframes_104 []
    noframes_  = Noframes_104 
instance C_Noframes Ent107 Ent67 where
    _noframes = Noframes_107 []
    noframes_  = Noframes_107 
instance C_Noframes Ent108 Ent67 where
    _noframes = Noframes_108 []
    noframes_  = Noframes_108 
instance C_Noframes Ent115 Ent115 where
    _noframes = Noframes_115 []
    noframes_  = Noframes_115 
instance C_Noframes Ent120 Ent115 where
    _noframes = Noframes_120 []
    noframes_  = Noframes_120 
instance C_Noframes Ent125 Ent115 where
    _noframes = Noframes_125 []
    noframes_  = Noframes_125 
instance C_Noframes Ent126 Ent115 where
    _noframes = Noframes_126 []
    noframes_  = Noframes_126 
instance C_Noframes Ent129 Ent115 where
    _noframes = Noframes_129 []
    noframes_  = Noframes_129 
instance C_Noframes Ent132 Ent4 where
    _noframes = Noframes_132 []
    noframes_  = Noframes_132 
instance C_Noframes Ent133 Ent4 where
    _noframes = Noframes_133 []
    noframes_  = Noframes_133 

class C_Body a b | a -> b where
    _body :: [b] -> a
    body_ :: [Att12] -> [b] -> a
instance C_Body Ent0 Ent4 where
    _body = Body_0 []
    body_  = Body_0 

class C_Div a b | a -> b where
    _div :: [b] -> a
    div_ :: [Att13] -> [b] -> a
instance C_Div Ent3 Ent4 where
    _div = Div_3 []
    div_  = Div_3 
instance C_Div Ent4 Ent4 where
    _div = Div_4 []
    div_  = Div_4 
instance C_Div Ent12 Ent12 where
    _div = Div_12 []
    div_  = Div_12 
instance C_Div Ent17 Ent17 where
    _div = Div_17 []
    div_  = Div_17 
instance C_Div Ent23 Ent17 where
    _div = Div_23 []
    div_  = Div_23 
instance C_Div Ent28 Ent12 where
    _div = Div_28 []
    div_  = Div_28 
instance C_Div Ent33 Ent12 where
    _div = Div_33 []
    div_  = Div_33 
instance C_Div Ent34 Ent12 where
    _div = Div_34 []
    div_  = Div_34 
instance C_Div Ent37 Ent37 where
    _div = Div_37 []
    div_  = Div_37 
instance C_Div Ent42 Ent42 where
    _div = Div_42 []
    div_  = Div_42 
instance C_Div Ent48 Ent42 where
    _div = Div_48 []
    div_  = Div_48 
instance C_Div Ent53 Ent37 where
    _div = Div_53 []
    div_  = Div_53 
instance C_Div Ent58 Ent37 where
    _div = Div_58 []
    div_  = Div_58 
instance C_Div Ent59 Ent37 where
    _div = Div_59 []
    div_  = Div_59 
instance C_Div Ent62 Ent37 where
    _div = Div_62 []
    div_  = Div_62 
instance C_Div Ent65 Ent12 where
    _div = Div_65 []
    div_  = Div_65 
instance C_Div Ent66 Ent4 where
    _div = Div_66 []
    div_  = Div_66 
instance C_Div Ent67 Ent67 where
    _div = Div_67 []
    div_  = Div_67 
instance C_Div Ent75 Ent17 where
    _div = Div_75 []
    div_  = Div_75 
instance C_Div Ent76 Ent17 where
    _div = Div_76 []
    div_  = Div_76 
instance C_Div Ent78 Ent42 where
    _div = Div_78 []
    div_  = Div_78 
instance C_Div Ent79 Ent42 where
    _div = Div_79 []
    div_  = Div_79 
instance C_Div Ent82 Ent42 where
    _div = Div_82 []
    div_  = Div_82 
instance C_Div Ent85 Ent17 where
    _div = Div_85 []
    div_  = Div_85 
instance C_Div Ent86 Ent67 where
    _div = Div_86 []
    div_  = Div_86 
instance C_Div Ent87 Ent67 where
    _div = Div_87 []
    div_  = Div_87 
instance C_Div Ent90 Ent90 where
    _div = Div_90 []
    div_  = Div_90 
instance C_Div Ent95 Ent90 where
    _div = Div_95 []
    div_  = Div_95 
instance C_Div Ent100 Ent90 where
    _div = Div_100 []
    div_  = Div_100 
instance C_Div Ent101 Ent90 where
    _div = Div_101 []
    div_  = Div_101 
instance C_Div Ent104 Ent90 where
    _div = Div_104 []
    div_  = Div_104 
instance C_Div Ent107 Ent67 where
    _div = Div_107 []
    div_  = Div_107 
instance C_Div Ent108 Ent67 where
    _div = Div_108 []
    div_  = Div_108 
instance C_Div Ent115 Ent115 where
    _div = Div_115 []
    div_  = Div_115 
instance C_Div Ent120 Ent115 where
    _div = Div_120 []
    div_  = Div_120 
instance C_Div Ent125 Ent115 where
    _div = Div_125 []
    div_  = Div_125 
instance C_Div Ent126 Ent115 where
    _div = Div_126 []
    div_  = Div_126 
instance C_Div Ent129 Ent115 where
    _div = Div_129 []
    div_  = Div_129 
instance C_Div Ent132 Ent4 where
    _div = Div_132 []
    div_  = Div_132 
instance C_Div Ent133 Ent4 where
    _div = Div_133 []
    div_  = Div_133 

class C_P a b | a -> b where
    _p :: [b] -> a
    p_ :: [Att13] -> [b] -> a
instance C_P Ent3 Ent5 where
    _p = P_3 []
    p_  = P_3 
instance C_P Ent4 Ent5 where
    _p = P_4 []
    p_  = P_4 
instance C_P Ent8 Ent5 where
    _p = P_8 []
    p_  = P_8 
instance C_P Ent12 Ent10 where
    _p = P_12 []
    p_  = P_12 
instance C_P Ent15 Ent10 where
    _p = P_15 []
    p_  = P_15 
instance C_P Ent17 Ent18 where
    _p = P_17 []
    p_  = P_17 
instance C_P Ent21 Ent18 where
    _p = P_21 []
    p_  = P_21 
instance C_P Ent23 Ent18 where
    _p = P_23 []
    p_  = P_23 
instance C_P Ent28 Ent10 where
    _p = P_28 []
    p_  = P_28 
instance C_P Ent33 Ent10 where
    _p = P_33 []
    p_  = P_33 
instance C_P Ent34 Ent10 where
    _p = P_34 []
    p_  = P_34 
instance C_P Ent37 Ent35 where
    _p = P_37 []
    p_  = P_37 
instance C_P Ent40 Ent35 where
    _p = P_40 []
    p_  = P_40 
instance C_P Ent42 Ent43 where
    _p = P_42 []
    p_  = P_42 
instance C_P Ent46 Ent43 where
    _p = P_46 []
    p_  = P_46 
instance C_P Ent48 Ent43 where
    _p = P_48 []
    p_  = P_48 
instance C_P Ent53 Ent35 where
    _p = P_53 []
    p_  = P_53 
instance C_P Ent58 Ent35 where
    _p = P_58 []
    p_  = P_58 
instance C_P Ent59 Ent35 where
    _p = P_59 []
    p_  = P_59 
instance C_P Ent62 Ent35 where
    _p = P_62 []
    p_  = P_62 
instance C_P Ent65 Ent10 where
    _p = P_65 []
    p_  = P_65 
instance C_P Ent66 Ent5 where
    _p = P_66 []
    p_  = P_66 
instance C_P Ent67 Ent69 where
    _p = P_67 []
    p_  = P_67 
instance C_P Ent72 Ent69 where
    _p = P_72 []
    p_  = P_72 
instance C_P Ent75 Ent18 where
    _p = P_75 []
    p_  = P_75 
instance C_P Ent76 Ent18 where
    _p = P_76 []
    p_  = P_76 
instance C_P Ent78 Ent43 where
    _p = P_78 []
    p_  = P_78 
instance C_P Ent79 Ent43 where
    _p = P_79 []
    p_  = P_79 
instance C_P Ent82 Ent43 where
    _p = P_82 []
    p_  = P_82 
instance C_P Ent85 Ent18 where
    _p = P_85 []
    p_  = P_85 
instance C_P Ent86 Ent69 where
    _p = P_86 []
    p_  = P_86 
instance C_P Ent87 Ent69 where
    _p = P_87 []
    p_  = P_87 
instance C_P Ent90 Ent88 where
    _p = P_90 []
    p_  = P_90 
instance C_P Ent93 Ent88 where
    _p = P_93 []
    p_  = P_93 
instance C_P Ent95 Ent88 where
    _p = P_95 []
    p_  = P_95 
instance C_P Ent100 Ent88 where
    _p = P_100 []
    p_  = P_100 
instance C_P Ent101 Ent88 where
    _p = P_101 []
    p_  = P_101 
instance C_P Ent104 Ent88 where
    _p = P_104 []
    p_  = P_104 
instance C_P Ent107 Ent69 where
    _p = P_107 []
    p_  = P_107 
instance C_P Ent108 Ent69 where
    _p = P_108 []
    p_  = P_108 
instance C_P Ent115 Ent113 where
    _p = P_115 []
    p_  = P_115 
instance C_P Ent118 Ent113 where
    _p = P_118 []
    p_  = P_118 
instance C_P Ent120 Ent113 where
    _p = P_120 []
    p_  = P_120 
instance C_P Ent125 Ent113 where
    _p = P_125 []
    p_  = P_125 
instance C_P Ent126 Ent113 where
    _p = P_126 []
    p_  = P_126 
instance C_P Ent129 Ent113 where
    _p = P_129 []
    p_  = P_129 
instance C_P Ent132 Ent5 where
    _p = P_132 []
    p_  = P_132 
instance C_P Ent133 Ent5 where
    _p = P_133 []
    p_  = P_133 

class C_H1 a b | a -> b where
    _h1 :: [b] -> a
    h1_ :: [Att13] -> [b] -> a
instance C_H1 Ent3 Ent5 where
    _h1 = H1_3 []
    h1_  = H1_3 
instance C_H1 Ent4 Ent5 where
    _h1 = H1_4 []
    h1_  = H1_4 
instance C_H1 Ent12 Ent10 where
    _h1 = H1_12 []
    h1_  = H1_12 
instance C_H1 Ent17 Ent18 where
    _h1 = H1_17 []
    h1_  = H1_17 
instance C_H1 Ent23 Ent18 where
    _h1 = H1_23 []
    h1_  = H1_23 
instance C_H1 Ent28 Ent10 where
    _h1 = H1_28 []
    h1_  = H1_28 
instance C_H1 Ent33 Ent10 where
    _h1 = H1_33 []
    h1_  = H1_33 
instance C_H1 Ent34 Ent10 where
    _h1 = H1_34 []
    h1_  = H1_34 
instance C_H1 Ent37 Ent35 where
    _h1 = H1_37 []
    h1_  = H1_37 
instance C_H1 Ent42 Ent43 where
    _h1 = H1_42 []
    h1_  = H1_42 
instance C_H1 Ent48 Ent43 where
    _h1 = H1_48 []
    h1_  = H1_48 
instance C_H1 Ent53 Ent35 where
    _h1 = H1_53 []
    h1_  = H1_53 
instance C_H1 Ent58 Ent35 where
    _h1 = H1_58 []
    h1_  = H1_58 
instance C_H1 Ent59 Ent35 where
    _h1 = H1_59 []
    h1_  = H1_59 
instance C_H1 Ent62 Ent35 where
    _h1 = H1_62 []
    h1_  = H1_62 
instance C_H1 Ent65 Ent10 where
    _h1 = H1_65 []
    h1_  = H1_65 
instance C_H1 Ent66 Ent5 where
    _h1 = H1_66 []
    h1_  = H1_66 
instance C_H1 Ent67 Ent69 where
    _h1 = H1_67 []
    h1_  = H1_67 
instance C_H1 Ent75 Ent18 where
    _h1 = H1_75 []
    h1_  = H1_75 
instance C_H1 Ent76 Ent18 where
    _h1 = H1_76 []
    h1_  = H1_76 
instance C_H1 Ent78 Ent43 where
    _h1 = H1_78 []
    h1_  = H1_78 
instance C_H1 Ent79 Ent43 where
    _h1 = H1_79 []
    h1_  = H1_79 
instance C_H1 Ent82 Ent43 where
    _h1 = H1_82 []
    h1_  = H1_82 
instance C_H1 Ent85 Ent18 where
    _h1 = H1_85 []
    h1_  = H1_85 
instance C_H1 Ent86 Ent69 where
    _h1 = H1_86 []
    h1_  = H1_86 
instance C_H1 Ent87 Ent69 where
    _h1 = H1_87 []
    h1_  = H1_87 
instance C_H1 Ent90 Ent88 where
    _h1 = H1_90 []
    h1_  = H1_90 
instance C_H1 Ent95 Ent88 where
    _h1 = H1_95 []
    h1_  = H1_95 
instance C_H1 Ent100 Ent88 where
    _h1 = H1_100 []
    h1_  = H1_100 
instance C_H1 Ent101 Ent88 where
    _h1 = H1_101 []
    h1_  = H1_101 
instance C_H1 Ent104 Ent88 where
    _h1 = H1_104 []
    h1_  = H1_104 
instance C_H1 Ent107 Ent69 where
    _h1 = H1_107 []
    h1_  = H1_107 
instance C_H1 Ent108 Ent69 where
    _h1 = H1_108 []
    h1_  = H1_108 
instance C_H1 Ent115 Ent113 where
    _h1 = H1_115 []
    h1_  = H1_115 
instance C_H1 Ent120 Ent113 where
    _h1 = H1_120 []
    h1_  = H1_120 
instance C_H1 Ent125 Ent113 where
    _h1 = H1_125 []
    h1_  = H1_125 
instance C_H1 Ent126 Ent113 where
    _h1 = H1_126 []
    h1_  = H1_126 
instance C_H1 Ent129 Ent113 where
    _h1 = H1_129 []
    h1_  = H1_129 
instance C_H1 Ent132 Ent5 where
    _h1 = H1_132 []
    h1_  = H1_132 
instance C_H1 Ent133 Ent5 where
    _h1 = H1_133 []
    h1_  = H1_133 

class C_H2 a b | a -> b where
    _h2 :: [b] -> a
    h2_ :: [Att13] -> [b] -> a
instance C_H2 Ent3 Ent5 where
    _h2 = H2_3 []
    h2_  = H2_3 
instance C_H2 Ent4 Ent5 where
    _h2 = H2_4 []
    h2_  = H2_4 
instance C_H2 Ent12 Ent10 where
    _h2 = H2_12 []
    h2_  = H2_12 
instance C_H2 Ent17 Ent18 where
    _h2 = H2_17 []
    h2_  = H2_17 
instance C_H2 Ent23 Ent18 where
    _h2 = H2_23 []
    h2_  = H2_23 
instance C_H2 Ent28 Ent10 where
    _h2 = H2_28 []
    h2_  = H2_28 
instance C_H2 Ent33 Ent10 where
    _h2 = H2_33 []
    h2_  = H2_33 
instance C_H2 Ent34 Ent10 where
    _h2 = H2_34 []
    h2_  = H2_34 
instance C_H2 Ent37 Ent35 where
    _h2 = H2_37 []
    h2_  = H2_37 
instance C_H2 Ent42 Ent43 where
    _h2 = H2_42 []
    h2_  = H2_42 
instance C_H2 Ent48 Ent43 where
    _h2 = H2_48 []
    h2_  = H2_48 
instance C_H2 Ent53 Ent35 where
    _h2 = H2_53 []
    h2_  = H2_53 
instance C_H2 Ent58 Ent35 where
    _h2 = H2_58 []
    h2_  = H2_58 
instance C_H2 Ent59 Ent35 where
    _h2 = H2_59 []
    h2_  = H2_59 
instance C_H2 Ent62 Ent35 where
    _h2 = H2_62 []
    h2_  = H2_62 
instance C_H2 Ent65 Ent10 where
    _h2 = H2_65 []
    h2_  = H2_65 
instance C_H2 Ent66 Ent5 where
    _h2 = H2_66 []
    h2_  = H2_66 
instance C_H2 Ent67 Ent69 where
    _h2 = H2_67 []
    h2_  = H2_67 
instance C_H2 Ent75 Ent18 where
    _h2 = H2_75 []
    h2_  = H2_75 
instance C_H2 Ent76 Ent18 where
    _h2 = H2_76 []
    h2_  = H2_76 
instance C_H2 Ent78 Ent43 where
    _h2 = H2_78 []
    h2_  = H2_78 
instance C_H2 Ent79 Ent43 where
    _h2 = H2_79 []
    h2_  = H2_79 
instance C_H2 Ent82 Ent43 where
    _h2 = H2_82 []
    h2_  = H2_82 
instance C_H2 Ent85 Ent18 where
    _h2 = H2_85 []
    h2_  = H2_85 
instance C_H2 Ent86 Ent69 where
    _h2 = H2_86 []
    h2_  = H2_86 
instance C_H2 Ent87 Ent69 where
    _h2 = H2_87 []
    h2_  = H2_87 
instance C_H2 Ent90 Ent88 where
    _h2 = H2_90 []
    h2_  = H2_90 
instance C_H2 Ent95 Ent88 where
    _h2 = H2_95 []
    h2_  = H2_95 
instance C_H2 Ent100 Ent88 where
    _h2 = H2_100 []
    h2_  = H2_100 
instance C_H2 Ent101 Ent88 where
    _h2 = H2_101 []
    h2_  = H2_101 
instance C_H2 Ent104 Ent88 where
    _h2 = H2_104 []
    h2_  = H2_104 
instance C_H2 Ent107 Ent69 where
    _h2 = H2_107 []
    h2_  = H2_107 
instance C_H2 Ent108 Ent69 where
    _h2 = H2_108 []
    h2_  = H2_108 
instance C_H2 Ent115 Ent113 where
    _h2 = H2_115 []
    h2_  = H2_115 
instance C_H2 Ent120 Ent113 where
    _h2 = H2_120 []
    h2_  = H2_120 
instance C_H2 Ent125 Ent113 where
    _h2 = H2_125 []
    h2_  = H2_125 
instance C_H2 Ent126 Ent113 where
    _h2 = H2_126 []
    h2_  = H2_126 
instance C_H2 Ent129 Ent113 where
    _h2 = H2_129 []
    h2_  = H2_129 
instance C_H2 Ent132 Ent5 where
    _h2 = H2_132 []
    h2_  = H2_132 
instance C_H2 Ent133 Ent5 where
    _h2 = H2_133 []
    h2_  = H2_133 

class C_H3 a b | a -> b where
    _h3 :: [b] -> a
    h3_ :: [Att13] -> [b] -> a
instance C_H3 Ent3 Ent5 where
    _h3 = H3_3 []
    h3_  = H3_3 
instance C_H3 Ent4 Ent5 where
    _h3 = H3_4 []
    h3_  = H3_4 
instance C_H3 Ent12 Ent10 where
    _h3 = H3_12 []
    h3_  = H3_12 
instance C_H3 Ent17 Ent18 where
    _h3 = H3_17 []
    h3_  = H3_17 
instance C_H3 Ent23 Ent18 where
    _h3 = H3_23 []
    h3_  = H3_23 
instance C_H3 Ent28 Ent10 where
    _h3 = H3_28 []
    h3_  = H3_28 
instance C_H3 Ent33 Ent10 where
    _h3 = H3_33 []
    h3_  = H3_33 
instance C_H3 Ent34 Ent10 where
    _h3 = H3_34 []
    h3_  = H3_34 
instance C_H3 Ent37 Ent35 where
    _h3 = H3_37 []
    h3_  = H3_37 
instance C_H3 Ent42 Ent43 where
    _h3 = H3_42 []
    h3_  = H3_42 
instance C_H3 Ent48 Ent43 where
    _h3 = H3_48 []
    h3_  = H3_48 
instance C_H3 Ent53 Ent35 where
    _h3 = H3_53 []
    h3_  = H3_53 
instance C_H3 Ent58 Ent35 where
    _h3 = H3_58 []
    h3_  = H3_58 
instance C_H3 Ent59 Ent35 where
    _h3 = H3_59 []
    h3_  = H3_59 
instance C_H3 Ent62 Ent35 where
    _h3 = H3_62 []
    h3_  = H3_62 
instance C_H3 Ent65 Ent10 where
    _h3 = H3_65 []
    h3_  = H3_65 
instance C_H3 Ent66 Ent5 where
    _h3 = H3_66 []
    h3_  = H3_66 
instance C_H3 Ent67 Ent69 where
    _h3 = H3_67 []
    h3_  = H3_67 
instance C_H3 Ent75 Ent18 where
    _h3 = H3_75 []
    h3_  = H3_75 
instance C_H3 Ent76 Ent18 where
    _h3 = H3_76 []
    h3_  = H3_76 
instance C_H3 Ent78 Ent43 where
    _h3 = H3_78 []
    h3_  = H3_78 
instance C_H3 Ent79 Ent43 where
    _h3 = H3_79 []
    h3_  = H3_79 
instance C_H3 Ent82 Ent43 where
    _h3 = H3_82 []
    h3_  = H3_82 
instance C_H3 Ent85 Ent18 where
    _h3 = H3_85 []
    h3_  = H3_85 
instance C_H3 Ent86 Ent69 where
    _h3 = H3_86 []
    h3_  = H3_86 
instance C_H3 Ent87 Ent69 where
    _h3 = H3_87 []
    h3_  = H3_87 
instance C_H3 Ent90 Ent88 where
    _h3 = H3_90 []
    h3_  = H3_90 
instance C_H3 Ent95 Ent88 where
    _h3 = H3_95 []
    h3_  = H3_95 
instance C_H3 Ent100 Ent88 where
    _h3 = H3_100 []
    h3_  = H3_100 
instance C_H3 Ent101 Ent88 where
    _h3 = H3_101 []
    h3_  = H3_101 
instance C_H3 Ent104 Ent88 where
    _h3 = H3_104 []
    h3_  = H3_104 
instance C_H3 Ent107 Ent69 where
    _h3 = H3_107 []
    h3_  = H3_107 
instance C_H3 Ent108 Ent69 where
    _h3 = H3_108 []
    h3_  = H3_108 
instance C_H3 Ent115 Ent113 where
    _h3 = H3_115 []
    h3_  = H3_115 
instance C_H3 Ent120 Ent113 where
    _h3 = H3_120 []
    h3_  = H3_120 
instance C_H3 Ent125 Ent113 where
    _h3 = H3_125 []
    h3_  = H3_125 
instance C_H3 Ent126 Ent113 where
    _h3 = H3_126 []
    h3_  = H3_126 
instance C_H3 Ent129 Ent113 where
    _h3 = H3_129 []
    h3_  = H3_129 
instance C_H3 Ent132 Ent5 where
    _h3 = H3_132 []
    h3_  = H3_132 
instance C_H3 Ent133 Ent5 where
    _h3 = H3_133 []
    h3_  = H3_133 

class C_H4 a b | a -> b where
    _h4 :: [b] -> a
    h4_ :: [Att13] -> [b] -> a
instance C_H4 Ent3 Ent5 where
    _h4 = H4_3 []
    h4_  = H4_3 
instance C_H4 Ent4 Ent5 where
    _h4 = H4_4 []
    h4_  = H4_4 
instance C_H4 Ent12 Ent10 where
    _h4 = H4_12 []
    h4_  = H4_12 
instance C_H4 Ent17 Ent18 where
    _h4 = H4_17 []
    h4_  = H4_17 
instance C_H4 Ent23 Ent18 where
    _h4 = H4_23 []
    h4_  = H4_23 
instance C_H4 Ent28 Ent10 where
    _h4 = H4_28 []
    h4_  = H4_28 
instance C_H4 Ent33 Ent10 where
    _h4 = H4_33 []
    h4_  = H4_33 
instance C_H4 Ent34 Ent10 where
    _h4 = H4_34 []
    h4_  = H4_34 
instance C_H4 Ent37 Ent35 where
    _h4 = H4_37 []
    h4_  = H4_37 
instance C_H4 Ent42 Ent43 where
    _h4 = H4_42 []
    h4_  = H4_42 
instance C_H4 Ent48 Ent43 where
    _h4 = H4_48 []
    h4_  = H4_48 
instance C_H4 Ent53 Ent35 where
    _h4 = H4_53 []
    h4_  = H4_53 
instance C_H4 Ent58 Ent35 where
    _h4 = H4_58 []
    h4_  = H4_58 
instance C_H4 Ent59 Ent35 where
    _h4 = H4_59 []
    h4_  = H4_59 
instance C_H4 Ent62 Ent35 where
    _h4 = H4_62 []
    h4_  = H4_62 
instance C_H4 Ent65 Ent10 where
    _h4 = H4_65 []
    h4_  = H4_65 
instance C_H4 Ent66 Ent5 where
    _h4 = H4_66 []
    h4_  = H4_66 
instance C_H4 Ent67 Ent69 where
    _h4 = H4_67 []
    h4_  = H4_67 
instance C_H4 Ent75 Ent18 where
    _h4 = H4_75 []
    h4_  = H4_75 
instance C_H4 Ent76 Ent18 where
    _h4 = H4_76 []
    h4_  = H4_76 
instance C_H4 Ent78 Ent43 where
    _h4 = H4_78 []
    h4_  = H4_78 
instance C_H4 Ent79 Ent43 where
    _h4 = H4_79 []
    h4_  = H4_79 
instance C_H4 Ent82 Ent43 where
    _h4 = H4_82 []
    h4_  = H4_82 
instance C_H4 Ent85 Ent18 where
    _h4 = H4_85 []
    h4_  = H4_85 
instance C_H4 Ent86 Ent69 where
    _h4 = H4_86 []
    h4_  = H4_86 
instance C_H4 Ent87 Ent69 where
    _h4 = H4_87 []
    h4_  = H4_87 
instance C_H4 Ent90 Ent88 where
    _h4 = H4_90 []
    h4_  = H4_90 
instance C_H4 Ent95 Ent88 where
    _h4 = H4_95 []
    h4_  = H4_95 
instance C_H4 Ent100 Ent88 where
    _h4 = H4_100 []
    h4_  = H4_100 
instance C_H4 Ent101 Ent88 where
    _h4 = H4_101 []
    h4_  = H4_101 
instance C_H4 Ent104 Ent88 where
    _h4 = H4_104 []
    h4_  = H4_104 
instance C_H4 Ent107 Ent69 where
    _h4 = H4_107 []
    h4_  = H4_107 
instance C_H4 Ent108 Ent69 where
    _h4 = H4_108 []
    h4_  = H4_108 
instance C_H4 Ent115 Ent113 where
    _h4 = H4_115 []
    h4_  = H4_115 
instance C_H4 Ent120 Ent113 where
    _h4 = H4_120 []
    h4_  = H4_120 
instance C_H4 Ent125 Ent113 where
    _h4 = H4_125 []
    h4_  = H4_125 
instance C_H4 Ent126 Ent113 where
    _h4 = H4_126 []
    h4_  = H4_126 
instance C_H4 Ent129 Ent113 where
    _h4 = H4_129 []
    h4_  = H4_129 
instance C_H4 Ent132 Ent5 where
    _h4 = H4_132 []
    h4_  = H4_132 
instance C_H4 Ent133 Ent5 where
    _h4 = H4_133 []
    h4_  = H4_133 

class C_H5 a b | a -> b where
    _h5 :: [b] -> a
    h5_ :: [Att13] -> [b] -> a
instance C_H5 Ent3 Ent5 where
    _h5 = H5_3 []
    h5_  = H5_3 
instance C_H5 Ent4 Ent5 where
    _h5 = H5_4 []
    h5_  = H5_4 
instance C_H5 Ent12 Ent10 where
    _h5 = H5_12 []
    h5_  = H5_12 
instance C_H5 Ent17 Ent18 where
    _h5 = H5_17 []
    h5_  = H5_17 
instance C_H5 Ent23 Ent18 where
    _h5 = H5_23 []
    h5_  = H5_23 
instance C_H5 Ent28 Ent10 where
    _h5 = H5_28 []
    h5_  = H5_28 
instance C_H5 Ent33 Ent10 where
    _h5 = H5_33 []
    h5_  = H5_33 
instance C_H5 Ent34 Ent10 where
    _h5 = H5_34 []
    h5_  = H5_34 
instance C_H5 Ent37 Ent35 where
    _h5 = H5_37 []
    h5_  = H5_37 
instance C_H5 Ent42 Ent43 where
    _h5 = H5_42 []
    h5_  = H5_42 
instance C_H5 Ent48 Ent43 where
    _h5 = H5_48 []
    h5_  = H5_48 
instance C_H5 Ent53 Ent35 where
    _h5 = H5_53 []
    h5_  = H5_53 
instance C_H5 Ent58 Ent35 where
    _h5 = H5_58 []
    h5_  = H5_58 
instance C_H5 Ent59 Ent35 where
    _h5 = H5_59 []
    h5_  = H5_59 
instance C_H5 Ent62 Ent35 where
    _h5 = H5_62 []
    h5_  = H5_62 
instance C_H5 Ent65 Ent10 where
    _h5 = H5_65 []
    h5_  = H5_65 
instance C_H5 Ent66 Ent5 where
    _h5 = H5_66 []
    h5_  = H5_66 
instance C_H5 Ent67 Ent69 where
    _h5 = H5_67 []
    h5_  = H5_67 
instance C_H5 Ent75 Ent18 where
    _h5 = H5_75 []
    h5_  = H5_75 
instance C_H5 Ent76 Ent18 where
    _h5 = H5_76 []
    h5_  = H5_76 
instance C_H5 Ent78 Ent43 where
    _h5 = H5_78 []
    h5_  = H5_78 
instance C_H5 Ent79 Ent43 where
    _h5 = H5_79 []
    h5_  = H5_79 
instance C_H5 Ent82 Ent43 where
    _h5 = H5_82 []
    h5_  = H5_82 
instance C_H5 Ent85 Ent18 where
    _h5 = H5_85 []
    h5_  = H5_85 
instance C_H5 Ent86 Ent69 where
    _h5 = H5_86 []
    h5_  = H5_86 
instance C_H5 Ent87 Ent69 where
    _h5 = H5_87 []
    h5_  = H5_87 
instance C_H5 Ent90 Ent88 where
    _h5 = H5_90 []
    h5_  = H5_90 
instance C_H5 Ent95 Ent88 where
    _h5 = H5_95 []
    h5_  = H5_95 
instance C_H5 Ent100 Ent88 where
    _h5 = H5_100 []
    h5_  = H5_100 
instance C_H5 Ent101 Ent88 where
    _h5 = H5_101 []
    h5_  = H5_101 
instance C_H5 Ent104 Ent88 where
    _h5 = H5_104 []
    h5_  = H5_104 
instance C_H5 Ent107 Ent69 where
    _h5 = H5_107 []
    h5_  = H5_107 
instance C_H5 Ent108 Ent69 where
    _h5 = H5_108 []
    h5_  = H5_108 
instance C_H5 Ent115 Ent113 where
    _h5 = H5_115 []
    h5_  = H5_115 
instance C_H5 Ent120 Ent113 where
    _h5 = H5_120 []
    h5_  = H5_120 
instance C_H5 Ent125 Ent113 where
    _h5 = H5_125 []
    h5_  = H5_125 
instance C_H5 Ent126 Ent113 where
    _h5 = H5_126 []
    h5_  = H5_126 
instance C_H5 Ent129 Ent113 where
    _h5 = H5_129 []
    h5_  = H5_129 
instance C_H5 Ent132 Ent5 where
    _h5 = H5_132 []
    h5_  = H5_132 
instance C_H5 Ent133 Ent5 where
    _h5 = H5_133 []
    h5_  = H5_133 

class C_H6 a b | a -> b where
    _h6 :: [b] -> a
    h6_ :: [Att13] -> [b] -> a
instance C_H6 Ent3 Ent5 where
    _h6 = H6_3 []
    h6_  = H6_3 
instance C_H6 Ent4 Ent5 where
    _h6 = H6_4 []
    h6_  = H6_4 
instance C_H6 Ent12 Ent10 where
    _h6 = H6_12 []
    h6_  = H6_12 
instance C_H6 Ent17 Ent18 where
    _h6 = H6_17 []
    h6_  = H6_17 
instance C_H6 Ent23 Ent18 where
    _h6 = H6_23 []
    h6_  = H6_23 
instance C_H6 Ent28 Ent10 where
    _h6 = H6_28 []
    h6_  = H6_28 
instance C_H6 Ent33 Ent10 where
    _h6 = H6_33 []
    h6_  = H6_33 
instance C_H6 Ent34 Ent10 where
    _h6 = H6_34 []
    h6_  = H6_34 
instance C_H6 Ent37 Ent35 where
    _h6 = H6_37 []
    h6_  = H6_37 
instance C_H6 Ent42 Ent43 where
    _h6 = H6_42 []
    h6_  = H6_42 
instance C_H6 Ent48 Ent43 where
    _h6 = H6_48 []
    h6_  = H6_48 
instance C_H6 Ent53 Ent35 where
    _h6 = H6_53 []
    h6_  = H6_53 
instance C_H6 Ent58 Ent35 where
    _h6 = H6_58 []
    h6_  = H6_58 
instance C_H6 Ent59 Ent35 where
    _h6 = H6_59 []
    h6_  = H6_59 
instance C_H6 Ent62 Ent35 where
    _h6 = H6_62 []
    h6_  = H6_62 
instance C_H6 Ent65 Ent10 where
    _h6 = H6_65 []
    h6_  = H6_65 
instance C_H6 Ent66 Ent5 where
    _h6 = H6_66 []
    h6_  = H6_66 
instance C_H6 Ent67 Ent69 where
    _h6 = H6_67 []
    h6_  = H6_67 
instance C_H6 Ent75 Ent18 where
    _h6 = H6_75 []
    h6_  = H6_75 
instance C_H6 Ent76 Ent18 where
    _h6 = H6_76 []
    h6_  = H6_76 
instance C_H6 Ent78 Ent43 where
    _h6 = H6_78 []
    h6_  = H6_78 
instance C_H6 Ent79 Ent43 where
    _h6 = H6_79 []
    h6_  = H6_79 
instance C_H6 Ent82 Ent43 where
    _h6 = H6_82 []
    h6_  = H6_82 
instance C_H6 Ent85 Ent18 where
    _h6 = H6_85 []
    h6_  = H6_85 
instance C_H6 Ent86 Ent69 where
    _h6 = H6_86 []
    h6_  = H6_86 
instance C_H6 Ent87 Ent69 where
    _h6 = H6_87 []
    h6_  = H6_87 
instance C_H6 Ent90 Ent88 where
    _h6 = H6_90 []
    h6_  = H6_90 
instance C_H6 Ent95 Ent88 where
    _h6 = H6_95 []
    h6_  = H6_95 
instance C_H6 Ent100 Ent88 where
    _h6 = H6_100 []
    h6_  = H6_100 
instance C_H6 Ent101 Ent88 where
    _h6 = H6_101 []
    h6_  = H6_101 
instance C_H6 Ent104 Ent88 where
    _h6 = H6_104 []
    h6_  = H6_104 
instance C_H6 Ent107 Ent69 where
    _h6 = H6_107 []
    h6_  = H6_107 
instance C_H6 Ent108 Ent69 where
    _h6 = H6_108 []
    h6_  = H6_108 
instance C_H6 Ent115 Ent113 where
    _h6 = H6_115 []
    h6_  = H6_115 
instance C_H6 Ent120 Ent113 where
    _h6 = H6_120 []
    h6_  = H6_120 
instance C_H6 Ent125 Ent113 where
    _h6 = H6_125 []
    h6_  = H6_125 
instance C_H6 Ent126 Ent113 where
    _h6 = H6_126 []
    h6_  = H6_126 
instance C_H6 Ent129 Ent113 where
    _h6 = H6_129 []
    h6_  = H6_129 
instance C_H6 Ent132 Ent5 where
    _h6 = H6_132 []
    h6_  = H6_132 
instance C_H6 Ent133 Ent5 where
    _h6 = H6_133 []
    h6_  = H6_133 

class C_Ul a b | a -> b where
    _ul :: [b] -> a
    ul_ :: [Att14] -> [b] -> a
instance C_Ul Ent3 Ent6 where
    _ul = Ul_3 []
    ul_  = Ul_3 
instance C_Ul Ent4 Ent6 where
    _ul = Ul_4 []
    ul_  = Ul_4 
instance C_Ul Ent12 Ent13 where
    _ul = Ul_12 []
    ul_  = Ul_12 
instance C_Ul Ent17 Ent19 where
    _ul = Ul_17 []
    ul_  = Ul_17 
instance C_Ul Ent23 Ent19 where
    _ul = Ul_23 []
    ul_  = Ul_23 
instance C_Ul Ent28 Ent13 where
    _ul = Ul_28 []
    ul_  = Ul_28 
instance C_Ul Ent33 Ent13 where
    _ul = Ul_33 []
    ul_  = Ul_33 
instance C_Ul Ent34 Ent13 where
    _ul = Ul_34 []
    ul_  = Ul_34 
instance C_Ul Ent37 Ent38 where
    _ul = Ul_37 []
    ul_  = Ul_37 
instance C_Ul Ent42 Ent44 where
    _ul = Ul_42 []
    ul_  = Ul_42 
instance C_Ul Ent48 Ent44 where
    _ul = Ul_48 []
    ul_  = Ul_48 
instance C_Ul Ent53 Ent38 where
    _ul = Ul_53 []
    ul_  = Ul_53 
instance C_Ul Ent58 Ent38 where
    _ul = Ul_58 []
    ul_  = Ul_58 
instance C_Ul Ent59 Ent38 where
    _ul = Ul_59 []
    ul_  = Ul_59 
instance C_Ul Ent62 Ent38 where
    _ul = Ul_62 []
    ul_  = Ul_62 
instance C_Ul Ent65 Ent13 where
    _ul = Ul_65 []
    ul_  = Ul_65 
instance C_Ul Ent66 Ent6 where
    _ul = Ul_66 []
    ul_  = Ul_66 
instance C_Ul Ent67 Ent70 where
    _ul = Ul_67 []
    ul_  = Ul_67 
instance C_Ul Ent75 Ent19 where
    _ul = Ul_75 []
    ul_  = Ul_75 
instance C_Ul Ent76 Ent19 where
    _ul = Ul_76 []
    ul_  = Ul_76 
instance C_Ul Ent78 Ent44 where
    _ul = Ul_78 []
    ul_  = Ul_78 
instance C_Ul Ent79 Ent44 where
    _ul = Ul_79 []
    ul_  = Ul_79 
instance C_Ul Ent82 Ent44 where
    _ul = Ul_82 []
    ul_  = Ul_82 
instance C_Ul Ent85 Ent19 where
    _ul = Ul_85 []
    ul_  = Ul_85 
instance C_Ul Ent86 Ent70 where
    _ul = Ul_86 []
    ul_  = Ul_86 
instance C_Ul Ent87 Ent70 where
    _ul = Ul_87 []
    ul_  = Ul_87 
instance C_Ul Ent90 Ent91 where
    _ul = Ul_90 []
    ul_  = Ul_90 
instance C_Ul Ent95 Ent91 where
    _ul = Ul_95 []
    ul_  = Ul_95 
instance C_Ul Ent100 Ent91 where
    _ul = Ul_100 []
    ul_  = Ul_100 
instance C_Ul Ent101 Ent91 where
    _ul = Ul_101 []
    ul_  = Ul_101 
instance C_Ul Ent104 Ent91 where
    _ul = Ul_104 []
    ul_  = Ul_104 
instance C_Ul Ent107 Ent70 where
    _ul = Ul_107 []
    ul_  = Ul_107 
instance C_Ul Ent108 Ent70 where
    _ul = Ul_108 []
    ul_  = Ul_108 
instance C_Ul Ent115 Ent116 where
    _ul = Ul_115 []
    ul_  = Ul_115 
instance C_Ul Ent120 Ent116 where
    _ul = Ul_120 []
    ul_  = Ul_120 
instance C_Ul Ent125 Ent116 where
    _ul = Ul_125 []
    ul_  = Ul_125 
instance C_Ul Ent126 Ent116 where
    _ul = Ul_126 []
    ul_  = Ul_126 
instance C_Ul Ent129 Ent116 where
    _ul = Ul_129 []
    ul_  = Ul_129 
instance C_Ul Ent132 Ent6 where
    _ul = Ul_132 []
    ul_  = Ul_132 
instance C_Ul Ent133 Ent6 where
    _ul = Ul_133 []
    ul_  = Ul_133 

class C_Ol a b | a -> b where
    _ol :: [b] -> a
    ol_ :: [Att15] -> [b] -> a
instance C_Ol Ent3 Ent6 where
    _ol = Ol_3 []
    ol_  = Ol_3 
instance C_Ol Ent4 Ent6 where
    _ol = Ol_4 []
    ol_  = Ol_4 
instance C_Ol Ent12 Ent13 where
    _ol = Ol_12 []
    ol_  = Ol_12 
instance C_Ol Ent17 Ent19 where
    _ol = Ol_17 []
    ol_  = Ol_17 
instance C_Ol Ent23 Ent19 where
    _ol = Ol_23 []
    ol_  = Ol_23 
instance C_Ol Ent28 Ent13 where
    _ol = Ol_28 []
    ol_  = Ol_28 
instance C_Ol Ent33 Ent13 where
    _ol = Ol_33 []
    ol_  = Ol_33 
instance C_Ol Ent34 Ent13 where
    _ol = Ol_34 []
    ol_  = Ol_34 
instance C_Ol Ent37 Ent38 where
    _ol = Ol_37 []
    ol_  = Ol_37 
instance C_Ol Ent42 Ent44 where
    _ol = Ol_42 []
    ol_  = Ol_42 
instance C_Ol Ent48 Ent44 where
    _ol = Ol_48 []
    ol_  = Ol_48 
instance C_Ol Ent53 Ent38 where
    _ol = Ol_53 []
    ol_  = Ol_53 
instance C_Ol Ent58 Ent38 where
    _ol = Ol_58 []
    ol_  = Ol_58 
instance C_Ol Ent59 Ent38 where
    _ol = Ol_59 []
    ol_  = Ol_59 
instance C_Ol Ent62 Ent38 where
    _ol = Ol_62 []
    ol_  = Ol_62 
instance C_Ol Ent65 Ent13 where
    _ol = Ol_65 []
    ol_  = Ol_65 
instance C_Ol Ent66 Ent6 where
    _ol = Ol_66 []
    ol_  = Ol_66 
instance C_Ol Ent67 Ent70 where
    _ol = Ol_67 []
    ol_  = Ol_67 
instance C_Ol Ent75 Ent19 where
    _ol = Ol_75 []
    ol_  = Ol_75 
instance C_Ol Ent76 Ent19 where
    _ol = Ol_76 []
    ol_  = Ol_76 
instance C_Ol Ent78 Ent44 where
    _ol = Ol_78 []
    ol_  = Ol_78 
instance C_Ol Ent79 Ent44 where
    _ol = Ol_79 []
    ol_  = Ol_79 
instance C_Ol Ent82 Ent44 where
    _ol = Ol_82 []
    ol_  = Ol_82 
instance C_Ol Ent85 Ent19 where
    _ol = Ol_85 []
    ol_  = Ol_85 
instance C_Ol Ent86 Ent70 where
    _ol = Ol_86 []
    ol_  = Ol_86 
instance C_Ol Ent87 Ent70 where
    _ol = Ol_87 []
    ol_  = Ol_87 
instance C_Ol Ent90 Ent91 where
    _ol = Ol_90 []
    ol_  = Ol_90 
instance C_Ol Ent95 Ent91 where
    _ol = Ol_95 []
    ol_  = Ol_95 
instance C_Ol Ent100 Ent91 where
    _ol = Ol_100 []
    ol_  = Ol_100 
instance C_Ol Ent101 Ent91 where
    _ol = Ol_101 []
    ol_  = Ol_101 
instance C_Ol Ent104 Ent91 where
    _ol = Ol_104 []
    ol_  = Ol_104 
instance C_Ol Ent107 Ent70 where
    _ol = Ol_107 []
    ol_  = Ol_107 
instance C_Ol Ent108 Ent70 where
    _ol = Ol_108 []
    ol_  = Ol_108 
instance C_Ol Ent115 Ent116 where
    _ol = Ol_115 []
    ol_  = Ol_115 
instance C_Ol Ent120 Ent116 where
    _ol = Ol_120 []
    ol_  = Ol_120 
instance C_Ol Ent125 Ent116 where
    _ol = Ol_125 []
    ol_  = Ol_125 
instance C_Ol Ent126 Ent116 where
    _ol = Ol_126 []
    ol_  = Ol_126 
instance C_Ol Ent129 Ent116 where
    _ol = Ol_129 []
    ol_  = Ol_129 
instance C_Ol Ent132 Ent6 where
    _ol = Ol_132 []
    ol_  = Ol_132 
instance C_Ol Ent133 Ent6 where
    _ol = Ol_133 []
    ol_  = Ol_133 

class C_Menu a b | a -> b where
    _menu :: [b] -> a
    menu_ :: [Att16] -> [b] -> a
instance C_Menu Ent3 Ent6 where
    _menu = Menu_3 []
    menu_  = Menu_3 
instance C_Menu Ent4 Ent6 where
    _menu = Menu_4 []
    menu_  = Menu_4 
instance C_Menu Ent12 Ent13 where
    _menu = Menu_12 []
    menu_  = Menu_12 
instance C_Menu Ent17 Ent19 where
    _menu = Menu_17 []
    menu_  = Menu_17 
instance C_Menu Ent23 Ent19 where
    _menu = Menu_23 []
    menu_  = Menu_23 
instance C_Menu Ent28 Ent13 where
    _menu = Menu_28 []
    menu_  = Menu_28 
instance C_Menu Ent33 Ent13 where
    _menu = Menu_33 []
    menu_  = Menu_33 
instance C_Menu Ent34 Ent13 where
    _menu = Menu_34 []
    menu_  = Menu_34 
instance C_Menu Ent37 Ent38 where
    _menu = Menu_37 []
    menu_  = Menu_37 
instance C_Menu Ent42 Ent44 where
    _menu = Menu_42 []
    menu_  = Menu_42 
instance C_Menu Ent48 Ent44 where
    _menu = Menu_48 []
    menu_  = Menu_48 
instance C_Menu Ent53 Ent38 where
    _menu = Menu_53 []
    menu_  = Menu_53 
instance C_Menu Ent58 Ent38 where
    _menu = Menu_58 []
    menu_  = Menu_58 
instance C_Menu Ent59 Ent38 where
    _menu = Menu_59 []
    menu_  = Menu_59 
instance C_Menu Ent62 Ent38 where
    _menu = Menu_62 []
    menu_  = Menu_62 
instance C_Menu Ent65 Ent13 where
    _menu = Menu_65 []
    menu_  = Menu_65 
instance C_Menu Ent66 Ent6 where
    _menu = Menu_66 []
    menu_  = Menu_66 
instance C_Menu Ent67 Ent70 where
    _menu = Menu_67 []
    menu_  = Menu_67 
instance C_Menu Ent75 Ent19 where
    _menu = Menu_75 []
    menu_  = Menu_75 
instance C_Menu Ent76 Ent19 where
    _menu = Menu_76 []
    menu_  = Menu_76 
instance C_Menu Ent78 Ent44 where
    _menu = Menu_78 []
    menu_  = Menu_78 
instance C_Menu Ent79 Ent44 where
    _menu = Menu_79 []
    menu_  = Menu_79 
instance C_Menu Ent82 Ent44 where
    _menu = Menu_82 []
    menu_  = Menu_82 
instance C_Menu Ent85 Ent19 where
    _menu = Menu_85 []
    menu_  = Menu_85 
instance C_Menu Ent86 Ent70 where
    _menu = Menu_86 []
    menu_  = Menu_86 
instance C_Menu Ent87 Ent70 where
    _menu = Menu_87 []
    menu_  = Menu_87 
instance C_Menu Ent90 Ent91 where
    _menu = Menu_90 []
    menu_  = Menu_90 
instance C_Menu Ent95 Ent91 where
    _menu = Menu_95 []
    menu_  = Menu_95 
instance C_Menu Ent100 Ent91 where
    _menu = Menu_100 []
    menu_  = Menu_100 
instance C_Menu Ent101 Ent91 where
    _menu = Menu_101 []
    menu_  = Menu_101 
instance C_Menu Ent104 Ent91 where
    _menu = Menu_104 []
    menu_  = Menu_104 
instance C_Menu Ent107 Ent70 where
    _menu = Menu_107 []
    menu_  = Menu_107 
instance C_Menu Ent108 Ent70 where
    _menu = Menu_108 []
    menu_  = Menu_108 
instance C_Menu Ent115 Ent116 where
    _menu = Menu_115 []
    menu_  = Menu_115 
instance C_Menu Ent120 Ent116 where
    _menu = Menu_120 []
    menu_  = Menu_120 
instance C_Menu Ent125 Ent116 where
    _menu = Menu_125 []
    menu_  = Menu_125 
instance C_Menu Ent126 Ent116 where
    _menu = Menu_126 []
    menu_  = Menu_126 
instance C_Menu Ent129 Ent116 where
    _menu = Menu_129 []
    menu_  = Menu_129 
instance C_Menu Ent132 Ent6 where
    _menu = Menu_132 []
    menu_  = Menu_132 
instance C_Menu Ent133 Ent6 where
    _menu = Menu_133 []
    menu_  = Menu_133 

class C_Dir a b | a -> b where
    _dir :: [b] -> a
    dir_ :: [Att16] -> [b] -> a
instance C_Dir Ent3 Ent6 where
    _dir = Dir_3 []
    dir_  = Dir_3 
instance C_Dir Ent4 Ent6 where
    _dir = Dir_4 []
    dir_  = Dir_4 
instance C_Dir Ent12 Ent13 where
    _dir = Dir_12 []
    dir_  = Dir_12 
instance C_Dir Ent17 Ent19 where
    _dir = Dir_17 []
    dir_  = Dir_17 
instance C_Dir Ent23 Ent19 where
    _dir = Dir_23 []
    dir_  = Dir_23 
instance C_Dir Ent28 Ent13 where
    _dir = Dir_28 []
    dir_  = Dir_28 
instance C_Dir Ent33 Ent13 where
    _dir = Dir_33 []
    dir_  = Dir_33 
instance C_Dir Ent34 Ent13 where
    _dir = Dir_34 []
    dir_  = Dir_34 
instance C_Dir Ent37 Ent38 where
    _dir = Dir_37 []
    dir_  = Dir_37 
instance C_Dir Ent42 Ent44 where
    _dir = Dir_42 []
    dir_  = Dir_42 
instance C_Dir Ent48 Ent44 where
    _dir = Dir_48 []
    dir_  = Dir_48 
instance C_Dir Ent53 Ent38 where
    _dir = Dir_53 []
    dir_  = Dir_53 
instance C_Dir Ent58 Ent38 where
    _dir = Dir_58 []
    dir_  = Dir_58 
instance C_Dir Ent59 Ent38 where
    _dir = Dir_59 []
    dir_  = Dir_59 
instance C_Dir Ent62 Ent38 where
    _dir = Dir_62 []
    dir_  = Dir_62 
instance C_Dir Ent65 Ent13 where
    _dir = Dir_65 []
    dir_  = Dir_65 
instance C_Dir Ent66 Ent6 where
    _dir = Dir_66 []
    dir_  = Dir_66 
instance C_Dir Ent67 Ent70 where
    _dir = Dir_67 []
    dir_  = Dir_67 
instance C_Dir Ent75 Ent19 where
    _dir = Dir_75 []
    dir_  = Dir_75 
instance C_Dir Ent76 Ent19 where
    _dir = Dir_76 []
    dir_  = Dir_76 
instance C_Dir Ent78 Ent44 where
    _dir = Dir_78 []
    dir_  = Dir_78 
instance C_Dir Ent79 Ent44 where
    _dir = Dir_79 []
    dir_  = Dir_79 
instance C_Dir Ent82 Ent44 where
    _dir = Dir_82 []
    dir_  = Dir_82 
instance C_Dir Ent85 Ent19 where
    _dir = Dir_85 []
    dir_  = Dir_85 
instance C_Dir Ent86 Ent70 where
    _dir = Dir_86 []
    dir_  = Dir_86 
instance C_Dir Ent87 Ent70 where
    _dir = Dir_87 []
    dir_  = Dir_87 
instance C_Dir Ent90 Ent91 where
    _dir = Dir_90 []
    dir_  = Dir_90 
instance C_Dir Ent95 Ent91 where
    _dir = Dir_95 []
    dir_  = Dir_95 
instance C_Dir Ent100 Ent91 where
    _dir = Dir_100 []
    dir_  = Dir_100 
instance C_Dir Ent101 Ent91 where
    _dir = Dir_101 []
    dir_  = Dir_101 
instance C_Dir Ent104 Ent91 where
    _dir = Dir_104 []
    dir_  = Dir_104 
instance C_Dir Ent107 Ent70 where
    _dir = Dir_107 []
    dir_  = Dir_107 
instance C_Dir Ent108 Ent70 where
    _dir = Dir_108 []
    dir_  = Dir_108 
instance C_Dir Ent115 Ent116 where
    _dir = Dir_115 []
    dir_  = Dir_115 
instance C_Dir Ent120 Ent116 where
    _dir = Dir_120 []
    dir_  = Dir_120 
instance C_Dir Ent125 Ent116 where
    _dir = Dir_125 []
    dir_  = Dir_125 
instance C_Dir Ent126 Ent116 where
    _dir = Dir_126 []
    dir_  = Dir_126 
instance C_Dir Ent129 Ent116 where
    _dir = Dir_129 []
    dir_  = Dir_129 
instance C_Dir Ent132 Ent6 where
    _dir = Dir_132 []
    dir_  = Dir_132 
instance C_Dir Ent133 Ent6 where
    _dir = Dir_133 []
    dir_  = Dir_133 

class C_Li a b | a -> b where
    _li :: [b] -> a
    li_ :: [Att17] -> [b] -> a
instance C_Li Ent6 Ent4 where
    _li = Li_6 []
    li_  = Li_6 
instance C_Li Ent13 Ent12 where
    _li = Li_13 []
    li_  = Li_13 
instance C_Li Ent19 Ent17 where
    _li = Li_19 []
    li_  = Li_19 
instance C_Li Ent38 Ent37 where
    _li = Li_38 []
    li_  = Li_38 
instance C_Li Ent44 Ent42 where
    _li = Li_44 []
    li_  = Li_44 
instance C_Li Ent70 Ent67 where
    _li = Li_70 []
    li_  = Li_70 
instance C_Li Ent91 Ent90 where
    _li = Li_91 []
    li_  = Li_91 
instance C_Li Ent116 Ent115 where
    _li = Li_116 []
    li_  = Li_116 

class C_Dl a b | a -> b where
    _dl :: [b] -> a
    dl_ :: [Att16] -> [b] -> a
instance C_Dl Ent3 Ent7 where
    _dl = Dl_3 []
    dl_  = Dl_3 
instance C_Dl Ent4 Ent7 where
    _dl = Dl_4 []
    dl_  = Dl_4 
instance C_Dl Ent12 Ent14 where
    _dl = Dl_12 []
    dl_  = Dl_12 
instance C_Dl Ent17 Ent20 where
    _dl = Dl_17 []
    dl_  = Dl_17 
instance C_Dl Ent23 Ent20 where
    _dl = Dl_23 []
    dl_  = Dl_23 
instance C_Dl Ent28 Ent14 where
    _dl = Dl_28 []
    dl_  = Dl_28 
instance C_Dl Ent33 Ent14 where
    _dl = Dl_33 []
    dl_  = Dl_33 
instance C_Dl Ent34 Ent14 where
    _dl = Dl_34 []
    dl_  = Dl_34 
instance C_Dl Ent37 Ent39 where
    _dl = Dl_37 []
    dl_  = Dl_37 
instance C_Dl Ent42 Ent45 where
    _dl = Dl_42 []
    dl_  = Dl_42 
instance C_Dl Ent48 Ent45 where
    _dl = Dl_48 []
    dl_  = Dl_48 
instance C_Dl Ent53 Ent39 where
    _dl = Dl_53 []
    dl_  = Dl_53 
instance C_Dl Ent58 Ent39 where
    _dl = Dl_58 []
    dl_  = Dl_58 
instance C_Dl Ent59 Ent39 where
    _dl = Dl_59 []
    dl_  = Dl_59 
instance C_Dl Ent62 Ent39 where
    _dl = Dl_62 []
    dl_  = Dl_62 
instance C_Dl Ent65 Ent14 where
    _dl = Dl_65 []
    dl_  = Dl_65 
instance C_Dl Ent66 Ent7 where
    _dl = Dl_66 []
    dl_  = Dl_66 
instance C_Dl Ent67 Ent71 where
    _dl = Dl_67 []
    dl_  = Dl_67 
instance C_Dl Ent75 Ent20 where
    _dl = Dl_75 []
    dl_  = Dl_75 
instance C_Dl Ent76 Ent20 where
    _dl = Dl_76 []
    dl_  = Dl_76 
instance C_Dl Ent78 Ent45 where
    _dl = Dl_78 []
    dl_  = Dl_78 
instance C_Dl Ent79 Ent45 where
    _dl = Dl_79 []
    dl_  = Dl_79 
instance C_Dl Ent82 Ent45 where
    _dl = Dl_82 []
    dl_  = Dl_82 
instance C_Dl Ent85 Ent20 where
    _dl = Dl_85 []
    dl_  = Dl_85 
instance C_Dl Ent86 Ent71 where
    _dl = Dl_86 []
    dl_  = Dl_86 
instance C_Dl Ent87 Ent71 where
    _dl = Dl_87 []
    dl_  = Dl_87 
instance C_Dl Ent90 Ent92 where
    _dl = Dl_90 []
    dl_  = Dl_90 
instance C_Dl Ent95 Ent92 where
    _dl = Dl_95 []
    dl_  = Dl_95 
instance C_Dl Ent100 Ent92 where
    _dl = Dl_100 []
    dl_  = Dl_100 
instance C_Dl Ent101 Ent92 where
    _dl = Dl_101 []
    dl_  = Dl_101 
instance C_Dl Ent104 Ent92 where
    _dl = Dl_104 []
    dl_  = Dl_104 
instance C_Dl Ent107 Ent71 where
    _dl = Dl_107 []
    dl_  = Dl_107 
instance C_Dl Ent108 Ent71 where
    _dl = Dl_108 []
    dl_  = Dl_108 
instance C_Dl Ent115 Ent117 where
    _dl = Dl_115 []
    dl_  = Dl_115 
instance C_Dl Ent120 Ent117 where
    _dl = Dl_120 []
    dl_  = Dl_120 
instance C_Dl Ent125 Ent117 where
    _dl = Dl_125 []
    dl_  = Dl_125 
instance C_Dl Ent126 Ent117 where
    _dl = Dl_126 []
    dl_  = Dl_126 
instance C_Dl Ent129 Ent117 where
    _dl = Dl_129 []
    dl_  = Dl_129 
instance C_Dl Ent132 Ent7 where
    _dl = Dl_132 []
    dl_  = Dl_132 
instance C_Dl Ent133 Ent7 where
    _dl = Dl_133 []
    dl_  = Dl_133 

class C_Dt a b | a -> b where
    _dt :: [b] -> a
    dt_ :: [Att10] -> [b] -> a
instance C_Dt Ent7 Ent5 where
    _dt = Dt_7 []
    dt_  = Dt_7 
instance C_Dt Ent14 Ent10 where
    _dt = Dt_14 []
    dt_  = Dt_14 
instance C_Dt Ent20 Ent18 where
    _dt = Dt_20 []
    dt_  = Dt_20 
instance C_Dt Ent39 Ent35 where
    _dt = Dt_39 []
    dt_  = Dt_39 
instance C_Dt Ent45 Ent43 where
    _dt = Dt_45 []
    dt_  = Dt_45 
instance C_Dt Ent71 Ent69 where
    _dt = Dt_71 []
    dt_  = Dt_71 
instance C_Dt Ent92 Ent88 where
    _dt = Dt_92 []
    dt_  = Dt_92 
instance C_Dt Ent117 Ent113 where
    _dt = Dt_117 []
    dt_  = Dt_117 

class C_Dd a b | a -> b where
    _dd :: [b] -> a
    dd_ :: [Att10] -> [b] -> a
instance C_Dd Ent7 Ent4 where
    _dd = Dd_7 []
    dd_  = Dd_7 
instance C_Dd Ent14 Ent12 where
    _dd = Dd_14 []
    dd_  = Dd_14 
instance C_Dd Ent20 Ent17 where
    _dd = Dd_20 []
    dd_  = Dd_20 
instance C_Dd Ent39 Ent37 where
    _dd = Dd_39 []
    dd_  = Dd_39 
instance C_Dd Ent45 Ent42 where
    _dd = Dd_45 []
    dd_  = Dd_45 
instance C_Dd Ent71 Ent67 where
    _dd = Dd_71 []
    dd_  = Dd_71 
instance C_Dd Ent92 Ent90 where
    _dd = Dd_92 []
    dd_  = Dd_92 
instance C_Dd Ent117 Ent115 where
    _dd = Dd_117 []
    dd_  = Dd_117 

class C_Address a b | a -> b where
    _address :: [b] -> a
    address_ :: [Att10] -> [b] -> a
instance C_Address Ent3 Ent8 where
    _address = Address_3 []
    address_  = Address_3 
instance C_Address Ent4 Ent8 where
    _address = Address_4 []
    address_  = Address_4 
instance C_Address Ent12 Ent15 where
    _address = Address_12 []
    address_  = Address_12 
instance C_Address Ent17 Ent21 where
    _address = Address_17 []
    address_  = Address_17 
instance C_Address Ent23 Ent21 where
    _address = Address_23 []
    address_  = Address_23 
instance C_Address Ent28 Ent15 where
    _address = Address_28 []
    address_  = Address_28 
instance C_Address Ent33 Ent15 where
    _address = Address_33 []
    address_  = Address_33 
instance C_Address Ent34 Ent15 where
    _address = Address_34 []
    address_  = Address_34 
instance C_Address Ent37 Ent40 where
    _address = Address_37 []
    address_  = Address_37 
instance C_Address Ent42 Ent46 where
    _address = Address_42 []
    address_  = Address_42 
instance C_Address Ent48 Ent46 where
    _address = Address_48 []
    address_  = Address_48 
instance C_Address Ent53 Ent40 where
    _address = Address_53 []
    address_  = Address_53 
instance C_Address Ent58 Ent40 where
    _address = Address_58 []
    address_  = Address_58 
instance C_Address Ent59 Ent40 where
    _address = Address_59 []
    address_  = Address_59 
instance C_Address Ent62 Ent40 where
    _address = Address_62 []
    address_  = Address_62 
instance C_Address Ent65 Ent15 where
    _address = Address_65 []
    address_  = Address_65 
instance C_Address Ent66 Ent8 where
    _address = Address_66 []
    address_  = Address_66 
instance C_Address Ent67 Ent72 where
    _address = Address_67 []
    address_  = Address_67 
instance C_Address Ent75 Ent21 where
    _address = Address_75 []
    address_  = Address_75 
instance C_Address Ent76 Ent21 where
    _address = Address_76 []
    address_  = Address_76 
instance C_Address Ent78 Ent46 where
    _address = Address_78 []
    address_  = Address_78 
instance C_Address Ent79 Ent46 where
    _address = Address_79 []
    address_  = Address_79 
instance C_Address Ent82 Ent46 where
    _address = Address_82 []
    address_  = Address_82 
instance C_Address Ent85 Ent21 where
    _address = Address_85 []
    address_  = Address_85 
instance C_Address Ent86 Ent72 where
    _address = Address_86 []
    address_  = Address_86 
instance C_Address Ent87 Ent72 where
    _address = Address_87 []
    address_  = Address_87 
instance C_Address Ent90 Ent93 where
    _address = Address_90 []
    address_  = Address_90 
instance C_Address Ent95 Ent93 where
    _address = Address_95 []
    address_  = Address_95 
instance C_Address Ent100 Ent93 where
    _address = Address_100 []
    address_  = Address_100 
instance C_Address Ent101 Ent93 where
    _address = Address_101 []
    address_  = Address_101 
instance C_Address Ent104 Ent93 where
    _address = Address_104 []
    address_  = Address_104 
instance C_Address Ent107 Ent72 where
    _address = Address_107 []
    address_  = Address_107 
instance C_Address Ent108 Ent72 where
    _address = Address_108 []
    address_  = Address_108 
instance C_Address Ent115 Ent118 where
    _address = Address_115 []
    address_  = Address_115 
instance C_Address Ent120 Ent118 where
    _address = Address_120 []
    address_  = Address_120 
instance C_Address Ent125 Ent118 where
    _address = Address_125 []
    address_  = Address_125 
instance C_Address Ent126 Ent118 where
    _address = Address_126 []
    address_  = Address_126 
instance C_Address Ent129 Ent118 where
    _address = Address_129 []
    address_  = Address_129 
instance C_Address Ent132 Ent8 where
    _address = Address_132 []
    address_  = Address_132 
instance C_Address Ent133 Ent8 where
    _address = Address_133 []
    address_  = Address_133 

class C_Hr a where
    _hr :: a
    hr_ :: [Att18] -> a
instance C_Hr Ent3 where
    _hr = Hr_3 []
    hr_ = Hr_3 
instance C_Hr Ent4 where
    _hr = Hr_4 []
    hr_ = Hr_4 
instance C_Hr Ent12 where
    _hr = Hr_12 []
    hr_ = Hr_12 
instance C_Hr Ent17 where
    _hr = Hr_17 []
    hr_ = Hr_17 
instance C_Hr Ent23 where
    _hr = Hr_23 []
    hr_ = Hr_23 
instance C_Hr Ent28 where
    _hr = Hr_28 []
    hr_ = Hr_28 
instance C_Hr Ent33 where
    _hr = Hr_33 []
    hr_ = Hr_33 
instance C_Hr Ent34 where
    _hr = Hr_34 []
    hr_ = Hr_34 
instance C_Hr Ent37 where
    _hr = Hr_37 []
    hr_ = Hr_37 
instance C_Hr Ent42 where
    _hr = Hr_42 []
    hr_ = Hr_42 
instance C_Hr Ent48 where
    _hr = Hr_48 []
    hr_ = Hr_48 
instance C_Hr Ent53 where
    _hr = Hr_53 []
    hr_ = Hr_53 
instance C_Hr Ent58 where
    _hr = Hr_58 []
    hr_ = Hr_58 
instance C_Hr Ent59 where
    _hr = Hr_59 []
    hr_ = Hr_59 
instance C_Hr Ent62 where
    _hr = Hr_62 []
    hr_ = Hr_62 
instance C_Hr Ent65 where
    _hr = Hr_65 []
    hr_ = Hr_65 
instance C_Hr Ent66 where
    _hr = Hr_66 []
    hr_ = Hr_66 
instance C_Hr Ent67 where
    _hr = Hr_67 []
    hr_ = Hr_67 
instance C_Hr Ent75 where
    _hr = Hr_75 []
    hr_ = Hr_75 
instance C_Hr Ent76 where
    _hr = Hr_76 []
    hr_ = Hr_76 
instance C_Hr Ent78 where
    _hr = Hr_78 []
    hr_ = Hr_78 
instance C_Hr Ent79 where
    _hr = Hr_79 []
    hr_ = Hr_79 
instance C_Hr Ent82 where
    _hr = Hr_82 []
    hr_ = Hr_82 
instance C_Hr Ent85 where
    _hr = Hr_85 []
    hr_ = Hr_85 
instance C_Hr Ent86 where
    _hr = Hr_86 []
    hr_ = Hr_86 
instance C_Hr Ent87 where
    _hr = Hr_87 []
    hr_ = Hr_87 
instance C_Hr Ent90 where
    _hr = Hr_90 []
    hr_ = Hr_90 
instance C_Hr Ent95 where
    _hr = Hr_95 []
    hr_ = Hr_95 
instance C_Hr Ent100 where
    _hr = Hr_100 []
    hr_ = Hr_100 
instance C_Hr Ent101 where
    _hr = Hr_101 []
    hr_ = Hr_101 
instance C_Hr Ent104 where
    _hr = Hr_104 []
    hr_ = Hr_104 
instance C_Hr Ent107 where
    _hr = Hr_107 []
    hr_ = Hr_107 
instance C_Hr Ent108 where
    _hr = Hr_108 []
    hr_ = Hr_108 
instance C_Hr Ent115 where
    _hr = Hr_115 []
    hr_ = Hr_115 
instance C_Hr Ent120 where
    _hr = Hr_120 []
    hr_ = Hr_120 
instance C_Hr Ent125 where
    _hr = Hr_125 []
    hr_ = Hr_125 
instance C_Hr Ent126 where
    _hr = Hr_126 []
    hr_ = Hr_126 
instance C_Hr Ent129 where
    _hr = Hr_129 []
    hr_ = Hr_129 
instance C_Hr Ent132 where
    _hr = Hr_132 []
    hr_ = Hr_132 
instance C_Hr Ent133 where
    _hr = Hr_133 []
    hr_ = Hr_133 

class C_Pre a b | a -> b where
    _pre :: [b] -> a
    pre_ :: [Att19] -> [b] -> a
instance C_Pre Ent3 Ent9 where
    _pre = Pre_3 []
    pre_  = Pre_3 
instance C_Pre Ent4 Ent9 where
    _pre = Pre_4 []
    pre_  = Pre_4 
instance C_Pre Ent12 Ent16 where
    _pre = Pre_12 []
    pre_  = Pre_12 
instance C_Pre Ent17 Ent22 where
    _pre = Pre_17 []
    pre_  = Pre_17 
instance C_Pre Ent23 Ent22 where
    _pre = Pre_23 []
    pre_  = Pre_23 
instance C_Pre Ent28 Ent16 where
    _pre = Pre_28 []
    pre_  = Pre_28 
instance C_Pre Ent33 Ent16 where
    _pre = Pre_33 []
    pre_  = Pre_33 
instance C_Pre Ent34 Ent16 where
    _pre = Pre_34 []
    pre_  = Pre_34 
instance C_Pre Ent37 Ent41 where
    _pre = Pre_37 []
    pre_  = Pre_37 
instance C_Pre Ent42 Ent47 where
    _pre = Pre_42 []
    pre_  = Pre_42 
instance C_Pre Ent48 Ent47 where
    _pre = Pre_48 []
    pre_  = Pre_48 
instance C_Pre Ent53 Ent41 where
    _pre = Pre_53 []
    pre_  = Pre_53 
instance C_Pre Ent58 Ent41 where
    _pre = Pre_58 []
    pre_  = Pre_58 
instance C_Pre Ent59 Ent41 where
    _pre = Pre_59 []
    pre_  = Pre_59 
instance C_Pre Ent62 Ent41 where
    _pre = Pre_62 []
    pre_  = Pre_62 
instance C_Pre Ent65 Ent16 where
    _pre = Pre_65 []
    pre_  = Pre_65 
instance C_Pre Ent66 Ent9 where
    _pre = Pre_66 []
    pre_  = Pre_66 
instance C_Pre Ent67 Ent73 where
    _pre = Pre_67 []
    pre_  = Pre_67 
instance C_Pre Ent75 Ent22 where
    _pre = Pre_75 []
    pre_  = Pre_75 
instance C_Pre Ent76 Ent22 where
    _pre = Pre_76 []
    pre_  = Pre_76 
instance C_Pre Ent78 Ent47 where
    _pre = Pre_78 []
    pre_  = Pre_78 
instance C_Pre Ent79 Ent47 where
    _pre = Pre_79 []
    pre_  = Pre_79 
instance C_Pre Ent82 Ent47 where
    _pre = Pre_82 []
    pre_  = Pre_82 
instance C_Pre Ent85 Ent22 where
    _pre = Pre_85 []
    pre_  = Pre_85 
instance C_Pre Ent86 Ent73 where
    _pre = Pre_86 []
    pre_  = Pre_86 
instance C_Pre Ent87 Ent73 where
    _pre = Pre_87 []
    pre_  = Pre_87 
instance C_Pre Ent90 Ent94 where
    _pre = Pre_90 []
    pre_  = Pre_90 
instance C_Pre Ent95 Ent94 where
    _pre = Pre_95 []
    pre_  = Pre_95 
instance C_Pre Ent100 Ent94 where
    _pre = Pre_100 []
    pre_  = Pre_100 
instance C_Pre Ent101 Ent94 where
    _pre = Pre_101 []
    pre_  = Pre_101 
instance C_Pre Ent104 Ent94 where
    _pre = Pre_104 []
    pre_  = Pre_104 
instance C_Pre Ent107 Ent73 where
    _pre = Pre_107 []
    pre_  = Pre_107 
instance C_Pre Ent108 Ent73 where
    _pre = Pre_108 []
    pre_  = Pre_108 
instance C_Pre Ent115 Ent119 where
    _pre = Pre_115 []
    pre_  = Pre_115 
instance C_Pre Ent120 Ent119 where
    _pre = Pre_120 []
    pre_  = Pre_120 
instance C_Pre Ent125 Ent119 where
    _pre = Pre_125 []
    pre_  = Pre_125 
instance C_Pre Ent126 Ent119 where
    _pre = Pre_126 []
    pre_  = Pre_126 
instance C_Pre Ent129 Ent119 where
    _pre = Pre_129 []
    pre_  = Pre_129 
instance C_Pre Ent132 Ent9 where
    _pre = Pre_132 []
    pre_  = Pre_132 
instance C_Pre Ent133 Ent9 where
    _pre = Pre_133 []
    pre_  = Pre_133 

class C_Blockquote a b | a -> b where
    _blockquote :: [b] -> a
    blockquote_ :: [Att20] -> [b] -> a
instance C_Blockquote Ent3 Ent4 where
    _blockquote = Blockquote_3 []
    blockquote_  = Blockquote_3 
instance C_Blockquote Ent4 Ent4 where
    _blockquote = Blockquote_4 []
    blockquote_  = Blockquote_4 
instance C_Blockquote Ent12 Ent12 where
    _blockquote = Blockquote_12 []
    blockquote_  = Blockquote_12 
instance C_Blockquote Ent17 Ent17 where
    _blockquote = Blockquote_17 []
    blockquote_  = Blockquote_17 
instance C_Blockquote Ent23 Ent17 where
    _blockquote = Blockquote_23 []
    blockquote_  = Blockquote_23 
instance C_Blockquote Ent28 Ent12 where
    _blockquote = Blockquote_28 []
    blockquote_  = Blockquote_28 
instance C_Blockquote Ent33 Ent12 where
    _blockquote = Blockquote_33 []
    blockquote_  = Blockquote_33 
instance C_Blockquote Ent34 Ent12 where
    _blockquote = Blockquote_34 []
    blockquote_  = Blockquote_34 
instance C_Blockquote Ent37 Ent37 where
    _blockquote = Blockquote_37 []
    blockquote_  = Blockquote_37 
instance C_Blockquote Ent42 Ent42 where
    _blockquote = Blockquote_42 []
    blockquote_  = Blockquote_42 
instance C_Blockquote Ent48 Ent42 where
    _blockquote = Blockquote_48 []
    blockquote_  = Blockquote_48 
instance C_Blockquote Ent53 Ent37 where
    _blockquote = Blockquote_53 []
    blockquote_  = Blockquote_53 
instance C_Blockquote Ent58 Ent37 where
    _blockquote = Blockquote_58 []
    blockquote_  = Blockquote_58 
instance C_Blockquote Ent59 Ent37 where
    _blockquote = Blockquote_59 []
    blockquote_  = Blockquote_59 
instance C_Blockquote Ent62 Ent37 where
    _blockquote = Blockquote_62 []
    blockquote_  = Blockquote_62 
instance C_Blockquote Ent65 Ent12 where
    _blockquote = Blockquote_65 []
    blockquote_  = Blockquote_65 
instance C_Blockquote Ent66 Ent4 where
    _blockquote = Blockquote_66 []
    blockquote_  = Blockquote_66 
instance C_Blockquote Ent67 Ent67 where
    _blockquote = Blockquote_67 []
    blockquote_  = Blockquote_67 
instance C_Blockquote Ent75 Ent17 where
    _blockquote = Blockquote_75 []
    blockquote_  = Blockquote_75 
instance C_Blockquote Ent76 Ent17 where
    _blockquote = Blockquote_76 []
    blockquote_  = Blockquote_76 
instance C_Blockquote Ent78 Ent42 where
    _blockquote = Blockquote_78 []
    blockquote_  = Blockquote_78 
instance C_Blockquote Ent79 Ent42 where
    _blockquote = Blockquote_79 []
    blockquote_  = Blockquote_79 
instance C_Blockquote Ent82 Ent42 where
    _blockquote = Blockquote_82 []
    blockquote_  = Blockquote_82 
instance C_Blockquote Ent85 Ent17 where
    _blockquote = Blockquote_85 []
    blockquote_  = Blockquote_85 
instance C_Blockquote Ent86 Ent67 where
    _blockquote = Blockquote_86 []
    blockquote_  = Blockquote_86 
instance C_Blockquote Ent87 Ent67 where
    _blockquote = Blockquote_87 []
    blockquote_  = Blockquote_87 
instance C_Blockquote Ent90 Ent90 where
    _blockquote = Blockquote_90 []
    blockquote_  = Blockquote_90 
instance C_Blockquote Ent95 Ent90 where
    _blockquote = Blockquote_95 []
    blockquote_  = Blockquote_95 
instance C_Blockquote Ent100 Ent90 where
    _blockquote = Blockquote_100 []
    blockquote_  = Blockquote_100 
instance C_Blockquote Ent101 Ent90 where
    _blockquote = Blockquote_101 []
    blockquote_  = Blockquote_101 
instance C_Blockquote Ent104 Ent90 where
    _blockquote = Blockquote_104 []
    blockquote_  = Blockquote_104 
instance C_Blockquote Ent107 Ent67 where
    _blockquote = Blockquote_107 []
    blockquote_  = Blockquote_107 
instance C_Blockquote Ent108 Ent67 where
    _blockquote = Blockquote_108 []
    blockquote_  = Blockquote_108 
instance C_Blockquote Ent115 Ent115 where
    _blockquote = Blockquote_115 []
    blockquote_  = Blockquote_115 
instance C_Blockquote Ent120 Ent115 where
    _blockquote = Blockquote_120 []
    blockquote_  = Blockquote_120 
instance C_Blockquote Ent125 Ent115 where
    _blockquote = Blockquote_125 []
    blockquote_  = Blockquote_125 
instance C_Blockquote Ent126 Ent115 where
    _blockquote = Blockquote_126 []
    blockquote_  = Blockquote_126 
instance C_Blockquote Ent129 Ent115 where
    _blockquote = Blockquote_129 []
    blockquote_  = Blockquote_129 
instance C_Blockquote Ent132 Ent4 where
    _blockquote = Blockquote_132 []
    blockquote_  = Blockquote_132 
instance C_Blockquote Ent133 Ent4 where
    _blockquote = Blockquote_133 []
    blockquote_  = Blockquote_133 

class C_Center a b | a -> b where
    _center :: [b] -> a
    center_ :: [Att10] -> [b] -> a
instance C_Center Ent3 Ent4 where
    _center = Center_3 []
    center_  = Center_3 
instance C_Center Ent4 Ent4 where
    _center = Center_4 []
    center_  = Center_4 
instance C_Center Ent12 Ent12 where
    _center = Center_12 []
    center_  = Center_12 
instance C_Center Ent17 Ent17 where
    _center = Center_17 []
    center_  = Center_17 
instance C_Center Ent23 Ent17 where
    _center = Center_23 []
    center_  = Center_23 
instance C_Center Ent28 Ent12 where
    _center = Center_28 []
    center_  = Center_28 
instance C_Center Ent33 Ent12 where
    _center = Center_33 []
    center_  = Center_33 
instance C_Center Ent34 Ent12 where
    _center = Center_34 []
    center_  = Center_34 
instance C_Center Ent37 Ent37 where
    _center = Center_37 []
    center_  = Center_37 
instance C_Center Ent42 Ent42 where
    _center = Center_42 []
    center_  = Center_42 
instance C_Center Ent48 Ent42 where
    _center = Center_48 []
    center_  = Center_48 
instance C_Center Ent53 Ent37 where
    _center = Center_53 []
    center_  = Center_53 
instance C_Center Ent58 Ent37 where
    _center = Center_58 []
    center_  = Center_58 
instance C_Center Ent59 Ent37 where
    _center = Center_59 []
    center_  = Center_59 
instance C_Center Ent62 Ent37 where
    _center = Center_62 []
    center_  = Center_62 
instance C_Center Ent65 Ent12 where
    _center = Center_65 []
    center_  = Center_65 
instance C_Center Ent66 Ent4 where
    _center = Center_66 []
    center_  = Center_66 
instance C_Center Ent67 Ent67 where
    _center = Center_67 []
    center_  = Center_67 
instance C_Center Ent75 Ent17 where
    _center = Center_75 []
    center_  = Center_75 
instance C_Center Ent76 Ent17 where
    _center = Center_76 []
    center_  = Center_76 
instance C_Center Ent78 Ent42 where
    _center = Center_78 []
    center_  = Center_78 
instance C_Center Ent79 Ent42 where
    _center = Center_79 []
    center_  = Center_79 
instance C_Center Ent82 Ent42 where
    _center = Center_82 []
    center_  = Center_82 
instance C_Center Ent85 Ent17 where
    _center = Center_85 []
    center_  = Center_85 
instance C_Center Ent86 Ent67 where
    _center = Center_86 []
    center_  = Center_86 
instance C_Center Ent87 Ent67 where
    _center = Center_87 []
    center_  = Center_87 
instance C_Center Ent90 Ent90 where
    _center = Center_90 []
    center_  = Center_90 
instance C_Center Ent95 Ent90 where
    _center = Center_95 []
    center_  = Center_95 
instance C_Center Ent100 Ent90 where
    _center = Center_100 []
    center_  = Center_100 
instance C_Center Ent101 Ent90 where
    _center = Center_101 []
    center_  = Center_101 
instance C_Center Ent104 Ent90 where
    _center = Center_104 []
    center_  = Center_104 
instance C_Center Ent107 Ent67 where
    _center = Center_107 []
    center_  = Center_107 
instance C_Center Ent108 Ent67 where
    _center = Center_108 []
    center_  = Center_108 
instance C_Center Ent115 Ent115 where
    _center = Center_115 []
    center_  = Center_115 
instance C_Center Ent120 Ent115 where
    _center = Center_120 []
    center_  = Center_120 
instance C_Center Ent125 Ent115 where
    _center = Center_125 []
    center_  = Center_125 
instance C_Center Ent126 Ent115 where
    _center = Center_126 []
    center_  = Center_126 
instance C_Center Ent129 Ent115 where
    _center = Center_129 []
    center_  = Center_129 
instance C_Center Ent132 Ent4 where
    _center = Center_132 []
    center_  = Center_132 
instance C_Center Ent133 Ent4 where
    _center = Center_133 []
    center_  = Center_133 

class C_Ins a b | a -> b where
    _ins :: [b] -> a
    ins_ :: [Att21] -> [b] -> a
instance C_Ins Ent3 Ent4 where
    _ins = Ins_3 []
    ins_  = Ins_3 
instance C_Ins Ent4 Ent4 where
    _ins = Ins_4 []
    ins_  = Ins_4 
instance C_Ins Ent5 Ent4 where
    _ins = Ins_5 []
    ins_  = Ins_5 
instance C_Ins Ent8 Ent4 where
    _ins = Ins_8 []
    ins_  = Ins_8 
instance C_Ins Ent9 Ent4 where
    _ins = Ins_9 []
    ins_  = Ins_9 
instance C_Ins Ent10 Ent12 where
    _ins = Ins_10 []
    ins_  = Ins_10 
instance C_Ins Ent12 Ent12 where
    _ins = Ins_12 []
    ins_  = Ins_12 
instance C_Ins Ent15 Ent12 where
    _ins = Ins_15 []
    ins_  = Ins_15 
instance C_Ins Ent16 Ent12 where
    _ins = Ins_16 []
    ins_  = Ins_16 
instance C_Ins Ent17 Ent17 where
    _ins = Ins_17 []
    ins_  = Ins_17 
instance C_Ins Ent18 Ent17 where
    _ins = Ins_18 []
    ins_  = Ins_18 
instance C_Ins Ent21 Ent17 where
    _ins = Ins_21 []
    ins_  = Ins_21 
instance C_Ins Ent22 Ent17 where
    _ins = Ins_22 []
    ins_  = Ins_22 
instance C_Ins Ent23 Ent17 where
    _ins = Ins_23 []
    ins_  = Ins_23 
instance C_Ins Ent28 Ent12 where
    _ins = Ins_28 []
    ins_  = Ins_28 
instance C_Ins Ent33 Ent12 where
    _ins = Ins_33 []
    ins_  = Ins_33 
instance C_Ins Ent34 Ent12 where
    _ins = Ins_34 []
    ins_  = Ins_34 
instance C_Ins Ent35 Ent37 where
    _ins = Ins_35 []
    ins_  = Ins_35 
instance C_Ins Ent37 Ent37 where
    _ins = Ins_37 []
    ins_  = Ins_37 
instance C_Ins Ent40 Ent37 where
    _ins = Ins_40 []
    ins_  = Ins_40 
instance C_Ins Ent41 Ent37 where
    _ins = Ins_41 []
    ins_  = Ins_41 
instance C_Ins Ent42 Ent42 where
    _ins = Ins_42 []
    ins_  = Ins_42 
instance C_Ins Ent43 Ent42 where
    _ins = Ins_43 []
    ins_  = Ins_43 
instance C_Ins Ent46 Ent42 where
    _ins = Ins_46 []
    ins_  = Ins_46 
instance C_Ins Ent47 Ent42 where
    _ins = Ins_47 []
    ins_  = Ins_47 
instance C_Ins Ent48 Ent42 where
    _ins = Ins_48 []
    ins_  = Ins_48 
instance C_Ins Ent53 Ent37 where
    _ins = Ins_53 []
    ins_  = Ins_53 
instance C_Ins Ent58 Ent37 where
    _ins = Ins_58 []
    ins_  = Ins_58 
instance C_Ins Ent59 Ent37 where
    _ins = Ins_59 []
    ins_  = Ins_59 
instance C_Ins Ent62 Ent37 where
    _ins = Ins_62 []
    ins_  = Ins_62 
instance C_Ins Ent65 Ent12 where
    _ins = Ins_65 []
    ins_  = Ins_65 
instance C_Ins Ent66 Ent4 where
    _ins = Ins_66 []
    ins_  = Ins_66 
instance C_Ins Ent67 Ent67 where
    _ins = Ins_67 []
    ins_  = Ins_67 
instance C_Ins Ent69 Ent67 where
    _ins = Ins_69 []
    ins_  = Ins_69 
instance C_Ins Ent72 Ent67 where
    _ins = Ins_72 []
    ins_  = Ins_72 
instance C_Ins Ent73 Ent67 where
    _ins = Ins_73 []
    ins_  = Ins_73 
instance C_Ins Ent75 Ent17 where
    _ins = Ins_75 []
    ins_  = Ins_75 
instance C_Ins Ent76 Ent17 where
    _ins = Ins_76 []
    ins_  = Ins_76 
instance C_Ins Ent78 Ent42 where
    _ins = Ins_78 []
    ins_  = Ins_78 
instance C_Ins Ent79 Ent42 where
    _ins = Ins_79 []
    ins_  = Ins_79 
instance C_Ins Ent82 Ent42 where
    _ins = Ins_82 []
    ins_  = Ins_82 
instance C_Ins Ent85 Ent17 where
    _ins = Ins_85 []
    ins_  = Ins_85 
instance C_Ins Ent86 Ent67 where
    _ins = Ins_86 []
    ins_  = Ins_86 
instance C_Ins Ent87 Ent67 where
    _ins = Ins_87 []
    ins_  = Ins_87 
instance C_Ins Ent88 Ent90 where
    _ins = Ins_88 []
    ins_  = Ins_88 
instance C_Ins Ent90 Ent90 where
    _ins = Ins_90 []
    ins_  = Ins_90 
instance C_Ins Ent93 Ent90 where
    _ins = Ins_93 []
    ins_  = Ins_93 
instance C_Ins Ent94 Ent90 where
    _ins = Ins_94 []
    ins_  = Ins_94 
instance C_Ins Ent95 Ent90 where
    _ins = Ins_95 []
    ins_  = Ins_95 
instance C_Ins Ent100 Ent90 where
    _ins = Ins_100 []
    ins_  = Ins_100 
instance C_Ins Ent101 Ent90 where
    _ins = Ins_101 []
    ins_  = Ins_101 
instance C_Ins Ent104 Ent90 where
    _ins = Ins_104 []
    ins_  = Ins_104 
instance C_Ins Ent107 Ent67 where
    _ins = Ins_107 []
    ins_  = Ins_107 
instance C_Ins Ent108 Ent67 where
    _ins = Ins_108 []
    ins_  = Ins_108 
instance C_Ins Ent113 Ent115 where
    _ins = Ins_113 []
    ins_  = Ins_113 
instance C_Ins Ent115 Ent115 where
    _ins = Ins_115 []
    ins_  = Ins_115 
instance C_Ins Ent118 Ent115 where
    _ins = Ins_118 []
    ins_  = Ins_118 
instance C_Ins Ent119 Ent115 where
    _ins = Ins_119 []
    ins_  = Ins_119 
instance C_Ins Ent120 Ent115 where
    _ins = Ins_120 []
    ins_  = Ins_120 
instance C_Ins Ent125 Ent115 where
    _ins = Ins_125 []
    ins_  = Ins_125 
instance C_Ins Ent126 Ent115 where
    _ins = Ins_126 []
    ins_  = Ins_126 
instance C_Ins Ent129 Ent115 where
    _ins = Ins_129 []
    ins_  = Ins_129 
instance C_Ins Ent132 Ent4 where
    _ins = Ins_132 []
    ins_  = Ins_132 
instance C_Ins Ent133 Ent4 where
    _ins = Ins_133 []
    ins_  = Ins_133 

class C_Del a b | a -> b where
    _del :: [b] -> a
    del_ :: [Att21] -> [b] -> a
instance C_Del Ent3 Ent4 where
    _del = Del_3 []
    del_  = Del_3 
instance C_Del Ent4 Ent4 where
    _del = Del_4 []
    del_  = Del_4 
instance C_Del Ent5 Ent4 where
    _del = Del_5 []
    del_  = Del_5 
instance C_Del Ent8 Ent4 where
    _del = Del_8 []
    del_  = Del_8 
instance C_Del Ent9 Ent4 where
    _del = Del_9 []
    del_  = Del_9 
instance C_Del Ent10 Ent12 where
    _del = Del_10 []
    del_  = Del_10 
instance C_Del Ent12 Ent12 where
    _del = Del_12 []
    del_  = Del_12 
instance C_Del Ent15 Ent12 where
    _del = Del_15 []
    del_  = Del_15 
instance C_Del Ent16 Ent12 where
    _del = Del_16 []
    del_  = Del_16 
instance C_Del Ent17 Ent17 where
    _del = Del_17 []
    del_  = Del_17 
instance C_Del Ent18 Ent17 where
    _del = Del_18 []
    del_  = Del_18 
instance C_Del Ent21 Ent17 where
    _del = Del_21 []
    del_  = Del_21 
instance C_Del Ent22 Ent17 where
    _del = Del_22 []
    del_  = Del_22 
instance C_Del Ent23 Ent17 where
    _del = Del_23 []
    del_  = Del_23 
instance C_Del Ent28 Ent12 where
    _del = Del_28 []
    del_  = Del_28 
instance C_Del Ent33 Ent12 where
    _del = Del_33 []
    del_  = Del_33 
instance C_Del Ent34 Ent12 where
    _del = Del_34 []
    del_  = Del_34 
instance C_Del Ent35 Ent37 where
    _del = Del_35 []
    del_  = Del_35 
instance C_Del Ent37 Ent37 where
    _del = Del_37 []
    del_  = Del_37 
instance C_Del Ent40 Ent37 where
    _del = Del_40 []
    del_  = Del_40 
instance C_Del Ent41 Ent37 where
    _del = Del_41 []
    del_  = Del_41 
instance C_Del Ent42 Ent42 where
    _del = Del_42 []
    del_  = Del_42 
instance C_Del Ent43 Ent42 where
    _del = Del_43 []
    del_  = Del_43 
instance C_Del Ent46 Ent42 where
    _del = Del_46 []
    del_  = Del_46 
instance C_Del Ent47 Ent42 where
    _del = Del_47 []
    del_  = Del_47 
instance C_Del Ent48 Ent42 where
    _del = Del_48 []
    del_  = Del_48 
instance C_Del Ent53 Ent37 where
    _del = Del_53 []
    del_  = Del_53 
instance C_Del Ent58 Ent37 where
    _del = Del_58 []
    del_  = Del_58 
instance C_Del Ent59 Ent37 where
    _del = Del_59 []
    del_  = Del_59 
instance C_Del Ent62 Ent37 where
    _del = Del_62 []
    del_  = Del_62 
instance C_Del Ent65 Ent12 where
    _del = Del_65 []
    del_  = Del_65 
instance C_Del Ent66 Ent4 where
    _del = Del_66 []
    del_  = Del_66 
instance C_Del Ent67 Ent67 where
    _del = Del_67 []
    del_  = Del_67 
instance C_Del Ent69 Ent67 where
    _del = Del_69 []
    del_  = Del_69 
instance C_Del Ent72 Ent67 where
    _del = Del_72 []
    del_  = Del_72 
instance C_Del Ent73 Ent67 where
    _del = Del_73 []
    del_  = Del_73 
instance C_Del Ent75 Ent17 where
    _del = Del_75 []
    del_  = Del_75 
instance C_Del Ent76 Ent17 where
    _del = Del_76 []
    del_  = Del_76 
instance C_Del Ent78 Ent42 where
    _del = Del_78 []
    del_  = Del_78 
instance C_Del Ent79 Ent42 where
    _del = Del_79 []
    del_  = Del_79 
instance C_Del Ent82 Ent42 where
    _del = Del_82 []
    del_  = Del_82 
instance C_Del Ent85 Ent17 where
    _del = Del_85 []
    del_  = Del_85 
instance C_Del Ent86 Ent67 where
    _del = Del_86 []
    del_  = Del_86 
instance C_Del Ent87 Ent67 where
    _del = Del_87 []
    del_  = Del_87 
instance C_Del Ent88 Ent90 where
    _del = Del_88 []
    del_  = Del_88 
instance C_Del Ent90 Ent90 where
    _del = Del_90 []
    del_  = Del_90 
instance C_Del Ent93 Ent90 where
    _del = Del_93 []
    del_  = Del_93 
instance C_Del Ent94 Ent90 where
    _del = Del_94 []
    del_  = Del_94 
instance C_Del Ent95 Ent90 where
    _del = Del_95 []
    del_  = Del_95 
instance C_Del Ent100 Ent90 where
    _del = Del_100 []
    del_  = Del_100 
instance C_Del Ent101 Ent90 where
    _del = Del_101 []
    del_  = Del_101 
instance C_Del Ent104 Ent90 where
    _del = Del_104 []
    del_  = Del_104 
instance C_Del Ent107 Ent67 where
    _del = Del_107 []
    del_  = Del_107 
instance C_Del Ent108 Ent67 where
    _del = Del_108 []
    del_  = Del_108 
instance C_Del Ent113 Ent115 where
    _del = Del_113 []
    del_  = Del_113 
instance C_Del Ent115 Ent115 where
    _del = Del_115 []
    del_  = Del_115 
instance C_Del Ent118 Ent115 where
    _del = Del_118 []
    del_  = Del_118 
instance C_Del Ent119 Ent115 where
    _del = Del_119 []
    del_  = Del_119 
instance C_Del Ent120 Ent115 where
    _del = Del_120 []
    del_  = Del_120 
instance C_Del Ent125 Ent115 where
    _del = Del_125 []
    del_  = Del_125 
instance C_Del Ent126 Ent115 where
    _del = Del_126 []
    del_  = Del_126 
instance C_Del Ent129 Ent115 where
    _del = Del_129 []
    del_  = Del_129 
instance C_Del Ent132 Ent4 where
    _del = Del_132 []
    del_  = Del_132 
instance C_Del Ent133 Ent4 where
    _del = Del_133 []
    del_  = Del_133 

class C_A a b | a -> b where
    _a :: [b] -> a
    a_ :: [Att22] -> [b] -> a
instance C_A Ent3 Ent10 where
    _a = A_3 []
    a_  = A_3 
instance C_A Ent4 Ent10 where
    _a = A_4 []
    a_  = A_4 
instance C_A Ent5 Ent10 where
    _a = A_5 []
    a_  = A_5 
instance C_A Ent8 Ent10 where
    _a = A_8 []
    a_  = A_8 
instance C_A Ent9 Ent10 where
    _a = A_9 []
    a_  = A_9 
instance C_A Ent67 Ent18 where
    _a = A_67 []
    a_  = A_67 
instance C_A Ent69 Ent18 where
    _a = A_69 []
    a_  = A_69 
instance C_A Ent72 Ent18 where
    _a = A_72 []
    a_  = A_72 
instance C_A Ent73 Ent18 where
    _a = A_73 []
    a_  = A_73 
instance C_A Ent86 Ent18 where
    _a = A_86 []
    a_  = A_86 
instance C_A Ent88 Ent43 where
    _a = A_88 []
    a_  = A_88 
instance C_A Ent90 Ent43 where
    _a = A_90 []
    a_  = A_90 
instance C_A Ent93 Ent43 where
    _a = A_93 []
    a_  = A_93 
instance C_A Ent94 Ent43 where
    _a = A_94 []
    a_  = A_94 
instance C_A Ent95 Ent43 where
    _a = A_95 []
    a_  = A_95 
instance C_A Ent100 Ent43 where
    _a = A_100 []
    a_  = A_100 
instance C_A Ent107 Ent18 where
    _a = A_107 []
    a_  = A_107 
instance C_A Ent113 Ent35 where
    _a = A_113 []
    a_  = A_113 
instance C_A Ent115 Ent35 where
    _a = A_115 []
    a_  = A_115 
instance C_A Ent118 Ent35 where
    _a = A_118 []
    a_  = A_118 
instance C_A Ent119 Ent35 where
    _a = A_119 []
    a_  = A_119 
instance C_A Ent120 Ent35 where
    _a = A_120 []
    a_  = A_120 
instance C_A Ent125 Ent35 where
    _a = A_125 []
    a_  = A_125 
instance C_A Ent132 Ent10 where
    _a = A_132 []
    a_  = A_132 

class C_Span a b | a -> b where
    _span :: [b] -> a
    span_ :: [Att10] -> [b] -> a
instance C_Span Ent3 Ent5 where
    _span = Span_3 []
    span_  = Span_3 
instance C_Span Ent4 Ent5 where
    _span = Span_4 []
    span_  = Span_4 
instance C_Span Ent5 Ent5 where
    _span = Span_5 []
    span_  = Span_5 
instance C_Span Ent8 Ent5 where
    _span = Span_8 []
    span_  = Span_8 
instance C_Span Ent9 Ent5 where
    _span = Span_9 []
    span_  = Span_9 
instance C_Span Ent10 Ent10 where
    _span = Span_10 []
    span_  = Span_10 
instance C_Span Ent12 Ent10 where
    _span = Span_12 []
    span_  = Span_12 
instance C_Span Ent15 Ent10 where
    _span = Span_15 []
    span_  = Span_15 
instance C_Span Ent16 Ent10 where
    _span = Span_16 []
    span_  = Span_16 
instance C_Span Ent17 Ent18 where
    _span = Span_17 []
    span_  = Span_17 
instance C_Span Ent18 Ent18 where
    _span = Span_18 []
    span_  = Span_18 
instance C_Span Ent21 Ent18 where
    _span = Span_21 []
    span_  = Span_21 
instance C_Span Ent22 Ent18 where
    _span = Span_22 []
    span_  = Span_22 
instance C_Span Ent23 Ent18 where
    _span = Span_23 []
    span_  = Span_23 
instance C_Span Ent28 Ent10 where
    _span = Span_28 []
    span_  = Span_28 
instance C_Span Ent33 Ent10 where
    _span = Span_33 []
    span_  = Span_33 
instance C_Span Ent35 Ent35 where
    _span = Span_35 []
    span_  = Span_35 
instance C_Span Ent37 Ent35 where
    _span = Span_37 []
    span_  = Span_37 
instance C_Span Ent40 Ent35 where
    _span = Span_40 []
    span_  = Span_40 
instance C_Span Ent41 Ent35 where
    _span = Span_41 []
    span_  = Span_41 
instance C_Span Ent42 Ent43 where
    _span = Span_42 []
    span_  = Span_42 
instance C_Span Ent43 Ent43 where
    _span = Span_43 []
    span_  = Span_43 
instance C_Span Ent46 Ent43 where
    _span = Span_46 []
    span_  = Span_46 
instance C_Span Ent47 Ent43 where
    _span = Span_47 []
    span_  = Span_47 
instance C_Span Ent48 Ent43 where
    _span = Span_48 []
    span_  = Span_48 
instance C_Span Ent53 Ent35 where
    _span = Span_53 []
    span_  = Span_53 
instance C_Span Ent58 Ent35 where
    _span = Span_58 []
    span_  = Span_58 
instance C_Span Ent62 Ent35 where
    _span = Span_62 []
    span_  = Span_62 
instance C_Span Ent65 Ent10 where
    _span = Span_65 []
    span_  = Span_65 
instance C_Span Ent67 Ent69 where
    _span = Span_67 []
    span_  = Span_67 
instance C_Span Ent69 Ent69 where
    _span = Span_69 []
    span_  = Span_69 
instance C_Span Ent72 Ent69 where
    _span = Span_72 []
    span_  = Span_72 
instance C_Span Ent73 Ent69 where
    _span = Span_73 []
    span_  = Span_73 
instance C_Span Ent75 Ent18 where
    _span = Span_75 []
    span_  = Span_75 
instance C_Span Ent78 Ent43 where
    _span = Span_78 []
    span_  = Span_78 
instance C_Span Ent82 Ent43 where
    _span = Span_82 []
    span_  = Span_82 
instance C_Span Ent85 Ent18 where
    _span = Span_85 []
    span_  = Span_85 
instance C_Span Ent86 Ent69 where
    _span = Span_86 []
    span_  = Span_86 
instance C_Span Ent88 Ent88 where
    _span = Span_88 []
    span_  = Span_88 
instance C_Span Ent90 Ent88 where
    _span = Span_90 []
    span_  = Span_90 
instance C_Span Ent93 Ent88 where
    _span = Span_93 []
    span_  = Span_93 
instance C_Span Ent94 Ent88 where
    _span = Span_94 []
    span_  = Span_94 
instance C_Span Ent95 Ent88 where
    _span = Span_95 []
    span_  = Span_95 
instance C_Span Ent100 Ent88 where
    _span = Span_100 []
    span_  = Span_100 
instance C_Span Ent104 Ent88 where
    _span = Span_104 []
    span_  = Span_104 
instance C_Span Ent107 Ent69 where
    _span = Span_107 []
    span_  = Span_107 
instance C_Span Ent108 Ent69 where
    _span = Span_108 []
    span_  = Span_108 
instance C_Span Ent113 Ent113 where
    _span = Span_113 []
    span_  = Span_113 
instance C_Span Ent115 Ent113 where
    _span = Span_115 []
    span_  = Span_115 
instance C_Span Ent118 Ent113 where
    _span = Span_118 []
    span_  = Span_118 
instance C_Span Ent119 Ent113 where
    _span = Span_119 []
    span_  = Span_119 
instance C_Span Ent120 Ent113 where
    _span = Span_120 []
    span_  = Span_120 
instance C_Span Ent125 Ent113 where
    _span = Span_125 []
    span_  = Span_125 
instance C_Span Ent129 Ent113 where
    _span = Span_129 []
    span_  = Span_129 
instance C_Span Ent132 Ent5 where
    _span = Span_132 []
    span_  = Span_132 
instance C_Span Ent133 Ent5 where
    _span = Span_133 []
    span_  = Span_133 

class C_Bdo a b | a -> b where
    _bdo :: [b] -> a
    bdo_ :: [Att10] -> [b] -> a
instance C_Bdo Ent3 Ent5 where
    _bdo = Bdo_3 []
    bdo_  = Bdo_3 
instance C_Bdo Ent4 Ent5 where
    _bdo = Bdo_4 []
    bdo_  = Bdo_4 
instance C_Bdo Ent5 Ent5 where
    _bdo = Bdo_5 []
    bdo_  = Bdo_5 
instance C_Bdo Ent8 Ent5 where
    _bdo = Bdo_8 []
    bdo_  = Bdo_8 
instance C_Bdo Ent9 Ent5 where
    _bdo = Bdo_9 []
    bdo_  = Bdo_9 
instance C_Bdo Ent10 Ent10 where
    _bdo = Bdo_10 []
    bdo_  = Bdo_10 
instance C_Bdo Ent12 Ent10 where
    _bdo = Bdo_12 []
    bdo_  = Bdo_12 
instance C_Bdo Ent15 Ent10 where
    _bdo = Bdo_15 []
    bdo_  = Bdo_15 
instance C_Bdo Ent16 Ent10 where
    _bdo = Bdo_16 []
    bdo_  = Bdo_16 
instance C_Bdo Ent17 Ent18 where
    _bdo = Bdo_17 []
    bdo_  = Bdo_17 
instance C_Bdo Ent18 Ent18 where
    _bdo = Bdo_18 []
    bdo_  = Bdo_18 
instance C_Bdo Ent21 Ent18 where
    _bdo = Bdo_21 []
    bdo_  = Bdo_21 
instance C_Bdo Ent22 Ent18 where
    _bdo = Bdo_22 []
    bdo_  = Bdo_22 
instance C_Bdo Ent23 Ent18 where
    _bdo = Bdo_23 []
    bdo_  = Bdo_23 
instance C_Bdo Ent28 Ent10 where
    _bdo = Bdo_28 []
    bdo_  = Bdo_28 
instance C_Bdo Ent33 Ent10 where
    _bdo = Bdo_33 []
    bdo_  = Bdo_33 
instance C_Bdo Ent35 Ent35 where
    _bdo = Bdo_35 []
    bdo_  = Bdo_35 
instance C_Bdo Ent37 Ent35 where
    _bdo = Bdo_37 []
    bdo_  = Bdo_37 
instance C_Bdo Ent40 Ent35 where
    _bdo = Bdo_40 []
    bdo_  = Bdo_40 
instance C_Bdo Ent41 Ent35 where
    _bdo = Bdo_41 []
    bdo_  = Bdo_41 
instance C_Bdo Ent42 Ent43 where
    _bdo = Bdo_42 []
    bdo_  = Bdo_42 
instance C_Bdo Ent43 Ent43 where
    _bdo = Bdo_43 []
    bdo_  = Bdo_43 
instance C_Bdo Ent46 Ent43 where
    _bdo = Bdo_46 []
    bdo_  = Bdo_46 
instance C_Bdo Ent47 Ent43 where
    _bdo = Bdo_47 []
    bdo_  = Bdo_47 
instance C_Bdo Ent48 Ent43 where
    _bdo = Bdo_48 []
    bdo_  = Bdo_48 
instance C_Bdo Ent53 Ent35 where
    _bdo = Bdo_53 []
    bdo_  = Bdo_53 
instance C_Bdo Ent58 Ent35 where
    _bdo = Bdo_58 []
    bdo_  = Bdo_58 
instance C_Bdo Ent62 Ent35 where
    _bdo = Bdo_62 []
    bdo_  = Bdo_62 
instance C_Bdo Ent65 Ent10 where
    _bdo = Bdo_65 []
    bdo_  = Bdo_65 
instance C_Bdo Ent67 Ent69 where
    _bdo = Bdo_67 []
    bdo_  = Bdo_67 
instance C_Bdo Ent69 Ent69 where
    _bdo = Bdo_69 []
    bdo_  = Bdo_69 
instance C_Bdo Ent72 Ent69 where
    _bdo = Bdo_72 []
    bdo_  = Bdo_72 
instance C_Bdo Ent73 Ent69 where
    _bdo = Bdo_73 []
    bdo_  = Bdo_73 
instance C_Bdo Ent75 Ent18 where
    _bdo = Bdo_75 []
    bdo_  = Bdo_75 
instance C_Bdo Ent78 Ent43 where
    _bdo = Bdo_78 []
    bdo_  = Bdo_78 
instance C_Bdo Ent82 Ent43 where
    _bdo = Bdo_82 []
    bdo_  = Bdo_82 
instance C_Bdo Ent85 Ent18 where
    _bdo = Bdo_85 []
    bdo_  = Bdo_85 
instance C_Bdo Ent86 Ent69 where
    _bdo = Bdo_86 []
    bdo_  = Bdo_86 
instance C_Bdo Ent88 Ent88 where
    _bdo = Bdo_88 []
    bdo_  = Bdo_88 
instance C_Bdo Ent90 Ent88 where
    _bdo = Bdo_90 []
    bdo_  = Bdo_90 
instance C_Bdo Ent93 Ent88 where
    _bdo = Bdo_93 []
    bdo_  = Bdo_93 
instance C_Bdo Ent94 Ent88 where
    _bdo = Bdo_94 []
    bdo_  = Bdo_94 
instance C_Bdo Ent95 Ent88 where
    _bdo = Bdo_95 []
    bdo_  = Bdo_95 
instance C_Bdo Ent100 Ent88 where
    _bdo = Bdo_100 []
    bdo_  = Bdo_100 
instance C_Bdo Ent104 Ent88 where
    _bdo = Bdo_104 []
    bdo_  = Bdo_104 
instance C_Bdo Ent107 Ent69 where
    _bdo = Bdo_107 []
    bdo_  = Bdo_107 
instance C_Bdo Ent108 Ent69 where
    _bdo = Bdo_108 []
    bdo_  = Bdo_108 
instance C_Bdo Ent113 Ent113 where
    _bdo = Bdo_113 []
    bdo_  = Bdo_113 
instance C_Bdo Ent115 Ent113 where
    _bdo = Bdo_115 []
    bdo_  = Bdo_115 
instance C_Bdo Ent118 Ent113 where
    _bdo = Bdo_118 []
    bdo_  = Bdo_118 
instance C_Bdo Ent119 Ent113 where
    _bdo = Bdo_119 []
    bdo_  = Bdo_119 
instance C_Bdo Ent120 Ent113 where
    _bdo = Bdo_120 []
    bdo_  = Bdo_120 
instance C_Bdo Ent125 Ent113 where
    _bdo = Bdo_125 []
    bdo_  = Bdo_125 
instance C_Bdo Ent129 Ent113 where
    _bdo = Bdo_129 []
    bdo_  = Bdo_129 
instance C_Bdo Ent132 Ent5 where
    _bdo = Bdo_132 []
    bdo_  = Bdo_132 
instance C_Bdo Ent133 Ent5 where
    _bdo = Bdo_133 []
    bdo_  = Bdo_133 

class C_Br a where
    _br :: a
    br_ :: [Att25] -> a
instance C_Br Ent3 where
    _br = Br_3 []
    br_ = Br_3 
instance C_Br Ent4 where
    _br = Br_4 []
    br_ = Br_4 
instance C_Br Ent5 where
    _br = Br_5 []
    br_ = Br_5 
instance C_Br Ent8 where
    _br = Br_8 []
    br_ = Br_8 
instance C_Br Ent9 where
    _br = Br_9 []
    br_ = Br_9 
instance C_Br Ent10 where
    _br = Br_10 []
    br_ = Br_10 
instance C_Br Ent12 where
    _br = Br_12 []
    br_ = Br_12 
instance C_Br Ent15 where
    _br = Br_15 []
    br_ = Br_15 
instance C_Br Ent16 where
    _br = Br_16 []
    br_ = Br_16 
instance C_Br Ent17 where
    _br = Br_17 []
    br_ = Br_17 
instance C_Br Ent18 where
    _br = Br_18 []
    br_ = Br_18 
instance C_Br Ent21 where
    _br = Br_21 []
    br_ = Br_21 
instance C_Br Ent22 where
    _br = Br_22 []
    br_ = Br_22 
instance C_Br Ent23 where
    _br = Br_23 []
    br_ = Br_23 
instance C_Br Ent28 where
    _br = Br_28 []
    br_ = Br_28 
instance C_Br Ent33 where
    _br = Br_33 []
    br_ = Br_33 
instance C_Br Ent35 where
    _br = Br_35 []
    br_ = Br_35 
instance C_Br Ent37 where
    _br = Br_37 []
    br_ = Br_37 
instance C_Br Ent40 where
    _br = Br_40 []
    br_ = Br_40 
instance C_Br Ent41 where
    _br = Br_41 []
    br_ = Br_41 
instance C_Br Ent42 where
    _br = Br_42 []
    br_ = Br_42 
instance C_Br Ent43 where
    _br = Br_43 []
    br_ = Br_43 
instance C_Br Ent46 where
    _br = Br_46 []
    br_ = Br_46 
instance C_Br Ent47 where
    _br = Br_47 []
    br_ = Br_47 
instance C_Br Ent48 where
    _br = Br_48 []
    br_ = Br_48 
instance C_Br Ent53 where
    _br = Br_53 []
    br_ = Br_53 
instance C_Br Ent58 where
    _br = Br_58 []
    br_ = Br_58 
instance C_Br Ent62 where
    _br = Br_62 []
    br_ = Br_62 
instance C_Br Ent65 where
    _br = Br_65 []
    br_ = Br_65 
instance C_Br Ent67 where
    _br = Br_67 []
    br_ = Br_67 
instance C_Br Ent69 where
    _br = Br_69 []
    br_ = Br_69 
instance C_Br Ent72 where
    _br = Br_72 []
    br_ = Br_72 
instance C_Br Ent73 where
    _br = Br_73 []
    br_ = Br_73 
instance C_Br Ent75 where
    _br = Br_75 []
    br_ = Br_75 
instance C_Br Ent78 where
    _br = Br_78 []
    br_ = Br_78 
instance C_Br Ent82 where
    _br = Br_82 []
    br_ = Br_82 
instance C_Br Ent85 where
    _br = Br_85 []
    br_ = Br_85 
instance C_Br Ent86 where
    _br = Br_86 []
    br_ = Br_86 
instance C_Br Ent88 where
    _br = Br_88 []
    br_ = Br_88 
instance C_Br Ent90 where
    _br = Br_90 []
    br_ = Br_90 
instance C_Br Ent93 where
    _br = Br_93 []
    br_ = Br_93 
instance C_Br Ent94 where
    _br = Br_94 []
    br_ = Br_94 
instance C_Br Ent95 where
    _br = Br_95 []
    br_ = Br_95 
instance C_Br Ent100 where
    _br = Br_100 []
    br_ = Br_100 
instance C_Br Ent104 where
    _br = Br_104 []
    br_ = Br_104 
instance C_Br Ent107 where
    _br = Br_107 []
    br_ = Br_107 
instance C_Br Ent108 where
    _br = Br_108 []
    br_ = Br_108 
instance C_Br Ent113 where
    _br = Br_113 []
    br_ = Br_113 
instance C_Br Ent115 where
    _br = Br_115 []
    br_ = Br_115 
instance C_Br Ent118 where
    _br = Br_118 []
    br_ = Br_118 
instance C_Br Ent119 where
    _br = Br_119 []
    br_ = Br_119 
instance C_Br Ent120 where
    _br = Br_120 []
    br_ = Br_120 
instance C_Br Ent125 where
    _br = Br_125 []
    br_ = Br_125 
instance C_Br Ent129 where
    _br = Br_129 []
    br_ = Br_129 
instance C_Br Ent132 where
    _br = Br_132 []
    br_ = Br_132 
instance C_Br Ent133 where
    _br = Br_133 []
    br_ = Br_133 

class C_Em a b | a -> b where
    _em :: [b] -> a
    em_ :: [Att10] -> [b] -> a
instance C_Em Ent3 Ent5 where
    _em = Em_3 []
    em_  = Em_3 
instance C_Em Ent4 Ent5 where
    _em = Em_4 []
    em_  = Em_4 
instance C_Em Ent5 Ent5 where
    _em = Em_5 []
    em_  = Em_5 
instance C_Em Ent8 Ent5 where
    _em = Em_8 []
    em_  = Em_8 
instance C_Em Ent9 Ent5 where
    _em = Em_9 []
    em_  = Em_9 
instance C_Em Ent10 Ent10 where
    _em = Em_10 []
    em_  = Em_10 
instance C_Em Ent12 Ent10 where
    _em = Em_12 []
    em_  = Em_12 
instance C_Em Ent15 Ent10 where
    _em = Em_15 []
    em_  = Em_15 
instance C_Em Ent16 Ent10 where
    _em = Em_16 []
    em_  = Em_16 
instance C_Em Ent17 Ent18 where
    _em = Em_17 []
    em_  = Em_17 
instance C_Em Ent18 Ent18 where
    _em = Em_18 []
    em_  = Em_18 
instance C_Em Ent21 Ent18 where
    _em = Em_21 []
    em_  = Em_21 
instance C_Em Ent22 Ent18 where
    _em = Em_22 []
    em_  = Em_22 
instance C_Em Ent23 Ent18 where
    _em = Em_23 []
    em_  = Em_23 
instance C_Em Ent28 Ent10 where
    _em = Em_28 []
    em_  = Em_28 
instance C_Em Ent33 Ent10 where
    _em = Em_33 []
    em_  = Em_33 
instance C_Em Ent35 Ent35 where
    _em = Em_35 []
    em_  = Em_35 
instance C_Em Ent37 Ent35 where
    _em = Em_37 []
    em_  = Em_37 
instance C_Em Ent40 Ent35 where
    _em = Em_40 []
    em_  = Em_40 
instance C_Em Ent41 Ent35 where
    _em = Em_41 []
    em_  = Em_41 
instance C_Em Ent42 Ent43 where
    _em = Em_42 []
    em_  = Em_42 
instance C_Em Ent43 Ent43 where
    _em = Em_43 []
    em_  = Em_43 
instance C_Em Ent46 Ent43 where
    _em = Em_46 []
    em_  = Em_46 
instance C_Em Ent47 Ent43 where
    _em = Em_47 []
    em_  = Em_47 
instance C_Em Ent48 Ent43 where
    _em = Em_48 []
    em_  = Em_48 
instance C_Em Ent53 Ent35 where
    _em = Em_53 []
    em_  = Em_53 
instance C_Em Ent58 Ent35 where
    _em = Em_58 []
    em_  = Em_58 
instance C_Em Ent62 Ent35 where
    _em = Em_62 []
    em_  = Em_62 
instance C_Em Ent65 Ent10 where
    _em = Em_65 []
    em_  = Em_65 
instance C_Em Ent67 Ent69 where
    _em = Em_67 []
    em_  = Em_67 
instance C_Em Ent69 Ent69 where
    _em = Em_69 []
    em_  = Em_69 
instance C_Em Ent72 Ent69 where
    _em = Em_72 []
    em_  = Em_72 
instance C_Em Ent73 Ent69 where
    _em = Em_73 []
    em_  = Em_73 
instance C_Em Ent75 Ent18 where
    _em = Em_75 []
    em_  = Em_75 
instance C_Em Ent78 Ent43 where
    _em = Em_78 []
    em_  = Em_78 
instance C_Em Ent82 Ent43 where
    _em = Em_82 []
    em_  = Em_82 
instance C_Em Ent85 Ent18 where
    _em = Em_85 []
    em_  = Em_85 
instance C_Em Ent86 Ent69 where
    _em = Em_86 []
    em_  = Em_86 
instance C_Em Ent88 Ent88 where
    _em = Em_88 []
    em_  = Em_88 
instance C_Em Ent90 Ent88 where
    _em = Em_90 []
    em_  = Em_90 
instance C_Em Ent93 Ent88 where
    _em = Em_93 []
    em_  = Em_93 
instance C_Em Ent94 Ent88 where
    _em = Em_94 []
    em_  = Em_94 
instance C_Em Ent95 Ent88 where
    _em = Em_95 []
    em_  = Em_95 
instance C_Em Ent100 Ent88 where
    _em = Em_100 []
    em_  = Em_100 
instance C_Em Ent104 Ent88 where
    _em = Em_104 []
    em_  = Em_104 
instance C_Em Ent107 Ent69 where
    _em = Em_107 []
    em_  = Em_107 
instance C_Em Ent108 Ent69 where
    _em = Em_108 []
    em_  = Em_108 
instance C_Em Ent113 Ent113 where
    _em = Em_113 []
    em_  = Em_113 
instance C_Em Ent115 Ent113 where
    _em = Em_115 []
    em_  = Em_115 
instance C_Em Ent118 Ent113 where
    _em = Em_118 []
    em_  = Em_118 
instance C_Em Ent119 Ent113 where
    _em = Em_119 []
    em_  = Em_119 
instance C_Em Ent120 Ent113 where
    _em = Em_120 []
    em_  = Em_120 
instance C_Em Ent125 Ent113 where
    _em = Em_125 []
    em_  = Em_125 
instance C_Em Ent129 Ent113 where
    _em = Em_129 []
    em_  = Em_129 
instance C_Em Ent132 Ent5 where
    _em = Em_132 []
    em_  = Em_132 
instance C_Em Ent133 Ent5 where
    _em = Em_133 []
    em_  = Em_133 

class C_Strong a b | a -> b where
    _strong :: [b] -> a
    strong_ :: [Att10] -> [b] -> a
instance C_Strong Ent3 Ent5 where
    _strong = Strong_3 []
    strong_  = Strong_3 
instance C_Strong Ent4 Ent5 where
    _strong = Strong_4 []
    strong_  = Strong_4 
instance C_Strong Ent5 Ent5 where
    _strong = Strong_5 []
    strong_  = Strong_5 
instance C_Strong Ent8 Ent5 where
    _strong = Strong_8 []
    strong_  = Strong_8 
instance C_Strong Ent9 Ent5 where
    _strong = Strong_9 []
    strong_  = Strong_9 
instance C_Strong Ent10 Ent10 where
    _strong = Strong_10 []
    strong_  = Strong_10 
instance C_Strong Ent12 Ent10 where
    _strong = Strong_12 []
    strong_  = Strong_12 
instance C_Strong Ent15 Ent10 where
    _strong = Strong_15 []
    strong_  = Strong_15 
instance C_Strong Ent16 Ent10 where
    _strong = Strong_16 []
    strong_  = Strong_16 
instance C_Strong Ent17 Ent18 where
    _strong = Strong_17 []
    strong_  = Strong_17 
instance C_Strong Ent18 Ent18 where
    _strong = Strong_18 []
    strong_  = Strong_18 
instance C_Strong Ent21 Ent18 where
    _strong = Strong_21 []
    strong_  = Strong_21 
instance C_Strong Ent22 Ent18 where
    _strong = Strong_22 []
    strong_  = Strong_22 
instance C_Strong Ent23 Ent18 where
    _strong = Strong_23 []
    strong_  = Strong_23 
instance C_Strong Ent28 Ent10 where
    _strong = Strong_28 []
    strong_  = Strong_28 
instance C_Strong Ent33 Ent10 where
    _strong = Strong_33 []
    strong_  = Strong_33 
instance C_Strong Ent35 Ent35 where
    _strong = Strong_35 []
    strong_  = Strong_35 
instance C_Strong Ent37 Ent35 where
    _strong = Strong_37 []
    strong_  = Strong_37 
instance C_Strong Ent40 Ent35 where
    _strong = Strong_40 []
    strong_  = Strong_40 
instance C_Strong Ent41 Ent35 where
    _strong = Strong_41 []
    strong_  = Strong_41 
instance C_Strong Ent42 Ent43 where
    _strong = Strong_42 []
    strong_  = Strong_42 
instance C_Strong Ent43 Ent43 where
    _strong = Strong_43 []
    strong_  = Strong_43 
instance C_Strong Ent46 Ent43 where
    _strong = Strong_46 []
    strong_  = Strong_46 
instance C_Strong Ent47 Ent43 where
    _strong = Strong_47 []
    strong_  = Strong_47 
instance C_Strong Ent48 Ent43 where
    _strong = Strong_48 []
    strong_  = Strong_48 
instance C_Strong Ent53 Ent35 where
    _strong = Strong_53 []
    strong_  = Strong_53 
instance C_Strong Ent58 Ent35 where
    _strong = Strong_58 []
    strong_  = Strong_58 
instance C_Strong Ent62 Ent35 where
    _strong = Strong_62 []
    strong_  = Strong_62 
instance C_Strong Ent65 Ent10 where
    _strong = Strong_65 []
    strong_  = Strong_65 
instance C_Strong Ent67 Ent69 where
    _strong = Strong_67 []
    strong_  = Strong_67 
instance C_Strong Ent69 Ent69 where
    _strong = Strong_69 []
    strong_  = Strong_69 
instance C_Strong Ent72 Ent69 where
    _strong = Strong_72 []
    strong_  = Strong_72 
instance C_Strong Ent73 Ent69 where
    _strong = Strong_73 []
    strong_  = Strong_73 
instance C_Strong Ent75 Ent18 where
    _strong = Strong_75 []
    strong_  = Strong_75 
instance C_Strong Ent78 Ent43 where
    _strong = Strong_78 []
    strong_  = Strong_78 
instance C_Strong Ent82 Ent43 where
    _strong = Strong_82 []
    strong_  = Strong_82 
instance C_Strong Ent85 Ent18 where
    _strong = Strong_85 []
    strong_  = Strong_85 
instance C_Strong Ent86 Ent69 where
    _strong = Strong_86 []
    strong_  = Strong_86 
instance C_Strong Ent88 Ent88 where
    _strong = Strong_88 []
    strong_  = Strong_88 
instance C_Strong Ent90 Ent88 where
    _strong = Strong_90 []
    strong_  = Strong_90 
instance C_Strong Ent93 Ent88 where
    _strong = Strong_93 []
    strong_  = Strong_93 
instance C_Strong Ent94 Ent88 where
    _strong = Strong_94 []
    strong_  = Strong_94 
instance C_Strong Ent95 Ent88 where
    _strong = Strong_95 []
    strong_  = Strong_95 
instance C_Strong Ent100 Ent88 where
    _strong = Strong_100 []
    strong_  = Strong_100 
instance C_Strong Ent104 Ent88 where
    _strong = Strong_104 []
    strong_  = Strong_104 
instance C_Strong Ent107 Ent69 where
    _strong = Strong_107 []
    strong_  = Strong_107 
instance C_Strong Ent108 Ent69 where
    _strong = Strong_108 []
    strong_  = Strong_108 
instance C_Strong Ent113 Ent113 where
    _strong = Strong_113 []
    strong_  = Strong_113 
instance C_Strong Ent115 Ent113 where
    _strong = Strong_115 []
    strong_  = Strong_115 
instance C_Strong Ent118 Ent113 where
    _strong = Strong_118 []
    strong_  = Strong_118 
instance C_Strong Ent119 Ent113 where
    _strong = Strong_119 []
    strong_  = Strong_119 
instance C_Strong Ent120 Ent113 where
    _strong = Strong_120 []
    strong_  = Strong_120 
instance C_Strong Ent125 Ent113 where
    _strong = Strong_125 []
    strong_  = Strong_125 
instance C_Strong Ent129 Ent113 where
    _strong = Strong_129 []
    strong_  = Strong_129 
instance C_Strong Ent132 Ent5 where
    _strong = Strong_132 []
    strong_  = Strong_132 
instance C_Strong Ent133 Ent5 where
    _strong = Strong_133 []
    strong_  = Strong_133 

class C_Dfn a b | a -> b where
    _dfn :: [b] -> a
    dfn_ :: [Att10] -> [b] -> a
instance C_Dfn Ent3 Ent5 where
    _dfn = Dfn_3 []
    dfn_  = Dfn_3 
instance C_Dfn Ent4 Ent5 where
    _dfn = Dfn_4 []
    dfn_  = Dfn_4 
instance C_Dfn Ent5 Ent5 where
    _dfn = Dfn_5 []
    dfn_  = Dfn_5 
instance C_Dfn Ent8 Ent5 where
    _dfn = Dfn_8 []
    dfn_  = Dfn_8 
instance C_Dfn Ent9 Ent5 where
    _dfn = Dfn_9 []
    dfn_  = Dfn_9 
instance C_Dfn Ent10 Ent10 where
    _dfn = Dfn_10 []
    dfn_  = Dfn_10 
instance C_Dfn Ent12 Ent10 where
    _dfn = Dfn_12 []
    dfn_  = Dfn_12 
instance C_Dfn Ent15 Ent10 where
    _dfn = Dfn_15 []
    dfn_  = Dfn_15 
instance C_Dfn Ent16 Ent10 where
    _dfn = Dfn_16 []
    dfn_  = Dfn_16 
instance C_Dfn Ent17 Ent18 where
    _dfn = Dfn_17 []
    dfn_  = Dfn_17 
instance C_Dfn Ent18 Ent18 where
    _dfn = Dfn_18 []
    dfn_  = Dfn_18 
instance C_Dfn Ent21 Ent18 where
    _dfn = Dfn_21 []
    dfn_  = Dfn_21 
instance C_Dfn Ent22 Ent18 where
    _dfn = Dfn_22 []
    dfn_  = Dfn_22 
instance C_Dfn Ent23 Ent18 where
    _dfn = Dfn_23 []
    dfn_  = Dfn_23 
instance C_Dfn Ent28 Ent10 where
    _dfn = Dfn_28 []
    dfn_  = Dfn_28 
instance C_Dfn Ent33 Ent10 where
    _dfn = Dfn_33 []
    dfn_  = Dfn_33 
instance C_Dfn Ent35 Ent35 where
    _dfn = Dfn_35 []
    dfn_  = Dfn_35 
instance C_Dfn Ent37 Ent35 where
    _dfn = Dfn_37 []
    dfn_  = Dfn_37 
instance C_Dfn Ent40 Ent35 where
    _dfn = Dfn_40 []
    dfn_  = Dfn_40 
instance C_Dfn Ent41 Ent35 where
    _dfn = Dfn_41 []
    dfn_  = Dfn_41 
instance C_Dfn Ent42 Ent43 where
    _dfn = Dfn_42 []
    dfn_  = Dfn_42 
instance C_Dfn Ent43 Ent43 where
    _dfn = Dfn_43 []
    dfn_  = Dfn_43 
instance C_Dfn Ent46 Ent43 where
    _dfn = Dfn_46 []
    dfn_  = Dfn_46 
instance C_Dfn Ent47 Ent43 where
    _dfn = Dfn_47 []
    dfn_  = Dfn_47 
instance C_Dfn Ent48 Ent43 where
    _dfn = Dfn_48 []
    dfn_  = Dfn_48 
instance C_Dfn Ent53 Ent35 where
    _dfn = Dfn_53 []
    dfn_  = Dfn_53 
instance C_Dfn Ent58 Ent35 where
    _dfn = Dfn_58 []
    dfn_  = Dfn_58 
instance C_Dfn Ent62 Ent35 where
    _dfn = Dfn_62 []
    dfn_  = Dfn_62 
instance C_Dfn Ent65 Ent10 where
    _dfn = Dfn_65 []
    dfn_  = Dfn_65 
instance C_Dfn Ent67 Ent69 where
    _dfn = Dfn_67 []
    dfn_  = Dfn_67 
instance C_Dfn Ent69 Ent69 where
    _dfn = Dfn_69 []
    dfn_  = Dfn_69 
instance C_Dfn Ent72 Ent69 where
    _dfn = Dfn_72 []
    dfn_  = Dfn_72 
instance C_Dfn Ent73 Ent69 where
    _dfn = Dfn_73 []
    dfn_  = Dfn_73 
instance C_Dfn Ent75 Ent18 where
    _dfn = Dfn_75 []
    dfn_  = Dfn_75 
instance C_Dfn Ent78 Ent43 where
    _dfn = Dfn_78 []
    dfn_  = Dfn_78 
instance C_Dfn Ent82 Ent43 where
    _dfn = Dfn_82 []
    dfn_  = Dfn_82 
instance C_Dfn Ent85 Ent18 where
    _dfn = Dfn_85 []
    dfn_  = Dfn_85 
instance C_Dfn Ent86 Ent69 where
    _dfn = Dfn_86 []
    dfn_  = Dfn_86 
instance C_Dfn Ent88 Ent88 where
    _dfn = Dfn_88 []
    dfn_  = Dfn_88 
instance C_Dfn Ent90 Ent88 where
    _dfn = Dfn_90 []
    dfn_  = Dfn_90 
instance C_Dfn Ent93 Ent88 where
    _dfn = Dfn_93 []
    dfn_  = Dfn_93 
instance C_Dfn Ent94 Ent88 where
    _dfn = Dfn_94 []
    dfn_  = Dfn_94 
instance C_Dfn Ent95 Ent88 where
    _dfn = Dfn_95 []
    dfn_  = Dfn_95 
instance C_Dfn Ent100 Ent88 where
    _dfn = Dfn_100 []
    dfn_  = Dfn_100 
instance C_Dfn Ent104 Ent88 where
    _dfn = Dfn_104 []
    dfn_  = Dfn_104 
instance C_Dfn Ent107 Ent69 where
    _dfn = Dfn_107 []
    dfn_  = Dfn_107 
instance C_Dfn Ent108 Ent69 where
    _dfn = Dfn_108 []
    dfn_  = Dfn_108 
instance C_Dfn Ent113 Ent113 where
    _dfn = Dfn_113 []
    dfn_  = Dfn_113 
instance C_Dfn Ent115 Ent113 where
    _dfn = Dfn_115 []
    dfn_  = Dfn_115 
instance C_Dfn Ent118 Ent113 where
    _dfn = Dfn_118 []
    dfn_  = Dfn_118 
instance C_Dfn Ent119 Ent113 where
    _dfn = Dfn_119 []
    dfn_  = Dfn_119 
instance C_Dfn Ent120 Ent113 where
    _dfn = Dfn_120 []
    dfn_  = Dfn_120 
instance C_Dfn Ent125 Ent113 where
    _dfn = Dfn_125 []
    dfn_  = Dfn_125 
instance C_Dfn Ent129 Ent113 where
    _dfn = Dfn_129 []
    dfn_  = Dfn_129 
instance C_Dfn Ent132 Ent5 where
    _dfn = Dfn_132 []
    dfn_  = Dfn_132 
instance C_Dfn Ent133 Ent5 where
    _dfn = Dfn_133 []
    dfn_  = Dfn_133 

class C_Code a b | a -> b where
    _code :: [b] -> a
    code_ :: [Att10] -> [b] -> a
instance C_Code Ent3 Ent5 where
    _code = Code_3 []
    code_  = Code_3 
instance C_Code Ent4 Ent5 where
    _code = Code_4 []
    code_  = Code_4 
instance C_Code Ent5 Ent5 where
    _code = Code_5 []
    code_  = Code_5 
instance C_Code Ent8 Ent5 where
    _code = Code_8 []
    code_  = Code_8 
instance C_Code Ent9 Ent5 where
    _code = Code_9 []
    code_  = Code_9 
instance C_Code Ent10 Ent10 where
    _code = Code_10 []
    code_  = Code_10 
instance C_Code Ent12 Ent10 where
    _code = Code_12 []
    code_  = Code_12 
instance C_Code Ent15 Ent10 where
    _code = Code_15 []
    code_  = Code_15 
instance C_Code Ent16 Ent10 where
    _code = Code_16 []
    code_  = Code_16 
instance C_Code Ent17 Ent18 where
    _code = Code_17 []
    code_  = Code_17 
instance C_Code Ent18 Ent18 where
    _code = Code_18 []
    code_  = Code_18 
instance C_Code Ent21 Ent18 where
    _code = Code_21 []
    code_  = Code_21 
instance C_Code Ent22 Ent18 where
    _code = Code_22 []
    code_  = Code_22 
instance C_Code Ent23 Ent18 where
    _code = Code_23 []
    code_  = Code_23 
instance C_Code Ent28 Ent10 where
    _code = Code_28 []
    code_  = Code_28 
instance C_Code Ent33 Ent10 where
    _code = Code_33 []
    code_  = Code_33 
instance C_Code Ent35 Ent35 where
    _code = Code_35 []
    code_  = Code_35 
instance C_Code Ent37 Ent35 where
    _code = Code_37 []
    code_  = Code_37 
instance C_Code Ent40 Ent35 where
    _code = Code_40 []
    code_  = Code_40 
instance C_Code Ent41 Ent35 where
    _code = Code_41 []
    code_  = Code_41 
instance C_Code Ent42 Ent43 where
    _code = Code_42 []
    code_  = Code_42 
instance C_Code Ent43 Ent43 where
    _code = Code_43 []
    code_  = Code_43 
instance C_Code Ent46 Ent43 where
    _code = Code_46 []
    code_  = Code_46 
instance C_Code Ent47 Ent43 where
    _code = Code_47 []
    code_  = Code_47 
instance C_Code Ent48 Ent43 where
    _code = Code_48 []
    code_  = Code_48 
instance C_Code Ent53 Ent35 where
    _code = Code_53 []
    code_  = Code_53 
instance C_Code Ent58 Ent35 where
    _code = Code_58 []
    code_  = Code_58 
instance C_Code Ent62 Ent35 where
    _code = Code_62 []
    code_  = Code_62 
instance C_Code Ent65 Ent10 where
    _code = Code_65 []
    code_  = Code_65 
instance C_Code Ent67 Ent69 where
    _code = Code_67 []
    code_  = Code_67 
instance C_Code Ent69 Ent69 where
    _code = Code_69 []
    code_  = Code_69 
instance C_Code Ent72 Ent69 where
    _code = Code_72 []
    code_  = Code_72 
instance C_Code Ent73 Ent69 where
    _code = Code_73 []
    code_  = Code_73 
instance C_Code Ent75 Ent18 where
    _code = Code_75 []
    code_  = Code_75 
instance C_Code Ent78 Ent43 where
    _code = Code_78 []
    code_  = Code_78 
instance C_Code Ent82 Ent43 where
    _code = Code_82 []
    code_  = Code_82 
instance C_Code Ent85 Ent18 where
    _code = Code_85 []
    code_  = Code_85 
instance C_Code Ent86 Ent69 where
    _code = Code_86 []
    code_  = Code_86 
instance C_Code Ent88 Ent88 where
    _code = Code_88 []
    code_  = Code_88 
instance C_Code Ent90 Ent88 where
    _code = Code_90 []
    code_  = Code_90 
instance C_Code Ent93 Ent88 where
    _code = Code_93 []
    code_  = Code_93 
instance C_Code Ent94 Ent88 where
    _code = Code_94 []
    code_  = Code_94 
instance C_Code Ent95 Ent88 where
    _code = Code_95 []
    code_  = Code_95 
instance C_Code Ent100 Ent88 where
    _code = Code_100 []
    code_  = Code_100 
instance C_Code Ent104 Ent88 where
    _code = Code_104 []
    code_  = Code_104 
instance C_Code Ent107 Ent69 where
    _code = Code_107 []
    code_  = Code_107 
instance C_Code Ent108 Ent69 where
    _code = Code_108 []
    code_  = Code_108 
instance C_Code Ent113 Ent113 where
    _code = Code_113 []
    code_  = Code_113 
instance C_Code Ent115 Ent113 where
    _code = Code_115 []
    code_  = Code_115 
instance C_Code Ent118 Ent113 where
    _code = Code_118 []
    code_  = Code_118 
instance C_Code Ent119 Ent113 where
    _code = Code_119 []
    code_  = Code_119 
instance C_Code Ent120 Ent113 where
    _code = Code_120 []
    code_  = Code_120 
instance C_Code Ent125 Ent113 where
    _code = Code_125 []
    code_  = Code_125 
instance C_Code Ent129 Ent113 where
    _code = Code_129 []
    code_  = Code_129 
instance C_Code Ent132 Ent5 where
    _code = Code_132 []
    code_  = Code_132 
instance C_Code Ent133 Ent5 where
    _code = Code_133 []
    code_  = Code_133 

class C_Samp a b | a -> b where
    _samp :: [b] -> a
    samp_ :: [Att10] -> [b] -> a
instance C_Samp Ent3 Ent5 where
    _samp = Samp_3 []
    samp_  = Samp_3 
instance C_Samp Ent4 Ent5 where
    _samp = Samp_4 []
    samp_  = Samp_4 
instance C_Samp Ent5 Ent5 where
    _samp = Samp_5 []
    samp_  = Samp_5 
instance C_Samp Ent8 Ent5 where
    _samp = Samp_8 []
    samp_  = Samp_8 
instance C_Samp Ent9 Ent5 where
    _samp = Samp_9 []
    samp_  = Samp_9 
instance C_Samp Ent10 Ent10 where
    _samp = Samp_10 []
    samp_  = Samp_10 
instance C_Samp Ent12 Ent10 where
    _samp = Samp_12 []
    samp_  = Samp_12 
instance C_Samp Ent15 Ent10 where
    _samp = Samp_15 []
    samp_  = Samp_15 
instance C_Samp Ent16 Ent10 where
    _samp = Samp_16 []
    samp_  = Samp_16 
instance C_Samp Ent17 Ent18 where
    _samp = Samp_17 []
    samp_  = Samp_17 
instance C_Samp Ent18 Ent18 where
    _samp = Samp_18 []
    samp_  = Samp_18 
instance C_Samp Ent21 Ent18 where
    _samp = Samp_21 []
    samp_  = Samp_21 
instance C_Samp Ent22 Ent18 where
    _samp = Samp_22 []
    samp_  = Samp_22 
instance C_Samp Ent23 Ent18 where
    _samp = Samp_23 []
    samp_  = Samp_23 
instance C_Samp Ent28 Ent10 where
    _samp = Samp_28 []
    samp_  = Samp_28 
instance C_Samp Ent33 Ent10 where
    _samp = Samp_33 []
    samp_  = Samp_33 
instance C_Samp Ent35 Ent35 where
    _samp = Samp_35 []
    samp_  = Samp_35 
instance C_Samp Ent37 Ent35 where
    _samp = Samp_37 []
    samp_  = Samp_37 
instance C_Samp Ent40 Ent35 where
    _samp = Samp_40 []
    samp_  = Samp_40 
instance C_Samp Ent41 Ent35 where
    _samp = Samp_41 []
    samp_  = Samp_41 
instance C_Samp Ent42 Ent43 where
    _samp = Samp_42 []
    samp_  = Samp_42 
instance C_Samp Ent43 Ent43 where
    _samp = Samp_43 []
    samp_  = Samp_43 
instance C_Samp Ent46 Ent43 where
    _samp = Samp_46 []
    samp_  = Samp_46 
instance C_Samp Ent47 Ent43 where
    _samp = Samp_47 []
    samp_  = Samp_47 
instance C_Samp Ent48 Ent43 where
    _samp = Samp_48 []
    samp_  = Samp_48 
instance C_Samp Ent53 Ent35 where
    _samp = Samp_53 []
    samp_  = Samp_53 
instance C_Samp Ent58 Ent35 where
    _samp = Samp_58 []
    samp_  = Samp_58 
instance C_Samp Ent62 Ent35 where
    _samp = Samp_62 []
    samp_  = Samp_62 
instance C_Samp Ent65 Ent10 where
    _samp = Samp_65 []
    samp_  = Samp_65 
instance C_Samp Ent67 Ent69 where
    _samp = Samp_67 []
    samp_  = Samp_67 
instance C_Samp Ent69 Ent69 where
    _samp = Samp_69 []
    samp_  = Samp_69 
instance C_Samp Ent72 Ent69 where
    _samp = Samp_72 []
    samp_  = Samp_72 
instance C_Samp Ent73 Ent69 where
    _samp = Samp_73 []
    samp_  = Samp_73 
instance C_Samp Ent75 Ent18 where
    _samp = Samp_75 []
    samp_  = Samp_75 
instance C_Samp Ent78 Ent43 where
    _samp = Samp_78 []
    samp_  = Samp_78 
instance C_Samp Ent82 Ent43 where
    _samp = Samp_82 []
    samp_  = Samp_82 
instance C_Samp Ent85 Ent18 where
    _samp = Samp_85 []
    samp_  = Samp_85 
instance C_Samp Ent86 Ent69 where
    _samp = Samp_86 []
    samp_  = Samp_86 
instance C_Samp Ent88 Ent88 where
    _samp = Samp_88 []
    samp_  = Samp_88 
instance C_Samp Ent90 Ent88 where
    _samp = Samp_90 []
    samp_  = Samp_90 
instance C_Samp Ent93 Ent88 where
    _samp = Samp_93 []
    samp_  = Samp_93 
instance C_Samp Ent94 Ent88 where
    _samp = Samp_94 []
    samp_  = Samp_94 
instance C_Samp Ent95 Ent88 where
    _samp = Samp_95 []
    samp_  = Samp_95 
instance C_Samp Ent100 Ent88 where
    _samp = Samp_100 []
    samp_  = Samp_100 
instance C_Samp Ent104 Ent88 where
    _samp = Samp_104 []
    samp_  = Samp_104 
instance C_Samp Ent107 Ent69 where
    _samp = Samp_107 []
    samp_  = Samp_107 
instance C_Samp Ent108 Ent69 where
    _samp = Samp_108 []
    samp_  = Samp_108 
instance C_Samp Ent113 Ent113 where
    _samp = Samp_113 []
    samp_  = Samp_113 
instance C_Samp Ent115 Ent113 where
    _samp = Samp_115 []
    samp_  = Samp_115 
instance C_Samp Ent118 Ent113 where
    _samp = Samp_118 []
    samp_  = Samp_118 
instance C_Samp Ent119 Ent113 where
    _samp = Samp_119 []
    samp_  = Samp_119 
instance C_Samp Ent120 Ent113 where
    _samp = Samp_120 []
    samp_  = Samp_120 
instance C_Samp Ent125 Ent113 where
    _samp = Samp_125 []
    samp_  = Samp_125 
instance C_Samp Ent129 Ent113 where
    _samp = Samp_129 []
    samp_  = Samp_129 
instance C_Samp Ent132 Ent5 where
    _samp = Samp_132 []
    samp_  = Samp_132 
instance C_Samp Ent133 Ent5 where
    _samp = Samp_133 []
    samp_  = Samp_133 

class C_Kbd a b | a -> b where
    _kbd :: [b] -> a
    kbd_ :: [Att10] -> [b] -> a
instance C_Kbd Ent3 Ent5 where
    _kbd = Kbd_3 []
    kbd_  = Kbd_3 
instance C_Kbd Ent4 Ent5 where
    _kbd = Kbd_4 []
    kbd_  = Kbd_4 
instance C_Kbd Ent5 Ent5 where
    _kbd = Kbd_5 []
    kbd_  = Kbd_5 
instance C_Kbd Ent8 Ent5 where
    _kbd = Kbd_8 []
    kbd_  = Kbd_8 
instance C_Kbd Ent9 Ent5 where
    _kbd = Kbd_9 []
    kbd_  = Kbd_9 
instance C_Kbd Ent10 Ent10 where
    _kbd = Kbd_10 []
    kbd_  = Kbd_10 
instance C_Kbd Ent12 Ent10 where
    _kbd = Kbd_12 []
    kbd_  = Kbd_12 
instance C_Kbd Ent15 Ent10 where
    _kbd = Kbd_15 []
    kbd_  = Kbd_15 
instance C_Kbd Ent16 Ent10 where
    _kbd = Kbd_16 []
    kbd_  = Kbd_16 
instance C_Kbd Ent17 Ent18 where
    _kbd = Kbd_17 []
    kbd_  = Kbd_17 
instance C_Kbd Ent18 Ent18 where
    _kbd = Kbd_18 []
    kbd_  = Kbd_18 
instance C_Kbd Ent21 Ent18 where
    _kbd = Kbd_21 []
    kbd_  = Kbd_21 
instance C_Kbd Ent22 Ent18 where
    _kbd = Kbd_22 []
    kbd_  = Kbd_22 
instance C_Kbd Ent23 Ent18 where
    _kbd = Kbd_23 []
    kbd_  = Kbd_23 
instance C_Kbd Ent28 Ent10 where
    _kbd = Kbd_28 []
    kbd_  = Kbd_28 
instance C_Kbd Ent33 Ent10 where
    _kbd = Kbd_33 []
    kbd_  = Kbd_33 
instance C_Kbd Ent35 Ent35 where
    _kbd = Kbd_35 []
    kbd_  = Kbd_35 
instance C_Kbd Ent37 Ent35 where
    _kbd = Kbd_37 []
    kbd_  = Kbd_37 
instance C_Kbd Ent40 Ent35 where
    _kbd = Kbd_40 []
    kbd_  = Kbd_40 
instance C_Kbd Ent41 Ent35 where
    _kbd = Kbd_41 []
    kbd_  = Kbd_41 
instance C_Kbd Ent42 Ent43 where
    _kbd = Kbd_42 []
    kbd_  = Kbd_42 
instance C_Kbd Ent43 Ent43 where
    _kbd = Kbd_43 []
    kbd_  = Kbd_43 
instance C_Kbd Ent46 Ent43 where
    _kbd = Kbd_46 []
    kbd_  = Kbd_46 
instance C_Kbd Ent47 Ent43 where
    _kbd = Kbd_47 []
    kbd_  = Kbd_47 
instance C_Kbd Ent48 Ent43 where
    _kbd = Kbd_48 []
    kbd_  = Kbd_48 
instance C_Kbd Ent53 Ent35 where
    _kbd = Kbd_53 []
    kbd_  = Kbd_53 
instance C_Kbd Ent58 Ent35 where
    _kbd = Kbd_58 []
    kbd_  = Kbd_58 
instance C_Kbd Ent62 Ent35 where
    _kbd = Kbd_62 []
    kbd_  = Kbd_62 
instance C_Kbd Ent65 Ent10 where
    _kbd = Kbd_65 []
    kbd_  = Kbd_65 
instance C_Kbd Ent67 Ent69 where
    _kbd = Kbd_67 []
    kbd_  = Kbd_67 
instance C_Kbd Ent69 Ent69 where
    _kbd = Kbd_69 []
    kbd_  = Kbd_69 
instance C_Kbd Ent72 Ent69 where
    _kbd = Kbd_72 []
    kbd_  = Kbd_72 
instance C_Kbd Ent73 Ent69 where
    _kbd = Kbd_73 []
    kbd_  = Kbd_73 
instance C_Kbd Ent75 Ent18 where
    _kbd = Kbd_75 []
    kbd_  = Kbd_75 
instance C_Kbd Ent78 Ent43 where
    _kbd = Kbd_78 []
    kbd_  = Kbd_78 
instance C_Kbd Ent82 Ent43 where
    _kbd = Kbd_82 []
    kbd_  = Kbd_82 
instance C_Kbd Ent85 Ent18 where
    _kbd = Kbd_85 []
    kbd_  = Kbd_85 
instance C_Kbd Ent86 Ent69 where
    _kbd = Kbd_86 []
    kbd_  = Kbd_86 
instance C_Kbd Ent88 Ent88 where
    _kbd = Kbd_88 []
    kbd_  = Kbd_88 
instance C_Kbd Ent90 Ent88 where
    _kbd = Kbd_90 []
    kbd_  = Kbd_90 
instance C_Kbd Ent93 Ent88 where
    _kbd = Kbd_93 []
    kbd_  = Kbd_93 
instance C_Kbd Ent94 Ent88 where
    _kbd = Kbd_94 []
    kbd_  = Kbd_94 
instance C_Kbd Ent95 Ent88 where
    _kbd = Kbd_95 []
    kbd_  = Kbd_95 
instance C_Kbd Ent100 Ent88 where
    _kbd = Kbd_100 []
    kbd_  = Kbd_100 
instance C_Kbd Ent104 Ent88 where
    _kbd = Kbd_104 []
    kbd_  = Kbd_104 
instance C_Kbd Ent107 Ent69 where
    _kbd = Kbd_107 []
    kbd_  = Kbd_107 
instance C_Kbd Ent108 Ent69 where
    _kbd = Kbd_108 []
    kbd_  = Kbd_108 
instance C_Kbd Ent113 Ent113 where
    _kbd = Kbd_113 []
    kbd_  = Kbd_113 
instance C_Kbd Ent115 Ent113 where
    _kbd = Kbd_115 []
    kbd_  = Kbd_115 
instance C_Kbd Ent118 Ent113 where
    _kbd = Kbd_118 []
    kbd_  = Kbd_118 
instance C_Kbd Ent119 Ent113 where
    _kbd = Kbd_119 []
    kbd_  = Kbd_119 
instance C_Kbd Ent120 Ent113 where
    _kbd = Kbd_120 []
    kbd_  = Kbd_120 
instance C_Kbd Ent125 Ent113 where
    _kbd = Kbd_125 []
    kbd_  = Kbd_125 
instance C_Kbd Ent129 Ent113 where
    _kbd = Kbd_129 []
    kbd_  = Kbd_129 
instance C_Kbd Ent132 Ent5 where
    _kbd = Kbd_132 []
    kbd_  = Kbd_132 
instance C_Kbd Ent133 Ent5 where
    _kbd = Kbd_133 []
    kbd_  = Kbd_133 

class C_Var a b | a -> b where
    _var :: [b] -> a
    var_ :: [Att10] -> [b] -> a
instance C_Var Ent3 Ent5 where
    _var = Var_3 []
    var_  = Var_3 
instance C_Var Ent4 Ent5 where
    _var = Var_4 []
    var_  = Var_4 
instance C_Var Ent5 Ent5 where
    _var = Var_5 []
    var_  = Var_5 
instance C_Var Ent8 Ent5 where
    _var = Var_8 []
    var_  = Var_8 
instance C_Var Ent9 Ent5 where
    _var = Var_9 []
    var_  = Var_9 
instance C_Var Ent10 Ent10 where
    _var = Var_10 []
    var_  = Var_10 
instance C_Var Ent12 Ent10 where
    _var = Var_12 []
    var_  = Var_12 
instance C_Var Ent15 Ent10 where
    _var = Var_15 []
    var_  = Var_15 
instance C_Var Ent16 Ent10 where
    _var = Var_16 []
    var_  = Var_16 
instance C_Var Ent17 Ent18 where
    _var = Var_17 []
    var_  = Var_17 
instance C_Var Ent18 Ent18 where
    _var = Var_18 []
    var_  = Var_18 
instance C_Var Ent21 Ent18 where
    _var = Var_21 []
    var_  = Var_21 
instance C_Var Ent22 Ent18 where
    _var = Var_22 []
    var_  = Var_22 
instance C_Var Ent23 Ent18 where
    _var = Var_23 []
    var_  = Var_23 
instance C_Var Ent28 Ent10 where
    _var = Var_28 []
    var_  = Var_28 
instance C_Var Ent33 Ent10 where
    _var = Var_33 []
    var_  = Var_33 
instance C_Var Ent35 Ent35 where
    _var = Var_35 []
    var_  = Var_35 
instance C_Var Ent37 Ent35 where
    _var = Var_37 []
    var_  = Var_37 
instance C_Var Ent40 Ent35 where
    _var = Var_40 []
    var_  = Var_40 
instance C_Var Ent41 Ent35 where
    _var = Var_41 []
    var_  = Var_41 
instance C_Var Ent42 Ent43 where
    _var = Var_42 []
    var_  = Var_42 
instance C_Var Ent43 Ent43 where
    _var = Var_43 []
    var_  = Var_43 
instance C_Var Ent46 Ent43 where
    _var = Var_46 []
    var_  = Var_46 
instance C_Var Ent47 Ent43 where
    _var = Var_47 []
    var_  = Var_47 
instance C_Var Ent48 Ent43 where
    _var = Var_48 []
    var_  = Var_48 
instance C_Var Ent53 Ent35 where
    _var = Var_53 []
    var_  = Var_53 
instance C_Var Ent58 Ent35 where
    _var = Var_58 []
    var_  = Var_58 
instance C_Var Ent62 Ent35 where
    _var = Var_62 []
    var_  = Var_62 
instance C_Var Ent65 Ent10 where
    _var = Var_65 []
    var_  = Var_65 
instance C_Var Ent67 Ent69 where
    _var = Var_67 []
    var_  = Var_67 
instance C_Var Ent69 Ent69 where
    _var = Var_69 []
    var_  = Var_69 
instance C_Var Ent72 Ent69 where
    _var = Var_72 []
    var_  = Var_72 
instance C_Var Ent73 Ent69 where
    _var = Var_73 []
    var_  = Var_73 
instance C_Var Ent75 Ent18 where
    _var = Var_75 []
    var_  = Var_75 
instance C_Var Ent78 Ent43 where
    _var = Var_78 []
    var_  = Var_78 
instance C_Var Ent82 Ent43 where
    _var = Var_82 []
    var_  = Var_82 
instance C_Var Ent85 Ent18 where
    _var = Var_85 []
    var_  = Var_85 
instance C_Var Ent86 Ent69 where
    _var = Var_86 []
    var_  = Var_86 
instance C_Var Ent88 Ent88 where
    _var = Var_88 []
    var_  = Var_88 
instance C_Var Ent90 Ent88 where
    _var = Var_90 []
    var_  = Var_90 
instance C_Var Ent93 Ent88 where
    _var = Var_93 []
    var_  = Var_93 
instance C_Var Ent94 Ent88 where
    _var = Var_94 []
    var_  = Var_94 
instance C_Var Ent95 Ent88 where
    _var = Var_95 []
    var_  = Var_95 
instance C_Var Ent100 Ent88 where
    _var = Var_100 []
    var_  = Var_100 
instance C_Var Ent104 Ent88 where
    _var = Var_104 []
    var_  = Var_104 
instance C_Var Ent107 Ent69 where
    _var = Var_107 []
    var_  = Var_107 
instance C_Var Ent108 Ent69 where
    _var = Var_108 []
    var_  = Var_108 
instance C_Var Ent113 Ent113 where
    _var = Var_113 []
    var_  = Var_113 
instance C_Var Ent115 Ent113 where
    _var = Var_115 []
    var_  = Var_115 
instance C_Var Ent118 Ent113 where
    _var = Var_118 []
    var_  = Var_118 
instance C_Var Ent119 Ent113 where
    _var = Var_119 []
    var_  = Var_119 
instance C_Var Ent120 Ent113 where
    _var = Var_120 []
    var_  = Var_120 
instance C_Var Ent125 Ent113 where
    _var = Var_125 []
    var_  = Var_125 
instance C_Var Ent129 Ent113 where
    _var = Var_129 []
    var_  = Var_129 
instance C_Var Ent132 Ent5 where
    _var = Var_132 []
    var_  = Var_132 
instance C_Var Ent133 Ent5 where
    _var = Var_133 []
    var_  = Var_133 

class C_Cite a b | a -> b where
    _cite :: [b] -> a
    cite_ :: [Att10] -> [b] -> a
instance C_Cite Ent3 Ent5 where
    _cite = Cite_3 []
    cite_  = Cite_3 
instance C_Cite Ent4 Ent5 where
    _cite = Cite_4 []
    cite_  = Cite_4 
instance C_Cite Ent5 Ent5 where
    _cite = Cite_5 []
    cite_  = Cite_5 
instance C_Cite Ent8 Ent5 where
    _cite = Cite_8 []
    cite_  = Cite_8 
instance C_Cite Ent9 Ent5 where
    _cite = Cite_9 []
    cite_  = Cite_9 
instance C_Cite Ent10 Ent10 where
    _cite = Cite_10 []
    cite_  = Cite_10 
instance C_Cite Ent12 Ent10 where
    _cite = Cite_12 []
    cite_  = Cite_12 
instance C_Cite Ent15 Ent10 where
    _cite = Cite_15 []
    cite_  = Cite_15 
instance C_Cite Ent16 Ent10 where
    _cite = Cite_16 []
    cite_  = Cite_16 
instance C_Cite Ent17 Ent18 where
    _cite = Cite_17 []
    cite_  = Cite_17 
instance C_Cite Ent18 Ent18 where
    _cite = Cite_18 []
    cite_  = Cite_18 
instance C_Cite Ent21 Ent18 where
    _cite = Cite_21 []
    cite_  = Cite_21 
instance C_Cite Ent22 Ent18 where
    _cite = Cite_22 []
    cite_  = Cite_22 
instance C_Cite Ent23 Ent18 where
    _cite = Cite_23 []
    cite_  = Cite_23 
instance C_Cite Ent28 Ent10 where
    _cite = Cite_28 []
    cite_  = Cite_28 
instance C_Cite Ent33 Ent10 where
    _cite = Cite_33 []
    cite_  = Cite_33 
instance C_Cite Ent35 Ent35 where
    _cite = Cite_35 []
    cite_  = Cite_35 
instance C_Cite Ent37 Ent35 where
    _cite = Cite_37 []
    cite_  = Cite_37 
instance C_Cite Ent40 Ent35 where
    _cite = Cite_40 []
    cite_  = Cite_40 
instance C_Cite Ent41 Ent35 where
    _cite = Cite_41 []
    cite_  = Cite_41 
instance C_Cite Ent42 Ent43 where
    _cite = Cite_42 []
    cite_  = Cite_42 
instance C_Cite Ent43 Ent43 where
    _cite = Cite_43 []
    cite_  = Cite_43 
instance C_Cite Ent46 Ent43 where
    _cite = Cite_46 []
    cite_  = Cite_46 
instance C_Cite Ent47 Ent43 where
    _cite = Cite_47 []
    cite_  = Cite_47 
instance C_Cite Ent48 Ent43 where
    _cite = Cite_48 []
    cite_  = Cite_48 
instance C_Cite Ent53 Ent35 where
    _cite = Cite_53 []
    cite_  = Cite_53 
instance C_Cite Ent58 Ent35 where
    _cite = Cite_58 []
    cite_  = Cite_58 
instance C_Cite Ent62 Ent35 where
    _cite = Cite_62 []
    cite_  = Cite_62 
instance C_Cite Ent65 Ent10 where
    _cite = Cite_65 []
    cite_  = Cite_65 
instance C_Cite Ent67 Ent69 where
    _cite = Cite_67 []
    cite_  = Cite_67 
instance C_Cite Ent69 Ent69 where
    _cite = Cite_69 []
    cite_  = Cite_69 
instance C_Cite Ent72 Ent69 where
    _cite = Cite_72 []
    cite_  = Cite_72 
instance C_Cite Ent73 Ent69 where
    _cite = Cite_73 []
    cite_  = Cite_73 
instance C_Cite Ent75 Ent18 where
    _cite = Cite_75 []
    cite_  = Cite_75 
instance C_Cite Ent78 Ent43 where
    _cite = Cite_78 []
    cite_  = Cite_78 
instance C_Cite Ent82 Ent43 where
    _cite = Cite_82 []
    cite_  = Cite_82 
instance C_Cite Ent85 Ent18 where
    _cite = Cite_85 []
    cite_  = Cite_85 
instance C_Cite Ent86 Ent69 where
    _cite = Cite_86 []
    cite_  = Cite_86 
instance C_Cite Ent88 Ent88 where
    _cite = Cite_88 []
    cite_  = Cite_88 
instance C_Cite Ent90 Ent88 where
    _cite = Cite_90 []
    cite_  = Cite_90 
instance C_Cite Ent93 Ent88 where
    _cite = Cite_93 []
    cite_  = Cite_93 
instance C_Cite Ent94 Ent88 where
    _cite = Cite_94 []
    cite_  = Cite_94 
instance C_Cite Ent95 Ent88 where
    _cite = Cite_95 []
    cite_  = Cite_95 
instance C_Cite Ent100 Ent88 where
    _cite = Cite_100 []
    cite_  = Cite_100 
instance C_Cite Ent104 Ent88 where
    _cite = Cite_104 []
    cite_  = Cite_104 
instance C_Cite Ent107 Ent69 where
    _cite = Cite_107 []
    cite_  = Cite_107 
instance C_Cite Ent108 Ent69 where
    _cite = Cite_108 []
    cite_  = Cite_108 
instance C_Cite Ent113 Ent113 where
    _cite = Cite_113 []
    cite_  = Cite_113 
instance C_Cite Ent115 Ent113 where
    _cite = Cite_115 []
    cite_  = Cite_115 
instance C_Cite Ent118 Ent113 where
    _cite = Cite_118 []
    cite_  = Cite_118 
instance C_Cite Ent119 Ent113 where
    _cite = Cite_119 []
    cite_  = Cite_119 
instance C_Cite Ent120 Ent113 where
    _cite = Cite_120 []
    cite_  = Cite_120 
instance C_Cite Ent125 Ent113 where
    _cite = Cite_125 []
    cite_  = Cite_125 
instance C_Cite Ent129 Ent113 where
    _cite = Cite_129 []
    cite_  = Cite_129 
instance C_Cite Ent132 Ent5 where
    _cite = Cite_132 []
    cite_  = Cite_132 
instance C_Cite Ent133 Ent5 where
    _cite = Cite_133 []
    cite_  = Cite_133 

class C_Abbr a b | a -> b where
    _abbr :: [b] -> a
    abbr_ :: [Att10] -> [b] -> a
instance C_Abbr Ent3 Ent5 where
    _abbr = Abbr_3 []
    abbr_  = Abbr_3 
instance C_Abbr Ent4 Ent5 where
    _abbr = Abbr_4 []
    abbr_  = Abbr_4 
instance C_Abbr Ent5 Ent5 where
    _abbr = Abbr_5 []
    abbr_  = Abbr_5 
instance C_Abbr Ent8 Ent5 where
    _abbr = Abbr_8 []
    abbr_  = Abbr_8 
instance C_Abbr Ent9 Ent5 where
    _abbr = Abbr_9 []
    abbr_  = Abbr_9 
instance C_Abbr Ent10 Ent10 where
    _abbr = Abbr_10 []
    abbr_  = Abbr_10 
instance C_Abbr Ent12 Ent10 where
    _abbr = Abbr_12 []
    abbr_  = Abbr_12 
instance C_Abbr Ent15 Ent10 where
    _abbr = Abbr_15 []
    abbr_  = Abbr_15 
instance C_Abbr Ent16 Ent10 where
    _abbr = Abbr_16 []
    abbr_  = Abbr_16 
instance C_Abbr Ent17 Ent18 where
    _abbr = Abbr_17 []
    abbr_  = Abbr_17 
instance C_Abbr Ent18 Ent18 where
    _abbr = Abbr_18 []
    abbr_  = Abbr_18 
instance C_Abbr Ent21 Ent18 where
    _abbr = Abbr_21 []
    abbr_  = Abbr_21 
instance C_Abbr Ent22 Ent18 where
    _abbr = Abbr_22 []
    abbr_  = Abbr_22 
instance C_Abbr Ent23 Ent18 where
    _abbr = Abbr_23 []
    abbr_  = Abbr_23 
instance C_Abbr Ent28 Ent10 where
    _abbr = Abbr_28 []
    abbr_  = Abbr_28 
instance C_Abbr Ent33 Ent10 where
    _abbr = Abbr_33 []
    abbr_  = Abbr_33 
instance C_Abbr Ent35 Ent35 where
    _abbr = Abbr_35 []
    abbr_  = Abbr_35 
instance C_Abbr Ent37 Ent35 where
    _abbr = Abbr_37 []
    abbr_  = Abbr_37 
instance C_Abbr Ent40 Ent35 where
    _abbr = Abbr_40 []
    abbr_  = Abbr_40 
instance C_Abbr Ent41 Ent35 where
    _abbr = Abbr_41 []
    abbr_  = Abbr_41 
instance C_Abbr Ent42 Ent43 where
    _abbr = Abbr_42 []
    abbr_  = Abbr_42 
instance C_Abbr Ent43 Ent43 where
    _abbr = Abbr_43 []
    abbr_  = Abbr_43 
instance C_Abbr Ent46 Ent43 where
    _abbr = Abbr_46 []
    abbr_  = Abbr_46 
instance C_Abbr Ent47 Ent43 where
    _abbr = Abbr_47 []
    abbr_  = Abbr_47 
instance C_Abbr Ent48 Ent43 where
    _abbr = Abbr_48 []
    abbr_  = Abbr_48 
instance C_Abbr Ent53 Ent35 where
    _abbr = Abbr_53 []
    abbr_  = Abbr_53 
instance C_Abbr Ent58 Ent35 where
    _abbr = Abbr_58 []
    abbr_  = Abbr_58 
instance C_Abbr Ent62 Ent35 where
    _abbr = Abbr_62 []
    abbr_  = Abbr_62 
instance C_Abbr Ent65 Ent10 where
    _abbr = Abbr_65 []
    abbr_  = Abbr_65 
instance C_Abbr Ent67 Ent69 where
    _abbr = Abbr_67 []
    abbr_  = Abbr_67 
instance C_Abbr Ent69 Ent69 where
    _abbr = Abbr_69 []
    abbr_  = Abbr_69 
instance C_Abbr Ent72 Ent69 where
    _abbr = Abbr_72 []
    abbr_  = Abbr_72 
instance C_Abbr Ent73 Ent69 where
    _abbr = Abbr_73 []
    abbr_  = Abbr_73 
instance C_Abbr Ent75 Ent18 where
    _abbr = Abbr_75 []
    abbr_  = Abbr_75 
instance C_Abbr Ent78 Ent43 where
    _abbr = Abbr_78 []
    abbr_  = Abbr_78 
instance C_Abbr Ent82 Ent43 where
    _abbr = Abbr_82 []
    abbr_  = Abbr_82 
instance C_Abbr Ent85 Ent18 where
    _abbr = Abbr_85 []
    abbr_  = Abbr_85 
instance C_Abbr Ent86 Ent69 where
    _abbr = Abbr_86 []
    abbr_  = Abbr_86 
instance C_Abbr Ent88 Ent88 where
    _abbr = Abbr_88 []
    abbr_  = Abbr_88 
instance C_Abbr Ent90 Ent88 where
    _abbr = Abbr_90 []
    abbr_  = Abbr_90 
instance C_Abbr Ent93 Ent88 where
    _abbr = Abbr_93 []
    abbr_  = Abbr_93 
instance C_Abbr Ent94 Ent88 where
    _abbr = Abbr_94 []
    abbr_  = Abbr_94 
instance C_Abbr Ent95 Ent88 where
    _abbr = Abbr_95 []
    abbr_  = Abbr_95 
instance C_Abbr Ent100 Ent88 where
    _abbr = Abbr_100 []
    abbr_  = Abbr_100 
instance C_Abbr Ent104 Ent88 where
    _abbr = Abbr_104 []
    abbr_  = Abbr_104 
instance C_Abbr Ent107 Ent69 where
    _abbr = Abbr_107 []
    abbr_  = Abbr_107 
instance C_Abbr Ent108 Ent69 where
    _abbr = Abbr_108 []
    abbr_  = Abbr_108 
instance C_Abbr Ent113 Ent113 where
    _abbr = Abbr_113 []
    abbr_  = Abbr_113 
instance C_Abbr Ent115 Ent113 where
    _abbr = Abbr_115 []
    abbr_  = Abbr_115 
instance C_Abbr Ent118 Ent113 where
    _abbr = Abbr_118 []
    abbr_  = Abbr_118 
instance C_Abbr Ent119 Ent113 where
    _abbr = Abbr_119 []
    abbr_  = Abbr_119 
instance C_Abbr Ent120 Ent113 where
    _abbr = Abbr_120 []
    abbr_  = Abbr_120 
instance C_Abbr Ent125 Ent113 where
    _abbr = Abbr_125 []
    abbr_  = Abbr_125 
instance C_Abbr Ent129 Ent113 where
    _abbr = Abbr_129 []
    abbr_  = Abbr_129 
instance C_Abbr Ent132 Ent5 where
    _abbr = Abbr_132 []
    abbr_  = Abbr_132 
instance C_Abbr Ent133 Ent5 where
    _abbr = Abbr_133 []
    abbr_  = Abbr_133 

class C_Acronym a b | a -> b where
    _acronym :: [b] -> a
    acronym_ :: [Att10] -> [b] -> a
instance C_Acronym Ent3 Ent5 where
    _acronym = Acronym_3 []
    acronym_  = Acronym_3 
instance C_Acronym Ent4 Ent5 where
    _acronym = Acronym_4 []
    acronym_  = Acronym_4 
instance C_Acronym Ent5 Ent5 where
    _acronym = Acronym_5 []
    acronym_  = Acronym_5 
instance C_Acronym Ent8 Ent5 where
    _acronym = Acronym_8 []
    acronym_  = Acronym_8 
instance C_Acronym Ent9 Ent5 where
    _acronym = Acronym_9 []
    acronym_  = Acronym_9 
instance C_Acronym Ent10 Ent10 where
    _acronym = Acronym_10 []
    acronym_  = Acronym_10 
instance C_Acronym Ent12 Ent10 where
    _acronym = Acronym_12 []
    acronym_  = Acronym_12 
instance C_Acronym Ent15 Ent10 where
    _acronym = Acronym_15 []
    acronym_  = Acronym_15 
instance C_Acronym Ent16 Ent10 where
    _acronym = Acronym_16 []
    acronym_  = Acronym_16 
instance C_Acronym Ent17 Ent18 where
    _acronym = Acronym_17 []
    acronym_  = Acronym_17 
instance C_Acronym Ent18 Ent18 where
    _acronym = Acronym_18 []
    acronym_  = Acronym_18 
instance C_Acronym Ent21 Ent18 where
    _acronym = Acronym_21 []
    acronym_  = Acronym_21 
instance C_Acronym Ent22 Ent18 where
    _acronym = Acronym_22 []
    acronym_  = Acronym_22 
instance C_Acronym Ent23 Ent18 where
    _acronym = Acronym_23 []
    acronym_  = Acronym_23 
instance C_Acronym Ent28 Ent10 where
    _acronym = Acronym_28 []
    acronym_  = Acronym_28 
instance C_Acronym Ent33 Ent10 where
    _acronym = Acronym_33 []
    acronym_  = Acronym_33 
instance C_Acronym Ent35 Ent35 where
    _acronym = Acronym_35 []
    acronym_  = Acronym_35 
instance C_Acronym Ent37 Ent35 where
    _acronym = Acronym_37 []
    acronym_  = Acronym_37 
instance C_Acronym Ent40 Ent35 where
    _acronym = Acronym_40 []
    acronym_  = Acronym_40 
instance C_Acronym Ent41 Ent35 where
    _acronym = Acronym_41 []
    acronym_  = Acronym_41 
instance C_Acronym Ent42 Ent43 where
    _acronym = Acronym_42 []
    acronym_  = Acronym_42 
instance C_Acronym Ent43 Ent43 where
    _acronym = Acronym_43 []
    acronym_  = Acronym_43 
instance C_Acronym Ent46 Ent43 where
    _acronym = Acronym_46 []
    acronym_  = Acronym_46 
instance C_Acronym Ent47 Ent43 where
    _acronym = Acronym_47 []
    acronym_  = Acronym_47 
instance C_Acronym Ent48 Ent43 where
    _acronym = Acronym_48 []
    acronym_  = Acronym_48 
instance C_Acronym Ent53 Ent35 where
    _acronym = Acronym_53 []
    acronym_  = Acronym_53 
instance C_Acronym Ent58 Ent35 where
    _acronym = Acronym_58 []
    acronym_  = Acronym_58 
instance C_Acronym Ent62 Ent35 where
    _acronym = Acronym_62 []
    acronym_  = Acronym_62 
instance C_Acronym Ent65 Ent10 where
    _acronym = Acronym_65 []
    acronym_  = Acronym_65 
instance C_Acronym Ent67 Ent69 where
    _acronym = Acronym_67 []
    acronym_  = Acronym_67 
instance C_Acronym Ent69 Ent69 where
    _acronym = Acronym_69 []
    acronym_  = Acronym_69 
instance C_Acronym Ent72 Ent69 where
    _acronym = Acronym_72 []
    acronym_  = Acronym_72 
instance C_Acronym Ent73 Ent69 where
    _acronym = Acronym_73 []
    acronym_  = Acronym_73 
instance C_Acronym Ent75 Ent18 where
    _acronym = Acronym_75 []
    acronym_  = Acronym_75 
instance C_Acronym Ent78 Ent43 where
    _acronym = Acronym_78 []
    acronym_  = Acronym_78 
instance C_Acronym Ent82 Ent43 where
    _acronym = Acronym_82 []
    acronym_  = Acronym_82 
instance C_Acronym Ent85 Ent18 where
    _acronym = Acronym_85 []
    acronym_  = Acronym_85 
instance C_Acronym Ent86 Ent69 where
    _acronym = Acronym_86 []
    acronym_  = Acronym_86 
instance C_Acronym Ent88 Ent88 where
    _acronym = Acronym_88 []
    acronym_  = Acronym_88 
instance C_Acronym Ent90 Ent88 where
    _acronym = Acronym_90 []
    acronym_  = Acronym_90 
instance C_Acronym Ent93 Ent88 where
    _acronym = Acronym_93 []
    acronym_  = Acronym_93 
instance C_Acronym Ent94 Ent88 where
    _acronym = Acronym_94 []
    acronym_  = Acronym_94 
instance C_Acronym Ent95 Ent88 where
    _acronym = Acronym_95 []
    acronym_  = Acronym_95 
instance C_Acronym Ent100 Ent88 where
    _acronym = Acronym_100 []
    acronym_  = Acronym_100 
instance C_Acronym Ent104 Ent88 where
    _acronym = Acronym_104 []
    acronym_  = Acronym_104 
instance C_Acronym Ent107 Ent69 where
    _acronym = Acronym_107 []
    acronym_  = Acronym_107 
instance C_Acronym Ent108 Ent69 where
    _acronym = Acronym_108 []
    acronym_  = Acronym_108 
instance C_Acronym Ent113 Ent113 where
    _acronym = Acronym_113 []
    acronym_  = Acronym_113 
instance C_Acronym Ent115 Ent113 where
    _acronym = Acronym_115 []
    acronym_  = Acronym_115 
instance C_Acronym Ent118 Ent113 where
    _acronym = Acronym_118 []
    acronym_  = Acronym_118 
instance C_Acronym Ent119 Ent113 where
    _acronym = Acronym_119 []
    acronym_  = Acronym_119 
instance C_Acronym Ent120 Ent113 where
    _acronym = Acronym_120 []
    acronym_  = Acronym_120 
instance C_Acronym Ent125 Ent113 where
    _acronym = Acronym_125 []
    acronym_  = Acronym_125 
instance C_Acronym Ent129 Ent113 where
    _acronym = Acronym_129 []
    acronym_  = Acronym_129 
instance C_Acronym Ent132 Ent5 where
    _acronym = Acronym_132 []
    acronym_  = Acronym_132 
instance C_Acronym Ent133 Ent5 where
    _acronym = Acronym_133 []
    acronym_  = Acronym_133 

class C_Q a b | a -> b where
    _q :: [b] -> a
    q_ :: [Att20] -> [b] -> a
instance C_Q Ent3 Ent5 where
    _q = Q_3 []
    q_  = Q_3 
instance C_Q Ent4 Ent5 where
    _q = Q_4 []
    q_  = Q_4 
instance C_Q Ent5 Ent5 where
    _q = Q_5 []
    q_  = Q_5 
instance C_Q Ent8 Ent5 where
    _q = Q_8 []
    q_  = Q_8 
instance C_Q Ent9 Ent5 where
    _q = Q_9 []
    q_  = Q_9 
instance C_Q Ent10 Ent10 where
    _q = Q_10 []
    q_  = Q_10 
instance C_Q Ent12 Ent10 where
    _q = Q_12 []
    q_  = Q_12 
instance C_Q Ent15 Ent10 where
    _q = Q_15 []
    q_  = Q_15 
instance C_Q Ent16 Ent10 where
    _q = Q_16 []
    q_  = Q_16 
instance C_Q Ent17 Ent18 where
    _q = Q_17 []
    q_  = Q_17 
instance C_Q Ent18 Ent18 where
    _q = Q_18 []
    q_  = Q_18 
instance C_Q Ent21 Ent18 where
    _q = Q_21 []
    q_  = Q_21 
instance C_Q Ent22 Ent18 where
    _q = Q_22 []
    q_  = Q_22 
instance C_Q Ent23 Ent18 where
    _q = Q_23 []
    q_  = Q_23 
instance C_Q Ent28 Ent10 where
    _q = Q_28 []
    q_  = Q_28 
instance C_Q Ent33 Ent10 where
    _q = Q_33 []
    q_  = Q_33 
instance C_Q Ent35 Ent35 where
    _q = Q_35 []
    q_  = Q_35 
instance C_Q Ent37 Ent35 where
    _q = Q_37 []
    q_  = Q_37 
instance C_Q Ent40 Ent35 where
    _q = Q_40 []
    q_  = Q_40 
instance C_Q Ent41 Ent35 where
    _q = Q_41 []
    q_  = Q_41 
instance C_Q Ent42 Ent43 where
    _q = Q_42 []
    q_  = Q_42 
instance C_Q Ent43 Ent43 where
    _q = Q_43 []
    q_  = Q_43 
instance C_Q Ent46 Ent43 where
    _q = Q_46 []
    q_  = Q_46 
instance C_Q Ent47 Ent43 where
    _q = Q_47 []
    q_  = Q_47 
instance C_Q Ent48 Ent43 where
    _q = Q_48 []
    q_  = Q_48 
instance C_Q Ent53 Ent35 where
    _q = Q_53 []
    q_  = Q_53 
instance C_Q Ent58 Ent35 where
    _q = Q_58 []
    q_  = Q_58 
instance C_Q Ent62 Ent35 where
    _q = Q_62 []
    q_  = Q_62 
instance C_Q Ent65 Ent10 where
    _q = Q_65 []
    q_  = Q_65 
instance C_Q Ent67 Ent69 where
    _q = Q_67 []
    q_  = Q_67 
instance C_Q Ent69 Ent69 where
    _q = Q_69 []
    q_  = Q_69 
instance C_Q Ent72 Ent69 where
    _q = Q_72 []
    q_  = Q_72 
instance C_Q Ent73 Ent69 where
    _q = Q_73 []
    q_  = Q_73 
instance C_Q Ent75 Ent18 where
    _q = Q_75 []
    q_  = Q_75 
instance C_Q Ent78 Ent43 where
    _q = Q_78 []
    q_  = Q_78 
instance C_Q Ent82 Ent43 where
    _q = Q_82 []
    q_  = Q_82 
instance C_Q Ent85 Ent18 where
    _q = Q_85 []
    q_  = Q_85 
instance C_Q Ent86 Ent69 where
    _q = Q_86 []
    q_  = Q_86 
instance C_Q Ent88 Ent88 where
    _q = Q_88 []
    q_  = Q_88 
instance C_Q Ent90 Ent88 where
    _q = Q_90 []
    q_  = Q_90 
instance C_Q Ent93 Ent88 where
    _q = Q_93 []
    q_  = Q_93 
instance C_Q Ent94 Ent88 where
    _q = Q_94 []
    q_  = Q_94 
instance C_Q Ent95 Ent88 where
    _q = Q_95 []
    q_  = Q_95 
instance C_Q Ent100 Ent88 where
    _q = Q_100 []
    q_  = Q_100 
instance C_Q Ent104 Ent88 where
    _q = Q_104 []
    q_  = Q_104 
instance C_Q Ent107 Ent69 where
    _q = Q_107 []
    q_  = Q_107 
instance C_Q Ent108 Ent69 where
    _q = Q_108 []
    q_  = Q_108 
instance C_Q Ent113 Ent113 where
    _q = Q_113 []
    q_  = Q_113 
instance C_Q Ent115 Ent113 where
    _q = Q_115 []
    q_  = Q_115 
instance C_Q Ent118 Ent113 where
    _q = Q_118 []
    q_  = Q_118 
instance C_Q Ent119 Ent113 where
    _q = Q_119 []
    q_  = Q_119 
instance C_Q Ent120 Ent113 where
    _q = Q_120 []
    q_  = Q_120 
instance C_Q Ent125 Ent113 where
    _q = Q_125 []
    q_  = Q_125 
instance C_Q Ent129 Ent113 where
    _q = Q_129 []
    q_  = Q_129 
instance C_Q Ent132 Ent5 where
    _q = Q_132 []
    q_  = Q_132 
instance C_Q Ent133 Ent5 where
    _q = Q_133 []
    q_  = Q_133 

class C_Sub a b | a -> b where
    _sub :: [b] -> a
    sub_ :: [Att10] -> [b] -> a
instance C_Sub Ent3 Ent5 where
    _sub = Sub_3 []
    sub_  = Sub_3 
instance C_Sub Ent4 Ent5 where
    _sub = Sub_4 []
    sub_  = Sub_4 
instance C_Sub Ent5 Ent5 where
    _sub = Sub_5 []
    sub_  = Sub_5 
instance C_Sub Ent8 Ent5 where
    _sub = Sub_8 []
    sub_  = Sub_8 
instance C_Sub Ent10 Ent10 where
    _sub = Sub_10 []
    sub_  = Sub_10 
instance C_Sub Ent12 Ent10 where
    _sub = Sub_12 []
    sub_  = Sub_12 
instance C_Sub Ent15 Ent10 where
    _sub = Sub_15 []
    sub_  = Sub_15 
instance C_Sub Ent17 Ent18 where
    _sub = Sub_17 []
    sub_  = Sub_17 
instance C_Sub Ent18 Ent18 where
    _sub = Sub_18 []
    sub_  = Sub_18 
instance C_Sub Ent21 Ent18 where
    _sub = Sub_21 []
    sub_  = Sub_21 
instance C_Sub Ent23 Ent18 where
    _sub = Sub_23 []
    sub_  = Sub_23 
instance C_Sub Ent28 Ent10 where
    _sub = Sub_28 []
    sub_  = Sub_28 
instance C_Sub Ent33 Ent10 where
    _sub = Sub_33 []
    sub_  = Sub_33 
instance C_Sub Ent35 Ent35 where
    _sub = Sub_35 []
    sub_  = Sub_35 
instance C_Sub Ent37 Ent35 where
    _sub = Sub_37 []
    sub_  = Sub_37 
instance C_Sub Ent40 Ent35 where
    _sub = Sub_40 []
    sub_  = Sub_40 
instance C_Sub Ent42 Ent43 where
    _sub = Sub_42 []
    sub_  = Sub_42 
instance C_Sub Ent43 Ent43 where
    _sub = Sub_43 []
    sub_  = Sub_43 
instance C_Sub Ent46 Ent43 where
    _sub = Sub_46 []
    sub_  = Sub_46 
instance C_Sub Ent48 Ent43 where
    _sub = Sub_48 []
    sub_  = Sub_48 
instance C_Sub Ent53 Ent35 where
    _sub = Sub_53 []
    sub_  = Sub_53 
instance C_Sub Ent58 Ent35 where
    _sub = Sub_58 []
    sub_  = Sub_58 
instance C_Sub Ent62 Ent35 where
    _sub = Sub_62 []
    sub_  = Sub_62 
instance C_Sub Ent65 Ent10 where
    _sub = Sub_65 []
    sub_  = Sub_65 
instance C_Sub Ent67 Ent69 where
    _sub = Sub_67 []
    sub_  = Sub_67 
instance C_Sub Ent69 Ent69 where
    _sub = Sub_69 []
    sub_  = Sub_69 
instance C_Sub Ent72 Ent69 where
    _sub = Sub_72 []
    sub_  = Sub_72 
instance C_Sub Ent75 Ent18 where
    _sub = Sub_75 []
    sub_  = Sub_75 
instance C_Sub Ent78 Ent43 where
    _sub = Sub_78 []
    sub_  = Sub_78 
instance C_Sub Ent82 Ent43 where
    _sub = Sub_82 []
    sub_  = Sub_82 
instance C_Sub Ent85 Ent18 where
    _sub = Sub_85 []
    sub_  = Sub_85 
instance C_Sub Ent86 Ent69 where
    _sub = Sub_86 []
    sub_  = Sub_86 
instance C_Sub Ent88 Ent88 where
    _sub = Sub_88 []
    sub_  = Sub_88 
instance C_Sub Ent90 Ent88 where
    _sub = Sub_90 []
    sub_  = Sub_90 
instance C_Sub Ent93 Ent88 where
    _sub = Sub_93 []
    sub_  = Sub_93 
instance C_Sub Ent95 Ent88 where
    _sub = Sub_95 []
    sub_  = Sub_95 
instance C_Sub Ent100 Ent88 where
    _sub = Sub_100 []
    sub_  = Sub_100 
instance C_Sub Ent104 Ent88 where
    _sub = Sub_104 []
    sub_  = Sub_104 
instance C_Sub Ent107 Ent69 where
    _sub = Sub_107 []
    sub_  = Sub_107 
instance C_Sub Ent108 Ent69 where
    _sub = Sub_108 []
    sub_  = Sub_108 
instance C_Sub Ent113 Ent113 where
    _sub = Sub_113 []
    sub_  = Sub_113 
instance C_Sub Ent115 Ent113 where
    _sub = Sub_115 []
    sub_  = Sub_115 
instance C_Sub Ent118 Ent113 where
    _sub = Sub_118 []
    sub_  = Sub_118 
instance C_Sub Ent120 Ent113 where
    _sub = Sub_120 []
    sub_  = Sub_120 
instance C_Sub Ent125 Ent113 where
    _sub = Sub_125 []
    sub_  = Sub_125 
instance C_Sub Ent129 Ent113 where
    _sub = Sub_129 []
    sub_  = Sub_129 
instance C_Sub Ent132 Ent5 where
    _sub = Sub_132 []
    sub_  = Sub_132 
instance C_Sub Ent133 Ent5 where
    _sub = Sub_133 []
    sub_  = Sub_133 

class C_Sup a b | a -> b where
    _sup :: [b] -> a
    sup_ :: [Att10] -> [b] -> a
instance C_Sup Ent3 Ent5 where
    _sup = Sup_3 []
    sup_  = Sup_3 
instance C_Sup Ent4 Ent5 where
    _sup = Sup_4 []
    sup_  = Sup_4 
instance C_Sup Ent5 Ent5 where
    _sup = Sup_5 []
    sup_  = Sup_5 
instance C_Sup Ent8 Ent5 where
    _sup = Sup_8 []
    sup_  = Sup_8 
instance C_Sup Ent10 Ent10 where
    _sup = Sup_10 []
    sup_  = Sup_10 
instance C_Sup Ent12 Ent10 where
    _sup = Sup_12 []
    sup_  = Sup_12 
instance C_Sup Ent15 Ent10 where
    _sup = Sup_15 []
    sup_  = Sup_15 
instance C_Sup Ent17 Ent18 where
    _sup = Sup_17 []
    sup_  = Sup_17 
instance C_Sup Ent18 Ent18 where
    _sup = Sup_18 []
    sup_  = Sup_18 
instance C_Sup Ent21 Ent18 where
    _sup = Sup_21 []
    sup_  = Sup_21 
instance C_Sup Ent23 Ent18 where
    _sup = Sup_23 []
    sup_  = Sup_23 
instance C_Sup Ent28 Ent10 where
    _sup = Sup_28 []
    sup_  = Sup_28 
instance C_Sup Ent33 Ent10 where
    _sup = Sup_33 []
    sup_  = Sup_33 
instance C_Sup Ent35 Ent35 where
    _sup = Sup_35 []
    sup_  = Sup_35 
instance C_Sup Ent37 Ent35 where
    _sup = Sup_37 []
    sup_  = Sup_37 
instance C_Sup Ent40 Ent35 where
    _sup = Sup_40 []
    sup_  = Sup_40 
instance C_Sup Ent42 Ent43 where
    _sup = Sup_42 []
    sup_  = Sup_42 
instance C_Sup Ent43 Ent43 where
    _sup = Sup_43 []
    sup_  = Sup_43 
instance C_Sup Ent46 Ent43 where
    _sup = Sup_46 []
    sup_  = Sup_46 
instance C_Sup Ent48 Ent43 where
    _sup = Sup_48 []
    sup_  = Sup_48 
instance C_Sup Ent53 Ent35 where
    _sup = Sup_53 []
    sup_  = Sup_53 
instance C_Sup Ent58 Ent35 where
    _sup = Sup_58 []
    sup_  = Sup_58 
instance C_Sup Ent62 Ent35 where
    _sup = Sup_62 []
    sup_  = Sup_62 
instance C_Sup Ent65 Ent10 where
    _sup = Sup_65 []
    sup_  = Sup_65 
instance C_Sup Ent67 Ent69 where
    _sup = Sup_67 []
    sup_  = Sup_67 
instance C_Sup Ent69 Ent69 where
    _sup = Sup_69 []
    sup_  = Sup_69 
instance C_Sup Ent72 Ent69 where
    _sup = Sup_72 []
    sup_  = Sup_72 
instance C_Sup Ent75 Ent18 where
    _sup = Sup_75 []
    sup_  = Sup_75 
instance C_Sup Ent78 Ent43 where
    _sup = Sup_78 []
    sup_  = Sup_78 
instance C_Sup Ent82 Ent43 where
    _sup = Sup_82 []
    sup_  = Sup_82 
instance C_Sup Ent85 Ent18 where
    _sup = Sup_85 []
    sup_  = Sup_85 
instance C_Sup Ent86 Ent69 where
    _sup = Sup_86 []
    sup_  = Sup_86 
instance C_Sup Ent88 Ent88 where
    _sup = Sup_88 []
    sup_  = Sup_88 
instance C_Sup Ent90 Ent88 where
    _sup = Sup_90 []
    sup_  = Sup_90 
instance C_Sup Ent93 Ent88 where
    _sup = Sup_93 []
    sup_  = Sup_93 
instance C_Sup Ent95 Ent88 where
    _sup = Sup_95 []
    sup_  = Sup_95 
instance C_Sup Ent100 Ent88 where
    _sup = Sup_100 []
    sup_  = Sup_100 
instance C_Sup Ent104 Ent88 where
    _sup = Sup_104 []
    sup_  = Sup_104 
instance C_Sup Ent107 Ent69 where
    _sup = Sup_107 []
    sup_  = Sup_107 
instance C_Sup Ent108 Ent69 where
    _sup = Sup_108 []
    sup_  = Sup_108 
instance C_Sup Ent113 Ent113 where
    _sup = Sup_113 []
    sup_  = Sup_113 
instance C_Sup Ent115 Ent113 where
    _sup = Sup_115 []
    sup_  = Sup_115 
instance C_Sup Ent118 Ent113 where
    _sup = Sup_118 []
    sup_  = Sup_118 
instance C_Sup Ent120 Ent113 where
    _sup = Sup_120 []
    sup_  = Sup_120 
instance C_Sup Ent125 Ent113 where
    _sup = Sup_125 []
    sup_  = Sup_125 
instance C_Sup Ent129 Ent113 where
    _sup = Sup_129 []
    sup_  = Sup_129 
instance C_Sup Ent132 Ent5 where
    _sup = Sup_132 []
    sup_  = Sup_132 
instance C_Sup Ent133 Ent5 where
    _sup = Sup_133 []
    sup_  = Sup_133 

class C_Tt a b | a -> b where
    _tt :: [b] -> a
    tt_ :: [Att10] -> [b] -> a
instance C_Tt Ent3 Ent5 where
    _tt = Tt_3 []
    tt_  = Tt_3 
instance C_Tt Ent4 Ent5 where
    _tt = Tt_4 []
    tt_  = Tt_4 
instance C_Tt Ent5 Ent5 where
    _tt = Tt_5 []
    tt_  = Tt_5 
instance C_Tt Ent8 Ent5 where
    _tt = Tt_8 []
    tt_  = Tt_8 
instance C_Tt Ent9 Ent5 where
    _tt = Tt_9 []
    tt_  = Tt_9 
instance C_Tt Ent10 Ent10 where
    _tt = Tt_10 []
    tt_  = Tt_10 
instance C_Tt Ent12 Ent10 where
    _tt = Tt_12 []
    tt_  = Tt_12 
instance C_Tt Ent15 Ent10 where
    _tt = Tt_15 []
    tt_  = Tt_15 
instance C_Tt Ent16 Ent10 where
    _tt = Tt_16 []
    tt_  = Tt_16 
instance C_Tt Ent17 Ent18 where
    _tt = Tt_17 []
    tt_  = Tt_17 
instance C_Tt Ent18 Ent18 where
    _tt = Tt_18 []
    tt_  = Tt_18 
instance C_Tt Ent21 Ent18 where
    _tt = Tt_21 []
    tt_  = Tt_21 
instance C_Tt Ent22 Ent18 where
    _tt = Tt_22 []
    tt_  = Tt_22 
instance C_Tt Ent23 Ent18 where
    _tt = Tt_23 []
    tt_  = Tt_23 
instance C_Tt Ent28 Ent10 where
    _tt = Tt_28 []
    tt_  = Tt_28 
instance C_Tt Ent33 Ent10 where
    _tt = Tt_33 []
    tt_  = Tt_33 
instance C_Tt Ent35 Ent35 where
    _tt = Tt_35 []
    tt_  = Tt_35 
instance C_Tt Ent37 Ent35 where
    _tt = Tt_37 []
    tt_  = Tt_37 
instance C_Tt Ent40 Ent35 where
    _tt = Tt_40 []
    tt_  = Tt_40 
instance C_Tt Ent41 Ent35 where
    _tt = Tt_41 []
    tt_  = Tt_41 
instance C_Tt Ent42 Ent43 where
    _tt = Tt_42 []
    tt_  = Tt_42 
instance C_Tt Ent43 Ent43 where
    _tt = Tt_43 []
    tt_  = Tt_43 
instance C_Tt Ent46 Ent43 where
    _tt = Tt_46 []
    tt_  = Tt_46 
instance C_Tt Ent47 Ent43 where
    _tt = Tt_47 []
    tt_  = Tt_47 
instance C_Tt Ent48 Ent43 where
    _tt = Tt_48 []
    tt_  = Tt_48 
instance C_Tt Ent53 Ent35 where
    _tt = Tt_53 []
    tt_  = Tt_53 
instance C_Tt Ent58 Ent35 where
    _tt = Tt_58 []
    tt_  = Tt_58 
instance C_Tt Ent62 Ent35 where
    _tt = Tt_62 []
    tt_  = Tt_62 
instance C_Tt Ent65 Ent10 where
    _tt = Tt_65 []
    tt_  = Tt_65 
instance C_Tt Ent67 Ent69 where
    _tt = Tt_67 []
    tt_  = Tt_67 
instance C_Tt Ent69 Ent69 where
    _tt = Tt_69 []
    tt_  = Tt_69 
instance C_Tt Ent72 Ent69 where
    _tt = Tt_72 []
    tt_  = Tt_72 
instance C_Tt Ent73 Ent69 where
    _tt = Tt_73 []
    tt_  = Tt_73 
instance C_Tt Ent75 Ent18 where
    _tt = Tt_75 []
    tt_  = Tt_75 
instance C_Tt Ent78 Ent43 where
    _tt = Tt_78 []
    tt_  = Tt_78 
instance C_Tt Ent82 Ent43 where
    _tt = Tt_82 []
    tt_  = Tt_82 
instance C_Tt Ent85 Ent18 where
    _tt = Tt_85 []
    tt_  = Tt_85 
instance C_Tt Ent86 Ent69 where
    _tt = Tt_86 []
    tt_  = Tt_86 
instance C_Tt Ent88 Ent88 where
    _tt = Tt_88 []
    tt_  = Tt_88 
instance C_Tt Ent90 Ent88 where
    _tt = Tt_90 []
    tt_  = Tt_90 
instance C_Tt Ent93 Ent88 where
    _tt = Tt_93 []
    tt_  = Tt_93 
instance C_Tt Ent94 Ent88 where
    _tt = Tt_94 []
    tt_  = Tt_94 
instance C_Tt Ent95 Ent88 where
    _tt = Tt_95 []
    tt_  = Tt_95 
instance C_Tt Ent100 Ent88 where
    _tt = Tt_100 []
    tt_  = Tt_100 
instance C_Tt Ent104 Ent88 where
    _tt = Tt_104 []
    tt_  = Tt_104 
instance C_Tt Ent107 Ent69 where
    _tt = Tt_107 []
    tt_  = Tt_107 
instance C_Tt Ent108 Ent69 where
    _tt = Tt_108 []
    tt_  = Tt_108 
instance C_Tt Ent113 Ent113 where
    _tt = Tt_113 []
    tt_  = Tt_113 
instance C_Tt Ent115 Ent113 where
    _tt = Tt_115 []
    tt_  = Tt_115 
instance C_Tt Ent118 Ent113 where
    _tt = Tt_118 []
    tt_  = Tt_118 
instance C_Tt Ent119 Ent113 where
    _tt = Tt_119 []
    tt_  = Tt_119 
instance C_Tt Ent120 Ent113 where
    _tt = Tt_120 []
    tt_  = Tt_120 
instance C_Tt Ent125 Ent113 where
    _tt = Tt_125 []
    tt_  = Tt_125 
instance C_Tt Ent129 Ent113 where
    _tt = Tt_129 []
    tt_  = Tt_129 
instance C_Tt Ent132 Ent5 where
    _tt = Tt_132 []
    tt_  = Tt_132 
instance C_Tt Ent133 Ent5 where
    _tt = Tt_133 []
    tt_  = Tt_133 

class C_I a b | a -> b where
    _i :: [b] -> a
    i_ :: [Att10] -> [b] -> a
instance C_I Ent3 Ent5 where
    _i = I_3 []
    i_  = I_3 
instance C_I Ent4 Ent5 where
    _i = I_4 []
    i_  = I_4 
instance C_I Ent5 Ent5 where
    _i = I_5 []
    i_  = I_5 
instance C_I Ent8 Ent5 where
    _i = I_8 []
    i_  = I_8 
instance C_I Ent9 Ent5 where
    _i = I_9 []
    i_  = I_9 
instance C_I Ent10 Ent10 where
    _i = I_10 []
    i_  = I_10 
instance C_I Ent12 Ent10 where
    _i = I_12 []
    i_  = I_12 
instance C_I Ent15 Ent10 where
    _i = I_15 []
    i_  = I_15 
instance C_I Ent16 Ent10 where
    _i = I_16 []
    i_  = I_16 
instance C_I Ent17 Ent18 where
    _i = I_17 []
    i_  = I_17 
instance C_I Ent18 Ent18 where
    _i = I_18 []
    i_  = I_18 
instance C_I Ent21 Ent18 where
    _i = I_21 []
    i_  = I_21 
instance C_I Ent22 Ent18 where
    _i = I_22 []
    i_  = I_22 
instance C_I Ent23 Ent18 where
    _i = I_23 []
    i_  = I_23 
instance C_I Ent28 Ent10 where
    _i = I_28 []
    i_  = I_28 
instance C_I Ent33 Ent10 where
    _i = I_33 []
    i_  = I_33 
instance C_I Ent35 Ent35 where
    _i = I_35 []
    i_  = I_35 
instance C_I Ent37 Ent35 where
    _i = I_37 []
    i_  = I_37 
instance C_I Ent40 Ent35 where
    _i = I_40 []
    i_  = I_40 
instance C_I Ent41 Ent35 where
    _i = I_41 []
    i_  = I_41 
instance C_I Ent42 Ent43 where
    _i = I_42 []
    i_  = I_42 
instance C_I Ent43 Ent43 where
    _i = I_43 []
    i_  = I_43 
instance C_I Ent46 Ent43 where
    _i = I_46 []
    i_  = I_46 
instance C_I Ent47 Ent43 where
    _i = I_47 []
    i_  = I_47 
instance C_I Ent48 Ent43 where
    _i = I_48 []
    i_  = I_48 
instance C_I Ent53 Ent35 where
    _i = I_53 []
    i_  = I_53 
instance C_I Ent58 Ent35 where
    _i = I_58 []
    i_  = I_58 
instance C_I Ent62 Ent35 where
    _i = I_62 []
    i_  = I_62 
instance C_I Ent65 Ent10 where
    _i = I_65 []
    i_  = I_65 
instance C_I Ent67 Ent69 where
    _i = I_67 []
    i_  = I_67 
instance C_I Ent69 Ent69 where
    _i = I_69 []
    i_  = I_69 
instance C_I Ent72 Ent69 where
    _i = I_72 []
    i_  = I_72 
instance C_I Ent73 Ent69 where
    _i = I_73 []
    i_  = I_73 
instance C_I Ent75 Ent18 where
    _i = I_75 []
    i_  = I_75 
instance C_I Ent78 Ent43 where
    _i = I_78 []
    i_  = I_78 
instance C_I Ent82 Ent43 where
    _i = I_82 []
    i_  = I_82 
instance C_I Ent85 Ent18 where
    _i = I_85 []
    i_  = I_85 
instance C_I Ent86 Ent69 where
    _i = I_86 []
    i_  = I_86 
instance C_I Ent88 Ent88 where
    _i = I_88 []
    i_  = I_88 
instance C_I Ent90 Ent88 where
    _i = I_90 []
    i_  = I_90 
instance C_I Ent93 Ent88 where
    _i = I_93 []
    i_  = I_93 
instance C_I Ent94 Ent88 where
    _i = I_94 []
    i_  = I_94 
instance C_I Ent95 Ent88 where
    _i = I_95 []
    i_  = I_95 
instance C_I Ent100 Ent88 where
    _i = I_100 []
    i_  = I_100 
instance C_I Ent104 Ent88 where
    _i = I_104 []
    i_  = I_104 
instance C_I Ent107 Ent69 where
    _i = I_107 []
    i_  = I_107 
instance C_I Ent108 Ent69 where
    _i = I_108 []
    i_  = I_108 
instance C_I Ent113 Ent113 where
    _i = I_113 []
    i_  = I_113 
instance C_I Ent115 Ent113 where
    _i = I_115 []
    i_  = I_115 
instance C_I Ent118 Ent113 where
    _i = I_118 []
    i_  = I_118 
instance C_I Ent119 Ent113 where
    _i = I_119 []
    i_  = I_119 
instance C_I Ent120 Ent113 where
    _i = I_120 []
    i_  = I_120 
instance C_I Ent125 Ent113 where
    _i = I_125 []
    i_  = I_125 
instance C_I Ent129 Ent113 where
    _i = I_129 []
    i_  = I_129 
instance C_I Ent132 Ent5 where
    _i = I_132 []
    i_  = I_132 
instance C_I Ent133 Ent5 where
    _i = I_133 []
    i_  = I_133 

class C_B a b | a -> b where
    _b :: [b] -> a
    b_ :: [Att10] -> [b] -> a
instance C_B Ent3 Ent5 where
    _b = B_3 []
    b_  = B_3 
instance C_B Ent4 Ent5 where
    _b = B_4 []
    b_  = B_4 
instance C_B Ent5 Ent5 where
    _b = B_5 []
    b_  = B_5 
instance C_B Ent8 Ent5 where
    _b = B_8 []
    b_  = B_8 
instance C_B Ent9 Ent5 where
    _b = B_9 []
    b_  = B_9 
instance C_B Ent10 Ent10 where
    _b = B_10 []
    b_  = B_10 
instance C_B Ent12 Ent10 where
    _b = B_12 []
    b_  = B_12 
instance C_B Ent15 Ent10 where
    _b = B_15 []
    b_  = B_15 
instance C_B Ent16 Ent10 where
    _b = B_16 []
    b_  = B_16 
instance C_B Ent17 Ent18 where
    _b = B_17 []
    b_  = B_17 
instance C_B Ent18 Ent18 where
    _b = B_18 []
    b_  = B_18 
instance C_B Ent21 Ent18 where
    _b = B_21 []
    b_  = B_21 
instance C_B Ent22 Ent18 where
    _b = B_22 []
    b_  = B_22 
instance C_B Ent23 Ent18 where
    _b = B_23 []
    b_  = B_23 
instance C_B Ent28 Ent10 where
    _b = B_28 []
    b_  = B_28 
instance C_B Ent33 Ent10 where
    _b = B_33 []
    b_  = B_33 
instance C_B Ent35 Ent35 where
    _b = B_35 []
    b_  = B_35 
instance C_B Ent37 Ent35 where
    _b = B_37 []
    b_  = B_37 
instance C_B Ent40 Ent35 where
    _b = B_40 []
    b_  = B_40 
instance C_B Ent41 Ent35 where
    _b = B_41 []
    b_  = B_41 
instance C_B Ent42 Ent43 where
    _b = B_42 []
    b_  = B_42 
instance C_B Ent43 Ent43 where
    _b = B_43 []
    b_  = B_43 
instance C_B Ent46 Ent43 where
    _b = B_46 []
    b_  = B_46 
instance C_B Ent47 Ent43 where
    _b = B_47 []
    b_  = B_47 
instance C_B Ent48 Ent43 where
    _b = B_48 []
    b_  = B_48 
instance C_B Ent53 Ent35 where
    _b = B_53 []
    b_  = B_53 
instance C_B Ent58 Ent35 where
    _b = B_58 []
    b_  = B_58 
instance C_B Ent62 Ent35 where
    _b = B_62 []
    b_  = B_62 
instance C_B Ent65 Ent10 where
    _b = B_65 []
    b_  = B_65 
instance C_B Ent67 Ent69 where
    _b = B_67 []
    b_  = B_67 
instance C_B Ent69 Ent69 where
    _b = B_69 []
    b_  = B_69 
instance C_B Ent72 Ent69 where
    _b = B_72 []
    b_  = B_72 
instance C_B Ent73 Ent69 where
    _b = B_73 []
    b_  = B_73 
instance C_B Ent75 Ent18 where
    _b = B_75 []
    b_  = B_75 
instance C_B Ent78 Ent43 where
    _b = B_78 []
    b_  = B_78 
instance C_B Ent82 Ent43 where
    _b = B_82 []
    b_  = B_82 
instance C_B Ent85 Ent18 where
    _b = B_85 []
    b_  = B_85 
instance C_B Ent86 Ent69 where
    _b = B_86 []
    b_  = B_86 
instance C_B Ent88 Ent88 where
    _b = B_88 []
    b_  = B_88 
instance C_B Ent90 Ent88 where
    _b = B_90 []
    b_  = B_90 
instance C_B Ent93 Ent88 where
    _b = B_93 []
    b_  = B_93 
instance C_B Ent94 Ent88 where
    _b = B_94 []
    b_  = B_94 
instance C_B Ent95 Ent88 where
    _b = B_95 []
    b_  = B_95 
instance C_B Ent100 Ent88 where
    _b = B_100 []
    b_  = B_100 
instance C_B Ent104 Ent88 where
    _b = B_104 []
    b_  = B_104 
instance C_B Ent107 Ent69 where
    _b = B_107 []
    b_  = B_107 
instance C_B Ent108 Ent69 where
    _b = B_108 []
    b_  = B_108 
instance C_B Ent113 Ent113 where
    _b = B_113 []
    b_  = B_113 
instance C_B Ent115 Ent113 where
    _b = B_115 []
    b_  = B_115 
instance C_B Ent118 Ent113 where
    _b = B_118 []
    b_  = B_118 
instance C_B Ent119 Ent113 where
    _b = B_119 []
    b_  = B_119 
instance C_B Ent120 Ent113 where
    _b = B_120 []
    b_  = B_120 
instance C_B Ent125 Ent113 where
    _b = B_125 []
    b_  = B_125 
instance C_B Ent129 Ent113 where
    _b = B_129 []
    b_  = B_129 
instance C_B Ent132 Ent5 where
    _b = B_132 []
    b_  = B_132 
instance C_B Ent133 Ent5 where
    _b = B_133 []
    b_  = B_133 

class C_Big a b | a -> b where
    _big :: [b] -> a
    big_ :: [Att10] -> [b] -> a
instance C_Big Ent3 Ent5 where
    _big = Big_3 []
    big_  = Big_3 
instance C_Big Ent4 Ent5 where
    _big = Big_4 []
    big_  = Big_4 
instance C_Big Ent5 Ent5 where
    _big = Big_5 []
    big_  = Big_5 
instance C_Big Ent8 Ent5 where
    _big = Big_8 []
    big_  = Big_8 
instance C_Big Ent10 Ent10 where
    _big = Big_10 []
    big_  = Big_10 
instance C_Big Ent12 Ent10 where
    _big = Big_12 []
    big_  = Big_12 
instance C_Big Ent15 Ent10 where
    _big = Big_15 []
    big_  = Big_15 
instance C_Big Ent17 Ent18 where
    _big = Big_17 []
    big_  = Big_17 
instance C_Big Ent18 Ent18 where
    _big = Big_18 []
    big_  = Big_18 
instance C_Big Ent21 Ent18 where
    _big = Big_21 []
    big_  = Big_21 
instance C_Big Ent23 Ent18 where
    _big = Big_23 []
    big_  = Big_23 
instance C_Big Ent28 Ent10 where
    _big = Big_28 []
    big_  = Big_28 
instance C_Big Ent33 Ent10 where
    _big = Big_33 []
    big_  = Big_33 
instance C_Big Ent35 Ent35 where
    _big = Big_35 []
    big_  = Big_35 
instance C_Big Ent37 Ent35 where
    _big = Big_37 []
    big_  = Big_37 
instance C_Big Ent40 Ent35 where
    _big = Big_40 []
    big_  = Big_40 
instance C_Big Ent42 Ent43 where
    _big = Big_42 []
    big_  = Big_42 
instance C_Big Ent43 Ent43 where
    _big = Big_43 []
    big_  = Big_43 
instance C_Big Ent46 Ent43 where
    _big = Big_46 []
    big_  = Big_46 
instance C_Big Ent48 Ent43 where
    _big = Big_48 []
    big_  = Big_48 
instance C_Big Ent53 Ent35 where
    _big = Big_53 []
    big_  = Big_53 
instance C_Big Ent58 Ent35 where
    _big = Big_58 []
    big_  = Big_58 
instance C_Big Ent62 Ent35 where
    _big = Big_62 []
    big_  = Big_62 
instance C_Big Ent65 Ent10 where
    _big = Big_65 []
    big_  = Big_65 
instance C_Big Ent67 Ent69 where
    _big = Big_67 []
    big_  = Big_67 
instance C_Big Ent69 Ent69 where
    _big = Big_69 []
    big_  = Big_69 
instance C_Big Ent72 Ent69 where
    _big = Big_72 []
    big_  = Big_72 
instance C_Big Ent75 Ent18 where
    _big = Big_75 []
    big_  = Big_75 
instance C_Big Ent78 Ent43 where
    _big = Big_78 []
    big_  = Big_78 
instance C_Big Ent82 Ent43 where
    _big = Big_82 []
    big_  = Big_82 
instance C_Big Ent85 Ent18 where
    _big = Big_85 []
    big_  = Big_85 
instance C_Big Ent86 Ent69 where
    _big = Big_86 []
    big_  = Big_86 
instance C_Big Ent88 Ent88 where
    _big = Big_88 []
    big_  = Big_88 
instance C_Big Ent90 Ent88 where
    _big = Big_90 []
    big_  = Big_90 
instance C_Big Ent93 Ent88 where
    _big = Big_93 []
    big_  = Big_93 
instance C_Big Ent95 Ent88 where
    _big = Big_95 []
    big_  = Big_95 
instance C_Big Ent100 Ent88 where
    _big = Big_100 []
    big_  = Big_100 
instance C_Big Ent104 Ent88 where
    _big = Big_104 []
    big_  = Big_104 
instance C_Big Ent107 Ent69 where
    _big = Big_107 []
    big_  = Big_107 
instance C_Big Ent108 Ent69 where
    _big = Big_108 []
    big_  = Big_108 
instance C_Big Ent113 Ent113 where
    _big = Big_113 []
    big_  = Big_113 
instance C_Big Ent115 Ent113 where
    _big = Big_115 []
    big_  = Big_115 
instance C_Big Ent118 Ent113 where
    _big = Big_118 []
    big_  = Big_118 
instance C_Big Ent120 Ent113 where
    _big = Big_120 []
    big_  = Big_120 
instance C_Big Ent125 Ent113 where
    _big = Big_125 []
    big_  = Big_125 
instance C_Big Ent129 Ent113 where
    _big = Big_129 []
    big_  = Big_129 
instance C_Big Ent132 Ent5 where
    _big = Big_132 []
    big_  = Big_132 
instance C_Big Ent133 Ent5 where
    _big = Big_133 []
    big_  = Big_133 

class C_Small a b | a -> b where
    _small :: [b] -> a
    small_ :: [Att10] -> [b] -> a
instance C_Small Ent3 Ent5 where
    _small = Small_3 []
    small_  = Small_3 
instance C_Small Ent4 Ent5 where
    _small = Small_4 []
    small_  = Small_4 
instance C_Small Ent5 Ent5 where
    _small = Small_5 []
    small_  = Small_5 
instance C_Small Ent8 Ent5 where
    _small = Small_8 []
    small_  = Small_8 
instance C_Small Ent10 Ent10 where
    _small = Small_10 []
    small_  = Small_10 
instance C_Small Ent12 Ent10 where
    _small = Small_12 []
    small_  = Small_12 
instance C_Small Ent15 Ent10 where
    _small = Small_15 []
    small_  = Small_15 
instance C_Small Ent17 Ent18 where
    _small = Small_17 []
    small_  = Small_17 
instance C_Small Ent18 Ent18 where
    _small = Small_18 []
    small_  = Small_18 
instance C_Small Ent21 Ent18 where
    _small = Small_21 []
    small_  = Small_21 
instance C_Small Ent23 Ent18 where
    _small = Small_23 []
    small_  = Small_23 
instance C_Small Ent28 Ent10 where
    _small = Small_28 []
    small_  = Small_28 
instance C_Small Ent33 Ent10 where
    _small = Small_33 []
    small_  = Small_33 
instance C_Small Ent35 Ent35 where
    _small = Small_35 []
    small_  = Small_35 
instance C_Small Ent37 Ent35 where
    _small = Small_37 []
    small_  = Small_37 
instance C_Small Ent40 Ent35 where
    _small = Small_40 []
    small_  = Small_40 
instance C_Small Ent42 Ent43 where
    _small = Small_42 []
    small_  = Small_42 
instance C_Small Ent43 Ent43 where
    _small = Small_43 []
    small_  = Small_43 
instance C_Small Ent46 Ent43 where
    _small = Small_46 []
    small_  = Small_46 
instance C_Small Ent48 Ent43 where
    _small = Small_48 []
    small_  = Small_48 
instance C_Small Ent53 Ent35 where
    _small = Small_53 []
    small_  = Small_53 
instance C_Small Ent58 Ent35 where
    _small = Small_58 []
    small_  = Small_58 
instance C_Small Ent62 Ent35 where
    _small = Small_62 []
    small_  = Small_62 
instance C_Small Ent65 Ent10 where
    _small = Small_65 []
    small_  = Small_65 
instance C_Small Ent67 Ent69 where
    _small = Small_67 []
    small_  = Small_67 
instance C_Small Ent69 Ent69 where
    _small = Small_69 []
    small_  = Small_69 
instance C_Small Ent72 Ent69 where
    _small = Small_72 []
    small_  = Small_72 
instance C_Small Ent75 Ent18 where
    _small = Small_75 []
    small_  = Small_75 
instance C_Small Ent78 Ent43 where
    _small = Small_78 []
    small_  = Small_78 
instance C_Small Ent82 Ent43 where
    _small = Small_82 []
    small_  = Small_82 
instance C_Small Ent85 Ent18 where
    _small = Small_85 []
    small_  = Small_85 
instance C_Small Ent86 Ent69 where
    _small = Small_86 []
    small_  = Small_86 
instance C_Small Ent88 Ent88 where
    _small = Small_88 []
    small_  = Small_88 
instance C_Small Ent90 Ent88 where
    _small = Small_90 []
    small_  = Small_90 
instance C_Small Ent93 Ent88 where
    _small = Small_93 []
    small_  = Small_93 
instance C_Small Ent95 Ent88 where
    _small = Small_95 []
    small_  = Small_95 
instance C_Small Ent100 Ent88 where
    _small = Small_100 []
    small_  = Small_100 
instance C_Small Ent104 Ent88 where
    _small = Small_104 []
    small_  = Small_104 
instance C_Small Ent107 Ent69 where
    _small = Small_107 []
    small_  = Small_107 
instance C_Small Ent108 Ent69 where
    _small = Small_108 []
    small_  = Small_108 
instance C_Small Ent113 Ent113 where
    _small = Small_113 []
    small_  = Small_113 
instance C_Small Ent115 Ent113 where
    _small = Small_115 []
    small_  = Small_115 
instance C_Small Ent118 Ent113 where
    _small = Small_118 []
    small_  = Small_118 
instance C_Small Ent120 Ent113 where
    _small = Small_120 []
    small_  = Small_120 
instance C_Small Ent125 Ent113 where
    _small = Small_125 []
    small_  = Small_125 
instance C_Small Ent129 Ent113 where
    _small = Small_129 []
    small_  = Small_129 
instance C_Small Ent132 Ent5 where
    _small = Small_132 []
    small_  = Small_132 
instance C_Small Ent133 Ent5 where
    _small = Small_133 []
    small_  = Small_133 

class C_U a b | a -> b where
    _u :: [b] -> a
    u_ :: [Att10] -> [b] -> a
instance C_U Ent3 Ent5 where
    _u = U_3 []
    u_  = U_3 
instance C_U Ent4 Ent5 where
    _u = U_4 []
    u_  = U_4 
instance C_U Ent5 Ent5 where
    _u = U_5 []
    u_  = U_5 
instance C_U Ent8 Ent5 where
    _u = U_8 []
    u_  = U_8 
instance C_U Ent9 Ent5 where
    _u = U_9 []
    u_  = U_9 
instance C_U Ent10 Ent10 where
    _u = U_10 []
    u_  = U_10 
instance C_U Ent12 Ent10 where
    _u = U_12 []
    u_  = U_12 
instance C_U Ent15 Ent10 where
    _u = U_15 []
    u_  = U_15 
instance C_U Ent16 Ent10 where
    _u = U_16 []
    u_  = U_16 
instance C_U Ent17 Ent18 where
    _u = U_17 []
    u_  = U_17 
instance C_U Ent18 Ent18 where
    _u = U_18 []
    u_  = U_18 
instance C_U Ent21 Ent18 where
    _u = U_21 []
    u_  = U_21 
instance C_U Ent22 Ent18 where
    _u = U_22 []
    u_  = U_22 
instance C_U Ent23 Ent18 where
    _u = U_23 []
    u_  = U_23 
instance C_U Ent28 Ent10 where
    _u = U_28 []
    u_  = U_28 
instance C_U Ent33 Ent10 where
    _u = U_33 []
    u_  = U_33 
instance C_U Ent35 Ent35 where
    _u = U_35 []
    u_  = U_35 
instance C_U Ent37 Ent35 where
    _u = U_37 []
    u_  = U_37 
instance C_U Ent40 Ent35 where
    _u = U_40 []
    u_  = U_40 
instance C_U Ent41 Ent35 where
    _u = U_41 []
    u_  = U_41 
instance C_U Ent42 Ent43 where
    _u = U_42 []
    u_  = U_42 
instance C_U Ent43 Ent43 where
    _u = U_43 []
    u_  = U_43 
instance C_U Ent46 Ent43 where
    _u = U_46 []
    u_  = U_46 
instance C_U Ent47 Ent43 where
    _u = U_47 []
    u_  = U_47 
instance C_U Ent48 Ent43 where
    _u = U_48 []
    u_  = U_48 
instance C_U Ent53 Ent35 where
    _u = U_53 []
    u_  = U_53 
instance C_U Ent58 Ent35 where
    _u = U_58 []
    u_  = U_58 
instance C_U Ent62 Ent35 where
    _u = U_62 []
    u_  = U_62 
instance C_U Ent65 Ent10 where
    _u = U_65 []
    u_  = U_65 
instance C_U Ent67 Ent69 where
    _u = U_67 []
    u_  = U_67 
instance C_U Ent69 Ent69 where
    _u = U_69 []
    u_  = U_69 
instance C_U Ent72 Ent69 where
    _u = U_72 []
    u_  = U_72 
instance C_U Ent73 Ent69 where
    _u = U_73 []
    u_  = U_73 
instance C_U Ent75 Ent18 where
    _u = U_75 []
    u_  = U_75 
instance C_U Ent78 Ent43 where
    _u = U_78 []
    u_  = U_78 
instance C_U Ent82 Ent43 where
    _u = U_82 []
    u_  = U_82 
instance C_U Ent85 Ent18 where
    _u = U_85 []
    u_  = U_85 
instance C_U Ent86 Ent69 where
    _u = U_86 []
    u_  = U_86 
instance C_U Ent88 Ent88 where
    _u = U_88 []
    u_  = U_88 
instance C_U Ent90 Ent88 where
    _u = U_90 []
    u_  = U_90 
instance C_U Ent93 Ent88 where
    _u = U_93 []
    u_  = U_93 
instance C_U Ent94 Ent88 where
    _u = U_94 []
    u_  = U_94 
instance C_U Ent95 Ent88 where
    _u = U_95 []
    u_  = U_95 
instance C_U Ent100 Ent88 where
    _u = U_100 []
    u_  = U_100 
instance C_U Ent104 Ent88 where
    _u = U_104 []
    u_  = U_104 
instance C_U Ent107 Ent69 where
    _u = U_107 []
    u_  = U_107 
instance C_U Ent108 Ent69 where
    _u = U_108 []
    u_  = U_108 
instance C_U Ent113 Ent113 where
    _u = U_113 []
    u_  = U_113 
instance C_U Ent115 Ent113 where
    _u = U_115 []
    u_  = U_115 
instance C_U Ent118 Ent113 where
    _u = U_118 []
    u_  = U_118 
instance C_U Ent119 Ent113 where
    _u = U_119 []
    u_  = U_119 
instance C_U Ent120 Ent113 where
    _u = U_120 []
    u_  = U_120 
instance C_U Ent125 Ent113 where
    _u = U_125 []
    u_  = U_125 
instance C_U Ent129 Ent113 where
    _u = U_129 []
    u_  = U_129 
instance C_U Ent132 Ent5 where
    _u = U_132 []
    u_  = U_132 
instance C_U Ent133 Ent5 where
    _u = U_133 []
    u_  = U_133 

class C_S a b | a -> b where
    _s :: [b] -> a
    s_ :: [Att10] -> [b] -> a
instance C_S Ent3 Ent5 where
    _s = S_3 []
    s_  = S_3 
instance C_S Ent4 Ent5 where
    _s = S_4 []
    s_  = S_4 
instance C_S Ent5 Ent5 where
    _s = S_5 []
    s_  = S_5 
instance C_S Ent8 Ent5 where
    _s = S_8 []
    s_  = S_8 
instance C_S Ent9 Ent5 where
    _s = S_9 []
    s_  = S_9 
instance C_S Ent10 Ent10 where
    _s = S_10 []
    s_  = S_10 
instance C_S Ent12 Ent10 where
    _s = S_12 []
    s_  = S_12 
instance C_S Ent15 Ent10 where
    _s = S_15 []
    s_  = S_15 
instance C_S Ent16 Ent10 where
    _s = S_16 []
    s_  = S_16 
instance C_S Ent17 Ent18 where
    _s = S_17 []
    s_  = S_17 
instance C_S Ent18 Ent18 where
    _s = S_18 []
    s_  = S_18 
instance C_S Ent21 Ent18 where
    _s = S_21 []
    s_  = S_21 
instance C_S Ent22 Ent18 where
    _s = S_22 []
    s_  = S_22 
instance C_S Ent23 Ent18 where
    _s = S_23 []
    s_  = S_23 
instance C_S Ent28 Ent10 where
    _s = S_28 []
    s_  = S_28 
instance C_S Ent33 Ent10 where
    _s = S_33 []
    s_  = S_33 
instance C_S Ent35 Ent35 where
    _s = S_35 []
    s_  = S_35 
instance C_S Ent37 Ent35 where
    _s = S_37 []
    s_  = S_37 
instance C_S Ent40 Ent35 where
    _s = S_40 []
    s_  = S_40 
instance C_S Ent41 Ent35 where
    _s = S_41 []
    s_  = S_41 
instance C_S Ent42 Ent43 where
    _s = S_42 []
    s_  = S_42 
instance C_S Ent43 Ent43 where
    _s = S_43 []
    s_  = S_43 
instance C_S Ent46 Ent43 where
    _s = S_46 []
    s_  = S_46 
instance C_S Ent47 Ent43 where
    _s = S_47 []
    s_  = S_47 
instance C_S Ent48 Ent43 where
    _s = S_48 []
    s_  = S_48 
instance C_S Ent53 Ent35 where
    _s = S_53 []
    s_  = S_53 
instance C_S Ent58 Ent35 where
    _s = S_58 []
    s_  = S_58 
instance C_S Ent62 Ent35 where
    _s = S_62 []
    s_  = S_62 
instance C_S Ent65 Ent10 where
    _s = S_65 []
    s_  = S_65 
instance C_S Ent67 Ent69 where
    _s = S_67 []
    s_  = S_67 
instance C_S Ent69 Ent69 where
    _s = S_69 []
    s_  = S_69 
instance C_S Ent72 Ent69 where
    _s = S_72 []
    s_  = S_72 
instance C_S Ent73 Ent69 where
    _s = S_73 []
    s_  = S_73 
instance C_S Ent75 Ent18 where
    _s = S_75 []
    s_  = S_75 
instance C_S Ent78 Ent43 where
    _s = S_78 []
    s_  = S_78 
instance C_S Ent82 Ent43 where
    _s = S_82 []
    s_  = S_82 
instance C_S Ent85 Ent18 where
    _s = S_85 []
    s_  = S_85 
instance C_S Ent86 Ent69 where
    _s = S_86 []
    s_  = S_86 
instance C_S Ent88 Ent88 where
    _s = S_88 []
    s_  = S_88 
instance C_S Ent90 Ent88 where
    _s = S_90 []
    s_  = S_90 
instance C_S Ent93 Ent88 where
    _s = S_93 []
    s_  = S_93 
instance C_S Ent94 Ent88 where
    _s = S_94 []
    s_  = S_94 
instance C_S Ent95 Ent88 where
    _s = S_95 []
    s_  = S_95 
instance C_S Ent100 Ent88 where
    _s = S_100 []
    s_  = S_100 
instance C_S Ent104 Ent88 where
    _s = S_104 []
    s_  = S_104 
instance C_S Ent107 Ent69 where
    _s = S_107 []
    s_  = S_107 
instance C_S Ent108 Ent69 where
    _s = S_108 []
    s_  = S_108 
instance C_S Ent113 Ent113 where
    _s = S_113 []
    s_  = S_113 
instance C_S Ent115 Ent113 where
    _s = S_115 []
    s_  = S_115 
instance C_S Ent118 Ent113 where
    _s = S_118 []
    s_  = S_118 
instance C_S Ent119 Ent113 where
    _s = S_119 []
    s_  = S_119 
instance C_S Ent120 Ent113 where
    _s = S_120 []
    s_  = S_120 
instance C_S Ent125 Ent113 where
    _s = S_125 []
    s_  = S_125 
instance C_S Ent129 Ent113 where
    _s = S_129 []
    s_  = S_129 
instance C_S Ent132 Ent5 where
    _s = S_132 []
    s_  = S_132 
instance C_S Ent133 Ent5 where
    _s = S_133 []
    s_  = S_133 

class C_Strike a b | a -> b where
    _strike :: [b] -> a
    strike_ :: [Att10] -> [b] -> a
instance C_Strike Ent3 Ent5 where
    _strike = Strike_3 []
    strike_  = Strike_3 
instance C_Strike Ent4 Ent5 where
    _strike = Strike_4 []
    strike_  = Strike_4 
instance C_Strike Ent5 Ent5 where
    _strike = Strike_5 []
    strike_  = Strike_5 
instance C_Strike Ent8 Ent5 where
    _strike = Strike_8 []
    strike_  = Strike_8 
instance C_Strike Ent9 Ent5 where
    _strike = Strike_9 []
    strike_  = Strike_9 
instance C_Strike Ent10 Ent10 where
    _strike = Strike_10 []
    strike_  = Strike_10 
instance C_Strike Ent12 Ent10 where
    _strike = Strike_12 []
    strike_  = Strike_12 
instance C_Strike Ent15 Ent10 where
    _strike = Strike_15 []
    strike_  = Strike_15 
instance C_Strike Ent16 Ent10 where
    _strike = Strike_16 []
    strike_  = Strike_16 
instance C_Strike Ent17 Ent18 where
    _strike = Strike_17 []
    strike_  = Strike_17 
instance C_Strike Ent18 Ent18 where
    _strike = Strike_18 []
    strike_  = Strike_18 
instance C_Strike Ent21 Ent18 where
    _strike = Strike_21 []
    strike_  = Strike_21 
instance C_Strike Ent22 Ent18 where
    _strike = Strike_22 []
    strike_  = Strike_22 
instance C_Strike Ent23 Ent18 where
    _strike = Strike_23 []
    strike_  = Strike_23 
instance C_Strike Ent28 Ent10 where
    _strike = Strike_28 []
    strike_  = Strike_28 
instance C_Strike Ent33 Ent10 where
    _strike = Strike_33 []
    strike_  = Strike_33 
instance C_Strike Ent35 Ent35 where
    _strike = Strike_35 []
    strike_  = Strike_35 
instance C_Strike Ent37 Ent35 where
    _strike = Strike_37 []
    strike_  = Strike_37 
instance C_Strike Ent40 Ent35 where
    _strike = Strike_40 []
    strike_  = Strike_40 
instance C_Strike Ent41 Ent35 where
    _strike = Strike_41 []
    strike_  = Strike_41 
instance C_Strike Ent42 Ent43 where
    _strike = Strike_42 []
    strike_  = Strike_42 
instance C_Strike Ent43 Ent43 where
    _strike = Strike_43 []
    strike_  = Strike_43 
instance C_Strike Ent46 Ent43 where
    _strike = Strike_46 []
    strike_  = Strike_46 
instance C_Strike Ent47 Ent43 where
    _strike = Strike_47 []
    strike_  = Strike_47 
instance C_Strike Ent48 Ent43 where
    _strike = Strike_48 []
    strike_  = Strike_48 
instance C_Strike Ent53 Ent35 where
    _strike = Strike_53 []
    strike_  = Strike_53 
instance C_Strike Ent58 Ent35 where
    _strike = Strike_58 []
    strike_  = Strike_58 
instance C_Strike Ent62 Ent35 where
    _strike = Strike_62 []
    strike_  = Strike_62 
instance C_Strike Ent65 Ent10 where
    _strike = Strike_65 []
    strike_  = Strike_65 
instance C_Strike Ent67 Ent69 where
    _strike = Strike_67 []
    strike_  = Strike_67 
instance C_Strike Ent69 Ent69 where
    _strike = Strike_69 []
    strike_  = Strike_69 
instance C_Strike Ent72 Ent69 where
    _strike = Strike_72 []
    strike_  = Strike_72 
instance C_Strike Ent73 Ent69 where
    _strike = Strike_73 []
    strike_  = Strike_73 
instance C_Strike Ent75 Ent18 where
    _strike = Strike_75 []
    strike_  = Strike_75 
instance C_Strike Ent78 Ent43 where
    _strike = Strike_78 []
    strike_  = Strike_78 
instance C_Strike Ent82 Ent43 where
    _strike = Strike_82 []
    strike_  = Strike_82 
instance C_Strike Ent85 Ent18 where
    _strike = Strike_85 []
    strike_  = Strike_85 
instance C_Strike Ent86 Ent69 where
    _strike = Strike_86 []
    strike_  = Strike_86 
instance C_Strike Ent88 Ent88 where
    _strike = Strike_88 []
    strike_  = Strike_88 
instance C_Strike Ent90 Ent88 where
    _strike = Strike_90 []
    strike_  = Strike_90 
instance C_Strike Ent93 Ent88 where
    _strike = Strike_93 []
    strike_  = Strike_93 
instance C_Strike Ent94 Ent88 where
    _strike = Strike_94 []
    strike_  = Strike_94 
instance C_Strike Ent95 Ent88 where
    _strike = Strike_95 []
    strike_  = Strike_95 
instance C_Strike Ent100 Ent88 where
    _strike = Strike_100 []
    strike_  = Strike_100 
instance C_Strike Ent104 Ent88 where
    _strike = Strike_104 []
    strike_  = Strike_104 
instance C_Strike Ent107 Ent69 where
    _strike = Strike_107 []
    strike_  = Strike_107 
instance C_Strike Ent108 Ent69 where
    _strike = Strike_108 []
    strike_  = Strike_108 
instance C_Strike Ent113 Ent113 where
    _strike = Strike_113 []
    strike_  = Strike_113 
instance C_Strike Ent115 Ent113 where
    _strike = Strike_115 []
    strike_  = Strike_115 
instance C_Strike Ent118 Ent113 where
    _strike = Strike_118 []
    strike_  = Strike_118 
instance C_Strike Ent119 Ent113 where
    _strike = Strike_119 []
    strike_  = Strike_119 
instance C_Strike Ent120 Ent113 where
    _strike = Strike_120 []
    strike_  = Strike_120 
instance C_Strike Ent125 Ent113 where
    _strike = Strike_125 []
    strike_  = Strike_125 
instance C_Strike Ent129 Ent113 where
    _strike = Strike_129 []
    strike_  = Strike_129 
instance C_Strike Ent132 Ent5 where
    _strike = Strike_132 []
    strike_  = Strike_132 
instance C_Strike Ent133 Ent5 where
    _strike = Strike_133 []
    strike_  = Strike_133 

class C_Basefont a where
    _basefont :: a
    basefont_ :: [Att26] -> a
instance C_Basefont Ent3 where
    _basefont = Basefont_3 []
    basefont_ = Basefont_3 
instance C_Basefont Ent4 where
    _basefont = Basefont_4 []
    basefont_ = Basefont_4 
instance C_Basefont Ent5 where
    _basefont = Basefont_5 []
    basefont_ = Basefont_5 
instance C_Basefont Ent8 where
    _basefont = Basefont_8 []
    basefont_ = Basefont_8 
instance C_Basefont Ent10 where
    _basefont = Basefont_10 []
    basefont_ = Basefont_10 
instance C_Basefont Ent12 where
    _basefont = Basefont_12 []
    basefont_ = Basefont_12 
instance C_Basefont Ent15 where
    _basefont = Basefont_15 []
    basefont_ = Basefont_15 
instance C_Basefont Ent17 where
    _basefont = Basefont_17 []
    basefont_ = Basefont_17 
instance C_Basefont Ent18 where
    _basefont = Basefont_18 []
    basefont_ = Basefont_18 
instance C_Basefont Ent21 where
    _basefont = Basefont_21 []
    basefont_ = Basefont_21 
instance C_Basefont Ent23 where
    _basefont = Basefont_23 []
    basefont_ = Basefont_23 
instance C_Basefont Ent28 where
    _basefont = Basefont_28 []
    basefont_ = Basefont_28 
instance C_Basefont Ent33 where
    _basefont = Basefont_33 []
    basefont_ = Basefont_33 
instance C_Basefont Ent35 where
    _basefont = Basefont_35 []
    basefont_ = Basefont_35 
instance C_Basefont Ent37 where
    _basefont = Basefont_37 []
    basefont_ = Basefont_37 
instance C_Basefont Ent40 where
    _basefont = Basefont_40 []
    basefont_ = Basefont_40 
instance C_Basefont Ent42 where
    _basefont = Basefont_42 []
    basefont_ = Basefont_42 
instance C_Basefont Ent43 where
    _basefont = Basefont_43 []
    basefont_ = Basefont_43 
instance C_Basefont Ent46 where
    _basefont = Basefont_46 []
    basefont_ = Basefont_46 
instance C_Basefont Ent48 where
    _basefont = Basefont_48 []
    basefont_ = Basefont_48 
instance C_Basefont Ent53 where
    _basefont = Basefont_53 []
    basefont_ = Basefont_53 
instance C_Basefont Ent58 where
    _basefont = Basefont_58 []
    basefont_ = Basefont_58 
instance C_Basefont Ent62 where
    _basefont = Basefont_62 []
    basefont_ = Basefont_62 
instance C_Basefont Ent65 where
    _basefont = Basefont_65 []
    basefont_ = Basefont_65 
instance C_Basefont Ent67 where
    _basefont = Basefont_67 []
    basefont_ = Basefont_67 
instance C_Basefont Ent69 where
    _basefont = Basefont_69 []
    basefont_ = Basefont_69 
instance C_Basefont Ent72 where
    _basefont = Basefont_72 []
    basefont_ = Basefont_72 
instance C_Basefont Ent75 where
    _basefont = Basefont_75 []
    basefont_ = Basefont_75 
instance C_Basefont Ent78 where
    _basefont = Basefont_78 []
    basefont_ = Basefont_78 
instance C_Basefont Ent82 where
    _basefont = Basefont_82 []
    basefont_ = Basefont_82 
instance C_Basefont Ent85 where
    _basefont = Basefont_85 []
    basefont_ = Basefont_85 
instance C_Basefont Ent86 where
    _basefont = Basefont_86 []
    basefont_ = Basefont_86 
instance C_Basefont Ent88 where
    _basefont = Basefont_88 []
    basefont_ = Basefont_88 
instance C_Basefont Ent90 where
    _basefont = Basefont_90 []
    basefont_ = Basefont_90 
instance C_Basefont Ent93 where
    _basefont = Basefont_93 []
    basefont_ = Basefont_93 
instance C_Basefont Ent95 where
    _basefont = Basefont_95 []
    basefont_ = Basefont_95 
instance C_Basefont Ent100 where
    _basefont = Basefont_100 []
    basefont_ = Basefont_100 
instance C_Basefont Ent104 where
    _basefont = Basefont_104 []
    basefont_ = Basefont_104 
instance C_Basefont Ent107 where
    _basefont = Basefont_107 []
    basefont_ = Basefont_107 
instance C_Basefont Ent108 where
    _basefont = Basefont_108 []
    basefont_ = Basefont_108 
instance C_Basefont Ent113 where
    _basefont = Basefont_113 []
    basefont_ = Basefont_113 
instance C_Basefont Ent115 where
    _basefont = Basefont_115 []
    basefont_ = Basefont_115 
instance C_Basefont Ent118 where
    _basefont = Basefont_118 []
    basefont_ = Basefont_118 
instance C_Basefont Ent120 where
    _basefont = Basefont_120 []
    basefont_ = Basefont_120 
instance C_Basefont Ent125 where
    _basefont = Basefont_125 []
    basefont_ = Basefont_125 
instance C_Basefont Ent129 where
    _basefont = Basefont_129 []
    basefont_ = Basefont_129 
instance C_Basefont Ent132 where
    _basefont = Basefont_132 []
    basefont_ = Basefont_132 
instance C_Basefont Ent133 where
    _basefont = Basefont_133 []
    basefont_ = Basefont_133 

class C_Font a b | a -> b where
    _font :: [b] -> a
    font_ :: [Att28] -> [b] -> a
instance C_Font Ent3 Ent5 where
    _font = Font_3 []
    font_  = Font_3 
instance C_Font Ent4 Ent5 where
    _font = Font_4 []
    font_  = Font_4 
instance C_Font Ent5 Ent5 where
    _font = Font_5 []
    font_  = Font_5 
instance C_Font Ent8 Ent5 where
    _font = Font_8 []
    font_  = Font_8 
instance C_Font Ent10 Ent10 where
    _font = Font_10 []
    font_  = Font_10 
instance C_Font Ent12 Ent10 where
    _font = Font_12 []
    font_  = Font_12 
instance C_Font Ent15 Ent10 where
    _font = Font_15 []
    font_  = Font_15 
instance C_Font Ent17 Ent18 where
    _font = Font_17 []
    font_  = Font_17 
instance C_Font Ent18 Ent18 where
    _font = Font_18 []
    font_  = Font_18 
instance C_Font Ent21 Ent18 where
    _font = Font_21 []
    font_  = Font_21 
instance C_Font Ent23 Ent18 where
    _font = Font_23 []
    font_  = Font_23 
instance C_Font Ent28 Ent10 where
    _font = Font_28 []
    font_  = Font_28 
instance C_Font Ent33 Ent10 where
    _font = Font_33 []
    font_  = Font_33 
instance C_Font Ent35 Ent35 where
    _font = Font_35 []
    font_  = Font_35 
instance C_Font Ent37 Ent35 where
    _font = Font_37 []
    font_  = Font_37 
instance C_Font Ent40 Ent35 where
    _font = Font_40 []
    font_  = Font_40 
instance C_Font Ent42 Ent43 where
    _font = Font_42 []
    font_  = Font_42 
instance C_Font Ent43 Ent43 where
    _font = Font_43 []
    font_  = Font_43 
instance C_Font Ent46 Ent43 where
    _font = Font_46 []
    font_  = Font_46 
instance C_Font Ent48 Ent43 where
    _font = Font_48 []
    font_  = Font_48 
instance C_Font Ent53 Ent35 where
    _font = Font_53 []
    font_  = Font_53 
instance C_Font Ent58 Ent35 where
    _font = Font_58 []
    font_  = Font_58 
instance C_Font Ent62 Ent35 where
    _font = Font_62 []
    font_  = Font_62 
instance C_Font Ent65 Ent10 where
    _font = Font_65 []
    font_  = Font_65 
instance C_Font Ent67 Ent69 where
    _font = Font_67 []
    font_  = Font_67 
instance C_Font Ent69 Ent69 where
    _font = Font_69 []
    font_  = Font_69 
instance C_Font Ent72 Ent69 where
    _font = Font_72 []
    font_  = Font_72 
instance C_Font Ent75 Ent18 where
    _font = Font_75 []
    font_  = Font_75 
instance C_Font Ent78 Ent43 where
    _font = Font_78 []
    font_  = Font_78 
instance C_Font Ent82 Ent43 where
    _font = Font_82 []
    font_  = Font_82 
instance C_Font Ent85 Ent18 where
    _font = Font_85 []
    font_  = Font_85 
instance C_Font Ent86 Ent69 where
    _font = Font_86 []
    font_  = Font_86 
instance C_Font Ent88 Ent88 where
    _font = Font_88 []
    font_  = Font_88 
instance C_Font Ent90 Ent88 where
    _font = Font_90 []
    font_  = Font_90 
instance C_Font Ent93 Ent88 where
    _font = Font_93 []
    font_  = Font_93 
instance C_Font Ent95 Ent88 where
    _font = Font_95 []
    font_  = Font_95 
instance C_Font Ent100 Ent88 where
    _font = Font_100 []
    font_  = Font_100 
instance C_Font Ent104 Ent88 where
    _font = Font_104 []
    font_  = Font_104 
instance C_Font Ent107 Ent69 where
    _font = Font_107 []
    font_  = Font_107 
instance C_Font Ent108 Ent69 where
    _font = Font_108 []
    font_  = Font_108 
instance C_Font Ent113 Ent113 where
    _font = Font_113 []
    font_  = Font_113 
instance C_Font Ent115 Ent113 where
    _font = Font_115 []
    font_  = Font_115 
instance C_Font Ent118 Ent113 where
    _font = Font_118 []
    font_  = Font_118 
instance C_Font Ent120 Ent113 where
    _font = Font_120 []
    font_  = Font_120 
instance C_Font Ent125 Ent113 where
    _font = Font_125 []
    font_  = Font_125 
instance C_Font Ent129 Ent113 where
    _font = Font_129 []
    font_  = Font_129 
instance C_Font Ent132 Ent5 where
    _font = Font_132 []
    font_  = Font_132 
instance C_Font Ent133 Ent5 where
    _font = Font_133 []
    font_  = Font_133 

class C_Object a b | a -> b where
    _object :: [b] -> a
    object_ :: [Att29] -> [b] -> a
instance C_Object Ent1 Ent3 where
    _object = Object_1 []
    object_  = Object_1 
instance C_Object Ent3 Ent3 where
    _object = Object_3 []
    object_  = Object_3 
instance C_Object Ent4 Ent3 where
    _object = Object_4 []
    object_  = Object_4 
instance C_Object Ent5 Ent3 where
    _object = Object_5 []
    object_  = Object_5 
instance C_Object Ent8 Ent3 where
    _object = Object_8 []
    object_  = Object_8 
instance C_Object Ent10 Ent33 where
    _object = Object_10 []
    object_  = Object_10 
instance C_Object Ent12 Ent33 where
    _object = Object_12 []
    object_  = Object_12 
instance C_Object Ent15 Ent33 where
    _object = Object_15 []
    object_  = Object_15 
instance C_Object Ent17 Ent75 where
    _object = Object_17 []
    object_  = Object_17 
instance C_Object Ent18 Ent75 where
    _object = Object_18 []
    object_  = Object_18 
instance C_Object Ent21 Ent75 where
    _object = Object_21 []
    object_  = Object_21 
instance C_Object Ent23 Ent75 where
    _object = Object_23 []
    object_  = Object_23 
instance C_Object Ent28 Ent33 where
    _object = Object_28 []
    object_  = Object_28 
instance C_Object Ent33 Ent33 where
    _object = Object_33 []
    object_  = Object_33 
instance C_Object Ent35 Ent58 where
    _object = Object_35 []
    object_  = Object_35 
instance C_Object Ent37 Ent58 where
    _object = Object_37 []
    object_  = Object_37 
instance C_Object Ent40 Ent58 where
    _object = Object_40 []
    object_  = Object_40 
instance C_Object Ent42 Ent78 where
    _object = Object_42 []
    object_  = Object_42 
instance C_Object Ent43 Ent78 where
    _object = Object_43 []
    object_  = Object_43 
instance C_Object Ent46 Ent78 where
    _object = Object_46 []
    object_  = Object_46 
instance C_Object Ent48 Ent78 where
    _object = Object_48 []
    object_  = Object_48 
instance C_Object Ent53 Ent58 where
    _object = Object_53 []
    object_  = Object_53 
instance C_Object Ent58 Ent58 where
    _object = Object_58 []
    object_  = Object_58 
instance C_Object Ent62 Ent58 where
    _object = Object_62 []
    object_  = Object_62 
instance C_Object Ent65 Ent33 where
    _object = Object_65 []
    object_  = Object_65 
instance C_Object Ent67 Ent86 where
    _object = Object_67 []
    object_  = Object_67 
instance C_Object Ent69 Ent86 where
    _object = Object_69 []
    object_  = Object_69 
instance C_Object Ent72 Ent86 where
    _object = Object_72 []
    object_  = Object_72 
instance C_Object Ent75 Ent75 where
    _object = Object_75 []
    object_  = Object_75 
instance C_Object Ent78 Ent78 where
    _object = Object_78 []
    object_  = Object_78 
instance C_Object Ent82 Ent78 where
    _object = Object_82 []
    object_  = Object_82 
instance C_Object Ent85 Ent75 where
    _object = Object_85 []
    object_  = Object_85 
instance C_Object Ent86 Ent86 where
    _object = Object_86 []
    object_  = Object_86 
instance C_Object Ent88 Ent100 where
    _object = Object_88 []
    object_  = Object_88 
instance C_Object Ent90 Ent100 where
    _object = Object_90 []
    object_  = Object_90 
instance C_Object Ent93 Ent100 where
    _object = Object_93 []
    object_  = Object_93 
instance C_Object Ent95 Ent100 where
    _object = Object_95 []
    object_  = Object_95 
instance C_Object Ent100 Ent100 where
    _object = Object_100 []
    object_  = Object_100 
instance C_Object Ent104 Ent100 where
    _object = Object_104 []
    object_  = Object_104 
instance C_Object Ent107 Ent86 where
    _object = Object_107 []
    object_  = Object_107 
instance C_Object Ent108 Ent86 where
    _object = Object_108 []
    object_  = Object_108 
instance C_Object Ent113 Ent125 where
    _object = Object_113 []
    object_  = Object_113 
instance C_Object Ent115 Ent125 where
    _object = Object_115 []
    object_  = Object_115 
instance C_Object Ent118 Ent125 where
    _object = Object_118 []
    object_  = Object_118 
instance C_Object Ent120 Ent125 where
    _object = Object_120 []
    object_  = Object_120 
instance C_Object Ent125 Ent125 where
    _object = Object_125 []
    object_  = Object_125 
instance C_Object Ent129 Ent125 where
    _object = Object_129 []
    object_  = Object_129 
instance C_Object Ent132 Ent3 where
    _object = Object_132 []
    object_  = Object_132 
instance C_Object Ent133 Ent3 where
    _object = Object_133 []
    object_  = Object_133 

class C_Param a where
    _param :: a
    param_ :: [Att30] -> a
instance C_Param Ent3 where
    _param = Param_3 []
    param_ = Param_3 
instance C_Param Ent33 where
    _param = Param_33 []
    param_ = Param_33 
instance C_Param Ent58 where
    _param = Param_58 []
    param_ = Param_58 
instance C_Param Ent75 where
    _param = Param_75 []
    param_ = Param_75 
instance C_Param Ent78 where
    _param = Param_78 []
    param_ = Param_78 
instance C_Param Ent86 where
    _param = Param_86 []
    param_ = Param_86 
instance C_Param Ent100 where
    _param = Param_100 []
    param_ = Param_100 
instance C_Param Ent125 where
    _param = Param_125 []
    param_ = Param_125 

class C_Applet a b | a -> b where
    _applet :: [b] -> a
    applet_ :: [Att32] -> [b] -> a
instance C_Applet Ent3 Ent3 where
    _applet = Applet_3 []
    applet_  = Applet_3 
instance C_Applet Ent4 Ent3 where
    _applet = Applet_4 []
    applet_  = Applet_4 
instance C_Applet Ent5 Ent3 where
    _applet = Applet_5 []
    applet_  = Applet_5 
instance C_Applet Ent8 Ent3 where
    _applet = Applet_8 []
    applet_  = Applet_8 
instance C_Applet Ent10 Ent33 where
    _applet = Applet_10 []
    applet_  = Applet_10 
instance C_Applet Ent12 Ent33 where
    _applet = Applet_12 []
    applet_  = Applet_12 
instance C_Applet Ent15 Ent33 where
    _applet = Applet_15 []
    applet_  = Applet_15 
instance C_Applet Ent17 Ent75 where
    _applet = Applet_17 []
    applet_  = Applet_17 
instance C_Applet Ent18 Ent75 where
    _applet = Applet_18 []
    applet_  = Applet_18 
instance C_Applet Ent21 Ent75 where
    _applet = Applet_21 []
    applet_  = Applet_21 
instance C_Applet Ent23 Ent75 where
    _applet = Applet_23 []
    applet_  = Applet_23 
instance C_Applet Ent28 Ent33 where
    _applet = Applet_28 []
    applet_  = Applet_28 
instance C_Applet Ent33 Ent33 where
    _applet = Applet_33 []
    applet_  = Applet_33 
instance C_Applet Ent35 Ent58 where
    _applet = Applet_35 []
    applet_  = Applet_35 
instance C_Applet Ent37 Ent58 where
    _applet = Applet_37 []
    applet_  = Applet_37 
instance C_Applet Ent40 Ent58 where
    _applet = Applet_40 []
    applet_  = Applet_40 
instance C_Applet Ent42 Ent78 where
    _applet = Applet_42 []
    applet_  = Applet_42 
instance C_Applet Ent43 Ent78 where
    _applet = Applet_43 []
    applet_  = Applet_43 
instance C_Applet Ent46 Ent78 where
    _applet = Applet_46 []
    applet_  = Applet_46 
instance C_Applet Ent48 Ent78 where
    _applet = Applet_48 []
    applet_  = Applet_48 
instance C_Applet Ent53 Ent58 where
    _applet = Applet_53 []
    applet_  = Applet_53 
instance C_Applet Ent58 Ent58 where
    _applet = Applet_58 []
    applet_  = Applet_58 
instance C_Applet Ent62 Ent58 where
    _applet = Applet_62 []
    applet_  = Applet_62 
instance C_Applet Ent65 Ent33 where
    _applet = Applet_65 []
    applet_  = Applet_65 
instance C_Applet Ent67 Ent86 where
    _applet = Applet_67 []
    applet_  = Applet_67 
instance C_Applet Ent69 Ent86 where
    _applet = Applet_69 []
    applet_  = Applet_69 
instance C_Applet Ent72 Ent86 where
    _applet = Applet_72 []
    applet_  = Applet_72 
instance C_Applet Ent75 Ent75 where
    _applet = Applet_75 []
    applet_  = Applet_75 
instance C_Applet Ent78 Ent78 where
    _applet = Applet_78 []
    applet_  = Applet_78 
instance C_Applet Ent82 Ent78 where
    _applet = Applet_82 []
    applet_  = Applet_82 
instance C_Applet Ent85 Ent75 where
    _applet = Applet_85 []
    applet_  = Applet_85 
instance C_Applet Ent86 Ent86 where
    _applet = Applet_86 []
    applet_  = Applet_86 
instance C_Applet Ent88 Ent100 where
    _applet = Applet_88 []
    applet_  = Applet_88 
instance C_Applet Ent90 Ent100 where
    _applet = Applet_90 []
    applet_  = Applet_90 
instance C_Applet Ent93 Ent100 where
    _applet = Applet_93 []
    applet_  = Applet_93 
instance C_Applet Ent95 Ent100 where
    _applet = Applet_95 []
    applet_  = Applet_95 
instance C_Applet Ent100 Ent100 where
    _applet = Applet_100 []
    applet_  = Applet_100 
instance C_Applet Ent104 Ent100 where
    _applet = Applet_104 []
    applet_  = Applet_104 
instance C_Applet Ent107 Ent86 where
    _applet = Applet_107 []
    applet_  = Applet_107 
instance C_Applet Ent108 Ent86 where
    _applet = Applet_108 []
    applet_  = Applet_108 
instance C_Applet Ent113 Ent125 where
    _applet = Applet_113 []
    applet_  = Applet_113 
instance C_Applet Ent115 Ent125 where
    _applet = Applet_115 []
    applet_  = Applet_115 
instance C_Applet Ent118 Ent125 where
    _applet = Applet_118 []
    applet_  = Applet_118 
instance C_Applet Ent120 Ent125 where
    _applet = Applet_120 []
    applet_  = Applet_120 
instance C_Applet Ent125 Ent125 where
    _applet = Applet_125 []
    applet_  = Applet_125 
instance C_Applet Ent129 Ent125 where
    _applet = Applet_129 []
    applet_  = Applet_129 
instance C_Applet Ent132 Ent3 where
    _applet = Applet_132 []
    applet_  = Applet_132 
instance C_Applet Ent133 Ent3 where
    _applet = Applet_133 []
    applet_  = Applet_133 

class C_Img a where
    _img :: a
    img_ :: [Att35] -> a
instance C_Img Ent3 where
    _img = Img_3 []
    img_ = Img_3 
instance C_Img Ent4 where
    _img = Img_4 []
    img_ = Img_4 
instance C_Img Ent5 where
    _img = Img_5 []
    img_ = Img_5 
instance C_Img Ent8 where
    _img = Img_8 []
    img_ = Img_8 
instance C_Img Ent10 where
    _img = Img_10 []
    img_ = Img_10 
instance C_Img Ent12 where
    _img = Img_12 []
    img_ = Img_12 
instance C_Img Ent15 where
    _img = Img_15 []
    img_ = Img_15 
instance C_Img Ent17 where
    _img = Img_17 []
    img_ = Img_17 
instance C_Img Ent18 where
    _img = Img_18 []
    img_ = Img_18 
instance C_Img Ent21 where
    _img = Img_21 []
    img_ = Img_21 
instance C_Img Ent23 where
    _img = Img_23 []
    img_ = Img_23 
instance C_Img Ent28 where
    _img = Img_28 []
    img_ = Img_28 
instance C_Img Ent33 where
    _img = Img_33 []
    img_ = Img_33 
instance C_Img Ent35 where
    _img = Img_35 []
    img_ = Img_35 
instance C_Img Ent37 where
    _img = Img_37 []
    img_ = Img_37 
instance C_Img Ent40 where
    _img = Img_40 []
    img_ = Img_40 
instance C_Img Ent42 where
    _img = Img_42 []
    img_ = Img_42 
instance C_Img Ent43 where
    _img = Img_43 []
    img_ = Img_43 
instance C_Img Ent46 where
    _img = Img_46 []
    img_ = Img_46 
instance C_Img Ent48 where
    _img = Img_48 []
    img_ = Img_48 
instance C_Img Ent53 where
    _img = Img_53 []
    img_ = Img_53 
instance C_Img Ent58 where
    _img = Img_58 []
    img_ = Img_58 
instance C_Img Ent62 where
    _img = Img_62 []
    img_ = Img_62 
instance C_Img Ent65 where
    _img = Img_65 []
    img_ = Img_65 
instance C_Img Ent67 where
    _img = Img_67 []
    img_ = Img_67 
instance C_Img Ent69 where
    _img = Img_69 []
    img_ = Img_69 
instance C_Img Ent72 where
    _img = Img_72 []
    img_ = Img_72 
instance C_Img Ent75 where
    _img = Img_75 []
    img_ = Img_75 
instance C_Img Ent78 where
    _img = Img_78 []
    img_ = Img_78 
instance C_Img Ent82 where
    _img = Img_82 []
    img_ = Img_82 
instance C_Img Ent85 where
    _img = Img_85 []
    img_ = Img_85 
instance C_Img Ent86 where
    _img = Img_86 []
    img_ = Img_86 
instance C_Img Ent88 where
    _img = Img_88 []
    img_ = Img_88 
instance C_Img Ent90 where
    _img = Img_90 []
    img_ = Img_90 
instance C_Img Ent93 where
    _img = Img_93 []
    img_ = Img_93 
instance C_Img Ent95 where
    _img = Img_95 []
    img_ = Img_95 
instance C_Img Ent100 where
    _img = Img_100 []
    img_ = Img_100 
instance C_Img Ent104 where
    _img = Img_104 []
    img_ = Img_104 
instance C_Img Ent107 where
    _img = Img_107 []
    img_ = Img_107 
instance C_Img Ent108 where
    _img = Img_108 []
    img_ = Img_108 
instance C_Img Ent113 where
    _img = Img_113 []
    img_ = Img_113 
instance C_Img Ent115 where
    _img = Img_115 []
    img_ = Img_115 
instance C_Img Ent118 where
    _img = Img_118 []
    img_ = Img_118 
instance C_Img Ent120 where
    _img = Img_120 []
    img_ = Img_120 
instance C_Img Ent125 where
    _img = Img_125 []
    img_ = Img_125 
instance C_Img Ent129 where
    _img = Img_129 []
    img_ = Img_129 
instance C_Img Ent132 where
    _img = Img_132 []
    img_ = Img_132 
instance C_Img Ent133 where
    _img = Img_133 []
    img_ = Img_133 

class C_Map a b | a -> b where
    _map :: [b] -> a
    map_ :: [Att38] -> [b] -> a
instance C_Map Ent3 Ent66 where
    _map = Map_3 []
    map_  = Map_3 
instance C_Map Ent4 Ent66 where
    _map = Map_4 []
    map_  = Map_4 
instance C_Map Ent5 Ent66 where
    _map = Map_5 []
    map_  = Map_5 
instance C_Map Ent8 Ent66 where
    _map = Map_8 []
    map_  = Map_8 
instance C_Map Ent10 Ent34 where
    _map = Map_10 []
    map_  = Map_10 
instance C_Map Ent12 Ent34 where
    _map = Map_12 []
    map_  = Map_12 
instance C_Map Ent15 Ent34 where
    _map = Map_15 []
    map_  = Map_15 
instance C_Map Ent17 Ent76 where
    _map = Map_17 []
    map_  = Map_17 
instance C_Map Ent18 Ent76 where
    _map = Map_18 []
    map_  = Map_18 
instance C_Map Ent21 Ent76 where
    _map = Map_21 []
    map_  = Map_21 
instance C_Map Ent23 Ent76 where
    _map = Map_23 []
    map_  = Map_23 
instance C_Map Ent28 Ent34 where
    _map = Map_28 []
    map_  = Map_28 
instance C_Map Ent33 Ent34 where
    _map = Map_33 []
    map_  = Map_33 
instance C_Map Ent35 Ent59 where
    _map = Map_35 []
    map_  = Map_35 
instance C_Map Ent37 Ent59 where
    _map = Map_37 []
    map_  = Map_37 
instance C_Map Ent40 Ent59 where
    _map = Map_40 []
    map_  = Map_40 
instance C_Map Ent42 Ent79 where
    _map = Map_42 []
    map_  = Map_42 
instance C_Map Ent43 Ent79 where
    _map = Map_43 []
    map_  = Map_43 
instance C_Map Ent46 Ent79 where
    _map = Map_46 []
    map_  = Map_46 
instance C_Map Ent48 Ent79 where
    _map = Map_48 []
    map_  = Map_48 
instance C_Map Ent53 Ent59 where
    _map = Map_53 []
    map_  = Map_53 
instance C_Map Ent58 Ent59 where
    _map = Map_58 []
    map_  = Map_58 
instance C_Map Ent62 Ent59 where
    _map = Map_62 []
    map_  = Map_62 
instance C_Map Ent65 Ent34 where
    _map = Map_65 []
    map_  = Map_65 
instance C_Map Ent67 Ent87 where
    _map = Map_67 []
    map_  = Map_67 
instance C_Map Ent69 Ent87 where
    _map = Map_69 []
    map_  = Map_69 
instance C_Map Ent72 Ent87 where
    _map = Map_72 []
    map_  = Map_72 
instance C_Map Ent75 Ent76 where
    _map = Map_75 []
    map_  = Map_75 
instance C_Map Ent78 Ent79 where
    _map = Map_78 []
    map_  = Map_78 
instance C_Map Ent82 Ent79 where
    _map = Map_82 []
    map_  = Map_82 
instance C_Map Ent85 Ent76 where
    _map = Map_85 []
    map_  = Map_85 
instance C_Map Ent86 Ent87 where
    _map = Map_86 []
    map_  = Map_86 
instance C_Map Ent88 Ent101 where
    _map = Map_88 []
    map_  = Map_88 
instance C_Map Ent90 Ent101 where
    _map = Map_90 []
    map_  = Map_90 
instance C_Map Ent93 Ent101 where
    _map = Map_93 []
    map_  = Map_93 
instance C_Map Ent95 Ent101 where
    _map = Map_95 []
    map_  = Map_95 
instance C_Map Ent100 Ent101 where
    _map = Map_100 []
    map_  = Map_100 
instance C_Map Ent104 Ent101 where
    _map = Map_104 []
    map_  = Map_104 
instance C_Map Ent107 Ent87 where
    _map = Map_107 []
    map_  = Map_107 
instance C_Map Ent108 Ent87 where
    _map = Map_108 []
    map_  = Map_108 
instance C_Map Ent113 Ent126 where
    _map = Map_113 []
    map_  = Map_113 
instance C_Map Ent115 Ent126 where
    _map = Map_115 []
    map_  = Map_115 
instance C_Map Ent118 Ent126 where
    _map = Map_118 []
    map_  = Map_118 
instance C_Map Ent120 Ent126 where
    _map = Map_120 []
    map_  = Map_120 
instance C_Map Ent125 Ent126 where
    _map = Map_125 []
    map_  = Map_125 
instance C_Map Ent129 Ent126 where
    _map = Map_129 []
    map_  = Map_129 
instance C_Map Ent132 Ent66 where
    _map = Map_132 []
    map_  = Map_132 
instance C_Map Ent133 Ent66 where
    _map = Map_133 []
    map_  = Map_133 

class C_Area a where
    _area :: a
    area_ :: [Att40] -> a
instance C_Area Ent34 where
    _area = Area_34 []
    area_ = Area_34 
instance C_Area Ent59 where
    _area = Area_59 []
    area_ = Area_59 
instance C_Area Ent66 where
    _area = Area_66 []
    area_ = Area_66 
instance C_Area Ent76 where
    _area = Area_76 []
    area_ = Area_76 
instance C_Area Ent79 where
    _area = Area_79 []
    area_ = Area_79 
instance C_Area Ent87 where
    _area = Area_87 []
    area_ = Area_87 
instance C_Area Ent101 where
    _area = Area_101 []
    area_ = Area_101 
instance C_Area Ent126 where
    _area = Area_126 []
    area_ = Area_126 

class C_Form a b | a -> b where
    _form :: [b] -> a
    form_ :: [Att41] -> [b] -> a
instance C_Form Ent3 Ent67 where
    _form = Form_3 []
    form_  = Form_3 
instance C_Form Ent4 Ent67 where
    _form = Form_4 []
    form_  = Form_4 
instance C_Form Ent12 Ent17 where
    _form = Form_12 []
    form_  = Form_12 
instance C_Form Ent28 Ent17 where
    _form = Form_28 []
    form_  = Form_28 
instance C_Form Ent33 Ent17 where
    _form = Form_33 []
    form_  = Form_33 
instance C_Form Ent34 Ent17 where
    _form = Form_34 []
    form_  = Form_34 
instance C_Form Ent37 Ent42 where
    _form = Form_37 []
    form_  = Form_37 
instance C_Form Ent53 Ent42 where
    _form = Form_53 []
    form_  = Form_53 
instance C_Form Ent58 Ent42 where
    _form = Form_58 []
    form_  = Form_58 
instance C_Form Ent59 Ent42 where
    _form = Form_59 []
    form_  = Form_59 
instance C_Form Ent66 Ent67 where
    _form = Form_66 []
    form_  = Form_66 
instance C_Form Ent115 Ent90 where
    _form = Form_115 []
    form_  = Form_115 
instance C_Form Ent120 Ent90 where
    _form = Form_120 []
    form_  = Form_120 
instance C_Form Ent125 Ent90 where
    _form = Form_125 []
    form_  = Form_125 
instance C_Form Ent126 Ent90 where
    _form = Form_126 []
    form_  = Form_126 
instance C_Form Ent132 Ent67 where
    _form = Form_132 []
    form_  = Form_132 

class C_Label a b | a -> b where
    _label :: [b] -> a
    label_ :: [Att43] -> [b] -> a
instance C_Label Ent3 Ent113 where
    _label = Label_3 []
    label_  = Label_3 
instance C_Label Ent4 Ent113 where
    _label = Label_4 []
    label_  = Label_4 
instance C_Label Ent5 Ent113 where
    _label = Label_5 []
    label_  = Label_5 
instance C_Label Ent8 Ent113 where
    _label = Label_8 []
    label_  = Label_8 
instance C_Label Ent9 Ent113 where
    _label = Label_9 []
    label_  = Label_9 
instance C_Label Ent10 Ent35 where
    _label = Label_10 []
    label_  = Label_10 
instance C_Label Ent12 Ent35 where
    _label = Label_12 []
    label_  = Label_12 
instance C_Label Ent15 Ent35 where
    _label = Label_15 []
    label_  = Label_15 
instance C_Label Ent16 Ent35 where
    _label = Label_16 []
    label_  = Label_16 
instance C_Label Ent17 Ent43 where
    _label = Label_17 []
    label_  = Label_17 
instance C_Label Ent18 Ent43 where
    _label = Label_18 []
    label_  = Label_18 
instance C_Label Ent21 Ent43 where
    _label = Label_21 []
    label_  = Label_21 
instance C_Label Ent22 Ent43 where
    _label = Label_22 []
    label_  = Label_22 
instance C_Label Ent23 Ent43 where
    _label = Label_23 []
    label_  = Label_23 
instance C_Label Ent28 Ent35 where
    _label = Label_28 []
    label_  = Label_28 
instance C_Label Ent33 Ent35 where
    _label = Label_33 []
    label_  = Label_33 
instance C_Label Ent67 Ent88 where
    _label = Label_67 []
    label_  = Label_67 
instance C_Label Ent69 Ent88 where
    _label = Label_69 []
    label_  = Label_69 
instance C_Label Ent72 Ent88 where
    _label = Label_72 []
    label_  = Label_72 
instance C_Label Ent73 Ent88 where
    _label = Label_73 []
    label_  = Label_73 
instance C_Label Ent75 Ent43 where
    _label = Label_75 []
    label_  = Label_75 
instance C_Label Ent86 Ent88 where
    _label = Label_86 []
    label_  = Label_86 
instance C_Label Ent107 Ent88 where
    _label = Label_107 []
    label_  = Label_107 
instance C_Label Ent132 Ent113 where
    _label = Label_132 []
    label_  = Label_132 

class C_Input a where
    _input :: a
    input_ :: [Att44] -> a
instance C_Input Ent3 where
    _input = Input_3 []
    input_ = Input_3 
instance C_Input Ent4 where
    _input = Input_4 []
    input_ = Input_4 
instance C_Input Ent5 where
    _input = Input_5 []
    input_ = Input_5 
instance C_Input Ent8 where
    _input = Input_8 []
    input_ = Input_8 
instance C_Input Ent9 where
    _input = Input_9 []
    input_ = Input_9 
instance C_Input Ent10 where
    _input = Input_10 []
    input_ = Input_10 
instance C_Input Ent12 where
    _input = Input_12 []
    input_ = Input_12 
instance C_Input Ent15 where
    _input = Input_15 []
    input_ = Input_15 
instance C_Input Ent16 where
    _input = Input_16 []
    input_ = Input_16 
instance C_Input Ent17 where
    _input = Input_17 []
    input_ = Input_17 
instance C_Input Ent18 where
    _input = Input_18 []
    input_ = Input_18 
instance C_Input Ent21 where
    _input = Input_21 []
    input_ = Input_21 
instance C_Input Ent22 where
    _input = Input_22 []
    input_ = Input_22 
instance C_Input Ent23 where
    _input = Input_23 []
    input_ = Input_23 
instance C_Input Ent28 where
    _input = Input_28 []
    input_ = Input_28 
instance C_Input Ent33 where
    _input = Input_33 []
    input_ = Input_33 
instance C_Input Ent35 where
    _input = Input_35 []
    input_ = Input_35 
instance C_Input Ent37 where
    _input = Input_37 []
    input_ = Input_37 
instance C_Input Ent40 where
    _input = Input_40 []
    input_ = Input_40 
instance C_Input Ent41 where
    _input = Input_41 []
    input_ = Input_41 
instance C_Input Ent42 where
    _input = Input_42 []
    input_ = Input_42 
instance C_Input Ent43 where
    _input = Input_43 []
    input_ = Input_43 
instance C_Input Ent46 where
    _input = Input_46 []
    input_ = Input_46 
instance C_Input Ent47 where
    _input = Input_47 []
    input_ = Input_47 
instance C_Input Ent48 where
    _input = Input_48 []
    input_ = Input_48 
instance C_Input Ent53 where
    _input = Input_53 []
    input_ = Input_53 
instance C_Input Ent58 where
    _input = Input_58 []
    input_ = Input_58 
instance C_Input Ent67 where
    _input = Input_67 []
    input_ = Input_67 
instance C_Input Ent69 where
    _input = Input_69 []
    input_ = Input_69 
instance C_Input Ent72 where
    _input = Input_72 []
    input_ = Input_72 
instance C_Input Ent73 where
    _input = Input_73 []
    input_ = Input_73 
instance C_Input Ent75 where
    _input = Input_75 []
    input_ = Input_75 
instance C_Input Ent78 where
    _input = Input_78 []
    input_ = Input_78 
instance C_Input Ent86 where
    _input = Input_86 []
    input_ = Input_86 
instance C_Input Ent88 where
    _input = Input_88 []
    input_ = Input_88 
instance C_Input Ent90 where
    _input = Input_90 []
    input_ = Input_90 
instance C_Input Ent93 where
    _input = Input_93 []
    input_ = Input_93 
instance C_Input Ent94 where
    _input = Input_94 []
    input_ = Input_94 
instance C_Input Ent95 where
    _input = Input_95 []
    input_ = Input_95 
instance C_Input Ent100 where
    _input = Input_100 []
    input_ = Input_100 
instance C_Input Ent107 where
    _input = Input_107 []
    input_ = Input_107 
instance C_Input Ent113 where
    _input = Input_113 []
    input_ = Input_113 
instance C_Input Ent115 where
    _input = Input_115 []
    input_ = Input_115 
instance C_Input Ent118 where
    _input = Input_118 []
    input_ = Input_118 
instance C_Input Ent119 where
    _input = Input_119 []
    input_ = Input_119 
instance C_Input Ent120 where
    _input = Input_120 []
    input_ = Input_120 
instance C_Input Ent125 where
    _input = Input_125 []
    input_ = Input_125 
instance C_Input Ent132 where
    _input = Input_132 []
    input_ = Input_132 

class C_Select a b | a -> b where
    _select :: [b] -> a
    select_ :: [Att45] -> [b] -> a
instance C_Select Ent3 Ent130 where
    _select = Select_3 []
    select_  = Select_3 
instance C_Select Ent4 Ent130 where
    _select = Select_4 []
    select_  = Select_4 
instance C_Select Ent5 Ent130 where
    _select = Select_5 []
    select_  = Select_5 
instance C_Select Ent8 Ent130 where
    _select = Select_8 []
    select_  = Select_8 
instance C_Select Ent9 Ent130 where
    _select = Select_9 []
    select_  = Select_9 
instance C_Select Ent10 Ent63 where
    _select = Select_10 []
    select_  = Select_10 
instance C_Select Ent12 Ent63 where
    _select = Select_12 []
    select_  = Select_12 
instance C_Select Ent15 Ent63 where
    _select = Select_15 []
    select_  = Select_15 
instance C_Select Ent16 Ent63 where
    _select = Select_16 []
    select_  = Select_16 
instance C_Select Ent17 Ent83 where
    _select = Select_17 []
    select_  = Select_17 
instance C_Select Ent18 Ent83 where
    _select = Select_18 []
    select_  = Select_18 
instance C_Select Ent21 Ent83 where
    _select = Select_21 []
    select_  = Select_21 
instance C_Select Ent22 Ent83 where
    _select = Select_22 []
    select_  = Select_22 
instance C_Select Ent23 Ent83 where
    _select = Select_23 []
    select_  = Select_23 
instance C_Select Ent28 Ent63 where
    _select = Select_28 []
    select_  = Select_28 
instance C_Select Ent33 Ent63 where
    _select = Select_33 []
    select_  = Select_33 
instance C_Select Ent35 Ent60 where
    _select = Select_35 []
    select_  = Select_35 
instance C_Select Ent37 Ent60 where
    _select = Select_37 []
    select_  = Select_37 
instance C_Select Ent40 Ent60 where
    _select = Select_40 []
    select_  = Select_40 
instance C_Select Ent41 Ent60 where
    _select = Select_41 []
    select_  = Select_41 
instance C_Select Ent42 Ent80 where
    _select = Select_42 []
    select_  = Select_42 
instance C_Select Ent43 Ent80 where
    _select = Select_43 []
    select_  = Select_43 
instance C_Select Ent46 Ent80 where
    _select = Select_46 []
    select_  = Select_46 
instance C_Select Ent47 Ent80 where
    _select = Select_47 []
    select_  = Select_47 
instance C_Select Ent48 Ent80 where
    _select = Select_48 []
    select_  = Select_48 
instance C_Select Ent53 Ent60 where
    _select = Select_53 []
    select_  = Select_53 
instance C_Select Ent58 Ent60 where
    _select = Select_58 []
    select_  = Select_58 
instance C_Select Ent67 Ent105 where
    _select = Select_67 []
    select_  = Select_67 
instance C_Select Ent69 Ent105 where
    _select = Select_69 []
    select_  = Select_69 
instance C_Select Ent72 Ent105 where
    _select = Select_72 []
    select_  = Select_72 
instance C_Select Ent73 Ent105 where
    _select = Select_73 []
    select_  = Select_73 
instance C_Select Ent75 Ent83 where
    _select = Select_75 []
    select_  = Select_75 
instance C_Select Ent78 Ent80 where
    _select = Select_78 []
    select_  = Select_78 
instance C_Select Ent86 Ent105 where
    _select = Select_86 []
    select_  = Select_86 
instance C_Select Ent88 Ent102 where
    _select = Select_88 []
    select_  = Select_88 
instance C_Select Ent90 Ent102 where
    _select = Select_90 []
    select_  = Select_90 
instance C_Select Ent93 Ent102 where
    _select = Select_93 []
    select_  = Select_93 
instance C_Select Ent94 Ent102 where
    _select = Select_94 []
    select_  = Select_94 
instance C_Select Ent95 Ent102 where
    _select = Select_95 []
    select_  = Select_95 
instance C_Select Ent100 Ent102 where
    _select = Select_100 []
    select_  = Select_100 
instance C_Select Ent107 Ent105 where
    _select = Select_107 []
    select_  = Select_107 
instance C_Select Ent113 Ent127 where
    _select = Select_113 []
    select_  = Select_113 
instance C_Select Ent115 Ent127 where
    _select = Select_115 []
    select_  = Select_115 
instance C_Select Ent118 Ent127 where
    _select = Select_118 []
    select_  = Select_118 
instance C_Select Ent119 Ent127 where
    _select = Select_119 []
    select_  = Select_119 
instance C_Select Ent120 Ent127 where
    _select = Select_120 []
    select_  = Select_120 
instance C_Select Ent125 Ent127 where
    _select = Select_125 []
    select_  = Select_125 
instance C_Select Ent132 Ent130 where
    _select = Select_132 []
    select_  = Select_132 

class C_Optgroup a b | a -> b where
    _optgroup :: [b] -> a
    optgroup_ :: [Att46] -> [b] -> a
instance C_Optgroup Ent60 Ent61 where
    _optgroup = Optgroup_60 []
    optgroup_  = Optgroup_60 
instance C_Optgroup Ent63 Ent64 where
    _optgroup = Optgroup_63 []
    optgroup_  = Optgroup_63 
instance C_Optgroup Ent80 Ent81 where
    _optgroup = Optgroup_80 []
    optgroup_  = Optgroup_80 
instance C_Optgroup Ent83 Ent84 where
    _optgroup = Optgroup_83 []
    optgroup_  = Optgroup_83 
instance C_Optgroup Ent102 Ent103 where
    _optgroup = Optgroup_102 []
    optgroup_  = Optgroup_102 
instance C_Optgroup Ent105 Ent106 where
    _optgroup = Optgroup_105 []
    optgroup_  = Optgroup_105 
instance C_Optgroup Ent127 Ent128 where
    _optgroup = Optgroup_127 []
    optgroup_  = Optgroup_127 
instance C_Optgroup Ent130 Ent131 where
    _optgroup = Optgroup_130 []
    optgroup_  = Optgroup_130 

class C_Option a b | a -> b where
    _option :: [b] -> a
    option_ :: [Att48] -> [b] -> a
instance C_Option Ent60 Ent36 where
    _option = Option_60 []
    option_  = Option_60 
instance C_Option Ent61 Ent36 where
    _option = Option_61 []
    option_  = Option_61 
instance C_Option Ent63 Ent11 where
    _option = Option_63 []
    option_  = Option_63 
instance C_Option Ent64 Ent11 where
    _option = Option_64 []
    option_  = Option_64 
instance C_Option Ent80 Ent77 where
    _option = Option_80 []
    option_  = Option_80 
instance C_Option Ent81 Ent77 where
    _option = Option_81 []
    option_  = Option_81 
instance C_Option Ent83 Ent74 where
    _option = Option_83 []
    option_  = Option_83 
instance C_Option Ent84 Ent74 where
    _option = Option_84 []
    option_  = Option_84 
instance C_Option Ent102 Ent89 where
    _option = Option_102 []
    option_  = Option_102 
instance C_Option Ent103 Ent89 where
    _option = Option_103 []
    option_  = Option_103 
instance C_Option Ent105 Ent68 where
    _option = Option_105 []
    option_  = Option_105 
instance C_Option Ent106 Ent68 where
    _option = Option_106 []
    option_  = Option_106 
instance C_Option Ent127 Ent114 where
    _option = Option_127 []
    option_  = Option_127 
instance C_Option Ent128 Ent114 where
    _option = Option_128 []
    option_  = Option_128 
instance C_Option Ent130 Ent2 where
    _option = Option_130 []
    option_  = Option_130 
instance C_Option Ent131 Ent2 where
    _option = Option_131 []
    option_  = Option_131 

class C_Textarea a b | a -> b where
    _textarea :: [b] -> a
    textarea_ :: [Att49] -> [b] -> a
instance C_Textarea Ent3 Ent2 where
    _textarea = Textarea_3 []
    textarea_  = Textarea_3 
instance C_Textarea Ent4 Ent2 where
    _textarea = Textarea_4 []
    textarea_  = Textarea_4 
instance C_Textarea Ent5 Ent2 where
    _textarea = Textarea_5 []
    textarea_  = Textarea_5 
instance C_Textarea Ent8 Ent2 where
    _textarea = Textarea_8 []
    textarea_  = Textarea_8 
instance C_Textarea Ent9 Ent2 where
    _textarea = Textarea_9 []
    textarea_  = Textarea_9 
instance C_Textarea Ent10 Ent11 where
    _textarea = Textarea_10 []
    textarea_  = Textarea_10 
instance C_Textarea Ent12 Ent11 where
    _textarea = Textarea_12 []
    textarea_  = Textarea_12 
instance C_Textarea Ent15 Ent11 where
    _textarea = Textarea_15 []
    textarea_  = Textarea_15 
instance C_Textarea Ent16 Ent11 where
    _textarea = Textarea_16 []
    textarea_  = Textarea_16 
instance C_Textarea Ent17 Ent74 where
    _textarea = Textarea_17 []
    textarea_  = Textarea_17 
instance C_Textarea Ent18 Ent74 where
    _textarea = Textarea_18 []
    textarea_  = Textarea_18 
instance C_Textarea Ent21 Ent74 where
    _textarea = Textarea_21 []
    textarea_  = Textarea_21 
instance C_Textarea Ent22 Ent74 where
    _textarea = Textarea_22 []
    textarea_  = Textarea_22 
instance C_Textarea Ent23 Ent74 where
    _textarea = Textarea_23 []
    textarea_  = Textarea_23 
instance C_Textarea Ent28 Ent11 where
    _textarea = Textarea_28 []
    textarea_  = Textarea_28 
instance C_Textarea Ent33 Ent11 where
    _textarea = Textarea_33 []
    textarea_  = Textarea_33 
instance C_Textarea Ent35 Ent36 where
    _textarea = Textarea_35 []
    textarea_  = Textarea_35 
instance C_Textarea Ent37 Ent36 where
    _textarea = Textarea_37 []
    textarea_  = Textarea_37 
instance C_Textarea Ent40 Ent36 where
    _textarea = Textarea_40 []
    textarea_  = Textarea_40 
instance C_Textarea Ent41 Ent36 where
    _textarea = Textarea_41 []
    textarea_  = Textarea_41 
instance C_Textarea Ent42 Ent77 where
    _textarea = Textarea_42 []
    textarea_  = Textarea_42 
instance C_Textarea Ent43 Ent77 where
    _textarea = Textarea_43 []
    textarea_  = Textarea_43 
instance C_Textarea Ent46 Ent77 where
    _textarea = Textarea_46 []
    textarea_  = Textarea_46 
instance C_Textarea Ent47 Ent77 where
    _textarea = Textarea_47 []
    textarea_  = Textarea_47 
instance C_Textarea Ent48 Ent77 where
    _textarea = Textarea_48 []
    textarea_  = Textarea_48 
instance C_Textarea Ent53 Ent36 where
    _textarea = Textarea_53 []
    textarea_  = Textarea_53 
instance C_Textarea Ent58 Ent36 where
    _textarea = Textarea_58 []
    textarea_  = Textarea_58 
instance C_Textarea Ent67 Ent68 where
    _textarea = Textarea_67 []
    textarea_  = Textarea_67 
instance C_Textarea Ent69 Ent68 where
    _textarea = Textarea_69 []
    textarea_  = Textarea_69 
instance C_Textarea Ent72 Ent68 where
    _textarea = Textarea_72 []
    textarea_  = Textarea_72 
instance C_Textarea Ent73 Ent68 where
    _textarea = Textarea_73 []
    textarea_  = Textarea_73 
instance C_Textarea Ent75 Ent74 where
    _textarea = Textarea_75 []
    textarea_  = Textarea_75 
instance C_Textarea Ent78 Ent77 where
    _textarea = Textarea_78 []
    textarea_  = Textarea_78 
instance C_Textarea Ent86 Ent68 where
    _textarea = Textarea_86 []
    textarea_  = Textarea_86 
instance C_Textarea Ent88 Ent89 where
    _textarea = Textarea_88 []
    textarea_  = Textarea_88 
instance C_Textarea Ent90 Ent89 where
    _textarea = Textarea_90 []
    textarea_  = Textarea_90 
instance C_Textarea Ent93 Ent89 where
    _textarea = Textarea_93 []
    textarea_  = Textarea_93 
instance C_Textarea Ent94 Ent89 where
    _textarea = Textarea_94 []
    textarea_  = Textarea_94 
instance C_Textarea Ent95 Ent89 where
    _textarea = Textarea_95 []
    textarea_  = Textarea_95 
instance C_Textarea Ent100 Ent89 where
    _textarea = Textarea_100 []
    textarea_  = Textarea_100 
instance C_Textarea Ent107 Ent68 where
    _textarea = Textarea_107 []
    textarea_  = Textarea_107 
instance C_Textarea Ent113 Ent114 where
    _textarea = Textarea_113 []
    textarea_  = Textarea_113 
instance C_Textarea Ent115 Ent114 where
    _textarea = Textarea_115 []
    textarea_  = Textarea_115 
instance C_Textarea Ent118 Ent114 where
    _textarea = Textarea_118 []
    textarea_  = Textarea_118 
instance C_Textarea Ent119 Ent114 where
    _textarea = Textarea_119 []
    textarea_  = Textarea_119 
instance C_Textarea Ent120 Ent114 where
    _textarea = Textarea_120 []
    textarea_  = Textarea_120 
instance C_Textarea Ent125 Ent114 where
    _textarea = Textarea_125 []
    textarea_  = Textarea_125 
instance C_Textarea Ent132 Ent2 where
    _textarea = Textarea_132 []
    textarea_  = Textarea_132 

class C_Fieldset a b | a -> b where
    _fieldset :: [b] -> a
    fieldset_ :: [Att10] -> [b] -> a
instance C_Fieldset Ent3 Ent132 where
    _fieldset = Fieldset_3 []
    fieldset_  = Fieldset_3 
instance C_Fieldset Ent4 Ent132 where
    _fieldset = Fieldset_4 []
    fieldset_  = Fieldset_4 
instance C_Fieldset Ent12 Ent28 where
    _fieldset = Fieldset_12 []
    fieldset_  = Fieldset_12 
instance C_Fieldset Ent17 Ent23 where
    _fieldset = Fieldset_17 []
    fieldset_  = Fieldset_17 
instance C_Fieldset Ent23 Ent23 where
    _fieldset = Fieldset_23 []
    fieldset_  = Fieldset_23 
instance C_Fieldset Ent28 Ent28 where
    _fieldset = Fieldset_28 []
    fieldset_  = Fieldset_28 
instance C_Fieldset Ent33 Ent28 where
    _fieldset = Fieldset_33 []
    fieldset_  = Fieldset_33 
instance C_Fieldset Ent34 Ent28 where
    _fieldset = Fieldset_34 []
    fieldset_  = Fieldset_34 
instance C_Fieldset Ent37 Ent53 where
    _fieldset = Fieldset_37 []
    fieldset_  = Fieldset_37 
instance C_Fieldset Ent42 Ent48 where
    _fieldset = Fieldset_42 []
    fieldset_  = Fieldset_42 
instance C_Fieldset Ent48 Ent48 where
    _fieldset = Fieldset_48 []
    fieldset_  = Fieldset_48 
instance C_Fieldset Ent53 Ent53 where
    _fieldset = Fieldset_53 []
    fieldset_  = Fieldset_53 
instance C_Fieldset Ent58 Ent53 where
    _fieldset = Fieldset_58 []
    fieldset_  = Fieldset_58 
instance C_Fieldset Ent59 Ent53 where
    _fieldset = Fieldset_59 []
    fieldset_  = Fieldset_59 
instance C_Fieldset Ent66 Ent132 where
    _fieldset = Fieldset_66 []
    fieldset_  = Fieldset_66 
instance C_Fieldset Ent67 Ent107 where
    _fieldset = Fieldset_67 []
    fieldset_  = Fieldset_67 
instance C_Fieldset Ent75 Ent23 where
    _fieldset = Fieldset_75 []
    fieldset_  = Fieldset_75 
instance C_Fieldset Ent76 Ent23 where
    _fieldset = Fieldset_76 []
    fieldset_  = Fieldset_76 
instance C_Fieldset Ent78 Ent48 where
    _fieldset = Fieldset_78 []
    fieldset_  = Fieldset_78 
instance C_Fieldset Ent79 Ent48 where
    _fieldset = Fieldset_79 []
    fieldset_  = Fieldset_79 
instance C_Fieldset Ent86 Ent107 where
    _fieldset = Fieldset_86 []
    fieldset_  = Fieldset_86 
instance C_Fieldset Ent87 Ent107 where
    _fieldset = Fieldset_87 []
    fieldset_  = Fieldset_87 
instance C_Fieldset Ent90 Ent95 where
    _fieldset = Fieldset_90 []
    fieldset_  = Fieldset_90 
instance C_Fieldset Ent95 Ent95 where
    _fieldset = Fieldset_95 []
    fieldset_  = Fieldset_95 
instance C_Fieldset Ent100 Ent95 where
    _fieldset = Fieldset_100 []
    fieldset_  = Fieldset_100 
instance C_Fieldset Ent101 Ent95 where
    _fieldset = Fieldset_101 []
    fieldset_  = Fieldset_101 
instance C_Fieldset Ent107 Ent107 where
    _fieldset = Fieldset_107 []
    fieldset_  = Fieldset_107 
instance C_Fieldset Ent115 Ent120 where
    _fieldset = Fieldset_115 []
    fieldset_  = Fieldset_115 
instance C_Fieldset Ent120 Ent120 where
    _fieldset = Fieldset_120 []
    fieldset_  = Fieldset_120 
instance C_Fieldset Ent125 Ent120 where
    _fieldset = Fieldset_125 []
    fieldset_  = Fieldset_125 
instance C_Fieldset Ent126 Ent120 where
    _fieldset = Fieldset_126 []
    fieldset_  = Fieldset_126 
instance C_Fieldset Ent132 Ent132 where
    _fieldset = Fieldset_132 []
    fieldset_  = Fieldset_132 

class C_Legend a b | a -> b where
    _legend :: [b] -> a
    legend_ :: [Att52] -> [b] -> a
instance C_Legend Ent23 Ent18 where
    _legend = Legend_23 []
    legend_  = Legend_23 
instance C_Legend Ent28 Ent10 where
    _legend = Legend_28 []
    legend_  = Legend_28 
instance C_Legend Ent48 Ent43 where
    _legend = Legend_48 []
    legend_  = Legend_48 
instance C_Legend Ent53 Ent35 where
    _legend = Legend_53 []
    legend_  = Legend_53 
instance C_Legend Ent95 Ent88 where
    _legend = Legend_95 []
    legend_  = Legend_95 
instance C_Legend Ent107 Ent69 where
    _legend = Legend_107 []
    legend_  = Legend_107 
instance C_Legend Ent120 Ent113 where
    _legend = Legend_120 []
    legend_  = Legend_120 
instance C_Legend Ent132 Ent5 where
    _legend = Legend_132 []
    legend_  = Legend_132 

class C_Button a b | a -> b where
    _button :: [b] -> a
    button_ :: [Att53] -> [b] -> a
instance C_Button Ent3 Ent133 where
    _button = Button_3 []
    button_  = Button_3 
instance C_Button Ent4 Ent133 where
    _button = Button_4 []
    button_  = Button_4 
instance C_Button Ent5 Ent133 where
    _button = Button_5 []
    button_  = Button_5 
instance C_Button Ent8 Ent133 where
    _button = Button_8 []
    button_  = Button_8 
instance C_Button Ent9 Ent133 where
    _button = Button_9 []
    button_  = Button_9 
instance C_Button Ent10 Ent65 where
    _button = Button_10 []
    button_  = Button_10 
instance C_Button Ent12 Ent65 where
    _button = Button_12 []
    button_  = Button_12 
instance C_Button Ent15 Ent65 where
    _button = Button_15 []
    button_  = Button_15 
instance C_Button Ent16 Ent65 where
    _button = Button_16 []
    button_  = Button_16 
instance C_Button Ent17 Ent85 where
    _button = Button_17 []
    button_  = Button_17 
instance C_Button Ent18 Ent85 where
    _button = Button_18 []
    button_  = Button_18 
instance C_Button Ent21 Ent85 where
    _button = Button_21 []
    button_  = Button_21 
instance C_Button Ent22 Ent85 where
    _button = Button_22 []
    button_  = Button_22 
instance C_Button Ent23 Ent85 where
    _button = Button_23 []
    button_  = Button_23 
instance C_Button Ent28 Ent65 where
    _button = Button_28 []
    button_  = Button_28 
instance C_Button Ent33 Ent65 where
    _button = Button_33 []
    button_  = Button_33 
instance C_Button Ent35 Ent62 where
    _button = Button_35 []
    button_  = Button_35 
instance C_Button Ent37 Ent62 where
    _button = Button_37 []
    button_  = Button_37 
instance C_Button Ent40 Ent62 where
    _button = Button_40 []
    button_  = Button_40 
instance C_Button Ent41 Ent62 where
    _button = Button_41 []
    button_  = Button_41 
instance C_Button Ent42 Ent82 where
    _button = Button_42 []
    button_  = Button_42 
instance C_Button Ent43 Ent82 where
    _button = Button_43 []
    button_  = Button_43 
instance C_Button Ent46 Ent82 where
    _button = Button_46 []
    button_  = Button_46 
instance C_Button Ent47 Ent82 where
    _button = Button_47 []
    button_  = Button_47 
instance C_Button Ent48 Ent82 where
    _button = Button_48 []
    button_  = Button_48 
instance C_Button Ent53 Ent62 where
    _button = Button_53 []
    button_  = Button_53 
instance C_Button Ent58 Ent62 where
    _button = Button_58 []
    button_  = Button_58 
instance C_Button Ent67 Ent108 where
    _button = Button_67 []
    button_  = Button_67 
instance C_Button Ent69 Ent108 where
    _button = Button_69 []
    button_  = Button_69 
instance C_Button Ent72 Ent108 where
    _button = Button_72 []
    button_  = Button_72 
instance C_Button Ent73 Ent108 where
    _button = Button_73 []
    button_  = Button_73 
instance C_Button Ent75 Ent85 where
    _button = Button_75 []
    button_  = Button_75 
instance C_Button Ent78 Ent82 where
    _button = Button_78 []
    button_  = Button_78 
instance C_Button Ent86 Ent108 where
    _button = Button_86 []
    button_  = Button_86 
instance C_Button Ent88 Ent104 where
    _button = Button_88 []
    button_  = Button_88 
instance C_Button Ent90 Ent104 where
    _button = Button_90 []
    button_  = Button_90 
instance C_Button Ent93 Ent104 where
    _button = Button_93 []
    button_  = Button_93 
instance C_Button Ent94 Ent104 where
    _button = Button_94 []
    button_  = Button_94 
instance C_Button Ent95 Ent104 where
    _button = Button_95 []
    button_  = Button_95 
instance C_Button Ent100 Ent104 where
    _button = Button_100 []
    button_  = Button_100 
instance C_Button Ent107 Ent108 where
    _button = Button_107 []
    button_  = Button_107 
instance C_Button Ent113 Ent129 where
    _button = Button_113 []
    button_  = Button_113 
instance C_Button Ent115 Ent129 where
    _button = Button_115 []
    button_  = Button_115 
instance C_Button Ent118 Ent129 where
    _button = Button_118 []
    button_  = Button_118 
instance C_Button Ent119 Ent129 where
    _button = Button_119 []
    button_  = Button_119 
instance C_Button Ent120 Ent129 where
    _button = Button_120 []
    button_  = Button_120 
instance C_Button Ent125 Ent129 where
    _button = Button_125 []
    button_  = Button_125 
instance C_Button Ent132 Ent133 where
    _button = Button_132 []
    button_  = Button_132 

class C_Isindex a where
    _isindex :: a
    isindex_ :: [Att54] -> a
instance C_Isindex Ent1 where
    _isindex = Isindex_1 []
    isindex_ = Isindex_1 
instance C_Isindex Ent3 where
    _isindex = Isindex_3 []
    isindex_ = Isindex_3 
instance C_Isindex Ent4 where
    _isindex = Isindex_4 []
    isindex_ = Isindex_4 
instance C_Isindex Ent12 where
    _isindex = Isindex_12 []
    isindex_ = Isindex_12 
instance C_Isindex Ent17 where
    _isindex = Isindex_17 []
    isindex_ = Isindex_17 
instance C_Isindex Ent23 where
    _isindex = Isindex_23 []
    isindex_ = Isindex_23 
instance C_Isindex Ent28 where
    _isindex = Isindex_28 []
    isindex_ = Isindex_28 
instance C_Isindex Ent33 where
    _isindex = Isindex_33 []
    isindex_ = Isindex_33 
instance C_Isindex Ent34 where
    _isindex = Isindex_34 []
    isindex_ = Isindex_34 
instance C_Isindex Ent37 where
    _isindex = Isindex_37 []
    isindex_ = Isindex_37 
instance C_Isindex Ent42 where
    _isindex = Isindex_42 []
    isindex_ = Isindex_42 
instance C_Isindex Ent48 where
    _isindex = Isindex_48 []
    isindex_ = Isindex_48 
instance C_Isindex Ent53 where
    _isindex = Isindex_53 []
    isindex_ = Isindex_53 
instance C_Isindex Ent58 where
    _isindex = Isindex_58 []
    isindex_ = Isindex_58 
instance C_Isindex Ent59 where
    _isindex = Isindex_59 []
    isindex_ = Isindex_59 
instance C_Isindex Ent66 where
    _isindex = Isindex_66 []
    isindex_ = Isindex_66 
instance C_Isindex Ent67 where
    _isindex = Isindex_67 []
    isindex_ = Isindex_67 
instance C_Isindex Ent75 where
    _isindex = Isindex_75 []
    isindex_ = Isindex_75 
instance C_Isindex Ent76 where
    _isindex = Isindex_76 []
    isindex_ = Isindex_76 
instance C_Isindex Ent78 where
    _isindex = Isindex_78 []
    isindex_ = Isindex_78 
instance C_Isindex Ent79 where
    _isindex = Isindex_79 []
    isindex_ = Isindex_79 
instance C_Isindex Ent86 where
    _isindex = Isindex_86 []
    isindex_ = Isindex_86 
instance C_Isindex Ent87 where
    _isindex = Isindex_87 []
    isindex_ = Isindex_87 
instance C_Isindex Ent90 where
    _isindex = Isindex_90 []
    isindex_ = Isindex_90 
instance C_Isindex Ent95 where
    _isindex = Isindex_95 []
    isindex_ = Isindex_95 
instance C_Isindex Ent100 where
    _isindex = Isindex_100 []
    isindex_ = Isindex_100 
instance C_Isindex Ent101 where
    _isindex = Isindex_101 []
    isindex_ = Isindex_101 
instance C_Isindex Ent107 where
    _isindex = Isindex_107 []
    isindex_ = Isindex_107 
instance C_Isindex Ent115 where
    _isindex = Isindex_115 []
    isindex_ = Isindex_115 
instance C_Isindex Ent120 where
    _isindex = Isindex_120 []
    isindex_ = Isindex_120 
instance C_Isindex Ent125 where
    _isindex = Isindex_125 []
    isindex_ = Isindex_125 
instance C_Isindex Ent126 where
    _isindex = Isindex_126 []
    isindex_ = Isindex_126 
instance C_Isindex Ent132 where
    _isindex = Isindex_132 []
    isindex_ = Isindex_132 

class C_Table a b | a -> b where
    _table :: [b] -> a
    table_ :: [Att55] -> [b] -> a
instance C_Table Ent3 Ent134 where
    _table = Table_3 []
    table_  = Table_3 
instance C_Table Ent4 Ent134 where
    _table = Table_4 []
    table_  = Table_4 
instance C_Table Ent12 Ent29 where
    _table = Table_12 []
    table_  = Table_12 
instance C_Table Ent17 Ent24 where
    _table = Table_17 []
    table_  = Table_17 
instance C_Table Ent23 Ent24 where
    _table = Table_23 []
    table_  = Table_23 
instance C_Table Ent28 Ent29 where
    _table = Table_28 []
    table_  = Table_28 
instance C_Table Ent33 Ent29 where
    _table = Table_33 []
    table_  = Table_33 
instance C_Table Ent34 Ent29 where
    _table = Table_34 []
    table_  = Table_34 
instance C_Table Ent37 Ent54 where
    _table = Table_37 []
    table_  = Table_37 
instance C_Table Ent42 Ent49 where
    _table = Table_42 []
    table_  = Table_42 
instance C_Table Ent48 Ent49 where
    _table = Table_48 []
    table_  = Table_48 
instance C_Table Ent53 Ent54 where
    _table = Table_53 []
    table_  = Table_53 
instance C_Table Ent58 Ent54 where
    _table = Table_58 []
    table_  = Table_58 
instance C_Table Ent59 Ent54 where
    _table = Table_59 []
    table_  = Table_59 
instance C_Table Ent62 Ent54 where
    _table = Table_62 []
    table_  = Table_62 
instance C_Table Ent65 Ent29 where
    _table = Table_65 []
    table_  = Table_65 
instance C_Table Ent66 Ent134 where
    _table = Table_66 []
    table_  = Table_66 
instance C_Table Ent67 Ent109 where
    _table = Table_67 []
    table_  = Table_67 
instance C_Table Ent75 Ent24 where
    _table = Table_75 []
    table_  = Table_75 
instance C_Table Ent76 Ent24 where
    _table = Table_76 []
    table_  = Table_76 
instance C_Table Ent78 Ent49 where
    _table = Table_78 []
    table_  = Table_78 
instance C_Table Ent79 Ent49 where
    _table = Table_79 []
    table_  = Table_79 
instance C_Table Ent82 Ent49 where
    _table = Table_82 []
    table_  = Table_82 
instance C_Table Ent85 Ent24 where
    _table = Table_85 []
    table_  = Table_85 
instance C_Table Ent86 Ent109 where
    _table = Table_86 []
    table_  = Table_86 
instance C_Table Ent87 Ent109 where
    _table = Table_87 []
    table_  = Table_87 
instance C_Table Ent90 Ent96 where
    _table = Table_90 []
    table_  = Table_90 
instance C_Table Ent95 Ent96 where
    _table = Table_95 []
    table_  = Table_95 
instance C_Table Ent100 Ent96 where
    _table = Table_100 []
    table_  = Table_100 
instance C_Table Ent101 Ent96 where
    _table = Table_101 []
    table_  = Table_101 
instance C_Table Ent104 Ent96 where
    _table = Table_104 []
    table_  = Table_104 
instance C_Table Ent107 Ent109 where
    _table = Table_107 []
    table_  = Table_107 
instance C_Table Ent108 Ent109 where
    _table = Table_108 []
    table_  = Table_108 
instance C_Table Ent115 Ent121 where
    _table = Table_115 []
    table_  = Table_115 
instance C_Table Ent120 Ent121 where
    _table = Table_120 []
    table_  = Table_120 
instance C_Table Ent125 Ent121 where
    _table = Table_125 []
    table_  = Table_125 
instance C_Table Ent126 Ent121 where
    _table = Table_126 []
    table_  = Table_126 
instance C_Table Ent129 Ent121 where
    _table = Table_129 []
    table_  = Table_129 
instance C_Table Ent132 Ent134 where
    _table = Table_132 []
    table_  = Table_132 
instance C_Table Ent133 Ent134 where
    _table = Table_133 []
    table_  = Table_133 

class C_Caption a b | a -> b where
    _caption :: [b] -> a
    caption_ :: [Att13] -> [b] -> a
instance C_Caption Ent24 Ent18 where
    _caption = Caption_24 []
    caption_  = Caption_24 
instance C_Caption Ent29 Ent10 where
    _caption = Caption_29 []
    caption_  = Caption_29 
instance C_Caption Ent49 Ent43 where
    _caption = Caption_49 []
    caption_  = Caption_49 
instance C_Caption Ent54 Ent35 where
    _caption = Caption_54 []
    caption_  = Caption_54 
instance C_Caption Ent96 Ent88 where
    _caption = Caption_96 []
    caption_  = Caption_96 
instance C_Caption Ent109 Ent69 where
    _caption = Caption_109 []
    caption_  = Caption_109 
instance C_Caption Ent121 Ent113 where
    _caption = Caption_121 []
    caption_  = Caption_121 
instance C_Caption Ent134 Ent5 where
    _caption = Caption_134 []
    caption_  = Caption_134 

class C_Thead a b | a -> b where
    _thead :: [b] -> a
    thead_ :: [Att56] -> [b] -> a
instance C_Thead Ent24 Ent25 where
    _thead = Thead_24 []
    thead_  = Thead_24 
instance C_Thead Ent29 Ent30 where
    _thead = Thead_29 []
    thead_  = Thead_29 
instance C_Thead Ent49 Ent50 where
    _thead = Thead_49 []
    thead_  = Thead_49 
instance C_Thead Ent54 Ent55 where
    _thead = Thead_54 []
    thead_  = Thead_54 
instance C_Thead Ent96 Ent97 where
    _thead = Thead_96 []
    thead_  = Thead_96 
instance C_Thead Ent109 Ent110 where
    _thead = Thead_109 []
    thead_  = Thead_109 
instance C_Thead Ent121 Ent122 where
    _thead = Thead_121 []
    thead_  = Thead_121 
instance C_Thead Ent134 Ent135 where
    _thead = Thead_134 []
    thead_  = Thead_134 

class C_Tfoot a b | a -> b where
    _tfoot :: [b] -> a
    tfoot_ :: [Att56] -> [b] -> a
instance C_Tfoot Ent24 Ent25 where
    _tfoot = Tfoot_24 []
    tfoot_  = Tfoot_24 
instance C_Tfoot Ent29 Ent30 where
    _tfoot = Tfoot_29 []
    tfoot_  = Tfoot_29 
instance C_Tfoot Ent49 Ent50 where
    _tfoot = Tfoot_49 []
    tfoot_  = Tfoot_49 
instance C_Tfoot Ent54 Ent55 where
    _tfoot = Tfoot_54 []
    tfoot_  = Tfoot_54 
instance C_Tfoot Ent96 Ent97 where
    _tfoot = Tfoot_96 []
    tfoot_  = Tfoot_96 
instance C_Tfoot Ent109 Ent110 where
    _tfoot = Tfoot_109 []
    tfoot_  = Tfoot_109 
instance C_Tfoot Ent121 Ent122 where
    _tfoot = Tfoot_121 []
    tfoot_  = Tfoot_121 
instance C_Tfoot Ent134 Ent135 where
    _tfoot = Tfoot_134 []
    tfoot_  = Tfoot_134 

class C_Tbody a b | a -> b where
    _tbody :: [b] -> a
    tbody_ :: [Att56] -> [b] -> a
instance C_Tbody Ent24 Ent25 where
    _tbody = Tbody_24 []
    tbody_  = Tbody_24 
instance C_Tbody Ent29 Ent30 where
    _tbody = Tbody_29 []
    tbody_  = Tbody_29 
instance C_Tbody Ent49 Ent50 where
    _tbody = Tbody_49 []
    tbody_  = Tbody_49 
instance C_Tbody Ent54 Ent55 where
    _tbody = Tbody_54 []
    tbody_  = Tbody_54 
instance C_Tbody Ent96 Ent97 where
    _tbody = Tbody_96 []
    tbody_  = Tbody_96 
instance C_Tbody Ent109 Ent110 where
    _tbody = Tbody_109 []
    tbody_  = Tbody_109 
instance C_Tbody Ent121 Ent122 where
    _tbody = Tbody_121 []
    tbody_  = Tbody_121 
instance C_Tbody Ent134 Ent135 where
    _tbody = Tbody_134 []
    tbody_  = Tbody_134 

class C_Colgroup a b | a -> b where
    _colgroup :: [b] -> a
    colgroup_ :: [Att57] -> [b] -> a
instance C_Colgroup Ent24 Ent26 where
    _colgroup = Colgroup_24 []
    colgroup_  = Colgroup_24 
instance C_Colgroup Ent29 Ent31 where
    _colgroup = Colgroup_29 []
    colgroup_  = Colgroup_29 
instance C_Colgroup Ent49 Ent51 where
    _colgroup = Colgroup_49 []
    colgroup_  = Colgroup_49 
instance C_Colgroup Ent54 Ent56 where
    _colgroup = Colgroup_54 []
    colgroup_  = Colgroup_54 
instance C_Colgroup Ent96 Ent98 where
    _colgroup = Colgroup_96 []
    colgroup_  = Colgroup_96 
instance C_Colgroup Ent109 Ent111 where
    _colgroup = Colgroup_109 []
    colgroup_  = Colgroup_109 
instance C_Colgroup Ent121 Ent123 where
    _colgroup = Colgroup_121 []
    colgroup_  = Colgroup_121 
instance C_Colgroup Ent134 Ent136 where
    _colgroup = Colgroup_134 []
    colgroup_  = Colgroup_134 

class C_Col a where
    _col :: a
    col_ :: [Att57] -> a
instance C_Col Ent24 where
    _col = Col_24 []
    col_ = Col_24 
instance C_Col Ent26 where
    _col = Col_26 []
    col_ = Col_26 
instance C_Col Ent29 where
    _col = Col_29 []
    col_ = Col_29 
instance C_Col Ent31 where
    _col = Col_31 []
    col_ = Col_31 
instance C_Col Ent49 where
    _col = Col_49 []
    col_ = Col_49 
instance C_Col Ent51 where
    _col = Col_51 []
    col_ = Col_51 
instance C_Col Ent54 where
    _col = Col_54 []
    col_ = Col_54 
instance C_Col Ent56 where
    _col = Col_56 []
    col_ = Col_56 
instance C_Col Ent96 where
    _col = Col_96 []
    col_ = Col_96 
instance C_Col Ent98 where
    _col = Col_98 []
    col_ = Col_98 
instance C_Col Ent109 where
    _col = Col_109 []
    col_ = Col_109 
instance C_Col Ent111 where
    _col = Col_111 []
    col_ = Col_111 
instance C_Col Ent121 where
    _col = Col_121 []
    col_ = Col_121 
instance C_Col Ent123 where
    _col = Col_123 []
    col_ = Col_123 
instance C_Col Ent134 where
    _col = Col_134 []
    col_ = Col_134 
instance C_Col Ent136 where
    _col = Col_136 []
    col_ = Col_136 

class C_Tr a b | a -> b where
    _tr :: [b] -> a
    tr_ :: [Att58] -> [b] -> a
instance C_Tr Ent24 Ent27 where
    _tr = Tr_24 []
    tr_  = Tr_24 
instance C_Tr Ent25 Ent27 where
    _tr = Tr_25 []
    tr_  = Tr_25 
instance C_Tr Ent29 Ent32 where
    _tr = Tr_29 []
    tr_  = Tr_29 
instance C_Tr Ent30 Ent32 where
    _tr = Tr_30 []
    tr_  = Tr_30 
instance C_Tr Ent49 Ent52 where
    _tr = Tr_49 []
    tr_  = Tr_49 
instance C_Tr Ent50 Ent52 where
    _tr = Tr_50 []
    tr_  = Tr_50 
instance C_Tr Ent54 Ent57 where
    _tr = Tr_54 []
    tr_  = Tr_54 
instance C_Tr Ent55 Ent57 where
    _tr = Tr_55 []
    tr_  = Tr_55 
instance C_Tr Ent96 Ent99 where
    _tr = Tr_96 []
    tr_  = Tr_96 
instance C_Tr Ent97 Ent99 where
    _tr = Tr_97 []
    tr_  = Tr_97 
instance C_Tr Ent109 Ent112 where
    _tr = Tr_109 []
    tr_  = Tr_109 
instance C_Tr Ent110 Ent112 where
    _tr = Tr_110 []
    tr_  = Tr_110 
instance C_Tr Ent121 Ent124 where
    _tr = Tr_121 []
    tr_  = Tr_121 
instance C_Tr Ent122 Ent124 where
    _tr = Tr_122 []
    tr_  = Tr_122 
instance C_Tr Ent134 Ent137 where
    _tr = Tr_134 []
    tr_  = Tr_134 
instance C_Tr Ent135 Ent137 where
    _tr = Tr_135 []
    tr_  = Tr_135 

class C_Th a b | a -> b where
    _th :: [b] -> a
    th_ :: [Att59] -> [b] -> a
instance C_Th Ent27 Ent17 where
    _th = Th_27 []
    th_  = Th_27 
instance C_Th Ent32 Ent12 where
    _th = Th_32 []
    th_  = Th_32 
instance C_Th Ent52 Ent42 where
    _th = Th_52 []
    th_  = Th_52 
instance C_Th Ent57 Ent37 where
    _th = Th_57 []
    th_  = Th_57 
instance C_Th Ent99 Ent90 where
    _th = Th_99 []
    th_  = Th_99 
instance C_Th Ent112 Ent67 where
    _th = Th_112 []
    th_  = Th_112 
instance C_Th Ent124 Ent115 where
    _th = Th_124 []
    th_  = Th_124 
instance C_Th Ent137 Ent4 where
    _th = Th_137 []
    th_  = Th_137 

class C_Td a b | a -> b where
    _td :: [b] -> a
    td_ :: [Att59] -> [b] -> a
instance C_Td Ent27 Ent17 where
    _td = Td_27 []
    td_  = Td_27 
instance C_Td Ent32 Ent12 where
    _td = Td_32 []
    td_  = Td_32 
instance C_Td Ent52 Ent42 where
    _td = Td_52 []
    td_  = Td_52 
instance C_Td Ent57 Ent37 where
    _td = Td_57 []
    td_  = Td_57 
instance C_Td Ent99 Ent90 where
    _td = Td_99 []
    td_  = Td_99 
instance C_Td Ent112 Ent67 where
    _td = Td_112 []
    td_  = Td_112 
instance C_Td Ent124 Ent115 where
    _td = Td_124 []
    td_  = Td_124 
instance C_Td Ent137 Ent4 where
    _td = Td_137 []
    td_  = Td_137 

class C_PCDATA a where
    pcdata :: String -> a
    pcdata_bs :: B.ByteString -> a
    ce_quot :: a
    ce_amp :: a
    ce_lt :: a
    ce_gt :: a
    ce_copy :: a
    ce_reg :: a
    ce_nbsp :: a
instance C_PCDATA Ent2 where
    pcdata s = PCDATA_2 [] (s2b_escape s)
    pcdata_bs = PCDATA_2 []
    ce_quot = PCDATA_2 [] (s2b "&quot;")
    ce_amp = PCDATA_2 [] (s2b "&amp;")
    ce_lt = PCDATA_2 [] (s2b "&lt;")
    ce_gt = PCDATA_2 [] (s2b "&gt;")
    ce_copy = PCDATA_2 [] (s2b "&copy;")
    ce_reg = PCDATA_2 [] (s2b "&reg;")
    ce_nbsp = PCDATA_2 [] (s2b "&nbsp;")
instance C_PCDATA Ent3 where
    pcdata s = PCDATA_3 [] (s2b_escape s)
    pcdata_bs = PCDATA_3 []
    ce_quot = PCDATA_3 [] (s2b "&quot;")
    ce_amp = PCDATA_3 [] (s2b "&amp;")
    ce_lt = PCDATA_3 [] (s2b "&lt;")
    ce_gt = PCDATA_3 [] (s2b "&gt;")
    ce_copy = PCDATA_3 [] (s2b "&copy;")
    ce_reg = PCDATA_3 [] (s2b "&reg;")
    ce_nbsp = PCDATA_3 [] (s2b "&nbsp;")
instance C_PCDATA Ent4 where
    pcdata s = PCDATA_4 [] (s2b_escape s)
    pcdata_bs = PCDATA_4 []
    ce_quot = PCDATA_4 [] (s2b "&quot;")
    ce_amp = PCDATA_4 [] (s2b "&amp;")
    ce_lt = PCDATA_4 [] (s2b "&lt;")
    ce_gt = PCDATA_4 [] (s2b "&gt;")
    ce_copy = PCDATA_4 [] (s2b "&copy;")
    ce_reg = PCDATA_4 [] (s2b "&reg;")
    ce_nbsp = PCDATA_4 [] (s2b "&nbsp;")
instance C_PCDATA Ent5 where
    pcdata s = PCDATA_5 [] (s2b_escape s)
    pcdata_bs = PCDATA_5 []
    ce_quot = PCDATA_5 [] (s2b "&quot;")
    ce_amp = PCDATA_5 [] (s2b "&amp;")
    ce_lt = PCDATA_5 [] (s2b "&lt;")
    ce_gt = PCDATA_5 [] (s2b "&gt;")
    ce_copy = PCDATA_5 [] (s2b "&copy;")
    ce_reg = PCDATA_5 [] (s2b "&reg;")
    ce_nbsp = PCDATA_5 [] (s2b "&nbsp;")
instance C_PCDATA Ent8 where
    pcdata s = PCDATA_8 [] (s2b_escape s)
    pcdata_bs = PCDATA_8 []
    ce_quot = PCDATA_8 [] (s2b "&quot;")
    ce_amp = PCDATA_8 [] (s2b "&amp;")
    ce_lt = PCDATA_8 [] (s2b "&lt;")
    ce_gt = PCDATA_8 [] (s2b "&gt;")
    ce_copy = PCDATA_8 [] (s2b "&copy;")
    ce_reg = PCDATA_8 [] (s2b "&reg;")
    ce_nbsp = PCDATA_8 [] (s2b "&nbsp;")
instance C_PCDATA Ent9 where
    pcdata s = PCDATA_9 [] (s2b_escape s)
    pcdata_bs = PCDATA_9 []
    ce_quot = PCDATA_9 [] (s2b "&quot;")
    ce_amp = PCDATA_9 [] (s2b "&amp;")
    ce_lt = PCDATA_9 [] (s2b "&lt;")
    ce_gt = PCDATA_9 [] (s2b "&gt;")
    ce_copy = PCDATA_9 [] (s2b "&copy;")
    ce_reg = PCDATA_9 [] (s2b "&reg;")
    ce_nbsp = PCDATA_9 [] (s2b "&nbsp;")
instance C_PCDATA Ent10 where
    pcdata s = PCDATA_10 [] (s2b_escape s)
    pcdata_bs = PCDATA_10 []
    ce_quot = PCDATA_10 [] (s2b "&quot;")
    ce_amp = PCDATA_10 [] (s2b "&amp;")
    ce_lt = PCDATA_10 [] (s2b "&lt;")
    ce_gt = PCDATA_10 [] (s2b "&gt;")
    ce_copy = PCDATA_10 [] (s2b "&copy;")
    ce_reg = PCDATA_10 [] (s2b "&reg;")
    ce_nbsp = PCDATA_10 [] (s2b "&nbsp;")
instance C_PCDATA Ent11 where
    pcdata s = PCDATA_11 [] (s2b_escape s)
    pcdata_bs = PCDATA_11 []
    ce_quot = PCDATA_11 [] (s2b "&quot;")
    ce_amp = PCDATA_11 [] (s2b "&amp;")
    ce_lt = PCDATA_11 [] (s2b "&lt;")
    ce_gt = PCDATA_11 [] (s2b "&gt;")
    ce_copy = PCDATA_11 [] (s2b "&copy;")
    ce_reg = PCDATA_11 [] (s2b "&reg;")
    ce_nbsp = PCDATA_11 [] (s2b "&nbsp;")
instance C_PCDATA Ent12 where
    pcdata s = PCDATA_12 [] (s2b_escape s)
    pcdata_bs = PCDATA_12 []
    ce_quot = PCDATA_12 [] (s2b "&quot;")
    ce_amp = PCDATA_12 [] (s2b "&amp;")
    ce_lt = PCDATA_12 [] (s2b "&lt;")
    ce_gt = PCDATA_12 [] (s2b "&gt;")
    ce_copy = PCDATA_12 [] (s2b "&copy;")
    ce_reg = PCDATA_12 [] (s2b "&reg;")
    ce_nbsp = PCDATA_12 [] (s2b "&nbsp;")
instance C_PCDATA Ent15 where
    pcdata s = PCDATA_15 [] (s2b_escape s)
    pcdata_bs = PCDATA_15 []
    ce_quot = PCDATA_15 [] (s2b "&quot;")
    ce_amp = PCDATA_15 [] (s2b "&amp;")
    ce_lt = PCDATA_15 [] (s2b "&lt;")
    ce_gt = PCDATA_15 [] (s2b "&gt;")
    ce_copy = PCDATA_15 [] (s2b "&copy;")
    ce_reg = PCDATA_15 [] (s2b "&reg;")
    ce_nbsp = PCDATA_15 [] (s2b "&nbsp;")
instance C_PCDATA Ent16 where
    pcdata s = PCDATA_16 [] (s2b_escape s)
    pcdata_bs = PCDATA_16 []
    ce_quot = PCDATA_16 [] (s2b "&quot;")
    ce_amp = PCDATA_16 [] (s2b "&amp;")
    ce_lt = PCDATA_16 [] (s2b "&lt;")
    ce_gt = PCDATA_16 [] (s2b "&gt;")
    ce_copy = PCDATA_16 [] (s2b "&copy;")
    ce_reg = PCDATA_16 [] (s2b "&reg;")
    ce_nbsp = PCDATA_16 [] (s2b "&nbsp;")
instance C_PCDATA Ent17 where
    pcdata s = PCDATA_17 [] (s2b_escape s)
    pcdata_bs = PCDATA_17 []
    ce_quot = PCDATA_17 [] (s2b "&quot;")
    ce_amp = PCDATA_17 [] (s2b "&amp;")
    ce_lt = PCDATA_17 [] (s2b "&lt;")
    ce_gt = PCDATA_17 [] (s2b "&gt;")
    ce_copy = PCDATA_17 [] (s2b "&copy;")
    ce_reg = PCDATA_17 [] (s2b "&reg;")
    ce_nbsp = PCDATA_17 [] (s2b "&nbsp;")
instance C_PCDATA Ent18 where
    pcdata s = PCDATA_18 [] (s2b_escape s)
    pcdata_bs = PCDATA_18 []
    ce_quot = PCDATA_18 [] (s2b "&quot;")
    ce_amp = PCDATA_18 [] (s2b "&amp;")
    ce_lt = PCDATA_18 [] (s2b "&lt;")
    ce_gt = PCDATA_18 [] (s2b "&gt;")
    ce_copy = PCDATA_18 [] (s2b "&copy;")
    ce_reg = PCDATA_18 [] (s2b "&reg;")
    ce_nbsp = PCDATA_18 [] (s2b "&nbsp;")
instance C_PCDATA Ent21 where
    pcdata s = PCDATA_21 [] (s2b_escape s)
    pcdata_bs = PCDATA_21 []
    ce_quot = PCDATA_21 [] (s2b "&quot;")
    ce_amp = PCDATA_21 [] (s2b "&amp;")
    ce_lt = PCDATA_21 [] (s2b "&lt;")
    ce_gt = PCDATA_21 [] (s2b "&gt;")
    ce_copy = PCDATA_21 [] (s2b "&copy;")
    ce_reg = PCDATA_21 [] (s2b "&reg;")
    ce_nbsp = PCDATA_21 [] (s2b "&nbsp;")
instance C_PCDATA Ent22 where
    pcdata s = PCDATA_22 [] (s2b_escape s)
    pcdata_bs = PCDATA_22 []
    ce_quot = PCDATA_22 [] (s2b "&quot;")
    ce_amp = PCDATA_22 [] (s2b "&amp;")
    ce_lt = PCDATA_22 [] (s2b "&lt;")
    ce_gt = PCDATA_22 [] (s2b "&gt;")
    ce_copy = PCDATA_22 [] (s2b "&copy;")
    ce_reg = PCDATA_22 [] (s2b "&reg;")
    ce_nbsp = PCDATA_22 [] (s2b "&nbsp;")
instance C_PCDATA Ent23 where
    pcdata s = PCDATA_23 [] (s2b_escape s)
    pcdata_bs = PCDATA_23 []
    ce_quot = PCDATA_23 [] (s2b "&quot;")
    ce_amp = PCDATA_23 [] (s2b "&amp;")
    ce_lt = PCDATA_23 [] (s2b "&lt;")
    ce_gt = PCDATA_23 [] (s2b "&gt;")
    ce_copy = PCDATA_23 [] (s2b "&copy;")
    ce_reg = PCDATA_23 [] (s2b "&reg;")
    ce_nbsp = PCDATA_23 [] (s2b "&nbsp;")
instance C_PCDATA Ent28 where
    pcdata s = PCDATA_28 [] (s2b_escape s)
    pcdata_bs = PCDATA_28 []
    ce_quot = PCDATA_28 [] (s2b "&quot;")
    ce_amp = PCDATA_28 [] (s2b "&amp;")
    ce_lt = PCDATA_28 [] (s2b "&lt;")
    ce_gt = PCDATA_28 [] (s2b "&gt;")
    ce_copy = PCDATA_28 [] (s2b "&copy;")
    ce_reg = PCDATA_28 [] (s2b "&reg;")
    ce_nbsp = PCDATA_28 [] (s2b "&nbsp;")
instance C_PCDATA Ent33 where
    pcdata s = PCDATA_33 [] (s2b_escape s)
    pcdata_bs = PCDATA_33 []
    ce_quot = PCDATA_33 [] (s2b "&quot;")
    ce_amp = PCDATA_33 [] (s2b "&amp;")
    ce_lt = PCDATA_33 [] (s2b "&lt;")
    ce_gt = PCDATA_33 [] (s2b "&gt;")
    ce_copy = PCDATA_33 [] (s2b "&copy;")
    ce_reg = PCDATA_33 [] (s2b "&reg;")
    ce_nbsp = PCDATA_33 [] (s2b "&nbsp;")
instance C_PCDATA Ent35 where
    pcdata s = PCDATA_35 [] (s2b_escape s)
    pcdata_bs = PCDATA_35 []
    ce_quot = PCDATA_35 [] (s2b "&quot;")
    ce_amp = PCDATA_35 [] (s2b "&amp;")
    ce_lt = PCDATA_35 [] (s2b "&lt;")
    ce_gt = PCDATA_35 [] (s2b "&gt;")
    ce_copy = PCDATA_35 [] (s2b "&copy;")
    ce_reg = PCDATA_35 [] (s2b "&reg;")
    ce_nbsp = PCDATA_35 [] (s2b "&nbsp;")
instance C_PCDATA Ent36 where
    pcdata s = PCDATA_36 [] (s2b_escape s)
    pcdata_bs = PCDATA_36 []
    ce_quot = PCDATA_36 [] (s2b "&quot;")
    ce_amp = PCDATA_36 [] (s2b "&amp;")
    ce_lt = PCDATA_36 [] (s2b "&lt;")
    ce_gt = PCDATA_36 [] (s2b "&gt;")
    ce_copy = PCDATA_36 [] (s2b "&copy;")
    ce_reg = PCDATA_36 [] (s2b "&reg;")
    ce_nbsp = PCDATA_36 [] (s2b "&nbsp;")
instance C_PCDATA Ent37 where
    pcdata s = PCDATA_37 [] (s2b_escape s)
    pcdata_bs = PCDATA_37 []
    ce_quot = PCDATA_37 [] (s2b "&quot;")
    ce_amp = PCDATA_37 [] (s2b "&amp;")
    ce_lt = PCDATA_37 [] (s2b "&lt;")
    ce_gt = PCDATA_37 [] (s2b "&gt;")
    ce_copy = PCDATA_37 [] (s2b "&copy;")
    ce_reg = PCDATA_37 [] (s2b "&reg;")
    ce_nbsp = PCDATA_37 [] (s2b "&nbsp;")
instance C_PCDATA Ent40 where
    pcdata s = PCDATA_40 [] (s2b_escape s)
    pcdata_bs = PCDATA_40 []
    ce_quot = PCDATA_40 [] (s2b "&quot;")
    ce_amp = PCDATA_40 [] (s2b "&amp;")
    ce_lt = PCDATA_40 [] (s2b "&lt;")
    ce_gt = PCDATA_40 [] (s2b "&gt;")
    ce_copy = PCDATA_40 [] (s2b "&copy;")
    ce_reg = PCDATA_40 [] (s2b "&reg;")
    ce_nbsp = PCDATA_40 [] (s2b "&nbsp;")
instance C_PCDATA Ent41 where
    pcdata s = PCDATA_41 [] (s2b_escape s)
    pcdata_bs = PCDATA_41 []
    ce_quot = PCDATA_41 [] (s2b "&quot;")
    ce_amp = PCDATA_41 [] (s2b "&amp;")
    ce_lt = PCDATA_41 [] (s2b "&lt;")
    ce_gt = PCDATA_41 [] (s2b "&gt;")
    ce_copy = PCDATA_41 [] (s2b "&copy;")
    ce_reg = PCDATA_41 [] (s2b "&reg;")
    ce_nbsp = PCDATA_41 [] (s2b "&nbsp;")
instance C_PCDATA Ent42 where
    pcdata s = PCDATA_42 [] (s2b_escape s)
    pcdata_bs = PCDATA_42 []
    ce_quot = PCDATA_42 [] (s2b "&quot;")
    ce_amp = PCDATA_42 [] (s2b "&amp;")
    ce_lt = PCDATA_42 [] (s2b "&lt;")
    ce_gt = PCDATA_42 [] (s2b "&gt;")
    ce_copy = PCDATA_42 [] (s2b "&copy;")
    ce_reg = PCDATA_42 [] (s2b "&reg;")
    ce_nbsp = PCDATA_42 [] (s2b "&nbsp;")
instance C_PCDATA Ent43 where
    pcdata s = PCDATA_43 [] (s2b_escape s)
    pcdata_bs = PCDATA_43 []
    ce_quot = PCDATA_43 [] (s2b "&quot;")
    ce_amp = PCDATA_43 [] (s2b "&amp;")
    ce_lt = PCDATA_43 [] (s2b "&lt;")
    ce_gt = PCDATA_43 [] (s2b "&gt;")
    ce_copy = PCDATA_43 [] (s2b "&copy;")
    ce_reg = PCDATA_43 [] (s2b "&reg;")
    ce_nbsp = PCDATA_43 [] (s2b "&nbsp;")
instance C_PCDATA Ent46 where
    pcdata s = PCDATA_46 [] (s2b_escape s)
    pcdata_bs = PCDATA_46 []
    ce_quot = PCDATA_46 [] (s2b "&quot;")
    ce_amp = PCDATA_46 [] (s2b "&amp;")
    ce_lt = PCDATA_46 [] (s2b "&lt;")
    ce_gt = PCDATA_46 [] (s2b "&gt;")
    ce_copy = PCDATA_46 [] (s2b "&copy;")
    ce_reg = PCDATA_46 [] (s2b "&reg;")
    ce_nbsp = PCDATA_46 [] (s2b "&nbsp;")
instance C_PCDATA Ent47 where
    pcdata s = PCDATA_47 [] (s2b_escape s)
    pcdata_bs = PCDATA_47 []
    ce_quot = PCDATA_47 [] (s2b "&quot;")
    ce_amp = PCDATA_47 [] (s2b "&amp;")
    ce_lt = PCDATA_47 [] (s2b "&lt;")
    ce_gt = PCDATA_47 [] (s2b "&gt;")
    ce_copy = PCDATA_47 [] (s2b "&copy;")
    ce_reg = PCDATA_47 [] (s2b "&reg;")
    ce_nbsp = PCDATA_47 [] (s2b "&nbsp;")
instance C_PCDATA Ent48 where
    pcdata s = PCDATA_48 [] (s2b_escape s)
    pcdata_bs = PCDATA_48 []
    ce_quot = PCDATA_48 [] (s2b "&quot;")
    ce_amp = PCDATA_48 [] (s2b "&amp;")
    ce_lt = PCDATA_48 [] (s2b "&lt;")
    ce_gt = PCDATA_48 [] (s2b "&gt;")
    ce_copy = PCDATA_48 [] (s2b "&copy;")
    ce_reg = PCDATA_48 [] (s2b "&reg;")
    ce_nbsp = PCDATA_48 [] (s2b "&nbsp;")
instance C_PCDATA Ent53 where
    pcdata s = PCDATA_53 [] (s2b_escape s)
    pcdata_bs = PCDATA_53 []
    ce_quot = PCDATA_53 [] (s2b "&quot;")
    ce_amp = PCDATA_53 [] (s2b "&amp;")
    ce_lt = PCDATA_53 [] (s2b "&lt;")
    ce_gt = PCDATA_53 [] (s2b "&gt;")
    ce_copy = PCDATA_53 [] (s2b "&copy;")
    ce_reg = PCDATA_53 [] (s2b "&reg;")
    ce_nbsp = PCDATA_53 [] (s2b "&nbsp;")
instance C_PCDATA Ent58 where
    pcdata s = PCDATA_58 [] (s2b_escape s)
    pcdata_bs = PCDATA_58 []
    ce_quot = PCDATA_58 [] (s2b "&quot;")
    ce_amp = PCDATA_58 [] (s2b "&amp;")
    ce_lt = PCDATA_58 [] (s2b "&lt;")
    ce_gt = PCDATA_58 [] (s2b "&gt;")
    ce_copy = PCDATA_58 [] (s2b "&copy;")
    ce_reg = PCDATA_58 [] (s2b "&reg;")
    ce_nbsp = PCDATA_58 [] (s2b "&nbsp;")
instance C_PCDATA Ent62 where
    pcdata s = PCDATA_62 [] (s2b_escape s)
    pcdata_bs = PCDATA_62 []
    ce_quot = PCDATA_62 [] (s2b "&quot;")
    ce_amp = PCDATA_62 [] (s2b "&amp;")
    ce_lt = PCDATA_62 [] (s2b "&lt;")
    ce_gt = PCDATA_62 [] (s2b "&gt;")
    ce_copy = PCDATA_62 [] (s2b "&copy;")
    ce_reg = PCDATA_62 [] (s2b "&reg;")
    ce_nbsp = PCDATA_62 [] (s2b "&nbsp;")
instance C_PCDATA Ent65 where
    pcdata s = PCDATA_65 [] (s2b_escape s)
    pcdata_bs = PCDATA_65 []
    ce_quot = PCDATA_65 [] (s2b "&quot;")
    ce_amp = PCDATA_65 [] (s2b "&amp;")
    ce_lt = PCDATA_65 [] (s2b "&lt;")
    ce_gt = PCDATA_65 [] (s2b "&gt;")
    ce_copy = PCDATA_65 [] (s2b "&copy;")
    ce_reg = PCDATA_65 [] (s2b "&reg;")
    ce_nbsp = PCDATA_65 [] (s2b "&nbsp;")
instance C_PCDATA Ent67 where
    pcdata s = PCDATA_67 [] (s2b_escape s)
    pcdata_bs = PCDATA_67 []
    ce_quot = PCDATA_67 [] (s2b "&quot;")
    ce_amp = PCDATA_67 [] (s2b "&amp;")
    ce_lt = PCDATA_67 [] (s2b "&lt;")
    ce_gt = PCDATA_67 [] (s2b "&gt;")
    ce_copy = PCDATA_67 [] (s2b "&copy;")
    ce_reg = PCDATA_67 [] (s2b "&reg;")
    ce_nbsp = PCDATA_67 [] (s2b "&nbsp;")
instance C_PCDATA Ent68 where
    pcdata s = PCDATA_68 [] (s2b_escape s)
    pcdata_bs = PCDATA_68 []
    ce_quot = PCDATA_68 [] (s2b "&quot;")
    ce_amp = PCDATA_68 [] (s2b "&amp;")
    ce_lt = PCDATA_68 [] (s2b "&lt;")
    ce_gt = PCDATA_68 [] (s2b "&gt;")
    ce_copy = PCDATA_68 [] (s2b "&copy;")
    ce_reg = PCDATA_68 [] (s2b "&reg;")
    ce_nbsp = PCDATA_68 [] (s2b "&nbsp;")
instance C_PCDATA Ent69 where
    pcdata s = PCDATA_69 [] (s2b_escape s)
    pcdata_bs = PCDATA_69 []
    ce_quot = PCDATA_69 [] (s2b "&quot;")
    ce_amp = PCDATA_69 [] (s2b "&amp;")
    ce_lt = PCDATA_69 [] (s2b "&lt;")
    ce_gt = PCDATA_69 [] (s2b "&gt;")
    ce_copy = PCDATA_69 [] (s2b "&copy;")
    ce_reg = PCDATA_69 [] (s2b "&reg;")
    ce_nbsp = PCDATA_69 [] (s2b "&nbsp;")
instance C_PCDATA Ent72 where
    pcdata s = PCDATA_72 [] (s2b_escape s)
    pcdata_bs = PCDATA_72 []
    ce_quot = PCDATA_72 [] (s2b "&quot;")
    ce_amp = PCDATA_72 [] (s2b "&amp;")
    ce_lt = PCDATA_72 [] (s2b "&lt;")
    ce_gt = PCDATA_72 [] (s2b "&gt;")
    ce_copy = PCDATA_72 [] (s2b "&copy;")
    ce_reg = PCDATA_72 [] (s2b "&reg;")
    ce_nbsp = PCDATA_72 [] (s2b "&nbsp;")
instance C_PCDATA Ent73 where
    pcdata s = PCDATA_73 [] (s2b_escape s)
    pcdata_bs = PCDATA_73 []
    ce_quot = PCDATA_73 [] (s2b "&quot;")
    ce_amp = PCDATA_73 [] (s2b "&amp;")
    ce_lt = PCDATA_73 [] (s2b "&lt;")
    ce_gt = PCDATA_73 [] (s2b "&gt;")
    ce_copy = PCDATA_73 [] (s2b "&copy;")
    ce_reg = PCDATA_73 [] (s2b "&reg;")
    ce_nbsp = PCDATA_73 [] (s2b "&nbsp;")
instance C_PCDATA Ent74 where
    pcdata s = PCDATA_74 [] (s2b_escape s)
    pcdata_bs = PCDATA_74 []
    ce_quot = PCDATA_74 [] (s2b "&quot;")
    ce_amp = PCDATA_74 [] (s2b "&amp;")
    ce_lt = PCDATA_74 [] (s2b "&lt;")
    ce_gt = PCDATA_74 [] (s2b "&gt;")
    ce_copy = PCDATA_74 [] (s2b "&copy;")
    ce_reg = PCDATA_74 [] (s2b "&reg;")
    ce_nbsp = PCDATA_74 [] (s2b "&nbsp;")
instance C_PCDATA Ent75 where
    pcdata s = PCDATA_75 [] (s2b_escape s)
    pcdata_bs = PCDATA_75 []
    ce_quot = PCDATA_75 [] (s2b "&quot;")
    ce_amp = PCDATA_75 [] (s2b "&amp;")
    ce_lt = PCDATA_75 [] (s2b "&lt;")
    ce_gt = PCDATA_75 [] (s2b "&gt;")
    ce_copy = PCDATA_75 [] (s2b "&copy;")
    ce_reg = PCDATA_75 [] (s2b "&reg;")
    ce_nbsp = PCDATA_75 [] (s2b "&nbsp;")
instance C_PCDATA Ent77 where
    pcdata s = PCDATA_77 [] (s2b_escape s)
    pcdata_bs = PCDATA_77 []
    ce_quot = PCDATA_77 [] (s2b "&quot;")
    ce_amp = PCDATA_77 [] (s2b "&amp;")
    ce_lt = PCDATA_77 [] (s2b "&lt;")
    ce_gt = PCDATA_77 [] (s2b "&gt;")
    ce_copy = PCDATA_77 [] (s2b "&copy;")
    ce_reg = PCDATA_77 [] (s2b "&reg;")
    ce_nbsp = PCDATA_77 [] (s2b "&nbsp;")
instance C_PCDATA Ent78 where
    pcdata s = PCDATA_78 [] (s2b_escape s)
    pcdata_bs = PCDATA_78 []
    ce_quot = PCDATA_78 [] (s2b "&quot;")
    ce_amp = PCDATA_78 [] (s2b "&amp;")
    ce_lt = PCDATA_78 [] (s2b "&lt;")
    ce_gt = PCDATA_78 [] (s2b "&gt;")
    ce_copy = PCDATA_78 [] (s2b "&copy;")
    ce_reg = PCDATA_78 [] (s2b "&reg;")
    ce_nbsp = PCDATA_78 [] (s2b "&nbsp;")
instance C_PCDATA Ent82 where
    pcdata s = PCDATA_82 [] (s2b_escape s)
    pcdata_bs = PCDATA_82 []
    ce_quot = PCDATA_82 [] (s2b "&quot;")
    ce_amp = PCDATA_82 [] (s2b "&amp;")
    ce_lt = PCDATA_82 [] (s2b "&lt;")
    ce_gt = PCDATA_82 [] (s2b "&gt;")
    ce_copy = PCDATA_82 [] (s2b "&copy;")
    ce_reg = PCDATA_82 [] (s2b "&reg;")
    ce_nbsp = PCDATA_82 [] (s2b "&nbsp;")
instance C_PCDATA Ent85 where
    pcdata s = PCDATA_85 [] (s2b_escape s)
    pcdata_bs = PCDATA_85 []
    ce_quot = PCDATA_85 [] (s2b "&quot;")
    ce_amp = PCDATA_85 [] (s2b "&amp;")
    ce_lt = PCDATA_85 [] (s2b "&lt;")
    ce_gt = PCDATA_85 [] (s2b "&gt;")
    ce_copy = PCDATA_85 [] (s2b "&copy;")
    ce_reg = PCDATA_85 [] (s2b "&reg;")
    ce_nbsp = PCDATA_85 [] (s2b "&nbsp;")
instance C_PCDATA Ent86 where
    pcdata s = PCDATA_86 [] (s2b_escape s)
    pcdata_bs = PCDATA_86 []
    ce_quot = PCDATA_86 [] (s2b "&quot;")
    ce_amp = PCDATA_86 [] (s2b "&amp;")
    ce_lt = PCDATA_86 [] (s2b "&lt;")
    ce_gt = PCDATA_86 [] (s2b "&gt;")
    ce_copy = PCDATA_86 [] (s2b "&copy;")
    ce_reg = PCDATA_86 [] (s2b "&reg;")
    ce_nbsp = PCDATA_86 [] (s2b "&nbsp;")
instance C_PCDATA Ent88 where
    pcdata s = PCDATA_88 [] (s2b_escape s)
    pcdata_bs = PCDATA_88 []
    ce_quot = PCDATA_88 [] (s2b "&quot;")
    ce_amp = PCDATA_88 [] (s2b "&amp;")
    ce_lt = PCDATA_88 [] (s2b "&lt;")
    ce_gt = PCDATA_88 [] (s2b "&gt;")
    ce_copy = PCDATA_88 [] (s2b "&copy;")
    ce_reg = PCDATA_88 [] (s2b "&reg;")
    ce_nbsp = PCDATA_88 [] (s2b "&nbsp;")
instance C_PCDATA Ent89 where
    pcdata s = PCDATA_89 [] (s2b_escape s)
    pcdata_bs = PCDATA_89 []
    ce_quot = PCDATA_89 [] (s2b "&quot;")
    ce_amp = PCDATA_89 [] (s2b "&amp;")
    ce_lt = PCDATA_89 [] (s2b "&lt;")
    ce_gt = PCDATA_89 [] (s2b "&gt;")
    ce_copy = PCDATA_89 [] (s2b "&copy;")
    ce_reg = PCDATA_89 [] (s2b "&reg;")
    ce_nbsp = PCDATA_89 [] (s2b "&nbsp;")
instance C_PCDATA Ent90 where
    pcdata s = PCDATA_90 [] (s2b_escape s)
    pcdata_bs = PCDATA_90 []
    ce_quot = PCDATA_90 [] (s2b "&quot;")
    ce_amp = PCDATA_90 [] (s2b "&amp;")
    ce_lt = PCDATA_90 [] (s2b "&lt;")
    ce_gt = PCDATA_90 [] (s2b "&gt;")
    ce_copy = PCDATA_90 [] (s2b "&copy;")
    ce_reg = PCDATA_90 [] (s2b "&reg;")
    ce_nbsp = PCDATA_90 [] (s2b "&nbsp;")
instance C_PCDATA Ent93 where
    pcdata s = PCDATA_93 [] (s2b_escape s)
    pcdata_bs = PCDATA_93 []
    ce_quot = PCDATA_93 [] (s2b "&quot;")
    ce_amp = PCDATA_93 [] (s2b "&amp;")
    ce_lt = PCDATA_93 [] (s2b "&lt;")
    ce_gt = PCDATA_93 [] (s2b "&gt;")
    ce_copy = PCDATA_93 [] (s2b "&copy;")
    ce_reg = PCDATA_93 [] (s2b "&reg;")
    ce_nbsp = PCDATA_93 [] (s2b "&nbsp;")
instance C_PCDATA Ent94 where
    pcdata s = PCDATA_94 [] (s2b_escape s)
    pcdata_bs = PCDATA_94 []
    ce_quot = PCDATA_94 [] (s2b "&quot;")
    ce_amp = PCDATA_94 [] (s2b "&amp;")
    ce_lt = PCDATA_94 [] (s2b "&lt;")
    ce_gt = PCDATA_94 [] (s2b "&gt;")
    ce_copy = PCDATA_94 [] (s2b "&copy;")
    ce_reg = PCDATA_94 [] (s2b "&reg;")
    ce_nbsp = PCDATA_94 [] (s2b "&nbsp;")
instance C_PCDATA Ent95 where
    pcdata s = PCDATA_95 [] (s2b_escape s)
    pcdata_bs = PCDATA_95 []
    ce_quot = PCDATA_95 [] (s2b "&quot;")
    ce_amp = PCDATA_95 [] (s2b "&amp;")
    ce_lt = PCDATA_95 [] (s2b "&lt;")
    ce_gt = PCDATA_95 [] (s2b "&gt;")
    ce_copy = PCDATA_95 [] (s2b "&copy;")
    ce_reg = PCDATA_95 [] (s2b "&reg;")
    ce_nbsp = PCDATA_95 [] (s2b "&nbsp;")
instance C_PCDATA Ent100 where
    pcdata s = PCDATA_100 [] (s2b_escape s)
    pcdata_bs = PCDATA_100 []
    ce_quot = PCDATA_100 [] (s2b "&quot;")
    ce_amp = PCDATA_100 [] (s2b "&amp;")
    ce_lt = PCDATA_100 [] (s2b "&lt;")
    ce_gt = PCDATA_100 [] (s2b "&gt;")
    ce_copy = PCDATA_100 [] (s2b "&copy;")
    ce_reg = PCDATA_100 [] (s2b "&reg;")
    ce_nbsp = PCDATA_100 [] (s2b "&nbsp;")
instance C_PCDATA Ent104 where
    pcdata s = PCDATA_104 [] (s2b_escape s)
    pcdata_bs = PCDATA_104 []
    ce_quot = PCDATA_104 [] (s2b "&quot;")
    ce_amp = PCDATA_104 [] (s2b "&amp;")
    ce_lt = PCDATA_104 [] (s2b "&lt;")
    ce_gt = PCDATA_104 [] (s2b "&gt;")
    ce_copy = PCDATA_104 [] (s2b "&copy;")
    ce_reg = PCDATA_104 [] (s2b "&reg;")
    ce_nbsp = PCDATA_104 [] (s2b "&nbsp;")
instance C_PCDATA Ent107 where
    pcdata s = PCDATA_107 [] (s2b_escape s)
    pcdata_bs = PCDATA_107 []
    ce_quot = PCDATA_107 [] (s2b "&quot;")
    ce_amp = PCDATA_107 [] (s2b "&amp;")
    ce_lt = PCDATA_107 [] (s2b "&lt;")
    ce_gt = PCDATA_107 [] (s2b "&gt;")
    ce_copy = PCDATA_107 [] (s2b "&copy;")
    ce_reg = PCDATA_107 [] (s2b "&reg;")
    ce_nbsp = PCDATA_107 [] (s2b "&nbsp;")
instance C_PCDATA Ent108 where
    pcdata s = PCDATA_108 [] (s2b_escape s)
    pcdata_bs = PCDATA_108 []
    ce_quot = PCDATA_108 [] (s2b "&quot;")
    ce_amp = PCDATA_108 [] (s2b "&amp;")
    ce_lt = PCDATA_108 [] (s2b "&lt;")
    ce_gt = PCDATA_108 [] (s2b "&gt;")
    ce_copy = PCDATA_108 [] (s2b "&copy;")
    ce_reg = PCDATA_108 [] (s2b "&reg;")
    ce_nbsp = PCDATA_108 [] (s2b "&nbsp;")
instance C_PCDATA Ent113 where
    pcdata s = PCDATA_113 [] (s2b_escape s)
    pcdata_bs = PCDATA_113 []
    ce_quot = PCDATA_113 [] (s2b "&quot;")
    ce_amp = PCDATA_113 [] (s2b "&amp;")
    ce_lt = PCDATA_113 [] (s2b "&lt;")
    ce_gt = PCDATA_113 [] (s2b "&gt;")
    ce_copy = PCDATA_113 [] (s2b "&copy;")
    ce_reg = PCDATA_113 [] (s2b "&reg;")
    ce_nbsp = PCDATA_113 [] (s2b "&nbsp;")
instance C_PCDATA Ent114 where
    pcdata s = PCDATA_114 [] (s2b_escape s)
    pcdata_bs = PCDATA_114 []
    ce_quot = PCDATA_114 [] (s2b "&quot;")
    ce_amp = PCDATA_114 [] (s2b "&amp;")
    ce_lt = PCDATA_114 [] (s2b "&lt;")
    ce_gt = PCDATA_114 [] (s2b "&gt;")
    ce_copy = PCDATA_114 [] (s2b "&copy;")
    ce_reg = PCDATA_114 [] (s2b "&reg;")
    ce_nbsp = PCDATA_114 [] (s2b "&nbsp;")
instance C_PCDATA Ent115 where
    pcdata s = PCDATA_115 [] (s2b_escape s)
    pcdata_bs = PCDATA_115 []
    ce_quot = PCDATA_115 [] (s2b "&quot;")
    ce_amp = PCDATA_115 [] (s2b "&amp;")
    ce_lt = PCDATA_115 [] (s2b "&lt;")
    ce_gt = PCDATA_115 [] (s2b "&gt;")
    ce_copy = PCDATA_115 [] (s2b "&copy;")
    ce_reg = PCDATA_115 [] (s2b "&reg;")
    ce_nbsp = PCDATA_115 [] (s2b "&nbsp;")
instance C_PCDATA Ent118 where
    pcdata s = PCDATA_118 [] (s2b_escape s)
    pcdata_bs = PCDATA_118 []
    ce_quot = PCDATA_118 [] (s2b "&quot;")
    ce_amp = PCDATA_118 [] (s2b "&amp;")
    ce_lt = PCDATA_118 [] (s2b "&lt;")
    ce_gt = PCDATA_118 [] (s2b "&gt;")
    ce_copy = PCDATA_118 [] (s2b "&copy;")
    ce_reg = PCDATA_118 [] (s2b "&reg;")
    ce_nbsp = PCDATA_118 [] (s2b "&nbsp;")
instance C_PCDATA Ent119 where
    pcdata s = PCDATA_119 [] (s2b_escape s)
    pcdata_bs = PCDATA_119 []
    ce_quot = PCDATA_119 [] (s2b "&quot;")
    ce_amp = PCDATA_119 [] (s2b "&amp;")
    ce_lt = PCDATA_119 [] (s2b "&lt;")
    ce_gt = PCDATA_119 [] (s2b "&gt;")
    ce_copy = PCDATA_119 [] (s2b "&copy;")
    ce_reg = PCDATA_119 [] (s2b "&reg;")
    ce_nbsp = PCDATA_119 [] (s2b "&nbsp;")
instance C_PCDATA Ent120 where
    pcdata s = PCDATA_120 [] (s2b_escape s)
    pcdata_bs = PCDATA_120 []
    ce_quot = PCDATA_120 [] (s2b "&quot;")
    ce_amp = PCDATA_120 [] (s2b "&amp;")
    ce_lt = PCDATA_120 [] (s2b "&lt;")
    ce_gt = PCDATA_120 [] (s2b "&gt;")
    ce_copy = PCDATA_120 [] (s2b "&copy;")
    ce_reg = PCDATA_120 [] (s2b "&reg;")
    ce_nbsp = PCDATA_120 [] (s2b "&nbsp;")
instance C_PCDATA Ent125 where
    pcdata s = PCDATA_125 [] (s2b_escape s)
    pcdata_bs = PCDATA_125 []
    ce_quot = PCDATA_125 [] (s2b "&quot;")
    ce_amp = PCDATA_125 [] (s2b "&amp;")
    ce_lt = PCDATA_125 [] (s2b "&lt;")
    ce_gt = PCDATA_125 [] (s2b "&gt;")
    ce_copy = PCDATA_125 [] (s2b "&copy;")
    ce_reg = PCDATA_125 [] (s2b "&reg;")
    ce_nbsp = PCDATA_125 [] (s2b "&nbsp;")
instance C_PCDATA Ent129 where
    pcdata s = PCDATA_129 [] (s2b_escape s)
    pcdata_bs = PCDATA_129 []
    ce_quot = PCDATA_129 [] (s2b "&quot;")
    ce_amp = PCDATA_129 [] (s2b "&amp;")
    ce_lt = PCDATA_129 [] (s2b "&lt;")
    ce_gt = PCDATA_129 [] (s2b "&gt;")
    ce_copy = PCDATA_129 [] (s2b "&copy;")
    ce_reg = PCDATA_129 [] (s2b "&reg;")
    ce_nbsp = PCDATA_129 [] (s2b "&nbsp;")
instance C_PCDATA Ent132 where
    pcdata s = PCDATA_132 [] (s2b_escape s)
    pcdata_bs = PCDATA_132 []
    ce_quot = PCDATA_132 [] (s2b "&quot;")
    ce_amp = PCDATA_132 [] (s2b "&amp;")
    ce_lt = PCDATA_132 [] (s2b "&lt;")
    ce_gt = PCDATA_132 [] (s2b "&gt;")
    ce_copy = PCDATA_132 [] (s2b "&copy;")
    ce_reg = PCDATA_132 [] (s2b "&reg;")
    ce_nbsp = PCDATA_132 [] (s2b "&nbsp;")
instance C_PCDATA Ent133 where
    pcdata s = PCDATA_133 [] (s2b_escape s)
    pcdata_bs = PCDATA_133 []
    ce_quot = PCDATA_133 [] (s2b "&quot;")
    ce_amp = PCDATA_133 [] (s2b "&amp;")
    ce_lt = PCDATA_133 [] (s2b "&lt;")
    ce_gt = PCDATA_133 [] (s2b "&gt;")
    ce_copy = PCDATA_133 [] (s2b "&copy;")
    ce_reg = PCDATA_133 [] (s2b "&reg;")
    ce_nbsp = PCDATA_133 [] (s2b "&nbsp;")


maprender a = B.concat (map render_bs a)

render :: Render a => a -> String
render a = U.toString (render_bs a)

class Render a where
    render_bs :: a -> B.ByteString
instance Render Ent where
    render_bs (Html att c) = B.concat [s2b "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\"\n    \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n", s2b "<html ", renderAtts att , gt_byte, maprender c ,s2b "</html>"]
instance Render Ent0 where
    render_bs (Head_0 att c) = B.concat [head_byte_b,renderAtts att,gt_byte, maprender c,head_byte_e]
    render_bs (Body_0 att c) = B.concat [body_byte_b,renderAtts att,gt_byte, maprender c,body_byte_e]
instance Render Ent1 where
    render_bs (Title_1 att c) = B.concat [title_byte_b,renderAtts att,gt_byte, maprender c,title_byte_e]
    render_bs (Base_1 att) = B.concat [base_byte_b,renderAtts att,gts_byte]
    render_bs (Meta_1 att) = B.concat [meta_byte_b,renderAtts (att++[content_att []]),gts_byte]
    render_bs (Link_1 att) = B.concat [link_byte_b,renderAtts att,gts_byte]
    render_bs (Style_1 att c) = B.concat [style_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,style_byte_e]
    render_bs (Script_1 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Object_1 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Isindex_1 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
instance Render Ent2 where
    render_bs (PCDATA_2 _ str) = str
instance Render Ent3 where
    render_bs (Script_3 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_3 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_3 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_3 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_3 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_3 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_3 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_3 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_3 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_3 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_3 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_3 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_3 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_3 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_3 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_3 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_3 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_3 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_3 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_3 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_3 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_3 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_3 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_3 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_3 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_3 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_3 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_3 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_3 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_3 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_3 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_3 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_3 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_3 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_3 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_3 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_3 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_3 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_3 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_3 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_3 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_3 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_3 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_3 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_3 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_3 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_3 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_3 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_3 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_3 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_3 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_3 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Param_3 att) = B.concat [param_byte_b,renderAtts (att++[name_att []]),gts_byte]
    render_bs (Applet_3 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_3 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_3 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Form_3 att c) = B.concat [form_byte_b,renderAtts (att++[action_att []]),gt_byte, maprender c,form_byte_e]
    render_bs (Label_3 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_3 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_3 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_3 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_3 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Button_3 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_3 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_3 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_3 _ str) = str
instance Render Ent4 where
    render_bs (Script_4 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_4 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_4 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_4 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_4 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_4 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_4 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_4 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_4 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_4 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_4 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_4 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_4 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_4 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_4 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_4 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_4 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_4 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_4 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_4 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_4 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_4 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_4 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_4 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_4 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_4 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_4 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_4 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_4 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_4 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_4 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_4 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_4 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_4 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_4 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_4 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_4 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_4 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_4 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_4 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_4 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_4 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_4 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_4 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_4 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_4 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_4 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_4 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_4 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_4 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_4 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_4 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_4 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_4 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_4 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Form_4 att c) = B.concat [form_byte_b,renderAtts (att++[action_att []]),gt_byte, maprender c,form_byte_e]
    render_bs (Label_4 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_4 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_4 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_4 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_4 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Button_4 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_4 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_4 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_4 _ str) = str
instance Render Ent5 where
    render_bs (Script_5 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Iframe_5 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Ins_5 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_5 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_5 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_5 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_5 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_5 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_5 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_5 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_5 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_5 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_5 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_5 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_5 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_5 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_5 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_5 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_5 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_5 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_5 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_5 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_5 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_5 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_5 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_5 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_5 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_5 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_5 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_5 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_5 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_5 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_5 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_5 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_5 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Label_5 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_5 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_5 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_5 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_5 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_5 _ str) = str
instance Render Ent6 where
    render_bs (Li_6 att c) = B.concat [li_byte_b,renderAtts att,gt_byte, maprender c,li_byte_e]
instance Render Ent7 where
    render_bs (Dt_7 att c) = B.concat [dt_byte_b,renderAtts att,gt_byte, maprender c,dt_byte_e]
    render_bs (Dd_7 att c) = B.concat [dd_byte_b,renderAtts att,gt_byte, maprender c,dd_byte_e]
instance Render Ent8 where
    render_bs (Script_8 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Iframe_8 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (P_8 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (Ins_8 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_8 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_8 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_8 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_8 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_8 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_8 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_8 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_8 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_8 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_8 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_8 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_8 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_8 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_8 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_8 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_8 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_8 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_8 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_8 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_8 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_8 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_8 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_8 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_8 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_8 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_8 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_8 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_8 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_8 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_8 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_8 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_8 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Label_8 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_8 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_8 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_8 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_8 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_8 _ str) = str
instance Render Ent9 where
    render_bs (Script_9 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Ins_9 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_9 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_9 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_9 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_9 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_9 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_9 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_9 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_9 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_9 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_9 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_9 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_9 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_9 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_9 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_9 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_9 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Tt_9 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_9 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_9 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (U_9 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_9 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_9 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Label_9 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_9 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_9 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_9 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_9 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_9 _ str) = str
instance Render Ent10 where
    render_bs (Script_10 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Iframe_10 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Ins_10 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_10 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_10 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_10 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_10 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_10 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_10 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_10 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_10 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_10 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_10 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_10 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_10 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_10 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_10 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_10 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_10 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_10 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_10 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_10 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_10 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_10 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_10 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_10 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_10 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_10 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_10 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_10 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_10 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_10 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_10 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_10 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Label_10 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_10 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_10 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_10 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_10 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_10 _ str) = str
instance Render Ent11 where
    render_bs (PCDATA_11 _ str) = str
instance Render Ent12 where
    render_bs (Script_12 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_12 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_12 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_12 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_12 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_12 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_12 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_12 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_12 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_12 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_12 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_12 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_12 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_12 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_12 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_12 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_12 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_12 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_12 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_12 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_12 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_12 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_12 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_12 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_12 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_12 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_12 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_12 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_12 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_12 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_12 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_12 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_12 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_12 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_12 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_12 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_12 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_12 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_12 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_12 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_12 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_12 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_12 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_12 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_12 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_12 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_12 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_12 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_12 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_12 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_12 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_12 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_12 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_12 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Form_12 att c) = B.concat [form_byte_b,renderAtts (att++[action_att []]),gt_byte, maprender c,form_byte_e]
    render_bs (Label_12 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_12 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_12 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_12 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_12 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Button_12 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_12 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_12 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_12 _ str) = str
instance Render Ent13 where
    render_bs (Li_13 att c) = B.concat [li_byte_b,renderAtts att,gt_byte, maprender c,li_byte_e]
instance Render Ent14 where
    render_bs (Dt_14 att c) = B.concat [dt_byte_b,renderAtts att,gt_byte, maprender c,dt_byte_e]
    render_bs (Dd_14 att c) = B.concat [dd_byte_b,renderAtts att,gt_byte, maprender c,dd_byte_e]
instance Render Ent15 where
    render_bs (Script_15 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Iframe_15 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (P_15 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (Ins_15 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_15 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_15 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_15 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_15 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_15 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_15 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_15 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_15 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_15 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_15 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_15 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_15 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_15 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_15 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_15 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_15 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_15 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_15 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_15 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_15 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_15 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_15 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_15 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_15 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_15 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_15 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_15 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_15 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_15 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_15 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_15 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Label_15 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_15 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_15 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_15 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_15 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_15 _ str) = str
instance Render Ent16 where
    render_bs (Script_16 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Ins_16 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_16 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_16 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_16 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_16 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_16 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_16 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_16 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_16 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_16 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_16 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_16 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_16 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_16 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_16 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_16 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Tt_16 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_16 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_16 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (U_16 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_16 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_16 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Label_16 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_16 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_16 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_16 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_16 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_16 _ str) = str
instance Render Ent17 where
    render_bs (Script_17 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_17 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_17 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_17 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_17 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_17 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_17 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_17 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_17 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_17 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_17 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_17 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_17 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_17 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_17 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_17 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_17 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_17 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_17 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_17 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_17 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_17 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_17 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_17 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_17 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_17 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_17 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_17 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_17 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_17 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_17 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_17 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_17 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_17 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_17 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_17 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_17 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_17 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_17 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_17 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_17 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_17 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_17 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_17 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_17 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_17 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_17 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_17 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_17 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_17 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_17 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_17 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_17 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_17 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Label_17 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_17 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_17 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_17 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_17 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Button_17 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_17 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_17 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_17 _ str) = str
instance Render Ent18 where
    render_bs (Script_18 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Iframe_18 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Ins_18 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_18 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_18 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_18 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_18 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_18 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_18 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_18 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_18 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_18 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_18 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_18 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_18 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_18 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_18 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_18 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_18 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_18 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_18 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_18 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_18 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_18 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_18 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_18 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_18 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_18 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_18 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_18 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_18 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_18 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_18 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_18 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Label_18 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_18 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_18 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_18 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_18 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_18 _ str) = str
instance Render Ent19 where
    render_bs (Li_19 att c) = B.concat [li_byte_b,renderAtts att,gt_byte, maprender c,li_byte_e]
instance Render Ent20 where
    render_bs (Dt_20 att c) = B.concat [dt_byte_b,renderAtts att,gt_byte, maprender c,dt_byte_e]
    render_bs (Dd_20 att c) = B.concat [dd_byte_b,renderAtts att,gt_byte, maprender c,dd_byte_e]
instance Render Ent21 where
    render_bs (Script_21 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Iframe_21 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (P_21 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (Ins_21 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_21 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_21 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_21 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_21 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_21 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_21 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_21 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_21 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_21 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_21 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_21 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_21 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_21 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_21 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_21 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_21 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_21 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_21 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_21 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_21 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_21 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_21 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_21 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_21 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_21 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_21 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_21 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_21 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_21 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_21 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_21 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Label_21 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_21 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_21 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_21 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_21 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_21 _ str) = str
instance Render Ent22 where
    render_bs (Script_22 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Ins_22 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_22 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_22 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_22 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_22 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_22 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_22 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_22 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_22 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_22 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_22 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_22 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_22 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_22 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_22 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_22 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Tt_22 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_22 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_22 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (U_22 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_22 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_22 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Label_22 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_22 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_22 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_22 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_22 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_22 _ str) = str
instance Render Ent23 where
    render_bs (Script_23 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_23 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_23 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_23 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_23 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_23 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_23 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_23 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_23 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_23 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_23 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_23 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_23 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_23 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_23 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_23 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_23 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_23 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_23 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_23 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_23 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_23 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_23 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_23 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_23 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_23 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_23 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_23 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_23 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_23 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_23 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_23 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_23 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_23 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_23 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_23 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_23 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_23 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_23 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_23 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_23 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_23 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_23 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_23 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_23 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_23 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_23 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_23 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_23 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_23 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_23 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_23 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_23 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_23 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Label_23 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_23 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_23 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_23 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_23 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Legend_23 att c) = B.concat [legend_byte_b,renderAtts att,gt_byte, maprender c,legend_byte_e]
    render_bs (Button_23 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_23 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_23 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_23 _ str) = str
instance Render Ent24 where
    render_bs (Caption_24 att c) = B.concat [caption_byte_b,renderAtts att,gt_byte, maprender c,caption_byte_e]
    render_bs (Thead_24 att c) = B.concat [thead_byte_b,renderAtts att,gt_byte, maprender c,thead_byte_e]
    render_bs (Tfoot_24 att c) = B.concat [tfoot_byte_b,renderAtts att,gt_byte, maprender c,tfoot_byte_e]
    render_bs (Tbody_24 att c) = B.concat [tbody_byte_b,renderAtts att,gt_byte, maprender c,tbody_byte_e]
    render_bs (Colgroup_24 att c) = B.concat [colgroup_byte_b,renderAtts att,gt_byte, maprender c,colgroup_byte_e]
    render_bs (Col_24 att) = B.concat [col_byte_b,renderAtts att,gts_byte]
    render_bs (Tr_24 att c) = B.concat [tr_byte_b,renderAtts att,gt_byte, maprender c,tr_byte_e]
instance Render Ent25 where
    render_bs (Tr_25 att c) = B.concat [tr_byte_b,renderAtts att,gt_byte, maprender c,tr_byte_e]
instance Render Ent26 where
    render_bs (Col_26 att) = B.concat [col_byte_b,renderAtts att,gts_byte]
instance Render Ent27 where
    render_bs (Th_27 att c) = B.concat [th_byte_b,renderAtts att,gt_byte, maprender c,th_byte_e]
    render_bs (Td_27 att c) = B.concat [td_byte_b,renderAtts att,gt_byte, maprender c,td_byte_e]
instance Render Ent28 where
    render_bs (Script_28 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_28 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_28 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_28 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_28 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_28 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_28 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_28 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_28 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_28 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_28 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_28 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_28 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_28 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_28 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_28 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_28 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_28 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_28 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_28 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_28 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_28 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_28 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_28 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_28 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_28 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_28 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_28 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_28 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_28 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_28 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_28 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_28 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_28 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_28 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_28 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_28 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_28 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_28 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_28 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_28 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_28 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_28 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_28 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_28 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_28 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_28 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_28 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_28 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_28 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_28 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_28 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_28 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_28 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Form_28 att c) = B.concat [form_byte_b,renderAtts (att++[action_att []]),gt_byte, maprender c,form_byte_e]
    render_bs (Label_28 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_28 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_28 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_28 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_28 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Legend_28 att c) = B.concat [legend_byte_b,renderAtts att,gt_byte, maprender c,legend_byte_e]
    render_bs (Button_28 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_28 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_28 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_28 _ str) = str
instance Render Ent29 where
    render_bs (Caption_29 att c) = B.concat [caption_byte_b,renderAtts att,gt_byte, maprender c,caption_byte_e]
    render_bs (Thead_29 att c) = B.concat [thead_byte_b,renderAtts att,gt_byte, maprender c,thead_byte_e]
    render_bs (Tfoot_29 att c) = B.concat [tfoot_byte_b,renderAtts att,gt_byte, maprender c,tfoot_byte_e]
    render_bs (Tbody_29 att c) = B.concat [tbody_byte_b,renderAtts att,gt_byte, maprender c,tbody_byte_e]
    render_bs (Colgroup_29 att c) = B.concat [colgroup_byte_b,renderAtts att,gt_byte, maprender c,colgroup_byte_e]
    render_bs (Col_29 att) = B.concat [col_byte_b,renderAtts att,gts_byte]
    render_bs (Tr_29 att c) = B.concat [tr_byte_b,renderAtts att,gt_byte, maprender c,tr_byte_e]
instance Render Ent30 where
    render_bs (Tr_30 att c) = B.concat [tr_byte_b,renderAtts att,gt_byte, maprender c,tr_byte_e]
instance Render Ent31 where
    render_bs (Col_31 att) = B.concat [col_byte_b,renderAtts att,gts_byte]
instance Render Ent32 where
    render_bs (Th_32 att c) = B.concat [th_byte_b,renderAtts att,gt_byte, maprender c,th_byte_e]
    render_bs (Td_32 att c) = B.concat [td_byte_b,renderAtts att,gt_byte, maprender c,td_byte_e]
instance Render Ent33 where
    render_bs (Script_33 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_33 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_33 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_33 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_33 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_33 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_33 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_33 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_33 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_33 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_33 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_33 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_33 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_33 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_33 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_33 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_33 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_33 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_33 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_33 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_33 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_33 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_33 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_33 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_33 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_33 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_33 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_33 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_33 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_33 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_33 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_33 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_33 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_33 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_33 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_33 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_33 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_33 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_33 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_33 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_33 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_33 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_33 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_33 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_33 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_33 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_33 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_33 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_33 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_33 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_33 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Param_33 att) = B.concat [param_byte_b,renderAtts (att++[name_att []]),gts_byte]
    render_bs (Applet_33 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_33 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_33 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Form_33 att c) = B.concat [form_byte_b,renderAtts (att++[action_att []]),gt_byte, maprender c,form_byte_e]
    render_bs (Label_33 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_33 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_33 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_33 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_33 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Button_33 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_33 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_33 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_33 _ str) = str
instance Render Ent34 where
    render_bs (Script_34 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_34 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Noframes_34 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_34 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_34 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_34 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_34 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_34 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_34 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_34 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_34 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_34 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_34 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_34 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_34 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_34 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_34 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_34 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_34 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_34 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_34 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_34 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_34 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Area_34 att) = B.concat [area_byte_b,renderAtts (att++[alt_att []]),gts_byte]
    render_bs (Form_34 att c) = B.concat [form_byte_b,renderAtts (att++[action_att []]),gt_byte, maprender c,form_byte_e]
    render_bs (Fieldset_34 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Isindex_34 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_34 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
instance Render Ent35 where
    render_bs (Script_35 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Iframe_35 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Ins_35 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_35 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_35 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_35 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_35 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_35 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_35 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_35 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_35 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_35 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_35 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_35 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_35 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_35 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_35 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_35 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_35 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_35 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_35 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_35 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_35 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_35 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_35 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_35 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_35 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_35 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_35 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_35 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_35 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_35 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_35 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_35 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Input_35 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_35 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_35 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_35 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_35 _ str) = str
instance Render Ent36 where
    render_bs (PCDATA_36 _ str) = str
instance Render Ent37 where
    render_bs (Script_37 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_37 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_37 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_37 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_37 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_37 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_37 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_37 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_37 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_37 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_37 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_37 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_37 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_37 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_37 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_37 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_37 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_37 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_37 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_37 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_37 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_37 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_37 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_37 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_37 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_37 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_37 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_37 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_37 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_37 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_37 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_37 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_37 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_37 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_37 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_37 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_37 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_37 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_37 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_37 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_37 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_37 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_37 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_37 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_37 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_37 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_37 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_37 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_37 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_37 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_37 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_37 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_37 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_37 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Form_37 att c) = B.concat [form_byte_b,renderAtts (att++[action_att []]),gt_byte, maprender c,form_byte_e]
    render_bs (Input_37 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_37 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_37 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_37 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Button_37 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_37 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_37 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_37 _ str) = str
instance Render Ent38 where
    render_bs (Li_38 att c) = B.concat [li_byte_b,renderAtts att,gt_byte, maprender c,li_byte_e]
instance Render Ent39 where
    render_bs (Dt_39 att c) = B.concat [dt_byte_b,renderAtts att,gt_byte, maprender c,dt_byte_e]
    render_bs (Dd_39 att c) = B.concat [dd_byte_b,renderAtts att,gt_byte, maprender c,dd_byte_e]
instance Render Ent40 where
    render_bs (Script_40 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Iframe_40 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (P_40 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (Ins_40 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_40 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_40 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_40 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_40 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_40 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_40 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_40 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_40 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_40 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_40 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_40 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_40 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_40 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_40 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_40 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_40 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_40 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_40 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_40 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_40 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_40 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_40 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_40 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_40 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_40 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_40 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_40 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_40 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_40 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_40 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_40 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Input_40 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_40 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_40 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_40 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_40 _ str) = str
instance Render Ent41 where
    render_bs (Script_41 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Ins_41 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_41 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_41 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_41 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_41 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_41 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_41 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_41 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_41 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_41 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_41 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_41 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_41 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_41 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_41 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_41 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Tt_41 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_41 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_41 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (U_41 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_41 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_41 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Input_41 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_41 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_41 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_41 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_41 _ str) = str
instance Render Ent42 where
    render_bs (Script_42 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_42 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_42 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_42 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_42 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_42 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_42 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_42 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_42 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_42 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_42 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_42 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_42 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_42 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_42 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_42 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_42 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_42 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_42 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_42 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_42 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_42 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_42 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_42 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_42 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_42 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_42 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_42 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_42 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_42 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_42 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_42 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_42 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_42 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_42 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_42 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_42 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_42 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_42 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_42 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_42 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_42 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_42 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_42 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_42 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_42 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_42 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_42 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_42 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_42 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_42 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_42 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_42 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_42 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Input_42 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_42 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_42 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_42 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Button_42 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_42 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_42 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_42 _ str) = str
instance Render Ent43 where
    render_bs (Script_43 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Iframe_43 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Ins_43 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_43 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_43 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_43 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_43 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_43 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_43 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_43 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_43 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_43 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_43 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_43 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_43 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_43 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_43 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_43 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_43 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_43 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_43 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_43 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_43 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_43 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_43 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_43 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_43 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_43 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_43 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_43 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_43 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_43 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_43 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_43 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Input_43 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_43 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_43 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_43 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_43 _ str) = str
instance Render Ent44 where
    render_bs (Li_44 att c) = B.concat [li_byte_b,renderAtts att,gt_byte, maprender c,li_byte_e]
instance Render Ent45 where
    render_bs (Dt_45 att c) = B.concat [dt_byte_b,renderAtts att,gt_byte, maprender c,dt_byte_e]
    render_bs (Dd_45 att c) = B.concat [dd_byte_b,renderAtts att,gt_byte, maprender c,dd_byte_e]
instance Render Ent46 where
    render_bs (Script_46 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Iframe_46 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (P_46 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (Ins_46 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_46 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_46 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_46 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_46 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_46 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_46 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_46 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_46 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_46 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_46 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_46 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_46 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_46 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_46 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_46 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_46 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_46 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_46 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_46 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_46 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_46 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_46 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_46 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_46 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_46 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_46 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_46 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_46 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_46 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_46 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_46 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Input_46 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_46 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_46 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_46 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_46 _ str) = str
instance Render Ent47 where
    render_bs (Script_47 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Ins_47 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_47 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_47 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_47 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_47 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_47 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_47 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_47 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_47 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_47 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_47 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_47 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_47 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_47 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_47 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_47 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Tt_47 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_47 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_47 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (U_47 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_47 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_47 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Input_47 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_47 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_47 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_47 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_47 _ str) = str
instance Render Ent48 where
    render_bs (Script_48 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_48 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_48 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_48 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_48 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_48 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_48 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_48 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_48 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_48 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_48 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_48 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_48 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_48 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_48 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_48 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_48 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_48 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_48 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_48 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_48 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_48 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_48 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_48 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_48 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_48 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_48 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_48 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_48 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_48 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_48 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_48 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_48 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_48 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_48 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_48 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_48 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_48 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_48 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_48 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_48 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_48 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_48 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_48 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_48 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_48 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_48 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_48 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_48 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_48 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_48 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_48 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_48 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_48 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Input_48 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_48 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_48 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_48 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Legend_48 att c) = B.concat [legend_byte_b,renderAtts att,gt_byte, maprender c,legend_byte_e]
    render_bs (Button_48 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_48 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_48 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_48 _ str) = str
instance Render Ent49 where
    render_bs (Caption_49 att c) = B.concat [caption_byte_b,renderAtts att,gt_byte, maprender c,caption_byte_e]
    render_bs (Thead_49 att c) = B.concat [thead_byte_b,renderAtts att,gt_byte, maprender c,thead_byte_e]
    render_bs (Tfoot_49 att c) = B.concat [tfoot_byte_b,renderAtts att,gt_byte, maprender c,tfoot_byte_e]
    render_bs (Tbody_49 att c) = B.concat [tbody_byte_b,renderAtts att,gt_byte, maprender c,tbody_byte_e]
    render_bs (Colgroup_49 att c) = B.concat [colgroup_byte_b,renderAtts att,gt_byte, maprender c,colgroup_byte_e]
    render_bs (Col_49 att) = B.concat [col_byte_b,renderAtts att,gts_byte]
    render_bs (Tr_49 att c) = B.concat [tr_byte_b,renderAtts att,gt_byte, maprender c,tr_byte_e]
instance Render Ent50 where
    render_bs (Tr_50 att c) = B.concat [tr_byte_b,renderAtts att,gt_byte, maprender c,tr_byte_e]
instance Render Ent51 where
    render_bs (Col_51 att) = B.concat [col_byte_b,renderAtts att,gts_byte]
instance Render Ent52 where
    render_bs (Th_52 att c) = B.concat [th_byte_b,renderAtts att,gt_byte, maprender c,th_byte_e]
    render_bs (Td_52 att c) = B.concat [td_byte_b,renderAtts att,gt_byte, maprender c,td_byte_e]
instance Render Ent53 where
    render_bs (Script_53 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_53 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_53 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_53 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_53 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_53 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_53 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_53 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_53 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_53 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_53 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_53 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_53 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_53 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_53 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_53 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_53 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_53 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_53 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_53 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_53 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_53 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_53 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_53 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_53 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_53 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_53 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_53 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_53 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_53 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_53 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_53 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_53 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_53 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_53 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_53 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_53 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_53 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_53 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_53 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_53 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_53 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_53 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_53 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_53 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_53 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_53 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_53 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_53 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_53 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_53 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_53 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_53 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_53 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Form_53 att c) = B.concat [form_byte_b,renderAtts (att++[action_att []]),gt_byte, maprender c,form_byte_e]
    render_bs (Input_53 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_53 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_53 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_53 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Legend_53 att c) = B.concat [legend_byte_b,renderAtts att,gt_byte, maprender c,legend_byte_e]
    render_bs (Button_53 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_53 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_53 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_53 _ str) = str
instance Render Ent54 where
    render_bs (Caption_54 att c) = B.concat [caption_byte_b,renderAtts att,gt_byte, maprender c,caption_byte_e]
    render_bs (Thead_54 att c) = B.concat [thead_byte_b,renderAtts att,gt_byte, maprender c,thead_byte_e]
    render_bs (Tfoot_54 att c) = B.concat [tfoot_byte_b,renderAtts att,gt_byte, maprender c,tfoot_byte_e]
    render_bs (Tbody_54 att c) = B.concat [tbody_byte_b,renderAtts att,gt_byte, maprender c,tbody_byte_e]
    render_bs (Colgroup_54 att c) = B.concat [colgroup_byte_b,renderAtts att,gt_byte, maprender c,colgroup_byte_e]
    render_bs (Col_54 att) = B.concat [col_byte_b,renderAtts att,gts_byte]
    render_bs (Tr_54 att c) = B.concat [tr_byte_b,renderAtts att,gt_byte, maprender c,tr_byte_e]
instance Render Ent55 where
    render_bs (Tr_55 att c) = B.concat [tr_byte_b,renderAtts att,gt_byte, maprender c,tr_byte_e]
instance Render Ent56 where
    render_bs (Col_56 att) = B.concat [col_byte_b,renderAtts att,gts_byte]
instance Render Ent57 where
    render_bs (Th_57 att c) = B.concat [th_byte_b,renderAtts att,gt_byte, maprender c,th_byte_e]
    render_bs (Td_57 att c) = B.concat [td_byte_b,renderAtts att,gt_byte, maprender c,td_byte_e]
instance Render Ent58 where
    render_bs (Script_58 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_58 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_58 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_58 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_58 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_58 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_58 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_58 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_58 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_58 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_58 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_58 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_58 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_58 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_58 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_58 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_58 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_58 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_58 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_58 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_58 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_58 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_58 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_58 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_58 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_58 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_58 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_58 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_58 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_58 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_58 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_58 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_58 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_58 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_58 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_58 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_58 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_58 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_58 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_58 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_58 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_58 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_58 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_58 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_58 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_58 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_58 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_58 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_58 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_58 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_58 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Param_58 att) = B.concat [param_byte_b,renderAtts (att++[name_att []]),gts_byte]
    render_bs (Applet_58 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_58 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_58 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Form_58 att c) = B.concat [form_byte_b,renderAtts (att++[action_att []]),gt_byte, maprender c,form_byte_e]
    render_bs (Input_58 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_58 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_58 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_58 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Button_58 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_58 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_58 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_58 _ str) = str
instance Render Ent59 where
    render_bs (Script_59 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_59 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Noframes_59 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_59 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_59 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_59 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_59 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_59 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_59 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_59 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_59 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_59 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_59 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_59 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_59 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_59 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_59 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_59 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_59 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_59 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_59 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_59 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_59 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Area_59 att) = B.concat [area_byte_b,renderAtts (att++[alt_att []]),gts_byte]
    render_bs (Form_59 att c) = B.concat [form_byte_b,renderAtts (att++[action_att []]),gt_byte, maprender c,form_byte_e]
    render_bs (Fieldset_59 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Isindex_59 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_59 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
instance Render Ent60 where
    render_bs (Optgroup_60 att c) = B.concat [optgroup_byte_b,renderAtts (att++[label_att []]),gt_byte, maprender c,optgroup_byte_e]
    render_bs (Option_60 att c) = B.concat [option_byte_b,renderAtts att,gt_byte, maprender c,option_byte_e]
instance Render Ent61 where
    render_bs (Option_61 att c) = B.concat [option_byte_b,renderAtts att,gt_byte, maprender c,option_byte_e]
instance Render Ent62 where
    render_bs (Script_62 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_62 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Noframes_62 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_62 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_62 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_62 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_62 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_62 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_62 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_62 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_62 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_62 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_62 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_62 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_62 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_62 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_62 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_62 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_62 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_62 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_62 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_62 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_62 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_62 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_62 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_62 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_62 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_62 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_62 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_62 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_62 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_62 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_62 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_62 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_62 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_62 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_62 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_62 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_62 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_62 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_62 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_62 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_62 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_62 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_62 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_62 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_62 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_62 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_62 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_62 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_62 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_62 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_62 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Table_62 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_62 _ str) = str
instance Render Ent63 where
    render_bs (Optgroup_63 att c) = B.concat [optgroup_byte_b,renderAtts (att++[label_att []]),gt_byte, maprender c,optgroup_byte_e]
    render_bs (Option_63 att c) = B.concat [option_byte_b,renderAtts att,gt_byte, maprender c,option_byte_e]
instance Render Ent64 where
    render_bs (Option_64 att c) = B.concat [option_byte_b,renderAtts att,gt_byte, maprender c,option_byte_e]
instance Render Ent65 where
    render_bs (Script_65 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_65 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Noframes_65 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_65 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_65 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_65 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_65 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_65 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_65 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_65 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_65 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_65 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_65 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_65 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_65 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_65 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_65 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_65 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_65 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_65 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_65 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_65 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_65 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_65 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_65 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_65 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_65 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_65 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_65 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_65 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_65 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_65 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_65 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_65 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_65 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_65 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_65 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_65 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_65 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_65 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_65 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_65 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_65 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_65 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_65 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_65 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_65 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_65 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_65 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_65 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_65 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_65 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_65 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Table_65 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_65 _ str) = str
instance Render Ent66 where
    render_bs (Script_66 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_66 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Noframes_66 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_66 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_66 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_66 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_66 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_66 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_66 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_66 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_66 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_66 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_66 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_66 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_66 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_66 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_66 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_66 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_66 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_66 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_66 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_66 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_66 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Area_66 att) = B.concat [area_byte_b,renderAtts (att++[alt_att []]),gts_byte]
    render_bs (Form_66 att c) = B.concat [form_byte_b,renderAtts (att++[action_att []]),gt_byte, maprender c,form_byte_e]
    render_bs (Fieldset_66 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Isindex_66 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_66 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
instance Render Ent67 where
    render_bs (Script_67 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_67 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_67 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_67 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_67 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_67 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_67 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_67 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_67 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_67 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_67 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_67 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_67 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_67 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_67 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_67 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_67 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_67 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_67 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_67 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_67 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_67 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_67 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_67 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_67 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_67 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_67 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_67 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_67 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_67 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_67 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_67 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_67 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_67 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_67 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_67 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_67 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_67 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_67 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_67 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_67 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_67 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_67 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_67 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_67 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_67 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_67 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_67 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_67 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_67 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_67 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_67 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_67 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_67 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_67 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Label_67 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_67 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_67 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_67 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_67 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Button_67 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_67 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_67 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_67 _ str) = str
instance Render Ent68 where
    render_bs (PCDATA_68 _ str) = str
instance Render Ent69 where
    render_bs (Script_69 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Iframe_69 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Ins_69 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_69 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_69 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_69 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_69 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_69 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_69 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_69 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_69 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_69 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_69 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_69 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_69 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_69 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_69 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_69 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_69 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_69 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_69 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_69 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_69 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_69 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_69 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_69 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_69 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_69 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_69 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_69 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_69 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_69 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_69 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_69 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_69 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Label_69 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_69 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_69 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_69 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_69 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_69 _ str) = str
instance Render Ent70 where
    render_bs (Li_70 att c) = B.concat [li_byte_b,renderAtts att,gt_byte, maprender c,li_byte_e]
instance Render Ent71 where
    render_bs (Dt_71 att c) = B.concat [dt_byte_b,renderAtts att,gt_byte, maprender c,dt_byte_e]
    render_bs (Dd_71 att c) = B.concat [dd_byte_b,renderAtts att,gt_byte, maprender c,dd_byte_e]
instance Render Ent72 where
    render_bs (Script_72 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Iframe_72 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (P_72 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (Ins_72 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_72 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_72 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_72 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_72 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_72 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_72 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_72 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_72 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_72 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_72 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_72 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_72 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_72 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_72 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_72 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_72 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_72 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_72 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_72 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_72 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_72 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_72 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_72 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_72 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_72 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_72 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_72 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_72 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_72 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_72 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_72 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_72 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Label_72 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_72 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_72 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_72 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_72 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_72 _ str) = str
instance Render Ent73 where
    render_bs (Script_73 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Ins_73 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_73 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_73 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_73 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_73 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_73 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_73 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_73 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_73 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_73 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_73 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_73 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_73 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_73 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_73 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_73 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_73 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Tt_73 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_73 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_73 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (U_73 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_73 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_73 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Label_73 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_73 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_73 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_73 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_73 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_73 _ str) = str
instance Render Ent74 where
    render_bs (PCDATA_74 _ str) = str
instance Render Ent75 where
    render_bs (Script_75 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_75 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_75 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_75 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_75 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_75 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_75 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_75 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_75 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_75 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_75 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_75 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_75 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_75 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_75 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_75 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_75 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_75 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_75 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_75 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_75 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_75 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_75 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_75 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_75 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_75 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_75 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_75 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_75 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_75 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_75 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_75 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_75 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_75 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_75 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_75 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_75 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_75 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_75 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_75 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_75 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_75 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_75 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_75 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_75 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_75 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_75 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_75 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_75 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_75 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_75 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Param_75 att) = B.concat [param_byte_b,renderAtts (att++[name_att []]),gts_byte]
    render_bs (Applet_75 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_75 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_75 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Label_75 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_75 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_75 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_75 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_75 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Button_75 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_75 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_75 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_75 _ str) = str
instance Render Ent76 where
    render_bs (Script_76 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_76 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Noframes_76 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_76 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_76 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_76 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_76 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_76 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_76 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_76 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_76 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_76 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_76 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_76 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_76 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_76 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_76 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_76 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_76 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_76 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_76 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_76 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_76 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Area_76 att) = B.concat [area_byte_b,renderAtts (att++[alt_att []]),gts_byte]
    render_bs (Fieldset_76 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Isindex_76 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_76 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
instance Render Ent77 where
    render_bs (PCDATA_77 _ str) = str
instance Render Ent78 where
    render_bs (Script_78 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_78 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_78 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_78 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_78 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_78 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_78 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_78 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_78 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_78 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_78 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_78 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_78 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_78 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_78 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_78 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_78 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_78 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_78 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_78 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_78 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_78 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_78 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_78 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_78 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_78 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_78 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_78 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_78 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_78 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_78 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_78 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_78 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_78 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_78 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_78 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_78 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_78 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_78 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_78 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_78 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_78 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_78 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_78 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_78 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_78 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_78 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_78 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_78 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_78 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_78 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Param_78 att) = B.concat [param_byte_b,renderAtts (att++[name_att []]),gts_byte]
    render_bs (Applet_78 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_78 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_78 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Input_78 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_78 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_78 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_78 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Button_78 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_78 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_78 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_78 _ str) = str
instance Render Ent79 where
    render_bs (Script_79 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_79 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Noframes_79 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_79 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_79 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_79 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_79 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_79 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_79 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_79 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_79 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_79 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_79 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_79 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_79 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_79 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_79 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_79 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_79 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_79 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_79 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_79 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_79 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Area_79 att) = B.concat [area_byte_b,renderAtts (att++[alt_att []]),gts_byte]
    render_bs (Fieldset_79 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Isindex_79 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_79 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
instance Render Ent80 where
    render_bs (Optgroup_80 att c) = B.concat [optgroup_byte_b,renderAtts (att++[label_att []]),gt_byte, maprender c,optgroup_byte_e]
    render_bs (Option_80 att c) = B.concat [option_byte_b,renderAtts att,gt_byte, maprender c,option_byte_e]
instance Render Ent81 where
    render_bs (Option_81 att c) = B.concat [option_byte_b,renderAtts att,gt_byte, maprender c,option_byte_e]
instance Render Ent82 where
    render_bs (Script_82 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_82 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Noframes_82 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_82 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_82 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_82 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_82 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_82 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_82 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_82 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_82 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_82 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_82 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_82 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_82 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_82 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_82 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_82 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_82 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_82 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_82 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_82 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_82 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_82 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_82 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_82 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_82 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_82 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_82 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_82 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_82 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_82 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_82 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_82 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_82 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_82 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_82 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_82 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_82 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_82 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_82 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_82 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_82 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_82 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_82 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_82 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_82 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_82 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_82 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_82 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_82 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_82 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_82 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Table_82 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_82 _ str) = str
instance Render Ent83 where
    render_bs (Optgroup_83 att c) = B.concat [optgroup_byte_b,renderAtts (att++[label_att []]),gt_byte, maprender c,optgroup_byte_e]
    render_bs (Option_83 att c) = B.concat [option_byte_b,renderAtts att,gt_byte, maprender c,option_byte_e]
instance Render Ent84 where
    render_bs (Option_84 att c) = B.concat [option_byte_b,renderAtts att,gt_byte, maprender c,option_byte_e]
instance Render Ent85 where
    render_bs (Script_85 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_85 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Noframes_85 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_85 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_85 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_85 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_85 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_85 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_85 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_85 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_85 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_85 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_85 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_85 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_85 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_85 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_85 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_85 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_85 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_85 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_85 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_85 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_85 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_85 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_85 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_85 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_85 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_85 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_85 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_85 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_85 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_85 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_85 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_85 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_85 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_85 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_85 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_85 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_85 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_85 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_85 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_85 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_85 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_85 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_85 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_85 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_85 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_85 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_85 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_85 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_85 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_85 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_85 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Table_85 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_85 _ str) = str
instance Render Ent86 where
    render_bs (Script_86 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_86 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_86 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_86 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_86 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_86 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_86 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_86 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_86 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_86 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_86 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_86 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_86 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_86 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_86 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_86 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_86 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_86 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_86 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_86 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_86 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_86 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_86 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_86 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_86 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_86 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_86 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_86 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_86 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_86 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_86 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_86 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_86 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_86 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_86 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_86 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_86 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_86 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_86 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_86 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_86 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_86 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_86 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_86 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_86 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_86 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_86 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_86 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_86 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_86 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_86 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_86 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Param_86 att) = B.concat [param_byte_b,renderAtts (att++[name_att []]),gts_byte]
    render_bs (Applet_86 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_86 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_86 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Label_86 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_86 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_86 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_86 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_86 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Button_86 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_86 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_86 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_86 _ str) = str
instance Render Ent87 where
    render_bs (Script_87 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_87 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Noframes_87 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_87 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_87 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_87 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_87 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_87 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_87 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_87 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_87 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_87 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_87 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_87 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_87 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_87 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_87 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_87 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_87 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_87 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_87 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_87 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_87 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Area_87 att) = B.concat [area_byte_b,renderAtts (att++[alt_att []]),gts_byte]
    render_bs (Fieldset_87 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Isindex_87 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_87 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
instance Render Ent88 where
    render_bs (Script_88 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Iframe_88 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Ins_88 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_88 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_88 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_88 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_88 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_88 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_88 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_88 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_88 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_88 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_88 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_88 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_88 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_88 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_88 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_88 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_88 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_88 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_88 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_88 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_88 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_88 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_88 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_88 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_88 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_88 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_88 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_88 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_88 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_88 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_88 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_88 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_88 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Input_88 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_88 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_88 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_88 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_88 _ str) = str
instance Render Ent89 where
    render_bs (PCDATA_89 _ str) = str
instance Render Ent90 where
    render_bs (Script_90 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_90 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_90 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_90 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_90 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_90 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_90 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_90 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_90 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_90 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_90 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_90 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_90 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_90 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_90 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_90 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_90 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_90 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_90 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_90 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_90 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_90 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_90 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_90 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_90 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_90 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_90 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_90 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_90 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_90 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_90 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_90 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_90 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_90 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_90 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_90 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_90 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_90 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_90 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_90 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_90 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_90 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_90 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_90 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_90 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_90 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_90 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_90 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_90 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_90 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_90 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_90 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_90 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_90 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_90 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Input_90 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_90 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_90 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_90 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Button_90 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_90 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_90 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_90 _ str) = str
instance Render Ent91 where
    render_bs (Li_91 att c) = B.concat [li_byte_b,renderAtts att,gt_byte, maprender c,li_byte_e]
instance Render Ent92 where
    render_bs (Dt_92 att c) = B.concat [dt_byte_b,renderAtts att,gt_byte, maprender c,dt_byte_e]
    render_bs (Dd_92 att c) = B.concat [dd_byte_b,renderAtts att,gt_byte, maprender c,dd_byte_e]
instance Render Ent93 where
    render_bs (Script_93 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Iframe_93 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (P_93 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (Ins_93 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_93 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_93 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_93 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_93 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_93 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_93 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_93 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_93 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_93 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_93 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_93 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_93 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_93 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_93 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_93 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_93 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_93 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_93 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_93 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_93 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_93 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_93 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_93 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_93 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_93 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_93 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_93 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_93 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_93 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_93 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_93 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_93 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Input_93 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_93 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_93 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_93 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_93 _ str) = str
instance Render Ent94 where
    render_bs (Script_94 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Ins_94 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_94 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_94 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_94 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_94 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_94 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_94 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_94 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_94 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_94 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_94 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_94 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_94 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_94 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_94 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_94 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_94 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Tt_94 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_94 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_94 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (U_94 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_94 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_94 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Input_94 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_94 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_94 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_94 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_94 _ str) = str
instance Render Ent95 where
    render_bs (Script_95 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_95 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_95 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_95 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_95 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_95 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_95 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_95 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_95 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_95 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_95 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_95 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_95 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_95 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_95 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_95 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_95 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_95 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_95 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_95 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_95 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_95 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_95 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_95 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_95 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_95 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_95 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_95 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_95 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_95 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_95 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_95 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_95 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_95 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_95 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_95 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_95 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_95 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_95 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_95 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_95 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_95 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_95 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_95 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_95 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_95 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_95 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_95 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_95 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_95 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_95 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_95 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_95 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_95 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_95 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Input_95 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_95 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_95 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_95 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Legend_95 att c) = B.concat [legend_byte_b,renderAtts att,gt_byte, maprender c,legend_byte_e]
    render_bs (Button_95 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_95 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_95 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_95 _ str) = str
instance Render Ent96 where
    render_bs (Caption_96 att c) = B.concat [caption_byte_b,renderAtts att,gt_byte, maprender c,caption_byte_e]
    render_bs (Thead_96 att c) = B.concat [thead_byte_b,renderAtts att,gt_byte, maprender c,thead_byte_e]
    render_bs (Tfoot_96 att c) = B.concat [tfoot_byte_b,renderAtts att,gt_byte, maprender c,tfoot_byte_e]
    render_bs (Tbody_96 att c) = B.concat [tbody_byte_b,renderAtts att,gt_byte, maprender c,tbody_byte_e]
    render_bs (Colgroup_96 att c) = B.concat [colgroup_byte_b,renderAtts att,gt_byte, maprender c,colgroup_byte_e]
    render_bs (Col_96 att) = B.concat [col_byte_b,renderAtts att,gts_byte]
    render_bs (Tr_96 att c) = B.concat [tr_byte_b,renderAtts att,gt_byte, maprender c,tr_byte_e]
instance Render Ent97 where
    render_bs (Tr_97 att c) = B.concat [tr_byte_b,renderAtts att,gt_byte, maprender c,tr_byte_e]
instance Render Ent98 where
    render_bs (Col_98 att) = B.concat [col_byte_b,renderAtts att,gts_byte]
instance Render Ent99 where
    render_bs (Th_99 att c) = B.concat [th_byte_b,renderAtts att,gt_byte, maprender c,th_byte_e]
    render_bs (Td_99 att c) = B.concat [td_byte_b,renderAtts att,gt_byte, maprender c,td_byte_e]
instance Render Ent100 where
    render_bs (Script_100 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_100 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_100 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_100 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_100 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_100 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_100 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_100 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_100 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_100 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_100 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_100 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_100 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_100 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_100 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_100 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_100 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_100 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_100 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_100 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_100 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_100 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_100 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_100 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_100 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_100 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_100 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_100 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_100 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_100 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_100 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_100 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_100 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_100 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_100 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_100 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_100 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_100 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_100 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_100 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_100 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_100 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_100 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_100 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_100 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_100 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_100 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_100 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_100 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_100 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_100 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_100 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Param_100 att) = B.concat [param_byte_b,renderAtts (att++[name_att []]),gts_byte]
    render_bs (Applet_100 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_100 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_100 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Input_100 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_100 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_100 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_100 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Button_100 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_100 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_100 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_100 _ str) = str
instance Render Ent101 where
    render_bs (Script_101 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_101 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Noframes_101 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_101 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_101 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_101 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_101 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_101 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_101 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_101 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_101 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_101 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_101 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_101 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_101 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_101 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_101 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_101 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_101 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_101 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_101 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_101 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_101 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Area_101 att) = B.concat [area_byte_b,renderAtts (att++[alt_att []]),gts_byte]
    render_bs (Fieldset_101 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Isindex_101 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_101 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
instance Render Ent102 where
    render_bs (Optgroup_102 att c) = B.concat [optgroup_byte_b,renderAtts (att++[label_att []]),gt_byte, maprender c,optgroup_byte_e]
    render_bs (Option_102 att c) = B.concat [option_byte_b,renderAtts att,gt_byte, maprender c,option_byte_e]
instance Render Ent103 where
    render_bs (Option_103 att c) = B.concat [option_byte_b,renderAtts att,gt_byte, maprender c,option_byte_e]
instance Render Ent104 where
    render_bs (Script_104 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_104 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Noframes_104 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_104 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_104 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_104 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_104 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_104 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_104 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_104 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_104 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_104 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_104 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_104 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_104 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_104 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_104 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_104 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_104 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_104 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_104 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_104 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_104 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_104 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_104 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_104 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_104 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_104 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_104 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_104 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_104 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_104 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_104 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_104 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_104 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_104 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_104 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_104 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_104 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_104 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_104 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_104 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_104 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_104 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_104 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_104 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_104 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_104 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_104 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_104 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_104 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_104 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_104 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Table_104 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_104 _ str) = str
instance Render Ent105 where
    render_bs (Optgroup_105 att c) = B.concat [optgroup_byte_b,renderAtts (att++[label_att []]),gt_byte, maprender c,optgroup_byte_e]
    render_bs (Option_105 att c) = B.concat [option_byte_b,renderAtts att,gt_byte, maprender c,option_byte_e]
instance Render Ent106 where
    render_bs (Option_106 att c) = B.concat [option_byte_b,renderAtts att,gt_byte, maprender c,option_byte_e]
instance Render Ent107 where
    render_bs (Script_107 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_107 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_107 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_107 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_107 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_107 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_107 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_107 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_107 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_107 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_107 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_107 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_107 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_107 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_107 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_107 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_107 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_107 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_107 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_107 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_107 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_107 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_107 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_107 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_107 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_107 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_107 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_107 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_107 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_107 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_107 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_107 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_107 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_107 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_107 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_107 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_107 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_107 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_107 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_107 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_107 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_107 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_107 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_107 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_107 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_107 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_107 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_107 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_107 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_107 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_107 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_107 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_107 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_107 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_107 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Label_107 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_107 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_107 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_107 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_107 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Legend_107 att c) = B.concat [legend_byte_b,renderAtts att,gt_byte, maprender c,legend_byte_e]
    render_bs (Button_107 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_107 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_107 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_107 _ str) = str
instance Render Ent108 where
    render_bs (Script_108 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_108 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Noframes_108 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_108 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_108 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_108 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_108 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_108 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_108 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_108 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_108 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_108 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_108 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_108 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_108 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_108 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_108 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_108 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_108 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_108 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_108 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_108 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_108 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_108 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_108 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_108 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_108 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_108 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_108 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_108 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_108 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_108 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_108 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_108 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_108 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_108 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_108 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_108 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_108 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_108 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_108 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_108 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_108 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_108 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_108 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_108 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_108 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_108 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_108 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_108 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_108 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_108 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_108 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Table_108 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_108 _ str) = str
instance Render Ent109 where
    render_bs (Caption_109 att c) = B.concat [caption_byte_b,renderAtts att,gt_byte, maprender c,caption_byte_e]
    render_bs (Thead_109 att c) = B.concat [thead_byte_b,renderAtts att,gt_byte, maprender c,thead_byte_e]
    render_bs (Tfoot_109 att c) = B.concat [tfoot_byte_b,renderAtts att,gt_byte, maprender c,tfoot_byte_e]
    render_bs (Tbody_109 att c) = B.concat [tbody_byte_b,renderAtts att,gt_byte, maprender c,tbody_byte_e]
    render_bs (Colgroup_109 att c) = B.concat [colgroup_byte_b,renderAtts att,gt_byte, maprender c,colgroup_byte_e]
    render_bs (Col_109 att) = B.concat [col_byte_b,renderAtts att,gts_byte]
    render_bs (Tr_109 att c) = B.concat [tr_byte_b,renderAtts att,gt_byte, maprender c,tr_byte_e]
instance Render Ent110 where
    render_bs (Tr_110 att c) = B.concat [tr_byte_b,renderAtts att,gt_byte, maprender c,tr_byte_e]
instance Render Ent111 where
    render_bs (Col_111 att) = B.concat [col_byte_b,renderAtts att,gts_byte]
instance Render Ent112 where
    render_bs (Th_112 att c) = B.concat [th_byte_b,renderAtts att,gt_byte, maprender c,th_byte_e]
    render_bs (Td_112 att c) = B.concat [td_byte_b,renderAtts att,gt_byte, maprender c,td_byte_e]
instance Render Ent113 where
    render_bs (Script_113 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Iframe_113 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Ins_113 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_113 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_113 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_113 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_113 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_113 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_113 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_113 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_113 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_113 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_113 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_113 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_113 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_113 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_113 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_113 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_113 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_113 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_113 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_113 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_113 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_113 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_113 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_113 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_113 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_113 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_113 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_113 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_113 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_113 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_113 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_113 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_113 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Input_113 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_113 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_113 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_113 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_113 _ str) = str
instance Render Ent114 where
    render_bs (PCDATA_114 _ str) = str
instance Render Ent115 where
    render_bs (Script_115 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_115 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_115 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_115 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_115 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_115 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_115 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_115 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_115 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_115 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_115 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_115 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_115 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_115 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_115 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_115 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_115 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_115 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_115 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_115 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_115 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_115 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_115 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_115 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_115 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_115 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_115 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_115 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_115 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_115 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_115 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_115 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_115 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_115 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_115 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_115 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_115 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_115 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_115 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_115 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_115 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_115 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_115 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_115 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_115 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_115 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_115 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_115 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_115 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_115 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_115 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_115 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_115 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_115 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_115 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Form_115 att c) = B.concat [form_byte_b,renderAtts (att++[action_att []]),gt_byte, maprender c,form_byte_e]
    render_bs (Input_115 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_115 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_115 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_115 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Button_115 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_115 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_115 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_115 _ str) = str
instance Render Ent116 where
    render_bs (Li_116 att c) = B.concat [li_byte_b,renderAtts att,gt_byte, maprender c,li_byte_e]
instance Render Ent117 where
    render_bs (Dt_117 att c) = B.concat [dt_byte_b,renderAtts att,gt_byte, maprender c,dt_byte_e]
    render_bs (Dd_117 att c) = B.concat [dd_byte_b,renderAtts att,gt_byte, maprender c,dd_byte_e]
instance Render Ent118 where
    render_bs (Script_118 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Iframe_118 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (P_118 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (Ins_118 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_118 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_118 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_118 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_118 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_118 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_118 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_118 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_118 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_118 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_118 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_118 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_118 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_118 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_118 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_118 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_118 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_118 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_118 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_118 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_118 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_118 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_118 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_118 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_118 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_118 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_118 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_118 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_118 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_118 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_118 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_118 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_118 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Input_118 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_118 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_118 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_118 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_118 _ str) = str
instance Render Ent119 where
    render_bs (Script_119 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Ins_119 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_119 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_119 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_119 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_119 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_119 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_119 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_119 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_119 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_119 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_119 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_119 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_119 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_119 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_119 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_119 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_119 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Tt_119 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_119 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_119 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (U_119 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_119 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_119 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Input_119 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_119 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_119 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Button_119 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (PCDATA_119 _ str) = str
instance Render Ent120 where
    render_bs (Script_120 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_120 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_120 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_120 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_120 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_120 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_120 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_120 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_120 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_120 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_120 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_120 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_120 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_120 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_120 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_120 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_120 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_120 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_120 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_120 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_120 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_120 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_120 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_120 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_120 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_120 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_120 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_120 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_120 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_120 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_120 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_120 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_120 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_120 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_120 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_120 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_120 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_120 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_120 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_120 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_120 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_120 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_120 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_120 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_120 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_120 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_120 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_120 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_120 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_120 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_120 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_120 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_120 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_120 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_120 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Form_120 att c) = B.concat [form_byte_b,renderAtts (att++[action_att []]),gt_byte, maprender c,form_byte_e]
    render_bs (Input_120 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_120 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_120 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_120 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Legend_120 att c) = B.concat [legend_byte_b,renderAtts att,gt_byte, maprender c,legend_byte_e]
    render_bs (Button_120 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_120 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_120 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_120 _ str) = str
instance Render Ent121 where
    render_bs (Caption_121 att c) = B.concat [caption_byte_b,renderAtts att,gt_byte, maprender c,caption_byte_e]
    render_bs (Thead_121 att c) = B.concat [thead_byte_b,renderAtts att,gt_byte, maprender c,thead_byte_e]
    render_bs (Tfoot_121 att c) = B.concat [tfoot_byte_b,renderAtts att,gt_byte, maprender c,tfoot_byte_e]
    render_bs (Tbody_121 att c) = B.concat [tbody_byte_b,renderAtts att,gt_byte, maprender c,tbody_byte_e]
    render_bs (Colgroup_121 att c) = B.concat [colgroup_byte_b,renderAtts att,gt_byte, maprender c,colgroup_byte_e]
    render_bs (Col_121 att) = B.concat [col_byte_b,renderAtts att,gts_byte]
    render_bs (Tr_121 att c) = B.concat [tr_byte_b,renderAtts att,gt_byte, maprender c,tr_byte_e]
instance Render Ent122 where
    render_bs (Tr_122 att c) = B.concat [tr_byte_b,renderAtts att,gt_byte, maprender c,tr_byte_e]
instance Render Ent123 where
    render_bs (Col_123 att) = B.concat [col_byte_b,renderAtts att,gts_byte]
instance Render Ent124 where
    render_bs (Th_124 att c) = B.concat [th_byte_b,renderAtts att,gt_byte, maprender c,th_byte_e]
    render_bs (Td_124 att c) = B.concat [td_byte_b,renderAtts att,gt_byte, maprender c,td_byte_e]
instance Render Ent125 where
    render_bs (Script_125 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_125 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_125 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_125 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_125 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_125 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_125 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_125 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_125 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_125 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_125 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_125 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_125 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_125 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_125 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_125 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_125 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_125 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_125 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_125 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_125 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_125 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_125 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_125 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_125 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_125 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_125 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_125 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_125 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_125 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_125 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_125 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_125 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_125 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_125 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_125 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_125 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_125 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_125 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_125 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_125 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_125 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_125 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_125 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_125 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_125 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_125 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_125 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_125 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_125 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_125 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_125 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Param_125 att) = B.concat [param_byte_b,renderAtts (att++[name_att []]),gts_byte]
    render_bs (Applet_125 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_125 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_125 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Form_125 att c) = B.concat [form_byte_b,renderAtts (att++[action_att []]),gt_byte, maprender c,form_byte_e]
    render_bs (Input_125 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_125 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_125 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_125 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Button_125 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_125 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_125 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_125 _ str) = str
instance Render Ent126 where
    render_bs (Script_126 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_126 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Noframes_126 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_126 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_126 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_126 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_126 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_126 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_126 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_126 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_126 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_126 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_126 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_126 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_126 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_126 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_126 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_126 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_126 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_126 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_126 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_126 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_126 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Area_126 att) = B.concat [area_byte_b,renderAtts (att++[alt_att []]),gts_byte]
    render_bs (Form_126 att c) = B.concat [form_byte_b,renderAtts (att++[action_att []]),gt_byte, maprender c,form_byte_e]
    render_bs (Fieldset_126 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Isindex_126 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_126 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
instance Render Ent127 where
    render_bs (Optgroup_127 att c) = B.concat [optgroup_byte_b,renderAtts (att++[label_att []]),gt_byte, maprender c,optgroup_byte_e]
    render_bs (Option_127 att c) = B.concat [option_byte_b,renderAtts att,gt_byte, maprender c,option_byte_e]
instance Render Ent128 where
    render_bs (Option_128 att c) = B.concat [option_byte_b,renderAtts att,gt_byte, maprender c,option_byte_e]
instance Render Ent129 where
    render_bs (Script_129 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_129 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Noframes_129 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_129 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_129 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_129 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_129 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_129 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_129 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_129 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_129 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_129 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_129 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_129 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_129 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_129 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_129 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_129 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_129 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_129 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_129 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_129 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_129 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_129 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_129 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_129 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_129 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_129 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_129 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_129 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_129 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_129 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_129 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_129 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_129 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_129 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_129 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_129 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_129 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_129 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_129 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_129 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_129 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_129 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_129 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_129 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_129 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_129 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_129 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_129 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_129 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_129 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_129 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Table_129 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_129 _ str) = str
instance Render Ent130 where
    render_bs (Optgroup_130 att c) = B.concat [optgroup_byte_b,renderAtts (att++[label_att []]),gt_byte, maprender c,optgroup_byte_e]
    render_bs (Option_130 att c) = B.concat [option_byte_b,renderAtts att,gt_byte, maprender c,option_byte_e]
instance Render Ent131 where
    render_bs (Option_131 att c) = B.concat [option_byte_b,renderAtts att,gt_byte, maprender c,option_byte_e]
instance Render Ent132 where
    render_bs (Script_132 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_132 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Iframe_132 att c) = B.concat [iframe_byte_b,renderAtts att,gt_byte, maprender c,iframe_byte_e]
    render_bs (Noframes_132 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_132 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_132 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_132 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_132 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_132 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_132 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_132 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_132 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_132 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_132 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_132 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_132 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_132 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_132 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_132 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_132 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_132 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_132 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_132 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_132 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (A_132 att c) = B.concat [a_byte_b,renderAtts att,gt_byte, maprender c,a_byte_e]
    render_bs (Span_132 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_132 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_132 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_132 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_132 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_132 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_132 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_132 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_132 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_132 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_132 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_132 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_132 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_132 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_132 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_132 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_132 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_132 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_132 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_132 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_132 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_132 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_132 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_132 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_132 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_132 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_132 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_132 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_132 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_132 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Form_132 att c) = B.concat [form_byte_b,renderAtts (att++[action_att []]),gt_byte, maprender c,form_byte_e]
    render_bs (Label_132 att c) = B.concat [label_byte_b,renderAtts att,gt_byte, maprender c,label_byte_e]
    render_bs (Input_132 att) = B.concat [input_byte_b,renderAtts att,gts_byte]
    render_bs (Select_132 att c) = B.concat [select_byte_b,renderAtts att,gt_byte, maprender c,select_byte_e]
    render_bs (Textarea_132 att c) = B.concat [textarea_byte_b,renderAtts (att++[rows_att [],cols_att []]),gt_byte, maprender c,textarea_byte_e]
    render_bs (Fieldset_132 att c) = B.concat [fieldset_byte_b,renderAtts att,gt_byte, maprender c,fieldset_byte_e]
    render_bs (Legend_132 att c) = B.concat [legend_byte_b,renderAtts att,gt_byte, maprender c,legend_byte_e]
    render_bs (Button_132 att c) = B.concat [button_byte_b,renderAtts att,gt_byte, maprender c,button_byte_e]
    render_bs (Isindex_132 att) = B.concat [isindex_byte_b,renderAtts att,gts_byte]
    render_bs (Table_132 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_132 _ str) = str
instance Render Ent133 where
    render_bs (Script_133 att c) = B.concat [script_byte_b,renderAtts (att++[type_att []]),gt_byte, maprender c,script_byte_e]
    render_bs (Noscript_133 att c) = B.concat [noscript_byte_b,renderAtts att,gt_byte, maprender c,noscript_byte_e]
    render_bs (Noframes_133 att c) = B.concat [noframes_byte_b,renderAtts att,gt_byte, maprender c,noframes_byte_e]
    render_bs (Div_133 att c) = B.concat [div_byte_b,renderAtts att,gt_byte, maprender c,div_byte_e]
    render_bs (P_133 att c) = B.concat [p_byte_b,renderAtts att,gt_byte, maprender c,p_byte_e]
    render_bs (H1_133 att c) = B.concat [h1_byte_b,renderAtts att,gt_byte, maprender c,h1_byte_e]
    render_bs (H2_133 att c) = B.concat [h2_byte_b,renderAtts att,gt_byte, maprender c,h2_byte_e]
    render_bs (H3_133 att c) = B.concat [h3_byte_b,renderAtts att,gt_byte, maprender c,h3_byte_e]
    render_bs (H4_133 att c) = B.concat [h4_byte_b,renderAtts att,gt_byte, maprender c,h4_byte_e]
    render_bs (H5_133 att c) = B.concat [h5_byte_b,renderAtts att,gt_byte, maprender c,h5_byte_e]
    render_bs (H6_133 att c) = B.concat [h6_byte_b,renderAtts att,gt_byte, maprender c,h6_byte_e]
    render_bs (Ul_133 att c) = B.concat [ul_byte_b,renderAtts att,gt_byte, maprender c,ul_byte_e]
    render_bs (Ol_133 att c) = B.concat [ol_byte_b,renderAtts att,gt_byte, maprender c,ol_byte_e]
    render_bs (Menu_133 att c) = B.concat [menu_byte_b,renderAtts att,gt_byte, maprender c,menu_byte_e]
    render_bs (Dir_133 att c) = B.concat [dir_byte_b,renderAtts att,gt_byte, maprender c,dir_byte_e]
    render_bs (Dl_133 att c) = B.concat [dl_byte_b,renderAtts att,gt_byte, maprender c,dl_byte_e]
    render_bs (Address_133 att c) = B.concat [address_byte_b,renderAtts att,gt_byte, maprender c,address_byte_e]
    render_bs (Hr_133 att) = B.concat [hr_byte_b,renderAtts att,gts_byte]
    render_bs (Pre_133 att c) = B.concat [pre_byte_b,renderAtts att,gt_byte, maprender c,pre_byte_e]
    render_bs (Blockquote_133 att c) = B.concat [blockquote_byte_b,renderAtts att,gt_byte, maprender c,blockquote_byte_e]
    render_bs (Center_133 att c) = B.concat [center_byte_b,renderAtts att,gt_byte, maprender c,center_byte_e]
    render_bs (Ins_133 att c) = B.concat [ins_byte_b,renderAtts att,gt_byte, maprender c,ins_byte_e]
    render_bs (Del_133 att c) = B.concat [del_byte_b,renderAtts att,gt_byte, maprender c,del_byte_e]
    render_bs (Span_133 att c) = B.concat [span_byte_b,renderAtts att,gt_byte, maprender c,span_byte_e]
    render_bs (Bdo_133 att c) = B.concat [bdo_byte_b,renderAtts (att++[dir_att Ltr]),gt_byte, maprender c,bdo_byte_e]
    render_bs (Br_133 att) = B.concat [br_byte_b,renderAtts att,gts_byte]
    render_bs (Em_133 att c) = B.concat [em_byte_b,renderAtts att,gt_byte, maprender c,em_byte_e]
    render_bs (Strong_133 att c) = B.concat [strong_byte_b,renderAtts att,gt_byte, maprender c,strong_byte_e]
    render_bs (Dfn_133 att c) = B.concat [dfn_byte_b,renderAtts att,gt_byte, maprender c,dfn_byte_e]
    render_bs (Code_133 att c) = B.concat [code_byte_b,renderAtts att,gt_byte, maprender c,code_byte_e]
    render_bs (Samp_133 att c) = B.concat [samp_byte_b,renderAtts att,gt_byte, maprender c,samp_byte_e]
    render_bs (Kbd_133 att c) = B.concat [kbd_byte_b,renderAtts att,gt_byte, maprender c,kbd_byte_e]
    render_bs (Var_133 att c) = B.concat [var_byte_b,renderAtts att,gt_byte, maprender c,var_byte_e]
    render_bs (Cite_133 att c) = B.concat [cite_byte_b,renderAtts att,gt_byte, maprender c,cite_byte_e]
    render_bs (Abbr_133 att c) = B.concat [abbr_byte_b,renderAtts att,gt_byte, maprender c,abbr_byte_e]
    render_bs (Acronym_133 att c) = B.concat [acronym_byte_b,renderAtts att,gt_byte, maprender c,acronym_byte_e]
    render_bs (Q_133 att c) = B.concat [q_byte_b,renderAtts att,gt_byte, maprender c,q_byte_e]
    render_bs (Sub_133 att c) = B.concat [sub_byte_b,renderAtts att,gt_byte, maprender c,sub_byte_e]
    render_bs (Sup_133 att c) = B.concat [sup_byte_b,renderAtts att,gt_byte, maprender c,sup_byte_e]
    render_bs (Tt_133 att c) = B.concat [tt_byte_b,renderAtts att,gt_byte, maprender c,tt_byte_e]
    render_bs (I_133 att c) = B.concat [i_byte_b,renderAtts att,gt_byte, maprender c,i_byte_e]
    render_bs (B_133 att c) = B.concat [b_byte_b,renderAtts att,gt_byte, maprender c,b_byte_e]
    render_bs (Big_133 att c) = B.concat [big_byte_b,renderAtts att,gt_byte, maprender c,big_byte_e]
    render_bs (Small_133 att c) = B.concat [small_byte_b,renderAtts att,gt_byte, maprender c,small_byte_e]
    render_bs (U_133 att c) = B.concat [u_byte_b,renderAtts att,gt_byte, maprender c,u_byte_e]
    render_bs (S_133 att c) = B.concat [s_byte_b,renderAtts att,gt_byte, maprender c,s_byte_e]
    render_bs (Strike_133 att c) = B.concat [strike_byte_b,renderAtts att,gt_byte, maprender c,strike_byte_e]
    render_bs (Basefont_133 att) = B.concat [basefont_byte_b,renderAtts (att++[size_att []]),gts_byte]
    render_bs (Font_133 att c) = B.concat [font_byte_b,renderAtts att,gt_byte, maprender c,font_byte_e]
    render_bs (Object_133 att c) = B.concat [object_byte_b,renderAtts att,gt_byte, maprender c,object_byte_e]
    render_bs (Applet_133 att c) = B.concat [applet_byte_b,renderAtts (att++[width_att [],height_att []]),gt_byte, maprender c,applet_byte_e]
    render_bs (Img_133 att) = B.concat [img_byte_b,renderAtts (att++[src_att [],alt_att []]),gts_byte]
    render_bs (Map_133 att c) = B.concat [map_byte_b,renderAtts (att++[id_att []]),gt_byte, maprender c,map_byte_e]
    render_bs (Table_133 att c) = B.concat [table_byte_b,renderAtts att,gt_byte, maprender c,table_byte_e]
    render_bs (PCDATA_133 _ str) = str
instance Render Ent134 where
    render_bs (Caption_134 att c) = B.concat [caption_byte_b,renderAtts att,gt_byte, maprender c,caption_byte_e]
    render_bs (Thead_134 att c) = B.concat [thead_byte_b,renderAtts att,gt_byte, maprender c,thead_byte_e]
    render_bs (Tfoot_134 att c) = B.concat [tfoot_byte_b,renderAtts att,gt_byte, maprender c,tfoot_byte_e]
    render_bs (Tbody_134 att c) = B.concat [tbody_byte_b,renderAtts att,gt_byte, maprender c,tbody_byte_e]
    render_bs (Colgroup_134 att c) = B.concat [colgroup_byte_b,renderAtts att,gt_byte, maprender c,colgroup_byte_e]
    render_bs (Col_134 att) = B.concat [col_byte_b,renderAtts att,gts_byte]
    render_bs (Tr_134 att c) = B.concat [tr_byte_b,renderAtts att,gt_byte, maprender c,tr_byte_e]
instance Render Ent135 where
    render_bs (Tr_135 att c) = B.concat [tr_byte_b,renderAtts att,gt_byte, maprender c,tr_byte_e]
instance Render Ent136 where
    render_bs (Col_136 att) = B.concat [col_byte_b,renderAtts att,gts_byte]
instance Render Ent137 where
    render_bs (Th_137 att c) = B.concat [th_byte_b,renderAtts att,gt_byte, maprender c,th_byte_e]
    render_bs (Td_137 att c) = B.concat [td_byte_b,renderAtts att,gt_byte, maprender c,td_byte_e]

none_byte_b = s2b "<none"
none_byte_e = s2b "</none>\n"
cdata_byte_b = s2b "<CDATA"
cdata_byte_e = s2b "</CDATA>\n"
pcdata_byte_b = s2b "<PCDATA"
pcdata_byte_e = s2b "</PCDATA>\n"
td_byte_b = s2b "<td"
td_byte_e = s2b "</td>\n"
th_byte_b = s2b "<th"
th_byte_e = s2b "</th>\n"
tr_byte_b = s2b "<tr"
tr_byte_e = s2b "</tr>\n"
col_byte_b = s2b "<col"
col_byte_e = s2b "</col>\n"
colgroup_byte_b = s2b "<colgroup"
colgroup_byte_e = s2b "</colgroup>\n"
tbody_byte_b = s2b "<tbody"
tbody_byte_e = s2b "</tbody>\n"
tfoot_byte_b = s2b "<tfoot"
tfoot_byte_e = s2b "</tfoot>\n"
thead_byte_b = s2b "<thead"
thead_byte_e = s2b "</thead>\n"
caption_byte_b = s2b "<caption"
caption_byte_e = s2b "</caption>\n"
table_byte_b = s2b "<table"
table_byte_e = s2b "</table>\n"
isindex_byte_b = s2b "<isindex"
isindex_byte_e = s2b "</isindex>\n"
button_byte_b = s2b "<button"
button_byte_e = s2b "</button>\n"
legend_byte_b = s2b "<legend"
legend_byte_e = s2b "</legend>\n"
fieldset_byte_b = s2b "<fieldset"
fieldset_byte_e = s2b "</fieldset>\n"
textarea_byte_b = s2b "<textarea"
textarea_byte_e = s2b "</textarea>\n"
option_byte_b = s2b "<option"
option_byte_e = s2b "</option>\n"
optgroup_byte_b = s2b "<optgroup"
optgroup_byte_e = s2b "</optgroup>\n"
select_byte_b = s2b "<select"
select_byte_e = s2b "</select>\n"
input_byte_b = s2b "<input"
input_byte_e = s2b "</input>\n"
label_byte_b = s2b "<label"
label_byte_e = s2b "</label>\n"
form_byte_b = s2b "<form"
form_byte_e = s2b "</form>\n"
area_byte_b = s2b "<area"
area_byte_e = s2b "</area>\n"
map_byte_b = s2b "<map"
map_byte_e = s2b "</map>\n"
img_byte_b = s2b "<img"
img_byte_e = s2b "</img>\n"
applet_byte_b = s2b "<applet"
applet_byte_e = s2b "</applet>\n"
param_byte_b = s2b "<param"
param_byte_e = s2b "</param>\n"
object_byte_b = s2b "<object"
object_byte_e = s2b "</object>\n"
font_byte_b = s2b "<font"
font_byte_e = s2b "</font>\n"
basefont_byte_b = s2b "<basefont"
basefont_byte_e = s2b "</basefont>\n"
strike_byte_b = s2b "<strike"
strike_byte_e = s2b "</strike>\n"
s_byte_b = s2b "<s"
s_byte_e = s2b "</s>\n"
u_byte_b = s2b "<u"
u_byte_e = s2b "</u>\n"
small_byte_b = s2b "<small"
small_byte_e = s2b "</small>\n"
big_byte_b = s2b "<big"
big_byte_e = s2b "</big>\n"
b_byte_b = s2b "<b"
b_byte_e = s2b "</b>\n"
i_byte_b = s2b "<i"
i_byte_e = s2b "</i>\n"
tt_byte_b = s2b "<tt"
tt_byte_e = s2b "</tt>\n"
sup_byte_b = s2b "<sup"
sup_byte_e = s2b "</sup>\n"
sub_byte_b = s2b "<sub"
sub_byte_e = s2b "</sub>\n"
q_byte_b = s2b "<q"
q_byte_e = s2b "</q>\n"
acronym_byte_b = s2b "<acronym"
acronym_byte_e = s2b "</acronym>\n"
abbr_byte_b = s2b "<abbr"
abbr_byte_e = s2b "</abbr>\n"
cite_byte_b = s2b "<cite"
cite_byte_e = s2b "</cite>\n"
var_byte_b = s2b "<var"
var_byte_e = s2b "</var>\n"
kbd_byte_b = s2b "<kbd"
kbd_byte_e = s2b "</kbd>\n"
samp_byte_b = s2b "<samp"
samp_byte_e = s2b "</samp>\n"
code_byte_b = s2b "<code"
code_byte_e = s2b "</code>\n"
dfn_byte_b = s2b "<dfn"
dfn_byte_e = s2b "</dfn>\n"
strong_byte_b = s2b "<strong"
strong_byte_e = s2b "</strong>\n"
em_byte_b = s2b "<em"
em_byte_e = s2b "</em>\n"
br_byte_b = s2b "<br"
br_byte_e = s2b "</br>\n"
bdo_byte_b = s2b "<bdo"
bdo_byte_e = s2b "</bdo>\n"
span_byte_b = s2b "<span"
span_byte_e = s2b "</span>\n"
a_byte_b = s2b "<a"
a_byte_e = s2b "</a>\n"
del_byte_b = s2b "<del"
del_byte_e = s2b "</del>\n"
ins_byte_b = s2b "<ins"
ins_byte_e = s2b "</ins>\n"
center_byte_b = s2b "<center"
center_byte_e = s2b "</center>\n"
blockquote_byte_b = s2b "<blockquote"
blockquote_byte_e = s2b "</blockquote>\n"
pre_byte_b = s2b "<pre"
pre_byte_e = s2b "</pre>\n"
hr_byte_b = s2b "<hr"
hr_byte_e = s2b "</hr>\n"
address_byte_b = s2b "<address"
address_byte_e = s2b "</address>\n"
dd_byte_b = s2b "<dd"
dd_byte_e = s2b "</dd>\n"
dt_byte_b = s2b "<dt"
dt_byte_e = s2b "</dt>\n"
dl_byte_b = s2b "<dl"
dl_byte_e = s2b "</dl>\n"
li_byte_b = s2b "<li"
li_byte_e = s2b "</li>\n"
dir_byte_b = s2b "<dir"
dir_byte_e = s2b "</dir>\n"
menu_byte_b = s2b "<menu"
menu_byte_e = s2b "</menu>\n"
ol_byte_b = s2b "<ol"
ol_byte_e = s2b "</ol>\n"
ul_byte_b = s2b "<ul"
ul_byte_e = s2b "</ul>\n"
h6_byte_b = s2b "<h6"
h6_byte_e = s2b "</h6>\n"
h5_byte_b = s2b "<h5"
h5_byte_e = s2b "</h5>\n"
h4_byte_b = s2b "<h4"
h4_byte_e = s2b "</h4>\n"
h3_byte_b = s2b "<h3"
h3_byte_e = s2b "</h3>\n"
h2_byte_b = s2b "<h2"
h2_byte_e = s2b "</h2>\n"
h1_byte_b = s2b "<h1"
h1_byte_e = s2b "</h1>\n"
p_byte_b = s2b "<p"
p_byte_e = s2b "</p>\n"
div_byte_b = s2b "<div"
div_byte_e = s2b "</div>\n"
body_byte_b = s2b "<body"
body_byte_e = s2b "</body>\n"
noframes_byte_b = s2b "<noframes"
noframes_byte_e = s2b "</noframes>\n"
iframe_byte_b = s2b "<iframe"
iframe_byte_e = s2b "</iframe>\n"
noscript_byte_b = s2b "<noscript"
noscript_byte_e = s2b "</noscript>\n"
script_byte_b = s2b "<script"
script_byte_e = s2b "</script>\n"
style_byte_b = s2b "<style"
style_byte_e = s2b "</style>\n"
link_byte_b = s2b "<link"
link_byte_e = s2b "</link>\n"
meta_byte_b = s2b "<meta"
meta_byte_e = s2b "</meta>\n"
base_byte_b = s2b "<base"
base_byte_e = s2b "</base>\n"
title_byte_b = s2b "<title"
title_byte_e = s2b "</title>\n"
head_byte_b = s2b "<head"
head_byte_e = s2b "</head>\n"
html_byte_b = s2b "<html"
html_byte_e = s2b "</html>\n"

http_equiv_byte = s2b "http-equiv"
clear_byte = s2b "clear"
content_byte = s2b "content"
nohref_byte = s2b "nohref"
onkeydown_byte = s2b "onkeydown"
target_byte = s2b "target"
onkeyup_byte = s2b "onkeyup"
onreset_byte = s2b "onreset"
onmouseup_byte = s2b "onmouseup"
scope_byte = s2b "scope"
code_byte = s2b "code"
onmouseover_byte = s2b "onmouseover"
align_byte = s2b "align"
lang_byte = s2b "lang"
valign_byte = s2b "valign"
name_byte = s2b "name"
charset_byte = s2b "charset"
scheme_byte = s2b "scheme"
prompt_byte = s2b "prompt"
accept_charset_byte = s2b "accept-charset"
frameborder_byte = s2b "frameborder"
onmousedown_byte = s2b "onmousedown"
rev_byte = s2b "rev"
span_byte = s2b "span"
title_byte = s2b "title"
onclick_byte = s2b "onclick"
start_byte = s2b "start"
width_byte = s2b "width"
vlink_byte = s2b "vlink"
enctype_byte = s2b "enctype"
ismap_byte = s2b "ismap"
usemap_byte = s2b "usemap"
nowrap_byte = s2b "nowrap"
coords_byte = s2b "coords"
frame_byte = s2b "frame"
onblur_byte = s2b "onblur"
datetime_byte = s2b "datetime"
size_byte = s2b "size"
dir_byte = s2b "dir"
face_byte = s2b "face"
color_byte = s2b "color"
summary_byte = s2b "summary"
bgcolor_byte = s2b "bgcolor"
text_byte = s2b "text"
method_byte = s2b "method"
vspace_byte = s2b "vspace"
standby_byte = s2b "standby"
tabindex_byte = s2b "tabindex"
language_byte = s2b "language"
background_byte = s2b "background"
style_byte = s2b "style"
onmousemove_byte = s2b "onmousemove"
height_byte = s2b "height"
codetype_byte = s2b "codetype"
char_byte = s2b "char"
multiple_byte = s2b "multiple"
codebase_byte = s2b "codebase"
xmlns_byte = s2b "xmlns"
profile_byte = s2b "profile"
rel_byte = s2b "rel"
onsubmit_byte = s2b "onsubmit"
ondblclick_byte = s2b "ondblclick"
axis_byte = s2b "axis"
cols_byte = s2b "cols"
marginwidth_byte = s2b "marginwidth"
abbr_byte = s2b "abbr"
onchange_byte = s2b "onchange"
readonly_byte = s2b "readonly"
href_byte = s2b "href"
media_byte = s2b "media"
id_byte = s2b "id"
compact_byte = s2b "compact"
for_byte = s2b "for"
src_byte = s2b "src"
value_byte = s2b "value"
data_byte = s2b "data"
hreflang_byte = s2b "hreflang"
checked_byte = s2b "checked"
declare_byte = s2b "declare"
onkeypress_byte = s2b "onkeypress"
label_byte = s2b "label"
class_byte = s2b "class"
type_byte = s2b "type"
shape_byte = s2b "shape"
accesskey_byte = s2b "accesskey"
headers_byte = s2b "headers"
disabled_byte = s2b "disabled"
object_byte = s2b "object"
scrolling_byte = s2b "scrolling"
rules_byte = s2b "rules"
rows_byte = s2b "rows"
alink_byte = s2b "alink"
onfocus_byte = s2b "onfocus"
colspan_byte = s2b "colspan"
rowspan_byte = s2b "rowspan"
defer_byte = s2b "defer"
cellspacing_byte = s2b "cellspacing"
charoff_byte = s2b "charoff"
cite_byte = s2b "cite"
marginheight_byte = s2b "marginheight"
maxlength_byte = s2b "maxlength"
link_byte = s2b "link"
onselect_byte = s2b "onselect"
accept_byte = s2b "accept"
alt_byte = s2b "alt"
archive_byte = s2b "archive"
classid_byte = s2b "classid"
longdesc_byte = s2b "longdesc"
onmouseout_byte = s2b "onmouseout"
border_byte = s2b "border"
noshade_byte = s2b "noshade"
onunload_byte = s2b "onunload"
hspace_byte = s2b "hspace"
action_byte = s2b "action"
onload_byte = s2b "onload"
cellpadding_byte = s2b "cellpadding"
valuetype_byte = s2b "valuetype"
selected_byte = s2b "selected"

class TagStr a where
    tagStr :: a -> String
instance TagStr Ent where
    tagStr (Html _ _) = "html"
instance TagStr Ent0 where
    tagStr (Head_0 _ _) = "head"
    tagStr (Body_0 _ _) = "body"
instance TagStr Ent1 where
    tagStr (Title_1 _ _) = "title"
    tagStr (Base_1 _) = "base"
    tagStr (Meta_1 _) = "meta"
    tagStr (Link_1 _) = "link"
    tagStr (Style_1 _ _) = "style"
    tagStr (Script_1 _ _) = "script"
    tagStr (Object_1 _ _) = "object"
    tagStr (Isindex_1 _) = "isindex"
instance TagStr Ent2 where
    tagStr (PCDATA_2 _ _) = "pcdata"
instance TagStr Ent3 where
    tagStr (Script_3 _ _) = "script"
    tagStr (Noscript_3 _ _) = "noscript"
    tagStr (Iframe_3 _ _) = "iframe"
    tagStr (Noframes_3 _ _) = "noframes"
    tagStr (Div_3 _ _) = "div"
    tagStr (P_3 _ _) = "p"
    tagStr (H1_3 _ _) = "h1"
    tagStr (H2_3 _ _) = "h2"
    tagStr (H3_3 _ _) = "h3"
    tagStr (H4_3 _ _) = "h4"
    tagStr (H5_3 _ _) = "h5"
    tagStr (H6_3 _ _) = "h6"
    tagStr (Ul_3 _ _) = "ul"
    tagStr (Ol_3 _ _) = "ol"
    tagStr (Menu_3 _ _) = "menu"
    tagStr (Dir_3 _ _) = "dir"
    tagStr (Dl_3 _ _) = "dl"
    tagStr (Address_3 _ _) = "address"
    tagStr (Hr_3 _) = "hr"
    tagStr (Pre_3 _ _) = "pre"
    tagStr (Blockquote_3 _ _) = "blockquote"
    tagStr (Center_3 _ _) = "center"
    tagStr (Ins_3 _ _) = "ins"
    tagStr (Del_3 _ _) = "del"
    tagStr (A_3 _ _) = "a"
    tagStr (Span_3 _ _) = "span"
    tagStr (Bdo_3 _ _) = "bdo"
    tagStr (Br_3 _) = "br"
    tagStr (Em_3 _ _) = "em"
    tagStr (Strong_3 _ _) = "strong"
    tagStr (Dfn_3 _ _) = "dfn"
    tagStr (Code_3 _ _) = "code"
    tagStr (Samp_3 _ _) = "samp"
    tagStr (Kbd_3 _ _) = "kbd"
    tagStr (Var_3 _ _) = "var"
    tagStr (Cite_3 _ _) = "cite"
    tagStr (Abbr_3 _ _) = "abbr"
    tagStr (Acronym_3 _ _) = "acronym"
    tagStr (Q_3 _ _) = "q"
    tagStr (Sub_3 _ _) = "sub"
    tagStr (Sup_3 _ _) = "sup"
    tagStr (Tt_3 _ _) = "tt"
    tagStr (I_3 _ _) = "i"
    tagStr (B_3 _ _) = "b"
    tagStr (Big_3 _ _) = "big"
    tagStr (Small_3 _ _) = "small"
    tagStr (U_3 _ _) = "u"
    tagStr (S_3 _ _) = "s"
    tagStr (Strike_3 _ _) = "strike"
    tagStr (Basefont_3 _) = "basefont"
    tagStr (Font_3 _ _) = "font"
    tagStr (Object_3 _ _) = "object"
    tagStr (Param_3 _) = "param"
    tagStr (Applet_3 _ _) = "applet"
    tagStr (Img_3 _) = "img"
    tagStr (Map_3 _ _) = "map"
    tagStr (Form_3 _ _) = "form"
    tagStr (Label_3 _ _) = "label"
    tagStr (Input_3 _) = "input"
    tagStr (Select_3 _ _) = "select"
    tagStr (Textarea_3 _ _) = "textarea"
    tagStr (Fieldset_3 _ _) = "fieldset"
    tagStr (Button_3 _ _) = "button"
    tagStr (Isindex_3 _) = "isindex"
    tagStr (Table_3 _ _) = "table"
    tagStr (PCDATA_3 _ _) = "pcdata"
instance TagStr Ent4 where
    tagStr (Script_4 _ _) = "script"
    tagStr (Noscript_4 _ _) = "noscript"
    tagStr (Iframe_4 _ _) = "iframe"
    tagStr (Noframes_4 _ _) = "noframes"
    tagStr (Div_4 _ _) = "div"
    tagStr (P_4 _ _) = "p"
    tagStr (H1_4 _ _) = "h1"
    tagStr (H2_4 _ _) = "h2"
    tagStr (H3_4 _ _) = "h3"
    tagStr (H4_4 _ _) = "h4"
    tagStr (H5_4 _ _) = "h5"
    tagStr (H6_4 _ _) = "h6"
    tagStr (Ul_4 _ _) = "ul"
    tagStr (Ol_4 _ _) = "ol"
    tagStr (Menu_4 _ _) = "menu"
    tagStr (Dir_4 _ _) = "dir"
    tagStr (Dl_4 _ _) = "dl"
    tagStr (Address_4 _ _) = "address"
    tagStr (Hr_4 _) = "hr"
    tagStr (Pre_4 _ _) = "pre"
    tagStr (Blockquote_4 _ _) = "blockquote"
    tagStr (Center_4 _ _) = "center"
    tagStr (Ins_4 _ _) = "ins"
    tagStr (Del_4 _ _) = "del"
    tagStr (A_4 _ _) = "a"
    tagStr (Span_4 _ _) = "span"
    tagStr (Bdo_4 _ _) = "bdo"
    tagStr (Br_4 _) = "br"
    tagStr (Em_4 _ _) = "em"
    tagStr (Strong_4 _ _) = "strong"
    tagStr (Dfn_4 _ _) = "dfn"
    tagStr (Code_4 _ _) = "code"
    tagStr (Samp_4 _ _) = "samp"
    tagStr (Kbd_4 _ _) = "kbd"
    tagStr (Var_4 _ _) = "var"
    tagStr (Cite_4 _ _) = "cite"
    tagStr (Abbr_4 _ _) = "abbr"
    tagStr (Acronym_4 _ _) = "acronym"
    tagStr (Q_4 _ _) = "q"
    tagStr (Sub_4 _ _) = "sub"
    tagStr (Sup_4 _ _) = "sup"
    tagStr (Tt_4 _ _) = "tt"
    tagStr (I_4 _ _) = "i"
    tagStr (B_4 _ _) = "b"
    tagStr (Big_4 _ _) = "big"
    tagStr (Small_4 _ _) = "small"
    tagStr (U_4 _ _) = "u"
    tagStr (S_4 _ _) = "s"
    tagStr (Strike_4 _ _) = "strike"
    tagStr (Basefont_4 _) = "basefont"
    tagStr (Font_4 _ _) = "font"
    tagStr (Object_4 _ _) = "object"
    tagStr (Applet_4 _ _) = "applet"
    tagStr (Img_4 _) = "img"
    tagStr (Map_4 _ _) = "map"
    tagStr (Form_4 _ _) = "form"
    tagStr (Label_4 _ _) = "label"
    tagStr (Input_4 _) = "input"
    tagStr (Select_4 _ _) = "select"
    tagStr (Textarea_4 _ _) = "textarea"
    tagStr (Fieldset_4 _ _) = "fieldset"
    tagStr (Button_4 _ _) = "button"
    tagStr (Isindex_4 _) = "isindex"
    tagStr (Table_4 _ _) = "table"
    tagStr (PCDATA_4 _ _) = "pcdata"
instance TagStr Ent5 where
    tagStr (Script_5 _ _) = "script"
    tagStr (Iframe_5 _ _) = "iframe"
    tagStr (Ins_5 _ _) = "ins"
    tagStr (Del_5 _ _) = "del"
    tagStr (A_5 _ _) = "a"
    tagStr (Span_5 _ _) = "span"
    tagStr (Bdo_5 _ _) = "bdo"
    tagStr (Br_5 _) = "br"
    tagStr (Em_5 _ _) = "em"
    tagStr (Strong_5 _ _) = "strong"
    tagStr (Dfn_5 _ _) = "dfn"
    tagStr (Code_5 _ _) = "code"
    tagStr (Samp_5 _ _) = "samp"
    tagStr (Kbd_5 _ _) = "kbd"
    tagStr (Var_5 _ _) = "var"
    tagStr (Cite_5 _ _) = "cite"
    tagStr (Abbr_5 _ _) = "abbr"
    tagStr (Acronym_5 _ _) = "acronym"
    tagStr (Q_5 _ _) = "q"
    tagStr (Sub_5 _ _) = "sub"
    tagStr (Sup_5 _ _) = "sup"
    tagStr (Tt_5 _ _) = "tt"
    tagStr (I_5 _ _) = "i"
    tagStr (B_5 _ _) = "b"
    tagStr (Big_5 _ _) = "big"
    tagStr (Small_5 _ _) = "small"
    tagStr (U_5 _ _) = "u"
    tagStr (S_5 _ _) = "s"
    tagStr (Strike_5 _ _) = "strike"
    tagStr (Basefont_5 _) = "basefont"
    tagStr (Font_5 _ _) = "font"
    tagStr (Object_5 _ _) = "object"
    tagStr (Applet_5 _ _) = "applet"
    tagStr (Img_5 _) = "img"
    tagStr (Map_5 _ _) = "map"
    tagStr (Label_5 _ _) = "label"
    tagStr (Input_5 _) = "input"
    tagStr (Select_5 _ _) = "select"
    tagStr (Textarea_5 _ _) = "textarea"
    tagStr (Button_5 _ _) = "button"
    tagStr (PCDATA_5 _ _) = "pcdata"
instance TagStr Ent6 where
    tagStr (Li_6 _ _) = "li"
instance TagStr Ent7 where
    tagStr (Dt_7 _ _) = "dt"
    tagStr (Dd_7 _ _) = "dd"
instance TagStr Ent8 where
    tagStr (Script_8 _ _) = "script"
    tagStr (Iframe_8 _ _) = "iframe"
    tagStr (P_8 _ _) = "p"
    tagStr (Ins_8 _ _) = "ins"
    tagStr (Del_8 _ _) = "del"
    tagStr (A_8 _ _) = "a"
    tagStr (Span_8 _ _) = "span"
    tagStr (Bdo_8 _ _) = "bdo"
    tagStr (Br_8 _) = "br"
    tagStr (Em_8 _ _) = "em"
    tagStr (Strong_8 _ _) = "strong"
    tagStr (Dfn_8 _ _) = "dfn"
    tagStr (Code_8 _ _) = "code"
    tagStr (Samp_8 _ _) = "samp"
    tagStr (Kbd_8 _ _) = "kbd"
    tagStr (Var_8 _ _) = "var"
    tagStr (Cite_8 _ _) = "cite"
    tagStr (Abbr_8 _ _) = "abbr"
    tagStr (Acronym_8 _ _) = "acronym"
    tagStr (Q_8 _ _) = "q"
    tagStr (Sub_8 _ _) = "sub"
    tagStr (Sup_8 _ _) = "sup"
    tagStr (Tt_8 _ _) = "tt"
    tagStr (I_8 _ _) = "i"
    tagStr (B_8 _ _) = "b"
    tagStr (Big_8 _ _) = "big"
    tagStr (Small_8 _ _) = "small"
    tagStr (U_8 _ _) = "u"
    tagStr (S_8 _ _) = "s"
    tagStr (Strike_8 _ _) = "strike"
    tagStr (Basefont_8 _) = "basefont"
    tagStr (Font_8 _ _) = "font"
    tagStr (Object_8 _ _) = "object"
    tagStr (Applet_8 _ _) = "applet"
    tagStr (Img_8 _) = "img"
    tagStr (Map_8 _ _) = "map"
    tagStr (Label_8 _ _) = "label"
    tagStr (Input_8 _) = "input"
    tagStr (Select_8 _ _) = "select"
    tagStr (Textarea_8 _ _) = "textarea"
    tagStr (Button_8 _ _) = "button"
    tagStr (PCDATA_8 _ _) = "pcdata"
instance TagStr Ent9 where
    tagStr (Script_9 _ _) = "script"
    tagStr (Ins_9 _ _) = "ins"
    tagStr (Del_9 _ _) = "del"
    tagStr (A_9 _ _) = "a"
    tagStr (Span_9 _ _) = "span"
    tagStr (Bdo_9 _ _) = "bdo"
    tagStr (Br_9 _) = "br"
    tagStr (Em_9 _ _) = "em"
    tagStr (Strong_9 _ _) = "strong"
    tagStr (Dfn_9 _ _) = "dfn"
    tagStr (Code_9 _ _) = "code"
    tagStr (Samp_9 _ _) = "samp"
    tagStr (Kbd_9 _ _) = "kbd"
    tagStr (Var_9 _ _) = "var"
    tagStr (Cite_9 _ _) = "cite"
    tagStr (Abbr_9 _ _) = "abbr"
    tagStr (Acronym_9 _ _) = "acronym"
    tagStr (Q_9 _ _) = "q"
    tagStr (Tt_9 _ _) = "tt"
    tagStr (I_9 _ _) = "i"
    tagStr (B_9 _ _) = "b"
    tagStr (U_9 _ _) = "u"
    tagStr (S_9 _ _) = "s"
    tagStr (Strike_9 _ _) = "strike"
    tagStr (Label_9 _ _) = "label"
    tagStr (Input_9 _) = "input"
    tagStr (Select_9 _ _) = "select"
    tagStr (Textarea_9 _ _) = "textarea"
    tagStr (Button_9 _ _) = "button"
    tagStr (PCDATA_9 _ _) = "pcdata"
instance TagStr Ent10 where
    tagStr (Script_10 _ _) = "script"
    tagStr (Iframe_10 _ _) = "iframe"
    tagStr (Ins_10 _ _) = "ins"
    tagStr (Del_10 _ _) = "del"
    tagStr (Span_10 _ _) = "span"
    tagStr (Bdo_10 _ _) = "bdo"
    tagStr (Br_10 _) = "br"
    tagStr (Em_10 _ _) = "em"
    tagStr (Strong_10 _ _) = "strong"
    tagStr (Dfn_10 _ _) = "dfn"
    tagStr (Code_10 _ _) = "code"
    tagStr (Samp_10 _ _) = "samp"
    tagStr (Kbd_10 _ _) = "kbd"
    tagStr (Var_10 _ _) = "var"
    tagStr (Cite_10 _ _) = "cite"
    tagStr (Abbr_10 _ _) = "abbr"
    tagStr (Acronym_10 _ _) = "acronym"
    tagStr (Q_10 _ _) = "q"
    tagStr (Sub_10 _ _) = "sub"
    tagStr (Sup_10 _ _) = "sup"
    tagStr (Tt_10 _ _) = "tt"
    tagStr (I_10 _ _) = "i"
    tagStr (B_10 _ _) = "b"
    tagStr (Big_10 _ _) = "big"
    tagStr (Small_10 _ _) = "small"
    tagStr (U_10 _ _) = "u"
    tagStr (S_10 _ _) = "s"
    tagStr (Strike_10 _ _) = "strike"
    tagStr (Basefont_10 _) = "basefont"
    tagStr (Font_10 _ _) = "font"
    tagStr (Object_10 _ _) = "object"
    tagStr (Applet_10 _ _) = "applet"
    tagStr (Img_10 _) = "img"
    tagStr (Map_10 _ _) = "map"
    tagStr (Label_10 _ _) = "label"
    tagStr (Input_10 _) = "input"
    tagStr (Select_10 _ _) = "select"
    tagStr (Textarea_10 _ _) = "textarea"
    tagStr (Button_10 _ _) = "button"
    tagStr (PCDATA_10 _ _) = "pcdata"
instance TagStr Ent11 where
    tagStr (PCDATA_11 _ _) = "pcdata"
instance TagStr Ent12 where
    tagStr (Script_12 _ _) = "script"
    tagStr (Noscript_12 _ _) = "noscript"
    tagStr (Iframe_12 _ _) = "iframe"
    tagStr (Noframes_12 _ _) = "noframes"
    tagStr (Div_12 _ _) = "div"
    tagStr (P_12 _ _) = "p"
    tagStr (H1_12 _ _) = "h1"
    tagStr (H2_12 _ _) = "h2"
    tagStr (H3_12 _ _) = "h3"
    tagStr (H4_12 _ _) = "h4"
    tagStr (H5_12 _ _) = "h5"
    tagStr (H6_12 _ _) = "h6"
    tagStr (Ul_12 _ _) = "ul"
    tagStr (Ol_12 _ _) = "ol"
    tagStr (Menu_12 _ _) = "menu"
    tagStr (Dir_12 _ _) = "dir"
    tagStr (Dl_12 _ _) = "dl"
    tagStr (Address_12 _ _) = "address"
    tagStr (Hr_12 _) = "hr"
    tagStr (Pre_12 _ _) = "pre"
    tagStr (Blockquote_12 _ _) = "blockquote"
    tagStr (Center_12 _ _) = "center"
    tagStr (Ins_12 _ _) = "ins"
    tagStr (Del_12 _ _) = "del"
    tagStr (Span_12 _ _) = "span"
    tagStr (Bdo_12 _ _) = "bdo"
    tagStr (Br_12 _) = "br"
    tagStr (Em_12 _ _) = "em"
    tagStr (Strong_12 _ _) = "strong"
    tagStr (Dfn_12 _ _) = "dfn"
    tagStr (Code_12 _ _) = "code"
    tagStr (Samp_12 _ _) = "samp"
    tagStr (Kbd_12 _ _) = "kbd"
    tagStr (Var_12 _ _) = "var"
    tagStr (Cite_12 _ _) = "cite"
    tagStr (Abbr_12 _ _) = "abbr"
    tagStr (Acronym_12 _ _) = "acronym"
    tagStr (Q_12 _ _) = "q"
    tagStr (Sub_12 _ _) = "sub"
    tagStr (Sup_12 _ _) = "sup"
    tagStr (Tt_12 _ _) = "tt"
    tagStr (I_12 _ _) = "i"
    tagStr (B_12 _ _) = "b"
    tagStr (Big_12 _ _) = "big"
    tagStr (Small_12 _ _) = "small"
    tagStr (U_12 _ _) = "u"
    tagStr (S_12 _ _) = "s"
    tagStr (Strike_12 _ _) = "strike"
    tagStr (Basefont_12 _) = "basefont"
    tagStr (Font_12 _ _) = "font"
    tagStr (Object_12 _ _) = "object"
    tagStr (Applet_12 _ _) = "applet"
    tagStr (Img_12 _) = "img"
    tagStr (Map_12 _ _) = "map"
    tagStr (Form_12 _ _) = "form"
    tagStr (Label_12 _ _) = "label"
    tagStr (Input_12 _) = "input"
    tagStr (Select_12 _ _) = "select"
    tagStr (Textarea_12 _ _) = "textarea"
    tagStr (Fieldset_12 _ _) = "fieldset"
    tagStr (Button_12 _ _) = "button"
    tagStr (Isindex_12 _) = "isindex"
    tagStr (Table_12 _ _) = "table"
    tagStr (PCDATA_12 _ _) = "pcdata"
instance TagStr Ent13 where
    tagStr (Li_13 _ _) = "li"
instance TagStr Ent14 where
    tagStr (Dt_14 _ _) = "dt"
    tagStr (Dd_14 _ _) = "dd"
instance TagStr Ent15 where
    tagStr (Script_15 _ _) = "script"
    tagStr (Iframe_15 _ _) = "iframe"
    tagStr (P_15 _ _) = "p"
    tagStr (Ins_15 _ _) = "ins"
    tagStr (Del_15 _ _) = "del"
    tagStr (Span_15 _ _) = "span"
    tagStr (Bdo_15 _ _) = "bdo"
    tagStr (Br_15 _) = "br"
    tagStr (Em_15 _ _) = "em"
    tagStr (Strong_15 _ _) = "strong"
    tagStr (Dfn_15 _ _) = "dfn"
    tagStr (Code_15 _ _) = "code"
    tagStr (Samp_15 _ _) = "samp"
    tagStr (Kbd_15 _ _) = "kbd"
    tagStr (Var_15 _ _) = "var"
    tagStr (Cite_15 _ _) = "cite"
    tagStr (Abbr_15 _ _) = "abbr"
    tagStr (Acronym_15 _ _) = "acronym"
    tagStr (Q_15 _ _) = "q"
    tagStr (Sub_15 _ _) = "sub"
    tagStr (Sup_15 _ _) = "sup"
    tagStr (Tt_15 _ _) = "tt"
    tagStr (I_15 _ _) = "i"
    tagStr (B_15 _ _) = "b"
    tagStr (Big_15 _ _) = "big"
    tagStr (Small_15 _ _) = "small"
    tagStr (U_15 _ _) = "u"
    tagStr (S_15 _ _) = "s"
    tagStr (Strike_15 _ _) = "strike"
    tagStr (Basefont_15 _) = "basefont"
    tagStr (Font_15 _ _) = "font"
    tagStr (Object_15 _ _) = "object"
    tagStr (Applet_15 _ _) = "applet"
    tagStr (Img_15 _) = "img"
    tagStr (Map_15 _ _) = "map"
    tagStr (Label_15 _ _) = "label"
    tagStr (Input_15 _) = "input"
    tagStr (Select_15 _ _) = "select"
    tagStr (Textarea_15 _ _) = "textarea"
    tagStr (Button_15 _ _) = "button"
    tagStr (PCDATA_15 _ _) = "pcdata"
instance TagStr Ent16 where
    tagStr (Script_16 _ _) = "script"
    tagStr (Ins_16 _ _) = "ins"
    tagStr (Del_16 _ _) = "del"
    tagStr (Span_16 _ _) = "span"
    tagStr (Bdo_16 _ _) = "bdo"
    tagStr (Br_16 _) = "br"
    tagStr (Em_16 _ _) = "em"
    tagStr (Strong_16 _ _) = "strong"
    tagStr (Dfn_16 _ _) = "dfn"
    tagStr (Code_16 _ _) = "code"
    tagStr (Samp_16 _ _) = "samp"
    tagStr (Kbd_16 _ _) = "kbd"
    tagStr (Var_16 _ _) = "var"
    tagStr (Cite_16 _ _) = "cite"
    tagStr (Abbr_16 _ _) = "abbr"
    tagStr (Acronym_16 _ _) = "acronym"
    tagStr (Q_16 _ _) = "q"
    tagStr (Tt_16 _ _) = "tt"
    tagStr (I_16 _ _) = "i"
    tagStr (B_16 _ _) = "b"
    tagStr (U_16 _ _) = "u"
    tagStr (S_16 _ _) = "s"
    tagStr (Strike_16 _ _) = "strike"
    tagStr (Label_16 _ _) = "label"
    tagStr (Input_16 _) = "input"
    tagStr (Select_16 _ _) = "select"
    tagStr (Textarea_16 _ _) = "textarea"
    tagStr (Button_16 _ _) = "button"
    tagStr (PCDATA_16 _ _) = "pcdata"
instance TagStr Ent17 where
    tagStr (Script_17 _ _) = "script"
    tagStr (Noscript_17 _ _) = "noscript"
    tagStr (Iframe_17 _ _) = "iframe"
    tagStr (Noframes_17 _ _) = "noframes"
    tagStr (Div_17 _ _) = "div"
    tagStr (P_17 _ _) = "p"
    tagStr (H1_17 _ _) = "h1"
    tagStr (H2_17 _ _) = "h2"
    tagStr (H3_17 _ _) = "h3"
    tagStr (H4_17 _ _) = "h4"
    tagStr (H5_17 _ _) = "h5"
    tagStr (H6_17 _ _) = "h6"
    tagStr (Ul_17 _ _) = "ul"
    tagStr (Ol_17 _ _) = "ol"
    tagStr (Menu_17 _ _) = "menu"
    tagStr (Dir_17 _ _) = "dir"
    tagStr (Dl_17 _ _) = "dl"
    tagStr (Address_17 _ _) = "address"
    tagStr (Hr_17 _) = "hr"
    tagStr (Pre_17 _ _) = "pre"
    tagStr (Blockquote_17 _ _) = "blockquote"
    tagStr (Center_17 _ _) = "center"
    tagStr (Ins_17 _ _) = "ins"
    tagStr (Del_17 _ _) = "del"
    tagStr (Span_17 _ _) = "span"
    tagStr (Bdo_17 _ _) = "bdo"
    tagStr (Br_17 _) = "br"
    tagStr (Em_17 _ _) = "em"
    tagStr (Strong_17 _ _) = "strong"
    tagStr (Dfn_17 _ _) = "dfn"
    tagStr (Code_17 _ _) = "code"
    tagStr (Samp_17 _ _) = "samp"
    tagStr (Kbd_17 _ _) = "kbd"
    tagStr (Var_17 _ _) = "var"
    tagStr (Cite_17 _ _) = "cite"
    tagStr (Abbr_17 _ _) = "abbr"
    tagStr (Acronym_17 _ _) = "acronym"
    tagStr (Q_17 _ _) = "q"
    tagStr (Sub_17 _ _) = "sub"
    tagStr (Sup_17 _ _) = "sup"
    tagStr (Tt_17 _ _) = "tt"
    tagStr (I_17 _ _) = "i"
    tagStr (B_17 _ _) = "b"
    tagStr (Big_17 _ _) = "big"
    tagStr (Small_17 _ _) = "small"
    tagStr (U_17 _ _) = "u"
    tagStr (S_17 _ _) = "s"
    tagStr (Strike_17 _ _) = "strike"
    tagStr (Basefont_17 _) = "basefont"
    tagStr (Font_17 _ _) = "font"
    tagStr (Object_17 _ _) = "object"
    tagStr (Applet_17 _ _) = "applet"
    tagStr (Img_17 _) = "img"
    tagStr (Map_17 _ _) = "map"
    tagStr (Label_17 _ _) = "label"
    tagStr (Input_17 _) = "input"
    tagStr (Select_17 _ _) = "select"
    tagStr (Textarea_17 _ _) = "textarea"
    tagStr (Fieldset_17 _ _) = "fieldset"
    tagStr (Button_17 _ _) = "button"
    tagStr (Isindex_17 _) = "isindex"
    tagStr (Table_17 _ _) = "table"
    tagStr (PCDATA_17 _ _) = "pcdata"
instance TagStr Ent18 where
    tagStr (Script_18 _ _) = "script"
    tagStr (Iframe_18 _ _) = "iframe"
    tagStr (Ins_18 _ _) = "ins"
    tagStr (Del_18 _ _) = "del"
    tagStr (Span_18 _ _) = "span"
    tagStr (Bdo_18 _ _) = "bdo"
    tagStr (Br_18 _) = "br"
    tagStr (Em_18 _ _) = "em"
    tagStr (Strong_18 _ _) = "strong"
    tagStr (Dfn_18 _ _) = "dfn"
    tagStr (Code_18 _ _) = "code"
    tagStr (Samp_18 _ _) = "samp"
    tagStr (Kbd_18 _ _) = "kbd"
    tagStr (Var_18 _ _) = "var"
    tagStr (Cite_18 _ _) = "cite"
    tagStr (Abbr_18 _ _) = "abbr"
    tagStr (Acronym_18 _ _) = "acronym"
    tagStr (Q_18 _ _) = "q"
    tagStr (Sub_18 _ _) = "sub"
    tagStr (Sup_18 _ _) = "sup"
    tagStr (Tt_18 _ _) = "tt"
    tagStr (I_18 _ _) = "i"
    tagStr (B_18 _ _) = "b"
    tagStr (Big_18 _ _) = "big"
    tagStr (Small_18 _ _) = "small"
    tagStr (U_18 _ _) = "u"
    tagStr (S_18 _ _) = "s"
    tagStr (Strike_18 _ _) = "strike"
    tagStr (Basefont_18 _) = "basefont"
    tagStr (Font_18 _ _) = "font"
    tagStr (Object_18 _ _) = "object"
    tagStr (Applet_18 _ _) = "applet"
    tagStr (Img_18 _) = "img"
    tagStr (Map_18 _ _) = "map"
    tagStr (Label_18 _ _) = "label"
    tagStr (Input_18 _) = "input"
    tagStr (Select_18 _ _) = "select"
    tagStr (Textarea_18 _ _) = "textarea"
    tagStr (Button_18 _ _) = "button"
    tagStr (PCDATA_18 _ _) = "pcdata"
instance TagStr Ent19 where
    tagStr (Li_19 _ _) = "li"
instance TagStr Ent20 where
    tagStr (Dt_20 _ _) = "dt"
    tagStr (Dd_20 _ _) = "dd"
instance TagStr Ent21 where
    tagStr (Script_21 _ _) = "script"
    tagStr (Iframe_21 _ _) = "iframe"
    tagStr (P_21 _ _) = "p"
    tagStr (Ins_21 _ _) = "ins"
    tagStr (Del_21 _ _) = "del"
    tagStr (Span_21 _ _) = "span"
    tagStr (Bdo_21 _ _) = "bdo"
    tagStr (Br_21 _) = "br"
    tagStr (Em_21 _ _) = "em"
    tagStr (Strong_21 _ _) = "strong"
    tagStr (Dfn_21 _ _) = "dfn"
    tagStr (Code_21 _ _) = "code"
    tagStr (Samp_21 _ _) = "samp"
    tagStr (Kbd_21 _ _) = "kbd"
    tagStr (Var_21 _ _) = "var"
    tagStr (Cite_21 _ _) = "cite"
    tagStr (Abbr_21 _ _) = "abbr"
    tagStr (Acronym_21 _ _) = "acronym"
    tagStr (Q_21 _ _) = "q"
    tagStr (Sub_21 _ _) = "sub"
    tagStr (Sup_21 _ _) = "sup"
    tagStr (Tt_21 _ _) = "tt"
    tagStr (I_21 _ _) = "i"
    tagStr (B_21 _ _) = "b"
    tagStr (Big_21 _ _) = "big"
    tagStr (Small_21 _ _) = "small"
    tagStr (U_21 _ _) = "u"
    tagStr (S_21 _ _) = "s"
    tagStr (Strike_21 _ _) = "strike"
    tagStr (Basefont_21 _) = "basefont"
    tagStr (Font_21 _ _) = "font"
    tagStr (Object_21 _ _) = "object"
    tagStr (Applet_21 _ _) = "applet"
    tagStr (Img_21 _) = "img"
    tagStr (Map_21 _ _) = "map"
    tagStr (Label_21 _ _) = "label"
    tagStr (Input_21 _) = "input"
    tagStr (Select_21 _ _) = "select"
    tagStr (Textarea_21 _ _) = "textarea"
    tagStr (Button_21 _ _) = "button"
    tagStr (PCDATA_21 _ _) = "pcdata"
instance TagStr Ent22 where
    tagStr (Script_22 _ _) = "script"
    tagStr (Ins_22 _ _) = "ins"
    tagStr (Del_22 _ _) = "del"
    tagStr (Span_22 _ _) = "span"
    tagStr (Bdo_22 _ _) = "bdo"
    tagStr (Br_22 _) = "br"
    tagStr (Em_22 _ _) = "em"
    tagStr (Strong_22 _ _) = "strong"
    tagStr (Dfn_22 _ _) = "dfn"
    tagStr (Code_22 _ _) = "code"
    tagStr (Samp_22 _ _) = "samp"
    tagStr (Kbd_22 _ _) = "kbd"
    tagStr (Var_22 _ _) = "var"
    tagStr (Cite_22 _ _) = "cite"
    tagStr (Abbr_22 _ _) = "abbr"
    tagStr (Acronym_22 _ _) = "acronym"
    tagStr (Q_22 _ _) = "q"
    tagStr (Tt_22 _ _) = "tt"
    tagStr (I_22 _ _) = "i"
    tagStr (B_22 _ _) = "b"
    tagStr (U_22 _ _) = "u"
    tagStr (S_22 _ _) = "s"
    tagStr (Strike_22 _ _) = "strike"
    tagStr (Label_22 _ _) = "label"
    tagStr (Input_22 _) = "input"
    tagStr (Select_22 _ _) = "select"
    tagStr (Textarea_22 _ _) = "textarea"
    tagStr (Button_22 _ _) = "button"
    tagStr (PCDATA_22 _ _) = "pcdata"
instance TagStr Ent23 where
    tagStr (Script_23 _ _) = "script"
    tagStr (Noscript_23 _ _) = "noscript"
    tagStr (Iframe_23 _ _) = "iframe"
    tagStr (Noframes_23 _ _) = "noframes"
    tagStr (Div_23 _ _) = "div"
    tagStr (P_23 _ _) = "p"
    tagStr (H1_23 _ _) = "h1"
    tagStr (H2_23 _ _) = "h2"
    tagStr (H3_23 _ _) = "h3"
    tagStr (H4_23 _ _) = "h4"
    tagStr (H5_23 _ _) = "h5"
    tagStr (H6_23 _ _) = "h6"
    tagStr (Ul_23 _ _) = "ul"
    tagStr (Ol_23 _ _) = "ol"
    tagStr (Menu_23 _ _) = "menu"
    tagStr (Dir_23 _ _) = "dir"
    tagStr (Dl_23 _ _) = "dl"
    tagStr (Address_23 _ _) = "address"
    tagStr (Hr_23 _) = "hr"
    tagStr (Pre_23 _ _) = "pre"
    tagStr (Blockquote_23 _ _) = "blockquote"
    tagStr (Center_23 _ _) = "center"
    tagStr (Ins_23 _ _) = "ins"
    tagStr (Del_23 _ _) = "del"
    tagStr (Span_23 _ _) = "span"
    tagStr (Bdo_23 _ _) = "bdo"
    tagStr (Br_23 _) = "br"
    tagStr (Em_23 _ _) = "em"
    tagStr (Strong_23 _ _) = "strong"
    tagStr (Dfn_23 _ _) = "dfn"
    tagStr (Code_23 _ _) = "code"
    tagStr (Samp_23 _ _) = "samp"
    tagStr (Kbd_23 _ _) = "kbd"
    tagStr (Var_23 _ _) = "var"
    tagStr (Cite_23 _ _) = "cite"
    tagStr (Abbr_23 _ _) = "abbr"
    tagStr (Acronym_23 _ _) = "acronym"
    tagStr (Q_23 _ _) = "q"
    tagStr (Sub_23 _ _) = "sub"
    tagStr (Sup_23 _ _) = "sup"
    tagStr (Tt_23 _ _) = "tt"
    tagStr (I_23 _ _) = "i"
    tagStr (B_23 _ _) = "b"
    tagStr (Big_23 _ _) = "big"
    tagStr (Small_23 _ _) = "small"
    tagStr (U_23 _ _) = "u"
    tagStr (S_23 _ _) = "s"
    tagStr (Strike_23 _ _) = "strike"
    tagStr (Basefont_23 _) = "basefont"
    tagStr (Font_23 _ _) = "font"
    tagStr (Object_23 _ _) = "object"
    tagStr (Applet_23 _ _) = "applet"
    tagStr (Img_23 _) = "img"
    tagStr (Map_23 _ _) = "map"
    tagStr (Label_23 _ _) = "label"
    tagStr (Input_23 _) = "input"
    tagStr (Select_23 _ _) = "select"
    tagStr (Textarea_23 _ _) = "textarea"
    tagStr (Fieldset_23 _ _) = "fieldset"
    tagStr (Legend_23 _ _) = "legend"
    tagStr (Button_23 _ _) = "button"
    tagStr (Isindex_23 _) = "isindex"
    tagStr (Table_23 _ _) = "table"
    tagStr (PCDATA_23 _ _) = "pcdata"
instance TagStr Ent24 where
    tagStr (Caption_24 _ _) = "caption"
    tagStr (Thead_24 _ _) = "thead"
    tagStr (Tfoot_24 _ _) = "tfoot"
    tagStr (Tbody_24 _ _) = "tbody"
    tagStr (Colgroup_24 _ _) = "colgroup"
    tagStr (Col_24 _) = "col"
    tagStr (Tr_24 _ _) = "tr"
instance TagStr Ent25 where
    tagStr (Tr_25 _ _) = "tr"
instance TagStr Ent26 where
    tagStr (Col_26 _) = "col"
instance TagStr Ent27 where
    tagStr (Th_27 _ _) = "th"
    tagStr (Td_27 _ _) = "td"
instance TagStr Ent28 where
    tagStr (Script_28 _ _) = "script"
    tagStr (Noscript_28 _ _) = "noscript"
    tagStr (Iframe_28 _ _) = "iframe"
    tagStr (Noframes_28 _ _) = "noframes"
    tagStr (Div_28 _ _) = "div"
    tagStr (P_28 _ _) = "p"
    tagStr (H1_28 _ _) = "h1"
    tagStr (H2_28 _ _) = "h2"
    tagStr (H3_28 _ _) = "h3"
    tagStr (H4_28 _ _) = "h4"
    tagStr (H5_28 _ _) = "h5"
    tagStr (H6_28 _ _) = "h6"
    tagStr (Ul_28 _ _) = "ul"
    tagStr (Ol_28 _ _) = "ol"
    tagStr (Menu_28 _ _) = "menu"
    tagStr (Dir_28 _ _) = "dir"
    tagStr (Dl_28 _ _) = "dl"
    tagStr (Address_28 _ _) = "address"
    tagStr (Hr_28 _) = "hr"
    tagStr (Pre_28 _ _) = "pre"
    tagStr (Blockquote_28 _ _) = "blockquote"
    tagStr (Center_28 _ _) = "center"
    tagStr (Ins_28 _ _) = "ins"
    tagStr (Del_28 _ _) = "del"
    tagStr (Span_28 _ _) = "span"
    tagStr (Bdo_28 _ _) = "bdo"
    tagStr (Br_28 _) = "br"
    tagStr (Em_28 _ _) = "em"
    tagStr (Strong_28 _ _) = "strong"
    tagStr (Dfn_28 _ _) = "dfn"
    tagStr (Code_28 _ _) = "code"
    tagStr (Samp_28 _ _) = "samp"
    tagStr (Kbd_28 _ _) = "kbd"
    tagStr (Var_28 _ _) = "var"
    tagStr (Cite_28 _ _) = "cite"
    tagStr (Abbr_28 _ _) = "abbr"
    tagStr (Acronym_28 _ _) = "acronym"
    tagStr (Q_28 _ _) = "q"
    tagStr (Sub_28 _ _) = "sub"
    tagStr (Sup_28 _ _) = "sup"
    tagStr (Tt_28 _ _) = "tt"
    tagStr (I_28 _ _) = "i"
    tagStr (B_28 _ _) = "b"
    tagStr (Big_28 _ _) = "big"
    tagStr (Small_28 _ _) = "small"
    tagStr (U_28 _ _) = "u"
    tagStr (S_28 _ _) = "s"
    tagStr (Strike_28 _ _) = "strike"
    tagStr (Basefont_28 _) = "basefont"
    tagStr (Font_28 _ _) = "font"
    tagStr (Object_28 _ _) = "object"
    tagStr (Applet_28 _ _) = "applet"
    tagStr (Img_28 _) = "img"
    tagStr (Map_28 _ _) = "map"
    tagStr (Form_28 _ _) = "form"
    tagStr (Label_28 _ _) = "label"
    tagStr (Input_28 _) = "input"
    tagStr (Select_28 _ _) = "select"
    tagStr (Textarea_28 _ _) = "textarea"
    tagStr (Fieldset_28 _ _) = "fieldset"
    tagStr (Legend_28 _ _) = "legend"
    tagStr (Button_28 _ _) = "button"
    tagStr (Isindex_28 _) = "isindex"
    tagStr (Table_28 _ _) = "table"
    tagStr (PCDATA_28 _ _) = "pcdata"
instance TagStr Ent29 where
    tagStr (Caption_29 _ _) = "caption"
    tagStr (Thead_29 _ _) = "thead"
    tagStr (Tfoot_29 _ _) = "tfoot"
    tagStr (Tbody_29 _ _) = "tbody"
    tagStr (Colgroup_29 _ _) = "colgroup"
    tagStr (Col_29 _) = "col"
    tagStr (Tr_29 _ _) = "tr"
instance TagStr Ent30 where
    tagStr (Tr_30 _ _) = "tr"
instance TagStr Ent31 where
    tagStr (Col_31 _) = "col"
instance TagStr Ent32 where
    tagStr (Th_32 _ _) = "th"
    tagStr (Td_32 _ _) = "td"
instance TagStr Ent33 where
    tagStr (Script_33 _ _) = "script"
    tagStr (Noscript_33 _ _) = "noscript"
    tagStr (Iframe_33 _ _) = "iframe"
    tagStr (Noframes_33 _ _) = "noframes"
    tagStr (Div_33 _ _) = "div"
    tagStr (P_33 _ _) = "p"
    tagStr (H1_33 _ _) = "h1"
    tagStr (H2_33 _ _) = "h2"
    tagStr (H3_33 _ _) = "h3"
    tagStr (H4_33 _ _) = "h4"
    tagStr (H5_33 _ _) = "h5"
    tagStr (H6_33 _ _) = "h6"
    tagStr (Ul_33 _ _) = "ul"
    tagStr (Ol_33 _ _) = "ol"
    tagStr (Menu_33 _ _) = "menu"
    tagStr (Dir_33 _ _) = "dir"
    tagStr (Dl_33 _ _) = "dl"
    tagStr (Address_33 _ _) = "address"
    tagStr (Hr_33 _) = "hr"
    tagStr (Pre_33 _ _) = "pre"
    tagStr (Blockquote_33 _ _) = "blockquote"
    tagStr (Center_33 _ _) = "center"
    tagStr (Ins_33 _ _) = "ins"
    tagStr (Del_33 _ _) = "del"
    tagStr (Span_33 _ _) = "span"
    tagStr (Bdo_33 _ _) = "bdo"
    tagStr (Br_33 _) = "br"
    tagStr (Em_33 _ _) = "em"
    tagStr (Strong_33 _ _) = "strong"
    tagStr (Dfn_33 _ _) = "dfn"
    tagStr (Code_33 _ _) = "code"
    tagStr (Samp_33 _ _) = "samp"
    tagStr (Kbd_33 _ _) = "kbd"
    tagStr (Var_33 _ _) = "var"
    tagStr (Cite_33 _ _) = "cite"
    tagStr (Abbr_33 _ _) = "abbr"
    tagStr (Acronym_33 _ _) = "acronym"
    tagStr (Q_33 _ _) = "q"
    tagStr (Sub_33 _ _) = "sub"
    tagStr (Sup_33 _ _) = "sup"
    tagStr (Tt_33 _ _) = "tt"
    tagStr (I_33 _ _) = "i"
    tagStr (B_33 _ _) = "b"
    tagStr (Big_33 _ _) = "big"
    tagStr (Small_33 _ _) = "small"
    tagStr (U_33 _ _) = "u"
    tagStr (S_33 _ _) = "s"
    tagStr (Strike_33 _ _) = "strike"
    tagStr (Basefont_33 _) = "basefont"
    tagStr (Font_33 _ _) = "font"
    tagStr (Object_33 _ _) = "object"
    tagStr (Param_33 _) = "param"
    tagStr (Applet_33 _ _) = "applet"
    tagStr (Img_33 _) = "img"
    tagStr (Map_33 _ _) = "map"
    tagStr (Form_33 _ _) = "form"
    tagStr (Label_33 _ _) = "label"
    tagStr (Input_33 _) = "input"
    tagStr (Select_33 _ _) = "select"
    tagStr (Textarea_33 _ _) = "textarea"
    tagStr (Fieldset_33 _ _) = "fieldset"
    tagStr (Button_33 _ _) = "button"
    tagStr (Isindex_33 _) = "isindex"
    tagStr (Table_33 _ _) = "table"
    tagStr (PCDATA_33 _ _) = "pcdata"
instance TagStr Ent34 where
    tagStr (Script_34 _ _) = "script"
    tagStr (Noscript_34 _ _) = "noscript"
    tagStr (Noframes_34 _ _) = "noframes"
    tagStr (Div_34 _ _) = "div"
    tagStr (P_34 _ _) = "p"
    tagStr (H1_34 _ _) = "h1"
    tagStr (H2_34 _ _) = "h2"
    tagStr (H3_34 _ _) = "h3"
    tagStr (H4_34 _ _) = "h4"
    tagStr (H5_34 _ _) = "h5"
    tagStr (H6_34 _ _) = "h6"
    tagStr (Ul_34 _ _) = "ul"
    tagStr (Ol_34 _ _) = "ol"
    tagStr (Menu_34 _ _) = "menu"
    tagStr (Dir_34 _ _) = "dir"
    tagStr (Dl_34 _ _) = "dl"
    tagStr (Address_34 _ _) = "address"
    tagStr (Hr_34 _) = "hr"
    tagStr (Pre_34 _ _) = "pre"
    tagStr (Blockquote_34 _ _) = "blockquote"
    tagStr (Center_34 _ _) = "center"
    tagStr (Ins_34 _ _) = "ins"
    tagStr (Del_34 _ _) = "del"
    tagStr (Area_34 _) = "area"
    tagStr (Form_34 _ _) = "form"
    tagStr (Fieldset_34 _ _) = "fieldset"
    tagStr (Isindex_34 _) = "isindex"
    tagStr (Table_34 _ _) = "table"
instance TagStr Ent35 where
    tagStr (Script_35 _ _) = "script"
    tagStr (Iframe_35 _ _) = "iframe"
    tagStr (Ins_35 _ _) = "ins"
    tagStr (Del_35 _ _) = "del"
    tagStr (Span_35 _ _) = "span"
    tagStr (Bdo_35 _ _) = "bdo"
    tagStr (Br_35 _) = "br"
    tagStr (Em_35 _ _) = "em"
    tagStr (Strong_35 _ _) = "strong"
    tagStr (Dfn_35 _ _) = "dfn"
    tagStr (Code_35 _ _) = "code"
    tagStr (Samp_35 _ _) = "samp"
    tagStr (Kbd_35 _ _) = "kbd"
    tagStr (Var_35 _ _) = "var"
    tagStr (Cite_35 _ _) = "cite"
    tagStr (Abbr_35 _ _) = "abbr"
    tagStr (Acronym_35 _ _) = "acronym"
    tagStr (Q_35 _ _) = "q"
    tagStr (Sub_35 _ _) = "sub"
    tagStr (Sup_35 _ _) = "sup"
    tagStr (Tt_35 _ _) = "tt"
    tagStr (I_35 _ _) = "i"
    tagStr (B_35 _ _) = "b"
    tagStr (Big_35 _ _) = "big"
    tagStr (Small_35 _ _) = "small"
    tagStr (U_35 _ _) = "u"
    tagStr (S_35 _ _) = "s"
    tagStr (Strike_35 _ _) = "strike"
    tagStr (Basefont_35 _) = "basefont"
    tagStr (Font_35 _ _) = "font"
    tagStr (Object_35 _ _) = "object"
    tagStr (Applet_35 _ _) = "applet"
    tagStr (Img_35 _) = "img"
    tagStr (Map_35 _ _) = "map"
    tagStr (Input_35 _) = "input"
    tagStr (Select_35 _ _) = "select"
    tagStr (Textarea_35 _ _) = "textarea"
    tagStr (Button_35 _ _) = "button"
    tagStr (PCDATA_35 _ _) = "pcdata"
instance TagStr Ent36 where
    tagStr (PCDATA_36 _ _) = "pcdata"
instance TagStr Ent37 where
    tagStr (Script_37 _ _) = "script"
    tagStr (Noscript_37 _ _) = "noscript"
    tagStr (Iframe_37 _ _) = "iframe"
    tagStr (Noframes_37 _ _) = "noframes"
    tagStr (Div_37 _ _) = "div"
    tagStr (P_37 _ _) = "p"
    tagStr (H1_37 _ _) = "h1"
    tagStr (H2_37 _ _) = "h2"
    tagStr (H3_37 _ _) = "h3"
    tagStr (H4_37 _ _) = "h4"
    tagStr (H5_37 _ _) = "h5"
    tagStr (H6_37 _ _) = "h6"
    tagStr (Ul_37 _ _) = "ul"
    tagStr (Ol_37 _ _) = "ol"
    tagStr (Menu_37 _ _) = "menu"
    tagStr (Dir_37 _ _) = "dir"
    tagStr (Dl_37 _ _) = "dl"
    tagStr (Address_37 _ _) = "address"
    tagStr (Hr_37 _) = "hr"
    tagStr (Pre_37 _ _) = "pre"
    tagStr (Blockquote_37 _ _) = "blockquote"
    tagStr (Center_37 _ _) = "center"
    tagStr (Ins_37 _ _) = "ins"
    tagStr (Del_37 _ _) = "del"
    tagStr (Span_37 _ _) = "span"
    tagStr (Bdo_37 _ _) = "bdo"
    tagStr (Br_37 _) = "br"
    tagStr (Em_37 _ _) = "em"
    tagStr (Strong_37 _ _) = "strong"
    tagStr (Dfn_37 _ _) = "dfn"
    tagStr (Code_37 _ _) = "code"
    tagStr (Samp_37 _ _) = "samp"
    tagStr (Kbd_37 _ _) = "kbd"
    tagStr (Var_37 _ _) = "var"
    tagStr (Cite_37 _ _) = "cite"
    tagStr (Abbr_37 _ _) = "abbr"
    tagStr (Acronym_37 _ _) = "acronym"
    tagStr (Q_37 _ _) = "q"
    tagStr (Sub_37 _ _) = "sub"
    tagStr (Sup_37 _ _) = "sup"
    tagStr (Tt_37 _ _) = "tt"
    tagStr (I_37 _ _) = "i"
    tagStr (B_37 _ _) = "b"
    tagStr (Big_37 _ _) = "big"
    tagStr (Small_37 _ _) = "small"
    tagStr (U_37 _ _) = "u"
    tagStr (S_37 _ _) = "s"
    tagStr (Strike_37 _ _) = "strike"
    tagStr (Basefont_37 _) = "basefont"
    tagStr (Font_37 _ _) = "font"
    tagStr (Object_37 _ _) = "object"
    tagStr (Applet_37 _ _) = "applet"
    tagStr (Img_37 _) = "img"
    tagStr (Map_37 _ _) = "map"
    tagStr (Form_37 _ _) = "form"
    tagStr (Input_37 _) = "input"
    tagStr (Select_37 _ _) = "select"
    tagStr (Textarea_37 _ _) = "textarea"
    tagStr (Fieldset_37 _ _) = "fieldset"
    tagStr (Button_37 _ _) = "button"
    tagStr (Isindex_37 _) = "isindex"
    tagStr (Table_37 _ _) = "table"
    tagStr (PCDATA_37 _ _) = "pcdata"
instance TagStr Ent38 where
    tagStr (Li_38 _ _) = "li"
instance TagStr Ent39 where
    tagStr (Dt_39 _ _) = "dt"
    tagStr (Dd_39 _ _) = "dd"
instance TagStr Ent40 where
    tagStr (Script_40 _ _) = "script"
    tagStr (Iframe_40 _ _) = "iframe"
    tagStr (P_40 _ _) = "p"
    tagStr (Ins_40 _ _) = "ins"
    tagStr (Del_40 _ _) = "del"
    tagStr (Span_40 _ _) = "span"
    tagStr (Bdo_40 _ _) = "bdo"
    tagStr (Br_40 _) = "br"
    tagStr (Em_40 _ _) = "em"
    tagStr (Strong_40 _ _) = "strong"
    tagStr (Dfn_40 _ _) = "dfn"
    tagStr (Code_40 _ _) = "code"
    tagStr (Samp_40 _ _) = "samp"
    tagStr (Kbd_40 _ _) = "kbd"
    tagStr (Var_40 _ _) = "var"
    tagStr (Cite_40 _ _) = "cite"
    tagStr (Abbr_40 _ _) = "abbr"
    tagStr (Acronym_40 _ _) = "acronym"
    tagStr (Q_40 _ _) = "q"
    tagStr (Sub_40 _ _) = "sub"
    tagStr (Sup_40 _ _) = "sup"
    tagStr (Tt_40 _ _) = "tt"
    tagStr (I_40 _ _) = "i"
    tagStr (B_40 _ _) = "b"
    tagStr (Big_40 _ _) = "big"
    tagStr (Small_40 _ _) = "small"
    tagStr (U_40 _ _) = "u"
    tagStr (S_40 _ _) = "s"
    tagStr (Strike_40 _ _) = "strike"
    tagStr (Basefont_40 _) = "basefont"
    tagStr (Font_40 _ _) = "font"
    tagStr (Object_40 _ _) = "object"
    tagStr (Applet_40 _ _) = "applet"
    tagStr (Img_40 _) = "img"
    tagStr (Map_40 _ _) = "map"
    tagStr (Input_40 _) = "input"
    tagStr (Select_40 _ _) = "select"
    tagStr (Textarea_40 _ _) = "textarea"
    tagStr (Button_40 _ _) = "button"
    tagStr (PCDATA_40 _ _) = "pcdata"
instance TagStr Ent41 where
    tagStr (Script_41 _ _) = "script"
    tagStr (Ins_41 _ _) = "ins"
    tagStr (Del_41 _ _) = "del"
    tagStr (Span_41 _ _) = "span"
    tagStr (Bdo_41 _ _) = "bdo"
    tagStr (Br_41 _) = "br"
    tagStr (Em_41 _ _) = "em"
    tagStr (Strong_41 _ _) = "strong"
    tagStr (Dfn_41 _ _) = "dfn"
    tagStr (Code_41 _ _) = "code"
    tagStr (Samp_41 _ _) = "samp"
    tagStr (Kbd_41 _ _) = "kbd"
    tagStr (Var_41 _ _) = "var"
    tagStr (Cite_41 _ _) = "cite"
    tagStr (Abbr_41 _ _) = "abbr"
    tagStr (Acronym_41 _ _) = "acronym"
    tagStr (Q_41 _ _) = "q"
    tagStr (Tt_41 _ _) = "tt"
    tagStr (I_41 _ _) = "i"
    tagStr (B_41 _ _) = "b"
    tagStr (U_41 _ _) = "u"
    tagStr (S_41 _ _) = "s"
    tagStr (Strike_41 _ _) = "strike"
    tagStr (Input_41 _) = "input"
    tagStr (Select_41 _ _) = "select"
    tagStr (Textarea_41 _ _) = "textarea"
    tagStr (Button_41 _ _) = "button"
    tagStr (PCDATA_41 _ _) = "pcdata"
instance TagStr Ent42 where
    tagStr (Script_42 _ _) = "script"
    tagStr (Noscript_42 _ _) = "noscript"
    tagStr (Iframe_42 _ _) = "iframe"
    tagStr (Noframes_42 _ _) = "noframes"
    tagStr (Div_42 _ _) = "div"
    tagStr (P_42 _ _) = "p"
    tagStr (H1_42 _ _) = "h1"
    tagStr (H2_42 _ _) = "h2"
    tagStr (H3_42 _ _) = "h3"
    tagStr (H4_42 _ _) = "h4"
    tagStr (H5_42 _ _) = "h5"
    tagStr (H6_42 _ _) = "h6"
    tagStr (Ul_42 _ _) = "ul"
    tagStr (Ol_42 _ _) = "ol"
    tagStr (Menu_42 _ _) = "menu"
    tagStr (Dir_42 _ _) = "dir"
    tagStr (Dl_42 _ _) = "dl"
    tagStr (Address_42 _ _) = "address"
    tagStr (Hr_42 _) = "hr"
    tagStr (Pre_42 _ _) = "pre"
    tagStr (Blockquote_42 _ _) = "blockquote"
    tagStr (Center_42 _ _) = "center"
    tagStr (Ins_42 _ _) = "ins"
    tagStr (Del_42 _ _) = "del"
    tagStr (Span_42 _ _) = "span"
    tagStr (Bdo_42 _ _) = "bdo"
    tagStr (Br_42 _) = "br"
    tagStr (Em_42 _ _) = "em"
    tagStr (Strong_42 _ _) = "strong"
    tagStr (Dfn_42 _ _) = "dfn"
    tagStr (Code_42 _ _) = "code"
    tagStr (Samp_42 _ _) = "samp"
    tagStr (Kbd_42 _ _) = "kbd"
    tagStr (Var_42 _ _) = "var"
    tagStr (Cite_42 _ _) = "cite"
    tagStr (Abbr_42 _ _) = "abbr"
    tagStr (Acronym_42 _ _) = "acronym"
    tagStr (Q_42 _ _) = "q"
    tagStr (Sub_42 _ _) = "sub"
    tagStr (Sup_42 _ _) = "sup"
    tagStr (Tt_42 _ _) = "tt"
    tagStr (I_42 _ _) = "i"
    tagStr (B_42 _ _) = "b"
    tagStr (Big_42 _ _) = "big"
    tagStr (Small_42 _ _) = "small"
    tagStr (U_42 _ _) = "u"
    tagStr (S_42 _ _) = "s"
    tagStr (Strike_42 _ _) = "strike"
    tagStr (Basefont_42 _) = "basefont"
    tagStr (Font_42 _ _) = "font"
    tagStr (Object_42 _ _) = "object"
    tagStr (Applet_42 _ _) = "applet"
    tagStr (Img_42 _) = "img"
    tagStr (Map_42 _ _) = "map"
    tagStr (Input_42 _) = "input"
    tagStr (Select_42 _ _) = "select"
    tagStr (Textarea_42 _ _) = "textarea"
    tagStr (Fieldset_42 _ _) = "fieldset"
    tagStr (Button_42 _ _) = "button"
    tagStr (Isindex_42 _) = "isindex"
    tagStr (Table_42 _ _) = "table"
    tagStr (PCDATA_42 _ _) = "pcdata"
instance TagStr Ent43 where
    tagStr (Script_43 _ _) = "script"
    tagStr (Iframe_43 _ _) = "iframe"
    tagStr (Ins_43 _ _) = "ins"
    tagStr (Del_43 _ _) = "del"
    tagStr (Span_43 _ _) = "span"
    tagStr (Bdo_43 _ _) = "bdo"
    tagStr (Br_43 _) = "br"
    tagStr (Em_43 _ _) = "em"
    tagStr (Strong_43 _ _) = "strong"
    tagStr (Dfn_43 _ _) = "dfn"
    tagStr (Code_43 _ _) = "code"
    tagStr (Samp_43 _ _) = "samp"
    tagStr (Kbd_43 _ _) = "kbd"
    tagStr (Var_43 _ _) = "var"
    tagStr (Cite_43 _ _) = "cite"
    tagStr (Abbr_43 _ _) = "abbr"
    tagStr (Acronym_43 _ _) = "acronym"
    tagStr (Q_43 _ _) = "q"
    tagStr (Sub_43 _ _) = "sub"
    tagStr (Sup_43 _ _) = "sup"
    tagStr (Tt_43 _ _) = "tt"
    tagStr (I_43 _ _) = "i"
    tagStr (B_43 _ _) = "b"
    tagStr (Big_43 _ _) = "big"
    tagStr (Small_43 _ _) = "small"
    tagStr (U_43 _ _) = "u"
    tagStr (S_43 _ _) = "s"
    tagStr (Strike_43 _ _) = "strike"
    tagStr (Basefont_43 _) = "basefont"
    tagStr (Font_43 _ _) = "font"
    tagStr (Object_43 _ _) = "object"
    tagStr (Applet_43 _ _) = "applet"
    tagStr (Img_43 _) = "img"
    tagStr (Map_43 _ _) = "map"
    tagStr (Input_43 _) = "input"
    tagStr (Select_43 _ _) = "select"
    tagStr (Textarea_43 _ _) = "textarea"
    tagStr (Button_43 _ _) = "button"
    tagStr (PCDATA_43 _ _) = "pcdata"
instance TagStr Ent44 where
    tagStr (Li_44 _ _) = "li"
instance TagStr Ent45 where
    tagStr (Dt_45 _ _) = "dt"
    tagStr (Dd_45 _ _) = "dd"
instance TagStr Ent46 where
    tagStr (Script_46 _ _) = "script"
    tagStr (Iframe_46 _ _) = "iframe"
    tagStr (P_46 _ _) = "p"
    tagStr (Ins_46 _ _) = "ins"
    tagStr (Del_46 _ _) = "del"
    tagStr (Span_46 _ _) = "span"
    tagStr (Bdo_46 _ _) = "bdo"
    tagStr (Br_46 _) = "br"
    tagStr (Em_46 _ _) = "em"
    tagStr (Strong_46 _ _) = "strong"
    tagStr (Dfn_46 _ _) = "dfn"
    tagStr (Code_46 _ _) = "code"
    tagStr (Samp_46 _ _) = "samp"
    tagStr (Kbd_46 _ _) = "kbd"
    tagStr (Var_46 _ _) = "var"
    tagStr (Cite_46 _ _) = "cite"
    tagStr (Abbr_46 _ _) = "abbr"
    tagStr (Acronym_46 _ _) = "acronym"
    tagStr (Q_46 _ _) = "q"
    tagStr (Sub_46 _ _) = "sub"
    tagStr (Sup_46 _ _) = "sup"
    tagStr (Tt_46 _ _) = "tt"
    tagStr (I_46 _ _) = "i"
    tagStr (B_46 _ _) = "b"
    tagStr (Big_46 _ _) = "big"
    tagStr (Small_46 _ _) = "small"
    tagStr (U_46 _ _) = "u"
    tagStr (S_46 _ _) = "s"
    tagStr (Strike_46 _ _) = "strike"
    tagStr (Basefont_46 _) = "basefont"
    tagStr (Font_46 _ _) = "font"
    tagStr (Object_46 _ _) = "object"
    tagStr (Applet_46 _ _) = "applet"
    tagStr (Img_46 _) = "img"
    tagStr (Map_46 _ _) = "map"
    tagStr (Input_46 _) = "input"
    tagStr (Select_46 _ _) = "select"
    tagStr (Textarea_46 _ _) = "textarea"
    tagStr (Button_46 _ _) = "button"
    tagStr (PCDATA_46 _ _) = "pcdata"
instance TagStr Ent47 where
    tagStr (Script_47 _ _) = "script"
    tagStr (Ins_47 _ _) = "ins"
    tagStr (Del_47 _ _) = "del"
    tagStr (Span_47 _ _) = "span"
    tagStr (Bdo_47 _ _) = "bdo"
    tagStr (Br_47 _) = "br"
    tagStr (Em_47 _ _) = "em"
    tagStr (Strong_47 _ _) = "strong"
    tagStr (Dfn_47 _ _) = "dfn"
    tagStr (Code_47 _ _) = "code"
    tagStr (Samp_47 _ _) = "samp"
    tagStr (Kbd_47 _ _) = "kbd"
    tagStr (Var_47 _ _) = "var"
    tagStr (Cite_47 _ _) = "cite"
    tagStr (Abbr_47 _ _) = "abbr"
    tagStr (Acronym_47 _ _) = "acronym"
    tagStr (Q_47 _ _) = "q"
    tagStr (Tt_47 _ _) = "tt"
    tagStr (I_47 _ _) = "i"
    tagStr (B_47 _ _) = "b"
    tagStr (U_47 _ _) = "u"
    tagStr (S_47 _ _) = "s"
    tagStr (Strike_47 _ _) = "strike"
    tagStr (Input_47 _) = "input"
    tagStr (Select_47 _ _) = "select"
    tagStr (Textarea_47 _ _) = "textarea"
    tagStr (Button_47 _ _) = "button"
    tagStr (PCDATA_47 _ _) = "pcdata"
instance TagStr Ent48 where
    tagStr (Script_48 _ _) = "script"
    tagStr (Noscript_48 _ _) = "noscript"
    tagStr (Iframe_48 _ _) = "iframe"
    tagStr (Noframes_48 _ _) = "noframes"
    tagStr (Div_48 _ _) = "div"
    tagStr (P_48 _ _) = "p"
    tagStr (H1_48 _ _) = "h1"
    tagStr (H2_48 _ _) = "h2"
    tagStr (H3_48 _ _) = "h3"
    tagStr (H4_48 _ _) = "h4"
    tagStr (H5_48 _ _) = "h5"
    tagStr (H6_48 _ _) = "h6"
    tagStr (Ul_48 _ _) = "ul"
    tagStr (Ol_48 _ _) = "ol"
    tagStr (Menu_48 _ _) = "menu"
    tagStr (Dir_48 _ _) = "dir"
    tagStr (Dl_48 _ _) = "dl"
    tagStr (Address_48 _ _) = "address"
    tagStr (Hr_48 _) = "hr"
    tagStr (Pre_48 _ _) = "pre"
    tagStr (Blockquote_48 _ _) = "blockquote"
    tagStr (Center_48 _ _) = "center"
    tagStr (Ins_48 _ _) = "ins"
    tagStr (Del_48 _ _) = "del"
    tagStr (Span_48 _ _) = "span"
    tagStr (Bdo_48 _ _) = "bdo"
    tagStr (Br_48 _) = "br"
    tagStr (Em_48 _ _) = "em"
    tagStr (Strong_48 _ _) = "strong"
    tagStr (Dfn_48 _ _) = "dfn"
    tagStr (Code_48 _ _) = "code"
    tagStr (Samp_48 _ _) = "samp"
    tagStr (Kbd_48 _ _) = "kbd"
    tagStr (Var_48 _ _) = "var"
    tagStr (Cite_48 _ _) = "cite"
    tagStr (Abbr_48 _ _) = "abbr"
    tagStr (Acronym_48 _ _) = "acronym"
    tagStr (Q_48 _ _) = "q"
    tagStr (Sub_48 _ _) = "sub"
    tagStr (Sup_48 _ _) = "sup"
    tagStr (Tt_48 _ _) = "tt"
    tagStr (I_48 _ _) = "i"
    tagStr (B_48 _ _) = "b"
    tagStr (Big_48 _ _) = "big"
    tagStr (Small_48 _ _) = "small"
    tagStr (U_48 _ _) = "u"
    tagStr (S_48 _ _) = "s"
    tagStr (Strike_48 _ _) = "strike"
    tagStr (Basefont_48 _) = "basefont"
    tagStr (Font_48 _ _) = "font"
    tagStr (Object_48 _ _) = "object"
    tagStr (Applet_48 _ _) = "applet"
    tagStr (Img_48 _) = "img"
    tagStr (Map_48 _ _) = "map"
    tagStr (Input_48 _) = "input"
    tagStr (Select_48 _ _) = "select"
    tagStr (Textarea_48 _ _) = "textarea"
    tagStr (Fieldset_48 _ _) = "fieldset"
    tagStr (Legend_48 _ _) = "legend"
    tagStr (Button_48 _ _) = "button"
    tagStr (Isindex_48 _) = "isindex"
    tagStr (Table_48 _ _) = "table"
    tagStr (PCDATA_48 _ _) = "pcdata"
instance TagStr Ent49 where
    tagStr (Caption_49 _ _) = "caption"
    tagStr (Thead_49 _ _) = "thead"
    tagStr (Tfoot_49 _ _) = "tfoot"
    tagStr (Tbody_49 _ _) = "tbody"
    tagStr (Colgroup_49 _ _) = "colgroup"
    tagStr (Col_49 _) = "col"
    tagStr (Tr_49 _ _) = "tr"
instance TagStr Ent50 where
    tagStr (Tr_50 _ _) = "tr"
instance TagStr Ent51 where
    tagStr (Col_51 _) = "col"
instance TagStr Ent52 where
    tagStr (Th_52 _ _) = "th"
    tagStr (Td_52 _ _) = "td"
instance TagStr Ent53 where
    tagStr (Script_53 _ _) = "script"
    tagStr (Noscript_53 _ _) = "noscript"
    tagStr (Iframe_53 _ _) = "iframe"
    tagStr (Noframes_53 _ _) = "noframes"
    tagStr (Div_53 _ _) = "div"
    tagStr (P_53 _ _) = "p"
    tagStr (H1_53 _ _) = "h1"
    tagStr (H2_53 _ _) = "h2"
    tagStr (H3_53 _ _) = "h3"
    tagStr (H4_53 _ _) = "h4"
    tagStr (H5_53 _ _) = "h5"
    tagStr (H6_53 _ _) = "h6"
    tagStr (Ul_53 _ _) = "ul"
    tagStr (Ol_53 _ _) = "ol"
    tagStr (Menu_53 _ _) = "menu"
    tagStr (Dir_53 _ _) = "dir"
    tagStr (Dl_53 _ _) = "dl"
    tagStr (Address_53 _ _) = "address"
    tagStr (Hr_53 _) = "hr"
    tagStr (Pre_53 _ _) = "pre"
    tagStr (Blockquote_53 _ _) = "blockquote"
    tagStr (Center_53 _ _) = "center"
    tagStr (Ins_53 _ _) = "ins"
    tagStr (Del_53 _ _) = "del"
    tagStr (Span_53 _ _) = "span"
    tagStr (Bdo_53 _ _) = "bdo"
    tagStr (Br_53 _) = "br"
    tagStr (Em_53 _ _) = "em"
    tagStr (Strong_53 _ _) = "strong"
    tagStr (Dfn_53 _ _) = "dfn"
    tagStr (Code_53 _ _) = "code"
    tagStr (Samp_53 _ _) = "samp"
    tagStr (Kbd_53 _ _) = "kbd"
    tagStr (Var_53 _ _) = "var"
    tagStr (Cite_53 _ _) = "cite"
    tagStr (Abbr_53 _ _) = "abbr"
    tagStr (Acronym_53 _ _) = "acronym"
    tagStr (Q_53 _ _) = "q"
    tagStr (Sub_53 _ _) = "sub"
    tagStr (Sup_53 _ _) = "sup"
    tagStr (Tt_53 _ _) = "tt"
    tagStr (I_53 _ _) = "i"
    tagStr (B_53 _ _) = "b"
    tagStr (Big_53 _ _) = "big"
    tagStr (Small_53 _ _) = "small"
    tagStr (U_53 _ _) = "u"
    tagStr (S_53 _ _) = "s"
    tagStr (Strike_53 _ _) = "strike"
    tagStr (Basefont_53 _) = "basefont"
    tagStr (Font_53 _ _) = "font"
    tagStr (Object_53 _ _) = "object"
    tagStr (Applet_53 _ _) = "applet"
    tagStr (Img_53 _) = "img"
    tagStr (Map_53 _ _) = "map"
    tagStr (Form_53 _ _) = "form"
    tagStr (Input_53 _) = "input"
    tagStr (Select_53 _ _) = "select"
    tagStr (Textarea_53 _ _) = "textarea"
    tagStr (Fieldset_53 _ _) = "fieldset"
    tagStr (Legend_53 _ _) = "legend"
    tagStr (Button_53 _ _) = "button"
    tagStr (Isindex_53 _) = "isindex"
    tagStr (Table_53 _ _) = "table"
    tagStr (PCDATA_53 _ _) = "pcdata"
instance TagStr Ent54 where
    tagStr (Caption_54 _ _) = "caption"
    tagStr (Thead_54 _ _) = "thead"
    tagStr (Tfoot_54 _ _) = "tfoot"
    tagStr (Tbody_54 _ _) = "tbody"
    tagStr (Colgroup_54 _ _) = "colgroup"
    tagStr (Col_54 _) = "col"
    tagStr (Tr_54 _ _) = "tr"
instance TagStr Ent55 where
    tagStr (Tr_55 _ _) = "tr"
instance TagStr Ent56 where
    tagStr (Col_56 _) = "col"
instance TagStr Ent57 where
    tagStr (Th_57 _ _) = "th"
    tagStr (Td_57 _ _) = "td"
instance TagStr Ent58 where
    tagStr (Script_58 _ _) = "script"
    tagStr (Noscript_58 _ _) = "noscript"
    tagStr (Iframe_58 _ _) = "iframe"
    tagStr (Noframes_58 _ _) = "noframes"
    tagStr (Div_58 _ _) = "div"
    tagStr (P_58 _ _) = "p"
    tagStr (H1_58 _ _) = "h1"
    tagStr (H2_58 _ _) = "h2"
    tagStr (H3_58 _ _) = "h3"
    tagStr (H4_58 _ _) = "h4"
    tagStr (H5_58 _ _) = "h5"
    tagStr (H6_58 _ _) = "h6"
    tagStr (Ul_58 _ _) = "ul"
    tagStr (Ol_58 _ _) = "ol"
    tagStr (Menu_58 _ _) = "menu"
    tagStr (Dir_58 _ _) = "dir"
    tagStr (Dl_58 _ _) = "dl"
    tagStr (Address_58 _ _) = "address"
    tagStr (Hr_58 _) = "hr"
    tagStr (Pre_58 _ _) = "pre"
    tagStr (Blockquote_58 _ _) = "blockquote"
    tagStr (Center_58 _ _) = "center"
    tagStr (Ins_58 _ _) = "ins"
    tagStr (Del_58 _ _) = "del"
    tagStr (Span_58 _ _) = "span"
    tagStr (Bdo_58 _ _) = "bdo"
    tagStr (Br_58 _) = "br"
    tagStr (Em_58 _ _) = "em"
    tagStr (Strong_58 _ _) = "strong"
    tagStr (Dfn_58 _ _) = "dfn"
    tagStr (Code_58 _ _) = "code"
    tagStr (Samp_58 _ _) = "samp"
    tagStr (Kbd_58 _ _) = "kbd"
    tagStr (Var_58 _ _) = "var"
    tagStr (Cite_58 _ _) = "cite"
    tagStr (Abbr_58 _ _) = "abbr"
    tagStr (Acronym_58 _ _) = "acronym"
    tagStr (Q_58 _ _) = "q"
    tagStr (Sub_58 _ _) = "sub"
    tagStr (Sup_58 _ _) = "sup"
    tagStr (Tt_58 _ _) = "tt"
    tagStr (I_58 _ _) = "i"
    tagStr (B_58 _ _) = "b"
    tagStr (Big_58 _ _) = "big"
    tagStr (Small_58 _ _) = "small"
    tagStr (U_58 _ _) = "u"
    tagStr (S_58 _ _) = "s"
    tagStr (Strike_58 _ _) = "strike"
    tagStr (Basefont_58 _) = "basefont"
    tagStr (Font_58 _ _) = "font"
    tagStr (Object_58 _ _) = "object"
    tagStr (Param_58 _) = "param"
    tagStr (Applet_58 _ _) = "applet"
    tagStr (Img_58 _) = "img"
    tagStr (Map_58 _ _) = "map"
    tagStr (Form_58 _ _) = "form"
    tagStr (Input_58 _) = "input"
    tagStr (Select_58 _ _) = "select"
    tagStr (Textarea_58 _ _) = "textarea"
    tagStr (Fieldset_58 _ _) = "fieldset"
    tagStr (Button_58 _ _) = "button"
    tagStr (Isindex_58 _) = "isindex"
    tagStr (Table_58 _ _) = "table"
    tagStr (PCDATA_58 _ _) = "pcdata"
instance TagStr Ent59 where
    tagStr (Script_59 _ _) = "script"
    tagStr (Noscript_59 _ _) = "noscript"
    tagStr (Noframes_59 _ _) = "noframes"
    tagStr (Div_59 _ _) = "div"
    tagStr (P_59 _ _) = "p"
    tagStr (H1_59 _ _) = "h1"
    tagStr (H2_59 _ _) = "h2"
    tagStr (H3_59 _ _) = "h3"
    tagStr (H4_59 _ _) = "h4"
    tagStr (H5_59 _ _) = "h5"
    tagStr (H6_59 _ _) = "h6"
    tagStr (Ul_59 _ _) = "ul"
    tagStr (Ol_59 _ _) = "ol"
    tagStr (Menu_59 _ _) = "menu"
    tagStr (Dir_59 _ _) = "dir"
    tagStr (Dl_59 _ _) = "dl"
    tagStr (Address_59 _ _) = "address"
    tagStr (Hr_59 _) = "hr"
    tagStr (Pre_59 _ _) = "pre"
    tagStr (Blockquote_59 _ _) = "blockquote"
    tagStr (Center_59 _ _) = "center"
    tagStr (Ins_59 _ _) = "ins"
    tagStr (Del_59 _ _) = "del"
    tagStr (Area_59 _) = "area"
    tagStr (Form_59 _ _) = "form"
    tagStr (Fieldset_59 _ _) = "fieldset"
    tagStr (Isindex_59 _) = "isindex"
    tagStr (Table_59 _ _) = "table"
instance TagStr Ent60 where
    tagStr (Optgroup_60 _ _) = "optgroup"
    tagStr (Option_60 _ _) = "option"
instance TagStr Ent61 where
    tagStr (Option_61 _ _) = "option"
instance TagStr Ent62 where
    tagStr (Script_62 _ _) = "script"
    tagStr (Noscript_62 _ _) = "noscript"
    tagStr (Noframes_62 _ _) = "noframes"
    tagStr (Div_62 _ _) = "div"
    tagStr (P_62 _ _) = "p"
    tagStr (H1_62 _ _) = "h1"
    tagStr (H2_62 _ _) = "h2"
    tagStr (H3_62 _ _) = "h3"
    tagStr (H4_62 _ _) = "h4"
    tagStr (H5_62 _ _) = "h5"
    tagStr (H6_62 _ _) = "h6"
    tagStr (Ul_62 _ _) = "ul"
    tagStr (Ol_62 _ _) = "ol"
    tagStr (Menu_62 _ _) = "menu"
    tagStr (Dir_62 _ _) = "dir"
    tagStr (Dl_62 _ _) = "dl"
    tagStr (Address_62 _ _) = "address"
    tagStr (Hr_62 _) = "hr"
    tagStr (Pre_62 _ _) = "pre"
    tagStr (Blockquote_62 _ _) = "blockquote"
    tagStr (Center_62 _ _) = "center"
    tagStr (Ins_62 _ _) = "ins"
    tagStr (Del_62 _ _) = "del"
    tagStr (Span_62 _ _) = "span"
    tagStr (Bdo_62 _ _) = "bdo"
    tagStr (Br_62 _) = "br"
    tagStr (Em_62 _ _) = "em"
    tagStr (Strong_62 _ _) = "strong"
    tagStr (Dfn_62 _ _) = "dfn"
    tagStr (Code_62 _ _) = "code"
    tagStr (Samp_62 _ _) = "samp"
    tagStr (Kbd_62 _ _) = "kbd"
    tagStr (Var_62 _ _) = "var"
    tagStr (Cite_62 _ _) = "cite"
    tagStr (Abbr_62 _ _) = "abbr"
    tagStr (Acronym_62 _ _) = "acronym"
    tagStr (Q_62 _ _) = "q"
    tagStr (Sub_62 _ _) = "sub"
    tagStr (Sup_62 _ _) = "sup"
    tagStr (Tt_62 _ _) = "tt"
    tagStr (I_62 _ _) = "i"
    tagStr (B_62 _ _) = "b"
    tagStr (Big_62 _ _) = "big"
    tagStr (Small_62 _ _) = "small"
    tagStr (U_62 _ _) = "u"
    tagStr (S_62 _ _) = "s"
    tagStr (Strike_62 _ _) = "strike"
    tagStr (Basefont_62 _) = "basefont"
    tagStr (Font_62 _ _) = "font"
    tagStr (Object_62 _ _) = "object"
    tagStr (Applet_62 _ _) = "applet"
    tagStr (Img_62 _) = "img"
    tagStr (Map_62 _ _) = "map"
    tagStr (Table_62 _ _) = "table"
    tagStr (PCDATA_62 _ _) = "pcdata"
instance TagStr Ent63 where
    tagStr (Optgroup_63 _ _) = "optgroup"
    tagStr (Option_63 _ _) = "option"
instance TagStr Ent64 where
    tagStr (Option_64 _ _) = "option"
instance TagStr Ent65 where
    tagStr (Script_65 _ _) = "script"
    tagStr (Noscript_65 _ _) = "noscript"
    tagStr (Noframes_65 _ _) = "noframes"
    tagStr (Div_65 _ _) = "div"
    tagStr (P_65 _ _) = "p"
    tagStr (H1_65 _ _) = "h1"
    tagStr (H2_65 _ _) = "h2"
    tagStr (H3_65 _ _) = "h3"
    tagStr (H4_65 _ _) = "h4"
    tagStr (H5_65 _ _) = "h5"
    tagStr (H6_65 _ _) = "h6"
    tagStr (Ul_65 _ _) = "ul"
    tagStr (Ol_65 _ _) = "ol"
    tagStr (Menu_65 _ _) = "menu"
    tagStr (Dir_65 _ _) = "dir"
    tagStr (Dl_65 _ _) = "dl"
    tagStr (Address_65 _ _) = "address"
    tagStr (Hr_65 _) = "hr"
    tagStr (Pre_65 _ _) = "pre"
    tagStr (Blockquote_65 _ _) = "blockquote"
    tagStr (Center_65 _ _) = "center"
    tagStr (Ins_65 _ _) = "ins"
    tagStr (Del_65 _ _) = "del"
    tagStr (Span_65 _ _) = "span"
    tagStr (Bdo_65 _ _) = "bdo"
    tagStr (Br_65 _) = "br"
    tagStr (Em_65 _ _) = "em"
    tagStr (Strong_65 _ _) = "strong"
    tagStr (Dfn_65 _ _) = "dfn"
    tagStr (Code_65 _ _) = "code"
    tagStr (Samp_65 _ _) = "samp"
    tagStr (Kbd_65 _ _) = "kbd"
    tagStr (Var_65 _ _) = "var"
    tagStr (Cite_65 _ _) = "cite"
    tagStr (Abbr_65 _ _) = "abbr"
    tagStr (Acronym_65 _ _) = "acronym"
    tagStr (Q_65 _ _) = "q"
    tagStr (Sub_65 _ _) = "sub"
    tagStr (Sup_65 _ _) = "sup"
    tagStr (Tt_65 _ _) = "tt"
    tagStr (I_65 _ _) = "i"
    tagStr (B_65 _ _) = "b"
    tagStr (Big_65 _ _) = "big"
    tagStr (Small_65 _ _) = "small"
    tagStr (U_65 _ _) = "u"
    tagStr (S_65 _ _) = "s"
    tagStr (Strike_65 _ _) = "strike"
    tagStr (Basefont_65 _) = "basefont"
    tagStr (Font_65 _ _) = "font"
    tagStr (Object_65 _ _) = "object"
    tagStr (Applet_65 _ _) = "applet"
    tagStr (Img_65 _) = "img"
    tagStr (Map_65 _ _) = "map"
    tagStr (Table_65 _ _) = "table"
    tagStr (PCDATA_65 _ _) = "pcdata"
instance TagStr Ent66 where
    tagStr (Script_66 _ _) = "script"
    tagStr (Noscript_66 _ _) = "noscript"
    tagStr (Noframes_66 _ _) = "noframes"
    tagStr (Div_66 _ _) = "div"
    tagStr (P_66 _ _) = "p"
    tagStr (H1_66 _ _) = "h1"
    tagStr (H2_66 _ _) = "h2"
    tagStr (H3_66 _ _) = "h3"
    tagStr (H4_66 _ _) = "h4"
    tagStr (H5_66 _ _) = "h5"
    tagStr (H6_66 _ _) = "h6"
    tagStr (Ul_66 _ _) = "ul"
    tagStr (Ol_66 _ _) = "ol"
    tagStr (Menu_66 _ _) = "menu"
    tagStr (Dir_66 _ _) = "dir"
    tagStr (Dl_66 _ _) = "dl"
    tagStr (Address_66 _ _) = "address"
    tagStr (Hr_66 _) = "hr"
    tagStr (Pre_66 _ _) = "pre"
    tagStr (Blockquote_66 _ _) = "blockquote"
    tagStr (Center_66 _ _) = "center"
    tagStr (Ins_66 _ _) = "ins"
    tagStr (Del_66 _ _) = "del"
    tagStr (Area_66 _) = "area"
    tagStr (Form_66 _ _) = "form"
    tagStr (Fieldset_66 _ _) = "fieldset"
    tagStr (Isindex_66 _) = "isindex"
    tagStr (Table_66 _ _) = "table"
instance TagStr Ent67 where
    tagStr (Script_67 _ _) = "script"
    tagStr (Noscript_67 _ _) = "noscript"
    tagStr (Iframe_67 _ _) = "iframe"
    tagStr (Noframes_67 _ _) = "noframes"
    tagStr (Div_67 _ _) = "div"
    tagStr (P_67 _ _) = "p"
    tagStr (H1_67 _ _) = "h1"
    tagStr (H2_67 _ _) = "h2"
    tagStr (H3_67 _ _) = "h3"
    tagStr (H4_67 _ _) = "h4"
    tagStr (H5_67 _ _) = "h5"
    tagStr (H6_67 _ _) = "h6"
    tagStr (Ul_67 _ _) = "ul"
    tagStr (Ol_67 _ _) = "ol"
    tagStr (Menu_67 _ _) = "menu"
    tagStr (Dir_67 _ _) = "dir"
    tagStr (Dl_67 _ _) = "dl"
    tagStr (Address_67 _ _) = "address"
    tagStr (Hr_67 _) = "hr"
    tagStr (Pre_67 _ _) = "pre"
    tagStr (Blockquote_67 _ _) = "blockquote"
    tagStr (Center_67 _ _) = "center"
    tagStr (Ins_67 _ _) = "ins"
    tagStr (Del_67 _ _) = "del"
    tagStr (A_67 _ _) = "a"
    tagStr (Span_67 _ _) = "span"
    tagStr (Bdo_67 _ _) = "bdo"
    tagStr (Br_67 _) = "br"
    tagStr (Em_67 _ _) = "em"
    tagStr (Strong_67 _ _) = "strong"
    tagStr (Dfn_67 _ _) = "dfn"
    tagStr (Code_67 _ _) = "code"
    tagStr (Samp_67 _ _) = "samp"
    tagStr (Kbd_67 _ _) = "kbd"
    tagStr (Var_67 _ _) = "var"
    tagStr (Cite_67 _ _) = "cite"
    tagStr (Abbr_67 _ _) = "abbr"
    tagStr (Acronym_67 _ _) = "acronym"
    tagStr (Q_67 _ _) = "q"
    tagStr (Sub_67 _ _) = "sub"
    tagStr (Sup_67 _ _) = "sup"
    tagStr (Tt_67 _ _) = "tt"
    tagStr (I_67 _ _) = "i"
    tagStr (B_67 _ _) = "b"
    tagStr (Big_67 _ _) = "big"
    tagStr (Small_67 _ _) = "small"
    tagStr (U_67 _ _) = "u"
    tagStr (S_67 _ _) = "s"
    tagStr (Strike_67 _ _) = "strike"
    tagStr (Basefont_67 _) = "basefont"
    tagStr (Font_67 _ _) = "font"
    tagStr (Object_67 _ _) = "object"
    tagStr (Applet_67 _ _) = "applet"
    tagStr (Img_67 _) = "img"
    tagStr (Map_67 _ _) = "map"
    tagStr (Label_67 _ _) = "label"
    tagStr (Input_67 _) = "input"
    tagStr (Select_67 _ _) = "select"
    tagStr (Textarea_67 _ _) = "textarea"
    tagStr (Fieldset_67 _ _) = "fieldset"
    tagStr (Button_67 _ _) = "button"
    tagStr (Isindex_67 _) = "isindex"
    tagStr (Table_67 _ _) = "table"
    tagStr (PCDATA_67 _ _) = "pcdata"
instance TagStr Ent68 where
    tagStr (PCDATA_68 _ _) = "pcdata"
instance TagStr Ent69 where
    tagStr (Script_69 _ _) = "script"
    tagStr (Iframe_69 _ _) = "iframe"
    tagStr (Ins_69 _ _) = "ins"
    tagStr (Del_69 _ _) = "del"
    tagStr (A_69 _ _) = "a"
    tagStr (Span_69 _ _) = "span"
    tagStr (Bdo_69 _ _) = "bdo"
    tagStr (Br_69 _) = "br"
    tagStr (Em_69 _ _) = "em"
    tagStr (Strong_69 _ _) = "strong"
    tagStr (Dfn_69 _ _) = "dfn"
    tagStr (Code_69 _ _) = "code"
    tagStr (Samp_69 _ _) = "samp"
    tagStr (Kbd_69 _ _) = "kbd"
    tagStr (Var_69 _ _) = "var"
    tagStr (Cite_69 _ _) = "cite"
    tagStr (Abbr_69 _ _) = "abbr"
    tagStr (Acronym_69 _ _) = "acronym"
    tagStr (Q_69 _ _) = "q"
    tagStr (Sub_69 _ _) = "sub"
    tagStr (Sup_69 _ _) = "sup"
    tagStr (Tt_69 _ _) = "tt"
    tagStr (I_69 _ _) = "i"
    tagStr (B_69 _ _) = "b"
    tagStr (Big_69 _ _) = "big"
    tagStr (Small_69 _ _) = "small"
    tagStr (U_69 _ _) = "u"
    tagStr (S_69 _ _) = "s"
    tagStr (Strike_69 _ _) = "strike"
    tagStr (Basefont_69 _) = "basefont"
    tagStr (Font_69 _ _) = "font"
    tagStr (Object_69 _ _) = "object"
    tagStr (Applet_69 _ _) = "applet"
    tagStr (Img_69 _) = "img"
    tagStr (Map_69 _ _) = "map"
    tagStr (Label_69 _ _) = "label"
    tagStr (Input_69 _) = "input"
    tagStr (Select_69 _ _) = "select"
    tagStr (Textarea_69 _ _) = "textarea"
    tagStr (Button_69 _ _) = "button"
    tagStr (PCDATA_69 _ _) = "pcdata"
instance TagStr Ent70 where
    tagStr (Li_70 _ _) = "li"
instance TagStr Ent71 where
    tagStr (Dt_71 _ _) = "dt"
    tagStr (Dd_71 _ _) = "dd"
instance TagStr Ent72 where
    tagStr (Script_72 _ _) = "script"
    tagStr (Iframe_72 _ _) = "iframe"
    tagStr (P_72 _ _) = "p"
    tagStr (Ins_72 _ _) = "ins"
    tagStr (Del_72 _ _) = "del"
    tagStr (A_72 _ _) = "a"
    tagStr (Span_72 _ _) = "span"
    tagStr (Bdo_72 _ _) = "bdo"
    tagStr (Br_72 _) = "br"
    tagStr (Em_72 _ _) = "em"
    tagStr (Strong_72 _ _) = "strong"
    tagStr (Dfn_72 _ _) = "dfn"
    tagStr (Code_72 _ _) = "code"
    tagStr (Samp_72 _ _) = "samp"
    tagStr (Kbd_72 _ _) = "kbd"
    tagStr (Var_72 _ _) = "var"
    tagStr (Cite_72 _ _) = "cite"
    tagStr (Abbr_72 _ _) = "abbr"
    tagStr (Acronym_72 _ _) = "acronym"
    tagStr (Q_72 _ _) = "q"
    tagStr (Sub_72 _ _) = "sub"
    tagStr (Sup_72 _ _) = "sup"
    tagStr (Tt_72 _ _) = "tt"
    tagStr (I_72 _ _) = "i"
    tagStr (B_72 _ _) = "b"
    tagStr (Big_72 _ _) = "big"
    tagStr (Small_72 _ _) = "small"
    tagStr (U_72 _ _) = "u"
    tagStr (S_72 _ _) = "s"
    tagStr (Strike_72 _ _) = "strike"
    tagStr (Basefont_72 _) = "basefont"
    tagStr (Font_72 _ _) = "font"
    tagStr (Object_72 _ _) = "object"
    tagStr (Applet_72 _ _) = "applet"
    tagStr (Img_72 _) = "img"
    tagStr (Map_72 _ _) = "map"
    tagStr (Label_72 _ _) = "label"
    tagStr (Input_72 _) = "input"
    tagStr (Select_72 _ _) = "select"
    tagStr (Textarea_72 _ _) = "textarea"
    tagStr (Button_72 _ _) = "button"
    tagStr (PCDATA_72 _ _) = "pcdata"
instance TagStr Ent73 where
    tagStr (Script_73 _ _) = "script"
    tagStr (Ins_73 _ _) = "ins"
    tagStr (Del_73 _ _) = "del"
    tagStr (A_73 _ _) = "a"
    tagStr (Span_73 _ _) = "span"
    tagStr (Bdo_73 _ _) = "bdo"
    tagStr (Br_73 _) = "br"
    tagStr (Em_73 _ _) = "em"
    tagStr (Strong_73 _ _) = "strong"
    tagStr (Dfn_73 _ _) = "dfn"
    tagStr (Code_73 _ _) = "code"
    tagStr (Samp_73 _ _) = "samp"
    tagStr (Kbd_73 _ _) = "kbd"
    tagStr (Var_73 _ _) = "var"
    tagStr (Cite_73 _ _) = "cite"
    tagStr (Abbr_73 _ _) = "abbr"
    tagStr (Acronym_73 _ _) = "acronym"
    tagStr (Q_73 _ _) = "q"
    tagStr (Tt_73 _ _) = "tt"
    tagStr (I_73 _ _) = "i"
    tagStr (B_73 _ _) = "b"
    tagStr (U_73 _ _) = "u"
    tagStr (S_73 _ _) = "s"
    tagStr (Strike_73 _ _) = "strike"
    tagStr (Label_73 _ _) = "label"
    tagStr (Input_73 _) = "input"
    tagStr (Select_73 _ _) = "select"
    tagStr (Textarea_73 _ _) = "textarea"
    tagStr (Button_73 _ _) = "button"
    tagStr (PCDATA_73 _ _) = "pcdata"
instance TagStr Ent74 where
    tagStr (PCDATA_74 _ _) = "pcdata"
instance TagStr Ent75 where
    tagStr (Script_75 _ _) = "script"
    tagStr (Noscript_75 _ _) = "noscript"
    tagStr (Iframe_75 _ _) = "iframe"
    tagStr (Noframes_75 _ _) = "noframes"
    tagStr (Div_75 _ _) = "div"
    tagStr (P_75 _ _) = "p"
    tagStr (H1_75 _ _) = "h1"
    tagStr (H2_75 _ _) = "h2"
    tagStr (H3_75 _ _) = "h3"
    tagStr (H4_75 _ _) = "h4"
    tagStr (H5_75 _ _) = "h5"
    tagStr (H6_75 _ _) = "h6"
    tagStr (Ul_75 _ _) = "ul"
    tagStr (Ol_75 _ _) = "ol"
    tagStr (Menu_75 _ _) = "menu"
    tagStr (Dir_75 _ _) = "dir"
    tagStr (Dl_75 _ _) = "dl"
    tagStr (Address_75 _ _) = "address"
    tagStr (Hr_75 _) = "hr"
    tagStr (Pre_75 _ _) = "pre"
    tagStr (Blockquote_75 _ _) = "blockquote"
    tagStr (Center_75 _ _) = "center"
    tagStr (Ins_75 _ _) = "ins"
    tagStr (Del_75 _ _) = "del"
    tagStr (Span_75 _ _) = "span"
    tagStr (Bdo_75 _ _) = "bdo"
    tagStr (Br_75 _) = "br"
    tagStr (Em_75 _ _) = "em"
    tagStr (Strong_75 _ _) = "strong"
    tagStr (Dfn_75 _ _) = "dfn"
    tagStr (Code_75 _ _) = "code"
    tagStr (Samp_75 _ _) = "samp"
    tagStr (Kbd_75 _ _) = "kbd"
    tagStr (Var_75 _ _) = "var"
    tagStr (Cite_75 _ _) = "cite"
    tagStr (Abbr_75 _ _) = "abbr"
    tagStr (Acronym_75 _ _) = "acronym"
    tagStr (Q_75 _ _) = "q"
    tagStr (Sub_75 _ _) = "sub"
    tagStr (Sup_75 _ _) = "sup"
    tagStr (Tt_75 _ _) = "tt"
    tagStr (I_75 _ _) = "i"
    tagStr (B_75 _ _) = "b"
    tagStr (Big_75 _ _) = "big"
    tagStr (Small_75 _ _) = "small"
    tagStr (U_75 _ _) = "u"
    tagStr (S_75 _ _) = "s"
    tagStr (Strike_75 _ _) = "strike"
    tagStr (Basefont_75 _) = "basefont"
    tagStr (Font_75 _ _) = "font"
    tagStr (Object_75 _ _) = "object"
    tagStr (Param_75 _) = "param"
    tagStr (Applet_75 _ _) = "applet"
    tagStr (Img_75 _) = "img"
    tagStr (Map_75 _ _) = "map"
    tagStr (Label_75 _ _) = "label"
    tagStr (Input_75 _) = "input"
    tagStr (Select_75 _ _) = "select"
    tagStr (Textarea_75 _ _) = "textarea"
    tagStr (Fieldset_75 _ _) = "fieldset"
    tagStr (Button_75 _ _) = "button"
    tagStr (Isindex_75 _) = "isindex"
    tagStr (Table_75 _ _) = "table"
    tagStr (PCDATA_75 _ _) = "pcdata"
instance TagStr Ent76 where
    tagStr (Script_76 _ _) = "script"
    tagStr (Noscript_76 _ _) = "noscript"
    tagStr (Noframes_76 _ _) = "noframes"
    tagStr (Div_76 _ _) = "div"
    tagStr (P_76 _ _) = "p"
    tagStr (H1_76 _ _) = "h1"
    tagStr (H2_76 _ _) = "h2"
    tagStr (H3_76 _ _) = "h3"
    tagStr (H4_76 _ _) = "h4"
    tagStr (H5_76 _ _) = "h5"
    tagStr (H6_76 _ _) = "h6"
    tagStr (Ul_76 _ _) = "ul"
    tagStr (Ol_76 _ _) = "ol"
    tagStr (Menu_76 _ _) = "menu"
    tagStr (Dir_76 _ _) = "dir"
    tagStr (Dl_76 _ _) = "dl"
    tagStr (Address_76 _ _) = "address"
    tagStr (Hr_76 _) = "hr"
    tagStr (Pre_76 _ _) = "pre"
    tagStr (Blockquote_76 _ _) = "blockquote"
    tagStr (Center_76 _ _) = "center"
    tagStr (Ins_76 _ _) = "ins"
    tagStr (Del_76 _ _) = "del"
    tagStr (Area_76 _) = "area"
    tagStr (Fieldset_76 _ _) = "fieldset"
    tagStr (Isindex_76 _) = "isindex"
    tagStr (Table_76 _ _) = "table"
instance TagStr Ent77 where
    tagStr (PCDATA_77 _ _) = "pcdata"
instance TagStr Ent78 where
    tagStr (Script_78 _ _) = "script"
    tagStr (Noscript_78 _ _) = "noscript"
    tagStr (Iframe_78 _ _) = "iframe"
    tagStr (Noframes_78 _ _) = "noframes"
    tagStr (Div_78 _ _) = "div"
    tagStr (P_78 _ _) = "p"
    tagStr (H1_78 _ _) = "h1"
    tagStr (H2_78 _ _) = "h2"
    tagStr (H3_78 _ _) = "h3"
    tagStr (H4_78 _ _) = "h4"
    tagStr (H5_78 _ _) = "h5"
    tagStr (H6_78 _ _) = "h6"
    tagStr (Ul_78 _ _) = "ul"
    tagStr (Ol_78 _ _) = "ol"
    tagStr (Menu_78 _ _) = "menu"
    tagStr (Dir_78 _ _) = "dir"
    tagStr (Dl_78 _ _) = "dl"
    tagStr (Address_78 _ _) = "address"
    tagStr (Hr_78 _) = "hr"
    tagStr (Pre_78 _ _) = "pre"
    tagStr (Blockquote_78 _ _) = "blockquote"
    tagStr (Center_78 _ _) = "center"
    tagStr (Ins_78 _ _) = "ins"
    tagStr (Del_78 _ _) = "del"
    tagStr (Span_78 _ _) = "span"
    tagStr (Bdo_78 _ _) = "bdo"
    tagStr (Br_78 _) = "br"
    tagStr (Em_78 _ _) = "em"
    tagStr (Strong_78 _ _) = "strong"
    tagStr (Dfn_78 _ _) = "dfn"
    tagStr (Code_78 _ _) = "code"
    tagStr (Samp_78 _ _) = "samp"
    tagStr (Kbd_78 _ _) = "kbd"
    tagStr (Var_78 _ _) = "var"
    tagStr (Cite_78 _ _) = "cite"
    tagStr (Abbr_78 _ _) = "abbr"
    tagStr (Acronym_78 _ _) = "acronym"
    tagStr (Q_78 _ _) = "q"
    tagStr (Sub_78 _ _) = "sub"
    tagStr (Sup_78 _ _) = "sup"
    tagStr (Tt_78 _ _) = "tt"
    tagStr (I_78 _ _) = "i"
    tagStr (B_78 _ _) = "b"
    tagStr (Big_78 _ _) = "big"
    tagStr (Small_78 _ _) = "small"
    tagStr (U_78 _ _) = "u"
    tagStr (S_78 _ _) = "s"
    tagStr (Strike_78 _ _) = "strike"
    tagStr (Basefont_78 _) = "basefont"
    tagStr (Font_78 _ _) = "font"
    tagStr (Object_78 _ _) = "object"
    tagStr (Param_78 _) = "param"
    tagStr (Applet_78 _ _) = "applet"
    tagStr (Img_78 _) = "img"
    tagStr (Map_78 _ _) = "map"
    tagStr (Input_78 _) = "input"
    tagStr (Select_78 _ _) = "select"
    tagStr (Textarea_78 _ _) = "textarea"
    tagStr (Fieldset_78 _ _) = "fieldset"
    tagStr (Button_78 _ _) = "button"
    tagStr (Isindex_78 _) = "isindex"
    tagStr (Table_78 _ _) = "table"
    tagStr (PCDATA_78 _ _) = "pcdata"
instance TagStr Ent79 where
    tagStr (Script_79 _ _) = "script"
    tagStr (Noscript_79 _ _) = "noscript"
    tagStr (Noframes_79 _ _) = "noframes"
    tagStr (Div_79 _ _) = "div"
    tagStr (P_79 _ _) = "p"
    tagStr (H1_79 _ _) = "h1"
    tagStr (H2_79 _ _) = "h2"
    tagStr (H3_79 _ _) = "h3"
    tagStr (H4_79 _ _) = "h4"
    tagStr (H5_79 _ _) = "h5"
    tagStr (H6_79 _ _) = "h6"
    tagStr (Ul_79 _ _) = "ul"
    tagStr (Ol_79 _ _) = "ol"
    tagStr (Menu_79 _ _) = "menu"
    tagStr (Dir_79 _ _) = "dir"
    tagStr (Dl_79 _ _) = "dl"
    tagStr (Address_79 _ _) = "address"
    tagStr (Hr_79 _) = "hr"
    tagStr (Pre_79 _ _) = "pre"
    tagStr (Blockquote_79 _ _) = "blockquote"
    tagStr (Center_79 _ _) = "center"
    tagStr (Ins_79 _ _) = "ins"
    tagStr (Del_79 _ _) = "del"
    tagStr (Area_79 _) = "area"
    tagStr (Fieldset_79 _ _) = "fieldset"
    tagStr (Isindex_79 _) = "isindex"
    tagStr (Table_79 _ _) = "table"
instance TagStr Ent80 where
    tagStr (Optgroup_80 _ _) = "optgroup"
    tagStr (Option_80 _ _) = "option"
instance TagStr Ent81 where
    tagStr (Option_81 _ _) = "option"
instance TagStr Ent82 where
    tagStr (Script_82 _ _) = "script"
    tagStr (Noscript_82 _ _) = "noscript"
    tagStr (Noframes_82 _ _) = "noframes"
    tagStr (Div_82 _ _) = "div"
    tagStr (P_82 _ _) = "p"
    tagStr (H1_82 _ _) = "h1"
    tagStr (H2_82 _ _) = "h2"
    tagStr (H3_82 _ _) = "h3"
    tagStr (H4_82 _ _) = "h4"
    tagStr (H5_82 _ _) = "h5"
    tagStr (H6_82 _ _) = "h6"
    tagStr (Ul_82 _ _) = "ul"
    tagStr (Ol_82 _ _) = "ol"
    tagStr (Menu_82 _ _) = "menu"
    tagStr (Dir_82 _ _) = "dir"
    tagStr (Dl_82 _ _) = "dl"
    tagStr (Address_82 _ _) = "address"
    tagStr (Hr_82 _) = "hr"
    tagStr (Pre_82 _ _) = "pre"
    tagStr (Blockquote_82 _ _) = "blockquote"
    tagStr (Center_82 _ _) = "center"
    tagStr (Ins_82 _ _) = "ins"
    tagStr (Del_82 _ _) = "del"
    tagStr (Span_82 _ _) = "span"
    tagStr (Bdo_82 _ _) = "bdo"
    tagStr (Br_82 _) = "br"
    tagStr (Em_82 _ _) = "em"
    tagStr (Strong_82 _ _) = "strong"
    tagStr (Dfn_82 _ _) = "dfn"
    tagStr (Code_82 _ _) = "code"
    tagStr (Samp_82 _ _) = "samp"
    tagStr (Kbd_82 _ _) = "kbd"
    tagStr (Var_82 _ _) = "var"
    tagStr (Cite_82 _ _) = "cite"
    tagStr (Abbr_82 _ _) = "abbr"
    tagStr (Acronym_82 _ _) = "acronym"
    tagStr (Q_82 _ _) = "q"
    tagStr (Sub_82 _ _) = "sub"
    tagStr (Sup_82 _ _) = "sup"
    tagStr (Tt_82 _ _) = "tt"
    tagStr (I_82 _ _) = "i"
    tagStr (B_82 _ _) = "b"
    tagStr (Big_82 _ _) = "big"
    tagStr (Small_82 _ _) = "small"
    tagStr (U_82 _ _) = "u"
    tagStr (S_82 _ _) = "s"
    tagStr (Strike_82 _ _) = "strike"
    tagStr (Basefont_82 _) = "basefont"
    tagStr (Font_82 _ _) = "font"
    tagStr (Object_82 _ _) = "object"
    tagStr (Applet_82 _ _) = "applet"
    tagStr (Img_82 _) = "img"
    tagStr (Map_82 _ _) = "map"
    tagStr (Table_82 _ _) = "table"
    tagStr (PCDATA_82 _ _) = "pcdata"
instance TagStr Ent83 where
    tagStr (Optgroup_83 _ _) = "optgroup"
    tagStr (Option_83 _ _) = "option"
instance TagStr Ent84 where
    tagStr (Option_84 _ _) = "option"
instance TagStr Ent85 where
    tagStr (Script_85 _ _) = "script"
    tagStr (Noscript_85 _ _) = "noscript"
    tagStr (Noframes_85 _ _) = "noframes"
    tagStr (Div_85 _ _) = "div"
    tagStr (P_85 _ _) = "p"
    tagStr (H1_85 _ _) = "h1"
    tagStr (H2_85 _ _) = "h2"
    tagStr (H3_85 _ _) = "h3"
    tagStr (H4_85 _ _) = "h4"
    tagStr (H5_85 _ _) = "h5"
    tagStr (H6_85 _ _) = "h6"
    tagStr (Ul_85 _ _) = "ul"
    tagStr (Ol_85 _ _) = "ol"
    tagStr (Menu_85 _ _) = "menu"
    tagStr (Dir_85 _ _) = "dir"
    tagStr (Dl_85 _ _) = "dl"
    tagStr (Address_85 _ _) = "address"
    tagStr (Hr_85 _) = "hr"
    tagStr (Pre_85 _ _) = "pre"
    tagStr (Blockquote_85 _ _) = "blockquote"
    tagStr (Center_85 _ _) = "center"
    tagStr (Ins_85 _ _) = "ins"
    tagStr (Del_85 _ _) = "del"
    tagStr (Span_85 _ _) = "span"
    tagStr (Bdo_85 _ _) = "bdo"
    tagStr (Br_85 _) = "br"
    tagStr (Em_85 _ _) = "em"
    tagStr (Strong_85 _ _) = "strong"
    tagStr (Dfn_85 _ _) = "dfn"
    tagStr (Code_85 _ _) = "code"
    tagStr (Samp_85 _ _) = "samp"
    tagStr (Kbd_85 _ _) = "kbd"
    tagStr (Var_85 _ _) = "var"
    tagStr (Cite_85 _ _) = "cite"
    tagStr (Abbr_85 _ _) = "abbr"
    tagStr (Acronym_85 _ _) = "acronym"
    tagStr (Q_85 _ _) = "q"
    tagStr (Sub_85 _ _) = "sub"
    tagStr (Sup_85 _ _) = "sup"
    tagStr (Tt_85 _ _) = "tt"
    tagStr (I_85 _ _) = "i"
    tagStr (B_85 _ _) = "b"
    tagStr (Big_85 _ _) = "big"
    tagStr (Small_85 _ _) = "small"
    tagStr (U_85 _ _) = "u"
    tagStr (S_85 _ _) = "s"
    tagStr (Strike_85 _ _) = "strike"
    tagStr (Basefont_85 _) = "basefont"
    tagStr (Font_85 _ _) = "font"
    tagStr (Object_85 _ _) = "object"
    tagStr (Applet_85 _ _) = "applet"
    tagStr (Img_85 _) = "img"
    tagStr (Map_85 _ _) = "map"
    tagStr (Table_85 _ _) = "table"
    tagStr (PCDATA_85 _ _) = "pcdata"
instance TagStr Ent86 where
    tagStr (Script_86 _ _) = "script"
    tagStr (Noscript_86 _ _) = "noscript"
    tagStr (Iframe_86 _ _) = "iframe"
    tagStr (Noframes_86 _ _) = "noframes"
    tagStr (Div_86 _ _) = "div"
    tagStr (P_86 _ _) = "p"
    tagStr (H1_86 _ _) = "h1"
    tagStr (H2_86 _ _) = "h2"
    tagStr (H3_86 _ _) = "h3"
    tagStr (H4_86 _ _) = "h4"
    tagStr (H5_86 _ _) = "h5"
    tagStr (H6_86 _ _) = "h6"
    tagStr (Ul_86 _ _) = "ul"
    tagStr (Ol_86 _ _) = "ol"
    tagStr (Menu_86 _ _) = "menu"
    tagStr (Dir_86 _ _) = "dir"
    tagStr (Dl_86 _ _) = "dl"
    tagStr (Address_86 _ _) = "address"
    tagStr (Hr_86 _) = "hr"
    tagStr (Pre_86 _ _) = "pre"
    tagStr (Blockquote_86 _ _) = "blockquote"
    tagStr (Center_86 _ _) = "center"
    tagStr (Ins_86 _ _) = "ins"
    tagStr (Del_86 _ _) = "del"
    tagStr (A_86 _ _) = "a"
    tagStr (Span_86 _ _) = "span"
    tagStr (Bdo_86 _ _) = "bdo"
    tagStr (Br_86 _) = "br"
    tagStr (Em_86 _ _) = "em"
    tagStr (Strong_86 _ _) = "strong"
    tagStr (Dfn_86 _ _) = "dfn"
    tagStr (Code_86 _ _) = "code"
    tagStr (Samp_86 _ _) = "samp"
    tagStr (Kbd_86 _ _) = "kbd"
    tagStr (Var_86 _ _) = "var"
    tagStr (Cite_86 _ _) = "cite"
    tagStr (Abbr_86 _ _) = "abbr"
    tagStr (Acronym_86 _ _) = "acronym"
    tagStr (Q_86 _ _) = "q"
    tagStr (Sub_86 _ _) = "sub"
    tagStr (Sup_86 _ _) = "sup"
    tagStr (Tt_86 _ _) = "tt"
    tagStr (I_86 _ _) = "i"
    tagStr (B_86 _ _) = "b"
    tagStr (Big_86 _ _) = "big"
    tagStr (Small_86 _ _) = "small"
    tagStr (U_86 _ _) = "u"
    tagStr (S_86 _ _) = "s"
    tagStr (Strike_86 _ _) = "strike"
    tagStr (Basefont_86 _) = "basefont"
    tagStr (Font_86 _ _) = "font"
    tagStr (Object_86 _ _) = "object"
    tagStr (Param_86 _) = "param"
    tagStr (Applet_86 _ _) = "applet"
    tagStr (Img_86 _) = "img"
    tagStr (Map_86 _ _) = "map"
    tagStr (Label_86 _ _) = "label"
    tagStr (Input_86 _) = "input"
    tagStr (Select_86 _ _) = "select"
    tagStr (Textarea_86 _ _) = "textarea"
    tagStr (Fieldset_86 _ _) = "fieldset"
    tagStr (Button_86 _ _) = "button"
    tagStr (Isindex_86 _) = "isindex"
    tagStr (Table_86 _ _) = "table"
    tagStr (PCDATA_86 _ _) = "pcdata"
instance TagStr Ent87 where
    tagStr (Script_87 _ _) = "script"
    tagStr (Noscript_87 _ _) = "noscript"
    tagStr (Noframes_87 _ _) = "noframes"
    tagStr (Div_87 _ _) = "div"
    tagStr (P_87 _ _) = "p"
    tagStr (H1_87 _ _) = "h1"
    tagStr (H2_87 _ _) = "h2"
    tagStr (H3_87 _ _) = "h3"
    tagStr (H4_87 _ _) = "h4"
    tagStr (H5_87 _ _) = "h5"
    tagStr (H6_87 _ _) = "h6"
    tagStr (Ul_87 _ _) = "ul"
    tagStr (Ol_87 _ _) = "ol"
    tagStr (Menu_87 _ _) = "menu"
    tagStr (Dir_87 _ _) = "dir"
    tagStr (Dl_87 _ _) = "dl"
    tagStr (Address_87 _ _) = "address"
    tagStr (Hr_87 _) = "hr"
    tagStr (Pre_87 _ _) = "pre"
    tagStr (Blockquote_87 _ _) = "blockquote"
    tagStr (Center_87 _ _) = "center"
    tagStr (Ins_87 _ _) = "ins"
    tagStr (Del_87 _ _) = "del"
    tagStr (Area_87 _) = "area"
    tagStr (Fieldset_87 _ _) = "fieldset"
    tagStr (Isindex_87 _) = "isindex"
    tagStr (Table_87 _ _) = "table"
instance TagStr Ent88 where
    tagStr (Script_88 _ _) = "script"
    tagStr (Iframe_88 _ _) = "iframe"
    tagStr (Ins_88 _ _) = "ins"
    tagStr (Del_88 _ _) = "del"
    tagStr (A_88 _ _) = "a"
    tagStr (Span_88 _ _) = "span"
    tagStr (Bdo_88 _ _) = "bdo"
    tagStr (Br_88 _) = "br"
    tagStr (Em_88 _ _) = "em"
    tagStr (Strong_88 _ _) = "strong"
    tagStr (Dfn_88 _ _) = "dfn"
    tagStr (Code_88 _ _) = "code"
    tagStr (Samp_88 _ _) = "samp"
    tagStr (Kbd_88 _ _) = "kbd"
    tagStr (Var_88 _ _) = "var"
    tagStr (Cite_88 _ _) = "cite"
    tagStr (Abbr_88 _ _) = "abbr"
    tagStr (Acronym_88 _ _) = "acronym"
    tagStr (Q_88 _ _) = "q"
    tagStr (Sub_88 _ _) = "sub"
    tagStr (Sup_88 _ _) = "sup"
    tagStr (Tt_88 _ _) = "tt"
    tagStr (I_88 _ _) = "i"
    tagStr (B_88 _ _) = "b"
    tagStr (Big_88 _ _) = "big"
    tagStr (Small_88 _ _) = "small"
    tagStr (U_88 _ _) = "u"
    tagStr (S_88 _ _) = "s"
    tagStr (Strike_88 _ _) = "strike"
    tagStr (Basefont_88 _) = "basefont"
    tagStr (Font_88 _ _) = "font"
    tagStr (Object_88 _ _) = "object"
    tagStr (Applet_88 _ _) = "applet"
    tagStr (Img_88 _) = "img"
    tagStr (Map_88 _ _) = "map"
    tagStr (Input_88 _) = "input"
    tagStr (Select_88 _ _) = "select"
    tagStr (Textarea_88 _ _) = "textarea"
    tagStr (Button_88 _ _) = "button"
    tagStr (PCDATA_88 _ _) = "pcdata"
instance TagStr Ent89 where
    tagStr (PCDATA_89 _ _) = "pcdata"
instance TagStr Ent90 where
    tagStr (Script_90 _ _) = "script"
    tagStr (Noscript_90 _ _) = "noscript"
    tagStr (Iframe_90 _ _) = "iframe"
    tagStr (Noframes_90 _ _) = "noframes"
    tagStr (Div_90 _ _) = "div"
    tagStr (P_90 _ _) = "p"
    tagStr (H1_90 _ _) = "h1"
    tagStr (H2_90 _ _) = "h2"
    tagStr (H3_90 _ _) = "h3"
    tagStr (H4_90 _ _) = "h4"
    tagStr (H5_90 _ _) = "h5"
    tagStr (H6_90 _ _) = "h6"
    tagStr (Ul_90 _ _) = "ul"
    tagStr (Ol_90 _ _) = "ol"
    tagStr (Menu_90 _ _) = "menu"
    tagStr (Dir_90 _ _) = "dir"
    tagStr (Dl_90 _ _) = "dl"
    tagStr (Address_90 _ _) = "address"
    tagStr (Hr_90 _) = "hr"
    tagStr (Pre_90 _ _) = "pre"
    tagStr (Blockquote_90 _ _) = "blockquote"
    tagStr (Center_90 _ _) = "center"
    tagStr (Ins_90 _ _) = "ins"
    tagStr (Del_90 _ _) = "del"
    tagStr (A_90 _ _) = "a"
    tagStr (Span_90 _ _) = "span"
    tagStr (Bdo_90 _ _) = "bdo"
    tagStr (Br_90 _) = "br"
    tagStr (Em_90 _ _) = "em"
    tagStr (Strong_90 _ _) = "strong"
    tagStr (Dfn_90 _ _) = "dfn"
    tagStr (Code_90 _ _) = "code"
    tagStr (Samp_90 _ _) = "samp"
    tagStr (Kbd_90 _ _) = "kbd"
    tagStr (Var_90 _ _) = "var"
    tagStr (Cite_90 _ _) = "cite"
    tagStr (Abbr_90 _ _) = "abbr"
    tagStr (Acronym_90 _ _) = "acronym"
    tagStr (Q_90 _ _) = "q"
    tagStr (Sub_90 _ _) = "sub"
    tagStr (Sup_90 _ _) = "sup"
    tagStr (Tt_90 _ _) = "tt"
    tagStr (I_90 _ _) = "i"
    tagStr (B_90 _ _) = "b"
    tagStr (Big_90 _ _) = "big"
    tagStr (Small_90 _ _) = "small"
    tagStr (U_90 _ _) = "u"
    tagStr (S_90 _ _) = "s"
    tagStr (Strike_90 _ _) = "strike"
    tagStr (Basefont_90 _) = "basefont"
    tagStr (Font_90 _ _) = "font"
    tagStr (Object_90 _ _) = "object"
    tagStr (Applet_90 _ _) = "applet"
    tagStr (Img_90 _) = "img"
    tagStr (Map_90 _ _) = "map"
    tagStr (Input_90 _) = "input"
    tagStr (Select_90 _ _) = "select"
    tagStr (Textarea_90 _ _) = "textarea"
    tagStr (Fieldset_90 _ _) = "fieldset"
    tagStr (Button_90 _ _) = "button"
    tagStr (Isindex_90 _) = "isindex"
    tagStr (Table_90 _ _) = "table"
    tagStr (PCDATA_90 _ _) = "pcdata"
instance TagStr Ent91 where
    tagStr (Li_91 _ _) = "li"
instance TagStr Ent92 where
    tagStr (Dt_92 _ _) = "dt"
    tagStr (Dd_92 _ _) = "dd"
instance TagStr Ent93 where
    tagStr (Script_93 _ _) = "script"
    tagStr (Iframe_93 _ _) = "iframe"
    tagStr (P_93 _ _) = "p"
    tagStr (Ins_93 _ _) = "ins"
    tagStr (Del_93 _ _) = "del"
    tagStr (A_93 _ _) = "a"
    tagStr (Span_93 _ _) = "span"
    tagStr (Bdo_93 _ _) = "bdo"
    tagStr (Br_93 _) = "br"
    tagStr (Em_93 _ _) = "em"
    tagStr (Strong_93 _ _) = "strong"
    tagStr (Dfn_93 _ _) = "dfn"
    tagStr (Code_93 _ _) = "code"
    tagStr (Samp_93 _ _) = "samp"
    tagStr (Kbd_93 _ _) = "kbd"
    tagStr (Var_93 _ _) = "var"
    tagStr (Cite_93 _ _) = "cite"
    tagStr (Abbr_93 _ _) = "abbr"
    tagStr (Acronym_93 _ _) = "acronym"
    tagStr (Q_93 _ _) = "q"
    tagStr (Sub_93 _ _) = "sub"
    tagStr (Sup_93 _ _) = "sup"
    tagStr (Tt_93 _ _) = "tt"
    tagStr (I_93 _ _) = "i"
    tagStr (B_93 _ _) = "b"
    tagStr (Big_93 _ _) = "big"
    tagStr (Small_93 _ _) = "small"
    tagStr (U_93 _ _) = "u"
    tagStr (S_93 _ _) = "s"
    tagStr (Strike_93 _ _) = "strike"
    tagStr (Basefont_93 _) = "basefont"
    tagStr (Font_93 _ _) = "font"
    tagStr (Object_93 _ _) = "object"
    tagStr (Applet_93 _ _) = "applet"
    tagStr (Img_93 _) = "img"
    tagStr (Map_93 _ _) = "map"
    tagStr (Input_93 _) = "input"
    tagStr (Select_93 _ _) = "select"
    tagStr (Textarea_93 _ _) = "textarea"
    tagStr (Button_93 _ _) = "button"
    tagStr (PCDATA_93 _ _) = "pcdata"
instance TagStr Ent94 where
    tagStr (Script_94 _ _) = "script"
    tagStr (Ins_94 _ _) = "ins"
    tagStr (Del_94 _ _) = "del"
    tagStr (A_94 _ _) = "a"
    tagStr (Span_94 _ _) = "span"
    tagStr (Bdo_94 _ _) = "bdo"
    tagStr (Br_94 _) = "br"
    tagStr (Em_94 _ _) = "em"
    tagStr (Strong_94 _ _) = "strong"
    tagStr (Dfn_94 _ _) = "dfn"
    tagStr (Code_94 _ _) = "code"
    tagStr (Samp_94 _ _) = "samp"
    tagStr (Kbd_94 _ _) = "kbd"
    tagStr (Var_94 _ _) = "var"
    tagStr (Cite_94 _ _) = "cite"
    tagStr (Abbr_94 _ _) = "abbr"
    tagStr (Acronym_94 _ _) = "acronym"
    tagStr (Q_94 _ _) = "q"
    tagStr (Tt_94 _ _) = "tt"
    tagStr (I_94 _ _) = "i"
    tagStr (B_94 _ _) = "b"
    tagStr (U_94 _ _) = "u"
    tagStr (S_94 _ _) = "s"
    tagStr (Strike_94 _ _) = "strike"
    tagStr (Input_94 _) = "input"
    tagStr (Select_94 _ _) = "select"
    tagStr (Textarea_94 _ _) = "textarea"
    tagStr (Button_94 _ _) = "button"
    tagStr (PCDATA_94 _ _) = "pcdata"
instance TagStr Ent95 where
    tagStr (Script_95 _ _) = "script"
    tagStr (Noscript_95 _ _) = "noscript"
    tagStr (Iframe_95 _ _) = "iframe"
    tagStr (Noframes_95 _ _) = "noframes"
    tagStr (Div_95 _ _) = "div"
    tagStr (P_95 _ _) = "p"
    tagStr (H1_95 _ _) = "h1"
    tagStr (H2_95 _ _) = "h2"
    tagStr (H3_95 _ _) = "h3"
    tagStr (H4_95 _ _) = "h4"
    tagStr (H5_95 _ _) = "h5"
    tagStr (H6_95 _ _) = "h6"
    tagStr (Ul_95 _ _) = "ul"
    tagStr (Ol_95 _ _) = "ol"
    tagStr (Menu_95 _ _) = "menu"
    tagStr (Dir_95 _ _) = "dir"
    tagStr (Dl_95 _ _) = "dl"
    tagStr (Address_95 _ _) = "address"
    tagStr (Hr_95 _) = "hr"
    tagStr (Pre_95 _ _) = "pre"
    tagStr (Blockquote_95 _ _) = "blockquote"
    tagStr (Center_95 _ _) = "center"
    tagStr (Ins_95 _ _) = "ins"
    tagStr (Del_95 _ _) = "del"
    tagStr (A_95 _ _) = "a"
    tagStr (Span_95 _ _) = "span"
    tagStr (Bdo_95 _ _) = "bdo"
    tagStr (Br_95 _) = "br"
    tagStr (Em_95 _ _) = "em"
    tagStr (Strong_95 _ _) = "strong"
    tagStr (Dfn_95 _ _) = "dfn"
    tagStr (Code_95 _ _) = "code"
    tagStr (Samp_95 _ _) = "samp"
    tagStr (Kbd_95 _ _) = "kbd"
    tagStr (Var_95 _ _) = "var"
    tagStr (Cite_95 _ _) = "cite"
    tagStr (Abbr_95 _ _) = "abbr"
    tagStr (Acronym_95 _ _) = "acronym"
    tagStr (Q_95 _ _) = "q"
    tagStr (Sub_95 _ _) = "sub"
    tagStr (Sup_95 _ _) = "sup"
    tagStr (Tt_95 _ _) = "tt"
    tagStr (I_95 _ _) = "i"
    tagStr (B_95 _ _) = "b"
    tagStr (Big_95 _ _) = "big"
    tagStr (Small_95 _ _) = "small"
    tagStr (U_95 _ _) = "u"
    tagStr (S_95 _ _) = "s"
    tagStr (Strike_95 _ _) = "strike"
    tagStr (Basefont_95 _) = "basefont"
    tagStr (Font_95 _ _) = "font"
    tagStr (Object_95 _ _) = "object"
    tagStr (Applet_95 _ _) = "applet"
    tagStr (Img_95 _) = "img"
    tagStr (Map_95 _ _) = "map"
    tagStr (Input_95 _) = "input"
    tagStr (Select_95 _ _) = "select"
    tagStr (Textarea_95 _ _) = "textarea"
    tagStr (Fieldset_95 _ _) = "fieldset"
    tagStr (Legend_95 _ _) = "legend"
    tagStr (Button_95 _ _) = "button"
    tagStr (Isindex_95 _) = "isindex"
    tagStr (Table_95 _ _) = "table"
    tagStr (PCDATA_95 _ _) = "pcdata"
instance TagStr Ent96 where
    tagStr (Caption_96 _ _) = "caption"
    tagStr (Thead_96 _ _) = "thead"
    tagStr (Tfoot_96 _ _) = "tfoot"
    tagStr (Tbody_96 _ _) = "tbody"
    tagStr (Colgroup_96 _ _) = "colgroup"
    tagStr (Col_96 _) = "col"
    tagStr (Tr_96 _ _) = "tr"
instance TagStr Ent97 where
    tagStr (Tr_97 _ _) = "tr"
instance TagStr Ent98 where
    tagStr (Col_98 _) = "col"
instance TagStr Ent99 where
    tagStr (Th_99 _ _) = "th"
    tagStr (Td_99 _ _) = "td"
instance TagStr Ent100 where
    tagStr (Script_100 _ _) = "script"
    tagStr (Noscript_100 _ _) = "noscript"
    tagStr (Iframe_100 _ _) = "iframe"
    tagStr (Noframes_100 _ _) = "noframes"
    tagStr (Div_100 _ _) = "div"
    tagStr (P_100 _ _) = "p"
    tagStr (H1_100 _ _) = "h1"
    tagStr (H2_100 _ _) = "h2"
    tagStr (H3_100 _ _) = "h3"
    tagStr (H4_100 _ _) = "h4"
    tagStr (H5_100 _ _) = "h5"
    tagStr (H6_100 _ _) = "h6"
    tagStr (Ul_100 _ _) = "ul"
    tagStr (Ol_100 _ _) = "ol"
    tagStr (Menu_100 _ _) = "menu"
    tagStr (Dir_100 _ _) = "dir"
    tagStr (Dl_100 _ _) = "dl"
    tagStr (Address_100 _ _) = "address"
    tagStr (Hr_100 _) = "hr"
    tagStr (Pre_100 _ _) = "pre"
    tagStr (Blockquote_100 _ _) = "blockquote"
    tagStr (Center_100 _ _) = "center"
    tagStr (Ins_100 _ _) = "ins"
    tagStr (Del_100 _ _) = "del"
    tagStr (A_100 _ _) = "a"
    tagStr (Span_100 _ _) = "span"
    tagStr (Bdo_100 _ _) = "bdo"
    tagStr (Br_100 _) = "br"
    tagStr (Em_100 _ _) = "em"
    tagStr (Strong_100 _ _) = "strong"
    tagStr (Dfn_100 _ _) = "dfn"
    tagStr (Code_100 _ _) = "code"
    tagStr (Samp_100 _ _) = "samp"
    tagStr (Kbd_100 _ _) = "kbd"
    tagStr (Var_100 _ _) = "var"
    tagStr (Cite_100 _ _) = "cite"
    tagStr (Abbr_100 _ _) = "abbr"
    tagStr (Acronym_100 _ _) = "acronym"
    tagStr (Q_100 _ _) = "q"
    tagStr (Sub_100 _ _) = "sub"
    tagStr (Sup_100 _ _) = "sup"
    tagStr (Tt_100 _ _) = "tt"
    tagStr (I_100 _ _) = "i"
    tagStr (B_100 _ _) = "b"
    tagStr (Big_100 _ _) = "big"
    tagStr (Small_100 _ _) = "small"
    tagStr (U_100 _ _) = "u"
    tagStr (S_100 _ _) = "s"
    tagStr (Strike_100 _ _) = "strike"
    tagStr (Basefont_100 _) = "basefont"
    tagStr (Font_100 _ _) = "font"
    tagStr (Object_100 _ _) = "object"
    tagStr (Param_100 _) = "param"
    tagStr (Applet_100 _ _) = "applet"
    tagStr (Img_100 _) = "img"
    tagStr (Map_100 _ _) = "map"
    tagStr (Input_100 _) = "input"
    tagStr (Select_100 _ _) = "select"
    tagStr (Textarea_100 _ _) = "textarea"
    tagStr (Fieldset_100 _ _) = "fieldset"
    tagStr (Button_100 _ _) = "button"
    tagStr (Isindex_100 _) = "isindex"
    tagStr (Table_100 _ _) = "table"
    tagStr (PCDATA_100 _ _) = "pcdata"
instance TagStr Ent101 where
    tagStr (Script_101 _ _) = "script"
    tagStr (Noscript_101 _ _) = "noscript"
    tagStr (Noframes_101 _ _) = "noframes"
    tagStr (Div_101 _ _) = "div"
    tagStr (P_101 _ _) = "p"
    tagStr (H1_101 _ _) = "h1"
    tagStr (H2_101 _ _) = "h2"
    tagStr (H3_101 _ _) = "h3"
    tagStr (H4_101 _ _) = "h4"
    tagStr (H5_101 _ _) = "h5"
    tagStr (H6_101 _ _) = "h6"
    tagStr (Ul_101 _ _) = "ul"
    tagStr (Ol_101 _ _) = "ol"
    tagStr (Menu_101 _ _) = "menu"
    tagStr (Dir_101 _ _) = "dir"
    tagStr (Dl_101 _ _) = "dl"
    tagStr (Address_101 _ _) = "address"
    tagStr (Hr_101 _) = "hr"
    tagStr (Pre_101 _ _) = "pre"
    tagStr (Blockquote_101 _ _) = "blockquote"
    tagStr (Center_101 _ _) = "center"
    tagStr (Ins_101 _ _) = "ins"
    tagStr (Del_101 _ _) = "del"
    tagStr (Area_101 _) = "area"
    tagStr (Fieldset_101 _ _) = "fieldset"
    tagStr (Isindex_101 _) = "isindex"
    tagStr (Table_101 _ _) = "table"
instance TagStr Ent102 where
    tagStr (Optgroup_102 _ _) = "optgroup"
    tagStr (Option_102 _ _) = "option"
instance TagStr Ent103 where
    tagStr (Option_103 _ _) = "option"
instance TagStr Ent104 where
    tagStr (Script_104 _ _) = "script"
    tagStr (Noscript_104 _ _) = "noscript"
    tagStr (Noframes_104 _ _) = "noframes"
    tagStr (Div_104 _ _) = "div"
    tagStr (P_104 _ _) = "p"
    tagStr (H1_104 _ _) = "h1"
    tagStr (H2_104 _ _) = "h2"
    tagStr (H3_104 _ _) = "h3"
    tagStr (H4_104 _ _) = "h4"
    tagStr (H5_104 _ _) = "h5"
    tagStr (H6_104 _ _) = "h6"
    tagStr (Ul_104 _ _) = "ul"
    tagStr (Ol_104 _ _) = "ol"
    tagStr (Menu_104 _ _) = "menu"
    tagStr (Dir_104 _ _) = "dir"
    tagStr (Dl_104 _ _) = "dl"
    tagStr (Address_104 _ _) = "address"
    tagStr (Hr_104 _) = "hr"
    tagStr (Pre_104 _ _) = "pre"
    tagStr (Blockquote_104 _ _) = "blockquote"
    tagStr (Center_104 _ _) = "center"
    tagStr (Ins_104 _ _) = "ins"
    tagStr (Del_104 _ _) = "del"
    tagStr (Span_104 _ _) = "span"
    tagStr (Bdo_104 _ _) = "bdo"
    tagStr (Br_104 _) = "br"
    tagStr (Em_104 _ _) = "em"
    tagStr (Strong_104 _ _) = "strong"
    tagStr (Dfn_104 _ _) = "dfn"
    tagStr (Code_104 _ _) = "code"
    tagStr (Samp_104 _ _) = "samp"
    tagStr (Kbd_104 _ _) = "kbd"
    tagStr (Var_104 _ _) = "var"
    tagStr (Cite_104 _ _) = "cite"
    tagStr (Abbr_104 _ _) = "abbr"
    tagStr (Acronym_104 _ _) = "acronym"
    tagStr (Q_104 _ _) = "q"
    tagStr (Sub_104 _ _) = "sub"
    tagStr (Sup_104 _ _) = "sup"
    tagStr (Tt_104 _ _) = "tt"
    tagStr (I_104 _ _) = "i"
    tagStr (B_104 _ _) = "b"
    tagStr (Big_104 _ _) = "big"
    tagStr (Small_104 _ _) = "small"
    tagStr (U_104 _ _) = "u"
    tagStr (S_104 _ _) = "s"
    tagStr (Strike_104 _ _) = "strike"
    tagStr (Basefont_104 _) = "basefont"
    tagStr (Font_104 _ _) = "font"
    tagStr (Object_104 _ _) = "object"
    tagStr (Applet_104 _ _) = "applet"
    tagStr (Img_104 _) = "img"
    tagStr (Map_104 _ _) = "map"
    tagStr (Table_104 _ _) = "table"
    tagStr (PCDATA_104 _ _) = "pcdata"
instance TagStr Ent105 where
    tagStr (Optgroup_105 _ _) = "optgroup"
    tagStr (Option_105 _ _) = "option"
instance TagStr Ent106 where
    tagStr (Option_106 _ _) = "option"
instance TagStr Ent107 where
    tagStr (Script_107 _ _) = "script"
    tagStr (Noscript_107 _ _) = "noscript"
    tagStr (Iframe_107 _ _) = "iframe"
    tagStr (Noframes_107 _ _) = "noframes"
    tagStr (Div_107 _ _) = "div"
    tagStr (P_107 _ _) = "p"
    tagStr (H1_107 _ _) = "h1"
    tagStr (H2_107 _ _) = "h2"
    tagStr (H3_107 _ _) = "h3"
    tagStr (H4_107 _ _) = "h4"
    tagStr (H5_107 _ _) = "h5"
    tagStr (H6_107 _ _) = "h6"
    tagStr (Ul_107 _ _) = "ul"
    tagStr (Ol_107 _ _) = "ol"
    tagStr (Menu_107 _ _) = "menu"
    tagStr (Dir_107 _ _) = "dir"
    tagStr (Dl_107 _ _) = "dl"
    tagStr (Address_107 _ _) = "address"
    tagStr (Hr_107 _) = "hr"
    tagStr (Pre_107 _ _) = "pre"
    tagStr (Blockquote_107 _ _) = "blockquote"
    tagStr (Center_107 _ _) = "center"
    tagStr (Ins_107 _ _) = "ins"
    tagStr (Del_107 _ _) = "del"
    tagStr (A_107 _ _) = "a"
    tagStr (Span_107 _ _) = "span"
    tagStr (Bdo_107 _ _) = "bdo"
    tagStr (Br_107 _) = "br"
    tagStr (Em_107 _ _) = "em"
    tagStr (Strong_107 _ _) = "strong"
    tagStr (Dfn_107 _ _) = "dfn"
    tagStr (Code_107 _ _) = "code"
    tagStr (Samp_107 _ _) = "samp"
    tagStr (Kbd_107 _ _) = "kbd"
    tagStr (Var_107 _ _) = "var"
    tagStr (Cite_107 _ _) = "cite"
    tagStr (Abbr_107 _ _) = "abbr"
    tagStr (Acronym_107 _ _) = "acronym"
    tagStr (Q_107 _ _) = "q"
    tagStr (Sub_107 _ _) = "sub"
    tagStr (Sup_107 _ _) = "sup"
    tagStr (Tt_107 _ _) = "tt"
    tagStr (I_107 _ _) = "i"
    tagStr (B_107 _ _) = "b"
    tagStr (Big_107 _ _) = "big"
    tagStr (Small_107 _ _) = "small"
    tagStr (U_107 _ _) = "u"
    tagStr (S_107 _ _) = "s"
    tagStr (Strike_107 _ _) = "strike"
    tagStr (Basefont_107 _) = "basefont"
    tagStr (Font_107 _ _) = "font"
    tagStr (Object_107 _ _) = "object"
    tagStr (Applet_107 _ _) = "applet"
    tagStr (Img_107 _) = "img"
    tagStr (Map_107 _ _) = "map"
    tagStr (Label_107 _ _) = "label"
    tagStr (Input_107 _) = "input"
    tagStr (Select_107 _ _) = "select"
    tagStr (Textarea_107 _ _) = "textarea"
    tagStr (Fieldset_107 _ _) = "fieldset"
    tagStr (Legend_107 _ _) = "legend"
    tagStr (Button_107 _ _) = "button"
    tagStr (Isindex_107 _) = "isindex"
    tagStr (Table_107 _ _) = "table"
    tagStr (PCDATA_107 _ _) = "pcdata"
instance TagStr Ent108 where
    tagStr (Script_108 _ _) = "script"
    tagStr (Noscript_108 _ _) = "noscript"
    tagStr (Noframes_108 _ _) = "noframes"
    tagStr (Div_108 _ _) = "div"
    tagStr (P_108 _ _) = "p"
    tagStr (H1_108 _ _) = "h1"
    tagStr (H2_108 _ _) = "h2"
    tagStr (H3_108 _ _) = "h3"
    tagStr (H4_108 _ _) = "h4"
    tagStr (H5_108 _ _) = "h5"
    tagStr (H6_108 _ _) = "h6"
    tagStr (Ul_108 _ _) = "ul"
    tagStr (Ol_108 _ _) = "ol"
    tagStr (Menu_108 _ _) = "menu"
    tagStr (Dir_108 _ _) = "dir"
    tagStr (Dl_108 _ _) = "dl"
    tagStr (Address_108 _ _) = "address"
    tagStr (Hr_108 _) = "hr"
    tagStr (Pre_108 _ _) = "pre"
    tagStr (Blockquote_108 _ _) = "blockquote"
    tagStr (Center_108 _ _) = "center"
    tagStr (Ins_108 _ _) = "ins"
    tagStr (Del_108 _ _) = "del"
    tagStr (Span_108 _ _) = "span"
    tagStr (Bdo_108 _ _) = "bdo"
    tagStr (Br_108 _) = "br"
    tagStr (Em_108 _ _) = "em"
    tagStr (Strong_108 _ _) = "strong"
    tagStr (Dfn_108 _ _) = "dfn"
    tagStr (Code_108 _ _) = "code"
    tagStr (Samp_108 _ _) = "samp"
    tagStr (Kbd_108 _ _) = "kbd"
    tagStr (Var_108 _ _) = "var"
    tagStr (Cite_108 _ _) = "cite"
    tagStr (Abbr_108 _ _) = "abbr"
    tagStr (Acronym_108 _ _) = "acronym"
    tagStr (Q_108 _ _) = "q"
    tagStr (Sub_108 _ _) = "sub"
    tagStr (Sup_108 _ _) = "sup"
    tagStr (Tt_108 _ _) = "tt"
    tagStr (I_108 _ _) = "i"
    tagStr (B_108 _ _) = "b"
    tagStr (Big_108 _ _) = "big"
    tagStr (Small_108 _ _) = "small"
    tagStr (U_108 _ _) = "u"
    tagStr (S_108 _ _) = "s"
    tagStr (Strike_108 _ _) = "strike"
    tagStr (Basefont_108 _) = "basefont"
    tagStr (Font_108 _ _) = "font"
    tagStr (Object_108 _ _) = "object"
    tagStr (Applet_108 _ _) = "applet"
    tagStr (Img_108 _) = "img"
    tagStr (Map_108 _ _) = "map"
    tagStr (Table_108 _ _) = "table"
    tagStr (PCDATA_108 _ _) = "pcdata"
instance TagStr Ent109 where
    tagStr (Caption_109 _ _) = "caption"
    tagStr (Thead_109 _ _) = "thead"
    tagStr (Tfoot_109 _ _) = "tfoot"
    tagStr (Tbody_109 _ _) = "tbody"
    tagStr (Colgroup_109 _ _) = "colgroup"
    tagStr (Col_109 _) = "col"
    tagStr (Tr_109 _ _) = "tr"
instance TagStr Ent110 where
    tagStr (Tr_110 _ _) = "tr"
instance TagStr Ent111 where
    tagStr (Col_111 _) = "col"
instance TagStr Ent112 where
    tagStr (Th_112 _ _) = "th"
    tagStr (Td_112 _ _) = "td"
instance TagStr Ent113 where
    tagStr (Script_113 _ _) = "script"
    tagStr (Iframe_113 _ _) = "iframe"
    tagStr (Ins_113 _ _) = "ins"
    tagStr (Del_113 _ _) = "del"
    tagStr (A_113 _ _) = "a"
    tagStr (Span_113 _ _) = "span"
    tagStr (Bdo_113 _ _) = "bdo"
    tagStr (Br_113 _) = "br"
    tagStr (Em_113 _ _) = "em"
    tagStr (Strong_113 _ _) = "strong"
    tagStr (Dfn_113 _ _) = "dfn"
    tagStr (Code_113 _ _) = "code"
    tagStr (Samp_113 _ _) = "samp"
    tagStr (Kbd_113 _ _) = "kbd"
    tagStr (Var_113 _ _) = "var"
    tagStr (Cite_113 _ _) = "cite"
    tagStr (Abbr_113 _ _) = "abbr"
    tagStr (Acronym_113 _ _) = "acronym"
    tagStr (Q_113 _ _) = "q"
    tagStr (Sub_113 _ _) = "sub"
    tagStr (Sup_113 _ _) = "sup"
    tagStr (Tt_113 _ _) = "tt"
    tagStr (I_113 _ _) = "i"
    tagStr (B_113 _ _) = "b"
    tagStr (Big_113 _ _) = "big"
    tagStr (Small_113 _ _) = "small"
    tagStr (U_113 _ _) = "u"
    tagStr (S_113 _ _) = "s"
    tagStr (Strike_113 _ _) = "strike"
    tagStr (Basefont_113 _) = "basefont"
    tagStr (Font_113 _ _) = "font"
    tagStr (Object_113 _ _) = "object"
    tagStr (Applet_113 _ _) = "applet"
    tagStr (Img_113 _) = "img"
    tagStr (Map_113 _ _) = "map"
    tagStr (Input_113 _) = "input"
    tagStr (Select_113 _ _) = "select"
    tagStr (Textarea_113 _ _) = "textarea"
    tagStr (Button_113 _ _) = "button"
    tagStr (PCDATA_113 _ _) = "pcdata"
instance TagStr Ent114 where
    tagStr (PCDATA_114 _ _) = "pcdata"
instance TagStr Ent115 where
    tagStr (Script_115 _ _) = "script"
    tagStr (Noscript_115 _ _) = "noscript"
    tagStr (Iframe_115 _ _) = "iframe"
    tagStr (Noframes_115 _ _) = "noframes"
    tagStr (Div_115 _ _) = "div"
    tagStr (P_115 _ _) = "p"
    tagStr (H1_115 _ _) = "h1"
    tagStr (H2_115 _ _) = "h2"
    tagStr (H3_115 _ _) = "h3"
    tagStr (H4_115 _ _) = "h4"
    tagStr (H5_115 _ _) = "h5"
    tagStr (H6_115 _ _) = "h6"
    tagStr (Ul_115 _ _) = "ul"
    tagStr (Ol_115 _ _) = "ol"
    tagStr (Menu_115 _ _) = "menu"
    tagStr (Dir_115 _ _) = "dir"
    tagStr (Dl_115 _ _) = "dl"
    tagStr (Address_115 _ _) = "address"
    tagStr (Hr_115 _) = "hr"
    tagStr (Pre_115 _ _) = "pre"
    tagStr (Blockquote_115 _ _) = "blockquote"
    tagStr (Center_115 _ _) = "center"
    tagStr (Ins_115 _ _) = "ins"
    tagStr (Del_115 _ _) = "del"
    tagStr (A_115 _ _) = "a"
    tagStr (Span_115 _ _) = "span"
    tagStr (Bdo_115 _ _) = "bdo"
    tagStr (Br_115 _) = "br"
    tagStr (Em_115 _ _) = "em"
    tagStr (Strong_115 _ _) = "strong"
    tagStr (Dfn_115 _ _) = "dfn"
    tagStr (Code_115 _ _) = "code"
    tagStr (Samp_115 _ _) = "samp"
    tagStr (Kbd_115 _ _) = "kbd"
    tagStr (Var_115 _ _) = "var"
    tagStr (Cite_115 _ _) = "cite"
    tagStr (Abbr_115 _ _) = "abbr"
    tagStr (Acronym_115 _ _) = "acronym"
    tagStr (Q_115 _ _) = "q"
    tagStr (Sub_115 _ _) = "sub"
    tagStr (Sup_115 _ _) = "sup"
    tagStr (Tt_115 _ _) = "tt"
    tagStr (I_115 _ _) = "i"
    tagStr (B_115 _ _) = "b"
    tagStr (Big_115 _ _) = "big"
    tagStr (Small_115 _ _) = "small"
    tagStr (U_115 _ _) = "u"
    tagStr (S_115 _ _) = "s"
    tagStr (Strike_115 _ _) = "strike"
    tagStr (Basefont_115 _) = "basefont"
    tagStr (Font_115 _ _) = "font"
    tagStr (Object_115 _ _) = "object"
    tagStr (Applet_115 _ _) = "applet"
    tagStr (Img_115 _) = "img"
    tagStr (Map_115 _ _) = "map"
    tagStr (Form_115 _ _) = "form"
    tagStr (Input_115 _) = "input"
    tagStr (Select_115 _ _) = "select"
    tagStr (Textarea_115 _ _) = "textarea"
    tagStr (Fieldset_115 _ _) = "fieldset"
    tagStr (Button_115 _ _) = "button"
    tagStr (Isindex_115 _) = "isindex"
    tagStr (Table_115 _ _) = "table"
    tagStr (PCDATA_115 _ _) = "pcdata"
instance TagStr Ent116 where
    tagStr (Li_116 _ _) = "li"
instance TagStr Ent117 where
    tagStr (Dt_117 _ _) = "dt"
    tagStr (Dd_117 _ _) = "dd"
instance TagStr Ent118 where
    tagStr (Script_118 _ _) = "script"
    tagStr (Iframe_118 _ _) = "iframe"
    tagStr (P_118 _ _) = "p"
    tagStr (Ins_118 _ _) = "ins"
    tagStr (Del_118 _ _) = "del"
    tagStr (A_118 _ _) = "a"
    tagStr (Span_118 _ _) = "span"
    tagStr (Bdo_118 _ _) = "bdo"
    tagStr (Br_118 _) = "br"
    tagStr (Em_118 _ _) = "em"
    tagStr (Strong_118 _ _) = "strong"
    tagStr (Dfn_118 _ _) = "dfn"
    tagStr (Code_118 _ _) = "code"
    tagStr (Samp_118 _ _) = "samp"
    tagStr (Kbd_118 _ _) = "kbd"
    tagStr (Var_118 _ _) = "var"
    tagStr (Cite_118 _ _) = "cite"
    tagStr (Abbr_118 _ _) = "abbr"
    tagStr (Acronym_118 _ _) = "acronym"
    tagStr (Q_118 _ _) = "q"
    tagStr (Sub_118 _ _) = "sub"
    tagStr (Sup_118 _ _) = "sup"
    tagStr (Tt_118 _ _) = "tt"
    tagStr (I_118 _ _) = "i"
    tagStr (B_118 _ _) = "b"
    tagStr (Big_118 _ _) = "big"
    tagStr (Small_118 _ _) = "small"
    tagStr (U_118 _ _) = "u"
    tagStr (S_118 _ _) = "s"
    tagStr (Strike_118 _ _) = "strike"
    tagStr (Basefont_118 _) = "basefont"
    tagStr (Font_118 _ _) = "font"
    tagStr (Object_118 _ _) = "object"
    tagStr (Applet_118 _ _) = "applet"
    tagStr (Img_118 _) = "img"
    tagStr (Map_118 _ _) = "map"
    tagStr (Input_118 _) = "input"
    tagStr (Select_118 _ _) = "select"
    tagStr (Textarea_118 _ _) = "textarea"
    tagStr (Button_118 _ _) = "button"
    tagStr (PCDATA_118 _ _) = "pcdata"
instance TagStr Ent119 where
    tagStr (Script_119 _ _) = "script"
    tagStr (Ins_119 _ _) = "ins"
    tagStr (Del_119 _ _) = "del"
    tagStr (A_119 _ _) = "a"
    tagStr (Span_119 _ _) = "span"
    tagStr (Bdo_119 _ _) = "bdo"
    tagStr (Br_119 _) = "br"
    tagStr (Em_119 _ _) = "em"
    tagStr (Strong_119 _ _) = "strong"
    tagStr (Dfn_119 _ _) = "dfn"
    tagStr (Code_119 _ _) = "code"
    tagStr (Samp_119 _ _) = "samp"
    tagStr (Kbd_119 _ _) = "kbd"
    tagStr (Var_119 _ _) = "var"
    tagStr (Cite_119 _ _) = "cite"
    tagStr (Abbr_119 _ _) = "abbr"
    tagStr (Acronym_119 _ _) = "acronym"
    tagStr (Q_119 _ _) = "q"
    tagStr (Tt_119 _ _) = "tt"
    tagStr (I_119 _ _) = "i"
    tagStr (B_119 _ _) = "b"
    tagStr (U_119 _ _) = "u"
    tagStr (S_119 _ _) = "s"
    tagStr (Strike_119 _ _) = "strike"
    tagStr (Input_119 _) = "input"
    tagStr (Select_119 _ _) = "select"
    tagStr (Textarea_119 _ _) = "textarea"
    tagStr (Button_119 _ _) = "button"
    tagStr (PCDATA_119 _ _) = "pcdata"
instance TagStr Ent120 where
    tagStr (Script_120 _ _) = "script"
    tagStr (Noscript_120 _ _) = "noscript"
    tagStr (Iframe_120 _ _) = "iframe"
    tagStr (Noframes_120 _ _) = "noframes"
    tagStr (Div_120 _ _) = "div"
    tagStr (P_120 _ _) = "p"
    tagStr (H1_120 _ _) = "h1"
    tagStr (H2_120 _ _) = "h2"
    tagStr (H3_120 _ _) = "h3"
    tagStr (H4_120 _ _) = "h4"
    tagStr (H5_120 _ _) = "h5"
    tagStr (H6_120 _ _) = "h6"
    tagStr (Ul_120 _ _) = "ul"
    tagStr (Ol_120 _ _) = "ol"
    tagStr (Menu_120 _ _) = "menu"
    tagStr (Dir_120 _ _) = "dir"
    tagStr (Dl_120 _ _) = "dl"
    tagStr (Address_120 _ _) = "address"
    tagStr (Hr_120 _) = "hr"
    tagStr (Pre_120 _ _) = "pre"
    tagStr (Blockquote_120 _ _) = "blockquote"
    tagStr (Center_120 _ _) = "center"
    tagStr (Ins_120 _ _) = "ins"
    tagStr (Del_120 _ _) = "del"
    tagStr (A_120 _ _) = "a"
    tagStr (Span_120 _ _) = "span"
    tagStr (Bdo_120 _ _) = "bdo"
    tagStr (Br_120 _) = "br"
    tagStr (Em_120 _ _) = "em"
    tagStr (Strong_120 _ _) = "strong"
    tagStr (Dfn_120 _ _) = "dfn"
    tagStr (Code_120 _ _) = "code"
    tagStr (Samp_120 _ _) = "samp"
    tagStr (Kbd_120 _ _) = "kbd"
    tagStr (Var_120 _ _) = "var"
    tagStr (Cite_120 _ _) = "cite"
    tagStr (Abbr_120 _ _) = "abbr"
    tagStr (Acronym_120 _ _) = "acronym"
    tagStr (Q_120 _ _) = "q"
    tagStr (Sub_120 _ _) = "sub"
    tagStr (Sup_120 _ _) = "sup"
    tagStr (Tt_120 _ _) = "tt"
    tagStr (I_120 _ _) = "i"
    tagStr (B_120 _ _) = "b"
    tagStr (Big_120 _ _) = "big"
    tagStr (Small_120 _ _) = "small"
    tagStr (U_120 _ _) = "u"
    tagStr (S_120 _ _) = "s"
    tagStr (Strike_120 _ _) = "strike"
    tagStr (Basefont_120 _) = "basefont"
    tagStr (Font_120 _ _) = "font"
    tagStr (Object_120 _ _) = "object"
    tagStr (Applet_120 _ _) = "applet"
    tagStr (Img_120 _) = "img"
    tagStr (Map_120 _ _) = "map"
    tagStr (Form_120 _ _) = "form"
    tagStr (Input_120 _) = "input"
    tagStr (Select_120 _ _) = "select"
    tagStr (Textarea_120 _ _) = "textarea"
    tagStr (Fieldset_120 _ _) = "fieldset"
    tagStr (Legend_120 _ _) = "legend"
    tagStr (Button_120 _ _) = "button"
    tagStr (Isindex_120 _) = "isindex"
    tagStr (Table_120 _ _) = "table"
    tagStr (PCDATA_120 _ _) = "pcdata"
instance TagStr Ent121 where
    tagStr (Caption_121 _ _) = "caption"
    tagStr (Thead_121 _ _) = "thead"
    tagStr (Tfoot_121 _ _) = "tfoot"
    tagStr (Tbody_121 _ _) = "tbody"
    tagStr (Colgroup_121 _ _) = "colgroup"
    tagStr (Col_121 _) = "col"
    tagStr (Tr_121 _ _) = "tr"
instance TagStr Ent122 where
    tagStr (Tr_122 _ _) = "tr"
instance TagStr Ent123 where
    tagStr (Col_123 _) = "col"
instance TagStr Ent124 where
    tagStr (Th_124 _ _) = "th"
    tagStr (Td_124 _ _) = "td"
instance TagStr Ent125 where
    tagStr (Script_125 _ _) = "script"
    tagStr (Noscript_125 _ _) = "noscript"
    tagStr (Iframe_125 _ _) = "iframe"
    tagStr (Noframes_125 _ _) = "noframes"
    tagStr (Div_125 _ _) = "div"
    tagStr (P_125 _ _) = "p"
    tagStr (H1_125 _ _) = "h1"
    tagStr (H2_125 _ _) = "h2"
    tagStr (H3_125 _ _) = "h3"
    tagStr (H4_125 _ _) = "h4"
    tagStr (H5_125 _ _) = "h5"
    tagStr (H6_125 _ _) = "h6"
    tagStr (Ul_125 _ _) = "ul"
    tagStr (Ol_125 _ _) = "ol"
    tagStr (Menu_125 _ _) = "menu"
    tagStr (Dir_125 _ _) = "dir"
    tagStr (Dl_125 _ _) = "dl"
    tagStr (Address_125 _ _) = "address"
    tagStr (Hr_125 _) = "hr"
    tagStr (Pre_125 _ _) = "pre"
    tagStr (Blockquote_125 _ _) = "blockquote"
    tagStr (Center_125 _ _) = "center"
    tagStr (Ins_125 _ _) = "ins"
    tagStr (Del_125 _ _) = "del"
    tagStr (A_125 _ _) = "a"
    tagStr (Span_125 _ _) = "span"
    tagStr (Bdo_125 _ _) = "bdo"
    tagStr (Br_125 _) = "br"
    tagStr (Em_125 _ _) = "em"
    tagStr (Strong_125 _ _) = "strong"
    tagStr (Dfn_125 _ _) = "dfn"
    tagStr (Code_125 _ _) = "code"
    tagStr (Samp_125 _ _) = "samp"
    tagStr (Kbd_125 _ _) = "kbd"
    tagStr (Var_125 _ _) = "var"
    tagStr (Cite_125 _ _) = "cite"
    tagStr (Abbr_125 _ _) = "abbr"
    tagStr (Acronym_125 _ _) = "acronym"
    tagStr (Q_125 _ _) = "q"
    tagStr (Sub_125 _ _) = "sub"
    tagStr (Sup_125 _ _) = "sup"
    tagStr (Tt_125 _ _) = "tt"
    tagStr (I_125 _ _) = "i"
    tagStr (B_125 _ _) = "b"
    tagStr (Big_125 _ _) = "big"
    tagStr (Small_125 _ _) = "small"
    tagStr (U_125 _ _) = "u"
    tagStr (S_125 _ _) = "s"
    tagStr (Strike_125 _ _) = "strike"
    tagStr (Basefont_125 _) = "basefont"
    tagStr (Font_125 _ _) = "font"
    tagStr (Object_125 _ _) = "object"
    tagStr (Param_125 _) = "param"
    tagStr (Applet_125 _ _) = "applet"
    tagStr (Img_125 _) = "img"
    tagStr (Map_125 _ _) = "map"
    tagStr (Form_125 _ _) = "form"
    tagStr (Input_125 _) = "input"
    tagStr (Select_125 _ _) = "select"
    tagStr (Textarea_125 _ _) = "textarea"
    tagStr (Fieldset_125 _ _) = "fieldset"
    tagStr (Button_125 _ _) = "button"
    tagStr (Isindex_125 _) = "isindex"
    tagStr (Table_125 _ _) = "table"
    tagStr (PCDATA_125 _ _) = "pcdata"
instance TagStr Ent126 where
    tagStr (Script_126 _ _) = "script"
    tagStr (Noscript_126 _ _) = "noscript"
    tagStr (Noframes_126 _ _) = "noframes"
    tagStr (Div_126 _ _) = "div"
    tagStr (P_126 _ _) = "p"
    tagStr (H1_126 _ _) = "h1"
    tagStr (H2_126 _ _) = "h2"
    tagStr (H3_126 _ _) = "h3"
    tagStr (H4_126 _ _) = "h4"
    tagStr (H5_126 _ _) = "h5"
    tagStr (H6_126 _ _) = "h6"
    tagStr (Ul_126 _ _) = "ul"
    tagStr (Ol_126 _ _) = "ol"
    tagStr (Menu_126 _ _) = "menu"
    tagStr (Dir_126 _ _) = "dir"
    tagStr (Dl_126 _ _) = "dl"
    tagStr (Address_126 _ _) = "address"
    tagStr (Hr_126 _) = "hr"
    tagStr (Pre_126 _ _) = "pre"
    tagStr (Blockquote_126 _ _) = "blockquote"
    tagStr (Center_126 _ _) = "center"
    tagStr (Ins_126 _ _) = "ins"
    tagStr (Del_126 _ _) = "del"
    tagStr (Area_126 _) = "area"
    tagStr (Form_126 _ _) = "form"
    tagStr (Fieldset_126 _ _) = "fieldset"
    tagStr (Isindex_126 _) = "isindex"
    tagStr (Table_126 _ _) = "table"
instance TagStr Ent127 where
    tagStr (Optgroup_127 _ _) = "optgroup"
    tagStr (Option_127 _ _) = "option"
instance TagStr Ent128 where
    tagStr (Option_128 _ _) = "option"
instance TagStr Ent129 where
    tagStr (Script_129 _ _) = "script"
    tagStr (Noscript_129 _ _) = "noscript"
    tagStr (Noframes_129 _ _) = "noframes"
    tagStr (Div_129 _ _) = "div"
    tagStr (P_129 _ _) = "p"
    tagStr (H1_129 _ _) = "h1"
    tagStr (H2_129 _ _) = "h2"
    tagStr (H3_129 _ _) = "h3"
    tagStr (H4_129 _ _) = "h4"
    tagStr (H5_129 _ _) = "h5"
    tagStr (H6_129 _ _) = "h6"
    tagStr (Ul_129 _ _) = "ul"
    tagStr (Ol_129 _ _) = "ol"
    tagStr (Menu_129 _ _) = "menu"
    tagStr (Dir_129 _ _) = "dir"
    tagStr (Dl_129 _ _) = "dl"
    tagStr (Address_129 _ _) = "address"
    tagStr (Hr_129 _) = "hr"
    tagStr (Pre_129 _ _) = "pre"
    tagStr (Blockquote_129 _ _) = "blockquote"
    tagStr (Center_129 _ _) = "center"
    tagStr (Ins_129 _ _) = "ins"
    tagStr (Del_129 _ _) = "del"
    tagStr (Span_129 _ _) = "span"
    tagStr (Bdo_129 _ _) = "bdo"
    tagStr (Br_129 _) = "br"
    tagStr (Em_129 _ _) = "em"
    tagStr (Strong_129 _ _) = "strong"
    tagStr (Dfn_129 _ _) = "dfn"
    tagStr (Code_129 _ _) = "code"
    tagStr (Samp_129 _ _) = "samp"
    tagStr (Kbd_129 _ _) = "kbd"
    tagStr (Var_129 _ _) = "var"
    tagStr (Cite_129 _ _) = "cite"
    tagStr (Abbr_129 _ _) = "abbr"
    tagStr (Acronym_129 _ _) = "acronym"
    tagStr (Q_129 _ _) = "q"
    tagStr (Sub_129 _ _) = "sub"
    tagStr (Sup_129 _ _) = "sup"
    tagStr (Tt_129 _ _) = "tt"
    tagStr (I_129 _ _) = "i"
    tagStr (B_129 _ _) = "b"
    tagStr (Big_129 _ _) = "big"
    tagStr (Small_129 _ _) = "small"
    tagStr (U_129 _ _) = "u"
    tagStr (S_129 _ _) = "s"
    tagStr (Strike_129 _ _) = "strike"
    tagStr (Basefont_129 _) = "basefont"
    tagStr (Font_129 _ _) = "font"
    tagStr (Object_129 _ _) = "object"
    tagStr (Applet_129 _ _) = "applet"
    tagStr (Img_129 _) = "img"
    tagStr (Map_129 _ _) = "map"
    tagStr (Table_129 _ _) = "table"
    tagStr (PCDATA_129 _ _) = "pcdata"
instance TagStr Ent130 where
    tagStr (Optgroup_130 _ _) = "optgroup"
    tagStr (Option_130 _ _) = "option"
instance TagStr Ent131 where
    tagStr (Option_131 _ _) = "option"
instance TagStr Ent132 where
    tagStr (Script_132 _ _) = "script"
    tagStr (Noscript_132 _ _) = "noscript"
    tagStr (Iframe_132 _ _) = "iframe"
    tagStr (Noframes_132 _ _) = "noframes"
    tagStr (Div_132 _ _) = "div"
    tagStr (P_132 _ _) = "p"
    tagStr (H1_132 _ _) = "h1"
    tagStr (H2_132 _ _) = "h2"
    tagStr (H3_132 _ _) = "h3"
    tagStr (H4_132 _ _) = "h4"
    tagStr (H5_132 _ _) = "h5"
    tagStr (H6_132 _ _) = "h6"
    tagStr (Ul_132 _ _) = "ul"
    tagStr (Ol_132 _ _) = "ol"
    tagStr (Menu_132 _ _) = "menu"
    tagStr (Dir_132 _ _) = "dir"
    tagStr (Dl_132 _ _) = "dl"
    tagStr (Address_132 _ _) = "address"
    tagStr (Hr_132 _) = "hr"
    tagStr (Pre_132 _ _) = "pre"
    tagStr (Blockquote_132 _ _) = "blockquote"
    tagStr (Center_132 _ _) = "center"
    tagStr (Ins_132 _ _) = "ins"
    tagStr (Del_132 _ _) = "del"
    tagStr (A_132 _ _) = "a"
    tagStr (Span_132 _ _) = "span"
    tagStr (Bdo_132 _ _) = "bdo"
    tagStr (Br_132 _) = "br"
    tagStr (Em_132 _ _) = "em"
    tagStr (Strong_132 _ _) = "strong"
    tagStr (Dfn_132 _ _) = "dfn"
    tagStr (Code_132 _ _) = "code"
    tagStr (Samp_132 _ _) = "samp"
    tagStr (Kbd_132 _ _) = "kbd"
    tagStr (Var_132 _ _) = "var"
    tagStr (Cite_132 _ _) = "cite"
    tagStr (Abbr_132 _ _) = "abbr"
    tagStr (Acronym_132 _ _) = "acronym"
    tagStr (Q_132 _ _) = "q"
    tagStr (Sub_132 _ _) = "sub"
    tagStr (Sup_132 _ _) = "sup"
    tagStr (Tt_132 _ _) = "tt"
    tagStr (I_132 _ _) = "i"
    tagStr (B_132 _ _) = "b"
    tagStr (Big_132 _ _) = "big"
    tagStr (Small_132 _ _) = "small"
    tagStr (U_132 _ _) = "u"
    tagStr (S_132 _ _) = "s"
    tagStr (Strike_132 _ _) = "strike"
    tagStr (Basefont_132 _) = "basefont"
    tagStr (Font_132 _ _) = "font"
    tagStr (Object_132 _ _) = "object"
    tagStr (Applet_132 _ _) = "applet"
    tagStr (Img_132 _) = "img"
    tagStr (Map_132 _ _) = "map"
    tagStr (Form_132 _ _) = "form"
    tagStr (Label_132 _ _) = "label"
    tagStr (Input_132 _) = "input"
    tagStr (Select_132 _ _) = "select"
    tagStr (Textarea_132 _ _) = "textarea"
    tagStr (Fieldset_132 _ _) = "fieldset"
    tagStr (Legend_132 _ _) = "legend"
    tagStr (Button_132 _ _) = "button"
    tagStr (Isindex_132 _) = "isindex"
    tagStr (Table_132 _ _) = "table"
    tagStr (PCDATA_132 _ _) = "pcdata"
instance TagStr Ent133 where
    tagStr (Script_133 _ _) = "script"
    tagStr (Noscript_133 _ _) = "noscript"
    tagStr (Noframes_133 _ _) = "noframes"
    tagStr (Div_133 _ _) = "div"
    tagStr (P_133 _ _) = "p"
    tagStr (H1_133 _ _) = "h1"
    tagStr (H2_133 _ _) = "h2"
    tagStr (H3_133 _ _) = "h3"
    tagStr (H4_133 _ _) = "h4"
    tagStr (H5_133 _ _) = "h5"
    tagStr (H6_133 _ _) = "h6"
    tagStr (Ul_133 _ _) = "ul"
    tagStr (Ol_133 _ _) = "ol"
    tagStr (Menu_133 _ _) = "menu"
    tagStr (Dir_133 _ _) = "dir"
    tagStr (Dl_133 _ _) = "dl"
    tagStr (Address_133 _ _) = "address"
    tagStr (Hr_133 _) = "hr"
    tagStr (Pre_133 _ _) = "pre"
    tagStr (Blockquote_133 _ _) = "blockquote"
    tagStr (Center_133 _ _) = "center"
    tagStr (Ins_133 _ _) = "ins"
    tagStr (Del_133 _ _) = "del"
    tagStr (Span_133 _ _) = "span"
    tagStr (Bdo_133 _ _) = "bdo"
    tagStr (Br_133 _) = "br"
    tagStr (Em_133 _ _) = "em"
    tagStr (Strong_133 _ _) = "strong"
    tagStr (Dfn_133 _ _) = "dfn"
    tagStr (Code_133 _ _) = "code"
    tagStr (Samp_133 _ _) = "samp"
    tagStr (Kbd_133 _ _) = "kbd"
    tagStr (Var_133 _ _) = "var"
    tagStr (Cite_133 _ _) = "cite"
    tagStr (Abbr_133 _ _) = "abbr"
    tagStr (Acronym_133 _ _) = "acronym"
    tagStr (Q_133 _ _) = "q"
    tagStr (Sub_133 _ _) = "sub"
    tagStr (Sup_133 _ _) = "sup"
    tagStr (Tt_133 _ _) = "tt"
    tagStr (I_133 _ _) = "i"
    tagStr (B_133 _ _) = "b"
    tagStr (Big_133 _ _) = "big"
    tagStr (Small_133 _ _) = "small"
    tagStr (U_133 _ _) = "u"
    tagStr (S_133 _ _) = "s"
    tagStr (Strike_133 _ _) = "strike"
    tagStr (Basefont_133 _) = "basefont"
    tagStr (Font_133 _ _) = "font"
    tagStr (Object_133 _ _) = "object"
    tagStr (Applet_133 _ _) = "applet"
    tagStr (Img_133 _) = "img"
    tagStr (Map_133 _ _) = "map"
    tagStr (Table_133 _ _) = "table"
    tagStr (PCDATA_133 _ _) = "pcdata"
instance TagStr Ent134 where
    tagStr (Caption_134 _ _) = "caption"
    tagStr (Thead_134 _ _) = "thead"
    tagStr (Tfoot_134 _ _) = "tfoot"
    tagStr (Tbody_134 _ _) = "tbody"
    tagStr (Colgroup_134 _ _) = "colgroup"
    tagStr (Col_134 _) = "col"
    tagStr (Tr_134 _ _) = "tr"
instance TagStr Ent135 where
    tagStr (Tr_135 _ _) = "tr"
instance TagStr Ent136 where
    tagStr (Col_136 _) = "col"
instance TagStr Ent137 where
    tagStr (Th_137 _ _) = "th"
    tagStr (Td_137 _ _) = "td"

class TagChildren a where
    tagChildren :: a -> [(Int,String,[String],[U.ByteString],[U.ByteString])]
instance TagChildren Ent where
    tagChildren (Html att c) = (0,"html",map tagStr c,[],[]):(concatMap tagChildren c)
instance TagChildren Ent0 where
    tagChildren (Head_0 a c) = (1,"head",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Body_0 a c) = (11,"body",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent1 where
    tagChildren (Title_1 a c) = (2,"title",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Base_1 a) = [(-1,"base",[],(map fst (map renderAtt a)),[])]
    tagChildren (Meta_1 a) = [(-1,"meta",[],(map fst (map renderAtt a)),[content_byte])]
    tagChildren (Link_1 a) = [(-1,"link",[],(map fst (map renderAtt a)),[])]
    tagChildren (Style_1 a c) = (6,"style",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Script_1 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Object_1 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_1 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
instance TagChildren Ent2 where
    tagChildren (PCDATA_2 _ _) = []
instance TagChildren Ent3 where
    tagChildren (Script_3 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_3 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_3 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_3 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_3 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_3 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_3 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_3 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_3 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_3 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_3 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_3 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_3 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_3 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_3 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_3 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_3 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_3 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_3 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_3 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_3 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_3 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_3 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_3 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_3 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_3 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_3 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_3 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_3 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_3 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_3 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_3 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_3 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_3 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_3 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_3 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_3 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_3 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_3 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_3 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_3 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_3 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_3 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_3 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_3 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_3 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_3 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_3 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_3 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_3 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_3 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_3 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Param_3 a) = [(-1,"param",[],(map fst (map renderAtt a)),[name_byte])]
    tagChildren (Applet_3 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_3 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_3 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Form_3 a c) = (68,"form",map tagStr c,(map fst (map renderAtt a)),[action_byte]):(concatMap tagChildren c)
    tagChildren (Label_3 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_3 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_3 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_3 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_3 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_3 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_3 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_3 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_3 _ _) = []
instance TagChildren Ent4 where
    tagChildren (Script_4 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_4 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_4 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_4 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_4 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_4 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_4 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_4 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_4 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_4 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_4 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_4 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_4 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_4 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_4 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_4 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_4 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_4 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_4 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_4 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_4 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_4 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_4 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_4 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_4 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_4 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_4 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_4 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_4 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_4 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_4 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_4 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_4 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_4 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_4 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_4 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_4 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_4 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_4 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_4 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_4 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_4 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_4 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_4 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_4 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_4 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_4 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_4 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_4 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_4 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_4 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_4 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_4 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_4 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_4 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Form_4 a c) = (68,"form",map tagStr c,(map fst (map renderAtt a)),[action_byte]):(concatMap tagChildren c)
    tagChildren (Label_4 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_4 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_4 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_4 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_4 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_4 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_4 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_4 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_4 _ _) = []
instance TagChildren Ent5 where
    tagChildren (Script_5 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Iframe_5 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_5 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_5 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_5 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_5 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_5 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_5 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_5 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_5 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_5 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_5 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_5 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_5 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_5 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_5 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_5 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_5 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_5 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_5 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_5 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_5 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_5 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_5 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_5 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_5 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_5 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_5 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_5 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_5 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_5 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_5 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_5 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_5 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_5 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Label_5 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_5 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_5 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_5 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_5 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_5 _ _) = []
instance TagChildren Ent6 where
    tagChildren (Li_6 a c) = (24,"li",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent7 where
    tagChildren (Dt_7 a c) = (26,"dt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dd_7 a c) = (27,"dd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent8 where
    tagChildren (Script_8 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Iframe_8 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_8 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_8 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_8 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_8 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_8 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_8 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_8 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_8 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_8 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_8 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_8 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_8 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_8 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_8 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_8 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_8 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_8 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_8 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_8 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_8 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_8 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_8 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_8 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_8 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_8 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_8 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_8 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_8 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_8 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_8 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_8 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_8 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_8 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_8 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Label_8 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_8 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_8 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_8 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_8 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_8 _ _) = []
instance TagChildren Ent9 where
    tagChildren (Script_9 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Ins_9 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_9 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_9 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_9 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_9 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_9 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_9 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_9 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_9 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_9 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_9 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_9 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_9 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_9 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_9 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_9 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_9 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_9 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_9 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_9 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_9 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_9 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_9 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Label_9 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_9 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_9 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_9 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_9 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_9 _ _) = []
instance TagChildren Ent10 where
    tagChildren (Script_10 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Iframe_10 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_10 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_10 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_10 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_10 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_10 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_10 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_10 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_10 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_10 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_10 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_10 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_10 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_10 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_10 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_10 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_10 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_10 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_10 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_10 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_10 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_10 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_10 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_10 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_10 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_10 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_10 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_10 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_10 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_10 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_10 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_10 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_10 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Label_10 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_10 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_10 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_10 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_10 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_10 _ _) = []
instance TagChildren Ent11 where
    tagChildren (PCDATA_11 _ _) = []
instance TagChildren Ent12 where
    tagChildren (Script_12 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_12 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_12 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_12 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_12 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_12 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_12 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_12 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_12 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_12 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_12 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_12 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_12 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_12 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_12 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_12 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_12 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_12 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_12 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_12 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_12 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_12 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_12 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_12 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_12 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_12 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_12 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_12 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_12 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_12 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_12 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_12 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_12 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_12 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_12 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_12 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_12 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_12 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_12 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_12 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_12 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_12 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_12 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_12 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_12 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_12 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_12 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_12 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_12 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_12 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_12 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_12 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_12 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_12 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Form_12 a c) = (68,"form",map tagStr c,(map fst (map renderAtt a)),[action_byte]):(concatMap tagChildren c)
    tagChildren (Label_12 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_12 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_12 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_12 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_12 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_12 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_12 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_12 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_12 _ _) = []
instance TagChildren Ent13 where
    tagChildren (Li_13 a c) = (24,"li",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent14 where
    tagChildren (Dt_14 a c) = (26,"dt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dd_14 a c) = (27,"dd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent15 where
    tagChildren (Script_15 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Iframe_15 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_15 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_15 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_15 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_15 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_15 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_15 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_15 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_15 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_15 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_15 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_15 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_15 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_15 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_15 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_15 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_15 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_15 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_15 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_15 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_15 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_15 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_15 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_15 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_15 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_15 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_15 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_15 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_15 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_15 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_15 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_15 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_15 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_15 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Label_15 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_15 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_15 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_15 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_15 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_15 _ _) = []
instance TagChildren Ent16 where
    tagChildren (Script_16 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Ins_16 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_16 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_16 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_16 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_16 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_16 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_16 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_16 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_16 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_16 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_16 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_16 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_16 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_16 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_16 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_16 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_16 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_16 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_16 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_16 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_16 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_16 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Label_16 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_16 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_16 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_16 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_16 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_16 _ _) = []
instance TagChildren Ent17 where
    tagChildren (Script_17 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_17 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_17 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_17 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_17 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_17 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_17 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_17 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_17 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_17 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_17 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_17 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_17 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_17 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_17 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_17 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_17 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_17 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_17 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_17 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_17 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_17 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_17 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_17 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_17 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_17 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_17 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_17 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_17 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_17 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_17 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_17 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_17 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_17 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_17 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_17 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_17 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_17 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_17 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_17 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_17 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_17 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_17 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_17 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_17 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_17 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_17 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_17 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_17 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_17 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_17 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_17 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_17 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_17 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Label_17 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_17 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_17 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_17 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_17 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_17 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_17 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_17 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_17 _ _) = []
instance TagChildren Ent18 where
    tagChildren (Script_18 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Iframe_18 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_18 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_18 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_18 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_18 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_18 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_18 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_18 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_18 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_18 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_18 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_18 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_18 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_18 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_18 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_18 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_18 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_18 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_18 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_18 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_18 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_18 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_18 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_18 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_18 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_18 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_18 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_18 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_18 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_18 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_18 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_18 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_18 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Label_18 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_18 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_18 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_18 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_18 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_18 _ _) = []
instance TagChildren Ent19 where
    tagChildren (Li_19 a c) = (24,"li",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent20 where
    tagChildren (Dt_20 a c) = (26,"dt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dd_20 a c) = (27,"dd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent21 where
    tagChildren (Script_21 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Iframe_21 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_21 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_21 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_21 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_21 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_21 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_21 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_21 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_21 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_21 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_21 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_21 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_21 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_21 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_21 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_21 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_21 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_21 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_21 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_21 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_21 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_21 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_21 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_21 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_21 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_21 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_21 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_21 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_21 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_21 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_21 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_21 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_21 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_21 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Label_21 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_21 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_21 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_21 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_21 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_21 _ _) = []
instance TagChildren Ent22 where
    tagChildren (Script_22 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Ins_22 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_22 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_22 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_22 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_22 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_22 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_22 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_22 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_22 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_22 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_22 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_22 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_22 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_22 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_22 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_22 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_22 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_22 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_22 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_22 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_22 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_22 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Label_22 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_22 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_22 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_22 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_22 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_22 _ _) = []
instance TagChildren Ent23 where
    tagChildren (Script_23 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_23 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_23 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_23 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_23 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_23 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_23 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_23 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_23 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_23 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_23 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_23 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_23 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_23 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_23 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_23 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_23 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_23 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_23 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_23 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_23 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_23 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_23 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_23 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_23 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_23 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_23 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_23 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_23 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_23 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_23 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_23 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_23 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_23 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_23 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_23 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_23 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_23 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_23 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_23 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_23 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_23 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_23 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_23 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_23 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_23 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_23 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_23 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_23 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_23 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_23 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_23 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_23 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_23 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Label_23 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_23 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_23 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_23 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_23 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Legend_23 a c) = (76,"legend",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_23 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_23 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_23 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_23 _ _) = []
instance TagChildren Ent24 where
    tagChildren (Caption_24 a c) = (80,"caption",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Thead_24 a c) = (81,"thead",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tfoot_24 a c) = (82,"tfoot",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tbody_24 a c) = (83,"tbody",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Colgroup_24 a c) = (84,"colgroup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Col_24 a) = [(-1,"col",[],(map fst (map renderAtt a)),[])]
    tagChildren (Tr_24 a c) = (86,"tr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent25 where
    tagChildren (Tr_25 a c) = (86,"tr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent26 where
    tagChildren (Col_26 a) = [(-1,"col",[],(map fst (map renderAtt a)),[])]
instance TagChildren Ent27 where
    tagChildren (Th_27 a c) = (87,"th",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Td_27 a c) = (88,"td",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent28 where
    tagChildren (Script_28 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_28 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_28 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_28 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_28 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_28 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_28 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_28 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_28 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_28 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_28 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_28 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_28 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_28 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_28 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_28 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_28 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_28 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_28 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_28 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_28 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_28 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_28 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_28 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_28 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_28 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_28 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_28 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_28 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_28 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_28 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_28 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_28 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_28 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_28 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_28 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_28 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_28 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_28 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_28 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_28 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_28 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_28 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_28 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_28 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_28 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_28 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_28 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_28 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_28 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_28 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_28 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_28 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_28 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Form_28 a c) = (68,"form",map tagStr c,(map fst (map renderAtt a)),[action_byte]):(concatMap tagChildren c)
    tagChildren (Label_28 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_28 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_28 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_28 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_28 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Legend_28 a c) = (76,"legend",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_28 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_28 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_28 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_28 _ _) = []
instance TagChildren Ent29 where
    tagChildren (Caption_29 a c) = (80,"caption",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Thead_29 a c) = (81,"thead",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tfoot_29 a c) = (82,"tfoot",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tbody_29 a c) = (83,"tbody",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Colgroup_29 a c) = (84,"colgroup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Col_29 a) = [(-1,"col",[],(map fst (map renderAtt a)),[])]
    tagChildren (Tr_29 a c) = (86,"tr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent30 where
    tagChildren (Tr_30 a c) = (86,"tr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent31 where
    tagChildren (Col_31 a) = [(-1,"col",[],(map fst (map renderAtt a)),[])]
instance TagChildren Ent32 where
    tagChildren (Th_32 a c) = (87,"th",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Td_32 a c) = (88,"td",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent33 where
    tagChildren (Script_33 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_33 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_33 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_33 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_33 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_33 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_33 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_33 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_33 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_33 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_33 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_33 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_33 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_33 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_33 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_33 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_33 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_33 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_33 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_33 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_33 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_33 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_33 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_33 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_33 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_33 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_33 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_33 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_33 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_33 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_33 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_33 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_33 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_33 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_33 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_33 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_33 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_33 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_33 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_33 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_33 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_33 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_33 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_33 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_33 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_33 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_33 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_33 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_33 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_33 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_33 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Param_33 a) = [(-1,"param",[],(map fst (map renderAtt a)),[name_byte])]
    tagChildren (Applet_33 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_33 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_33 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Form_33 a c) = (68,"form",map tagStr c,(map fst (map renderAtt a)),[action_byte]):(concatMap tagChildren c)
    tagChildren (Label_33 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_33 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_33 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_33 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_33 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_33 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_33 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_33 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_33 _ _) = []
instance TagChildren Ent34 where
    tagChildren (Script_34 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_34 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_34 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_34 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_34 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_34 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_34 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_34 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_34 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_34 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_34 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_34 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_34 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_34 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_34 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_34 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_34 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_34 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_34 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_34 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_34 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_34 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_34 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Area_34 a) = [(-1,"area",[],(map fst (map renderAtt a)),[alt_byte])]
    tagChildren (Form_34 a c) = (68,"form",map tagStr c,(map fst (map renderAtt a)),[action_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_34 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_34 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_34 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent35 where
    tagChildren (Script_35 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Iframe_35 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_35 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_35 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_35 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_35 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_35 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_35 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_35 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_35 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_35 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_35 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_35 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_35 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_35 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_35 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_35 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_35 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_35 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_35 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_35 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_35 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_35 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_35 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_35 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_35 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_35 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_35 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_35 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_35 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_35 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_35 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_35 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_35 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Input_35 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_35 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_35 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_35 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_35 _ _) = []
instance TagChildren Ent36 where
    tagChildren (PCDATA_36 _ _) = []
instance TagChildren Ent37 where
    tagChildren (Script_37 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_37 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_37 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_37 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_37 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_37 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_37 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_37 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_37 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_37 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_37 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_37 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_37 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_37 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_37 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_37 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_37 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_37 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_37 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_37 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_37 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_37 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_37 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_37 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_37 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_37 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_37 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_37 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_37 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_37 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_37 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_37 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_37 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_37 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_37 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_37 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_37 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_37 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_37 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_37 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_37 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_37 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_37 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_37 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_37 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_37 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_37 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_37 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_37 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_37 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_37 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_37 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_37 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_37 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Form_37 a c) = (68,"form",map tagStr c,(map fst (map renderAtt a)),[action_byte]):(concatMap tagChildren c)
    tagChildren (Input_37 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_37 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_37 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_37 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_37 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_37 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_37 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_37 _ _) = []
instance TagChildren Ent38 where
    tagChildren (Li_38 a c) = (24,"li",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent39 where
    tagChildren (Dt_39 a c) = (26,"dt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dd_39 a c) = (27,"dd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent40 where
    tagChildren (Script_40 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Iframe_40 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_40 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_40 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_40 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_40 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_40 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_40 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_40 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_40 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_40 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_40 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_40 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_40 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_40 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_40 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_40 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_40 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_40 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_40 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_40 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_40 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_40 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_40 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_40 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_40 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_40 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_40 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_40 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_40 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_40 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_40 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_40 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_40 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_40 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Input_40 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_40 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_40 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_40 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_40 _ _) = []
instance TagChildren Ent41 where
    tagChildren (Script_41 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Ins_41 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_41 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_41 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_41 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_41 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_41 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_41 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_41 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_41 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_41 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_41 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_41 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_41 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_41 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_41 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_41 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_41 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_41 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_41 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_41 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_41 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_41 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_41 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_41 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_41 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_41 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_41 _ _) = []
instance TagChildren Ent42 where
    tagChildren (Script_42 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_42 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_42 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_42 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_42 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_42 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_42 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_42 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_42 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_42 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_42 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_42 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_42 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_42 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_42 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_42 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_42 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_42 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_42 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_42 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_42 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_42 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_42 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_42 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_42 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_42 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_42 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_42 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_42 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_42 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_42 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_42 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_42 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_42 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_42 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_42 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_42 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_42 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_42 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_42 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_42 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_42 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_42 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_42 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_42 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_42 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_42 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_42 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_42 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_42 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_42 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_42 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_42 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_42 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Input_42 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_42 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_42 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_42 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_42 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_42 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_42 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_42 _ _) = []
instance TagChildren Ent43 where
    tagChildren (Script_43 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Iframe_43 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_43 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_43 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_43 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_43 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_43 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_43 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_43 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_43 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_43 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_43 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_43 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_43 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_43 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_43 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_43 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_43 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_43 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_43 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_43 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_43 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_43 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_43 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_43 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_43 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_43 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_43 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_43 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_43 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_43 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_43 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_43 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_43 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Input_43 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_43 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_43 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_43 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_43 _ _) = []
instance TagChildren Ent44 where
    tagChildren (Li_44 a c) = (24,"li",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent45 where
    tagChildren (Dt_45 a c) = (26,"dt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dd_45 a c) = (27,"dd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent46 where
    tagChildren (Script_46 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Iframe_46 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_46 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_46 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_46 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_46 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_46 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_46 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_46 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_46 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_46 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_46 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_46 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_46 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_46 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_46 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_46 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_46 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_46 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_46 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_46 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_46 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_46 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_46 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_46 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_46 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_46 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_46 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_46 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_46 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_46 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_46 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_46 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_46 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_46 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Input_46 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_46 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_46 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_46 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_46 _ _) = []
instance TagChildren Ent47 where
    tagChildren (Script_47 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Ins_47 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_47 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_47 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_47 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_47 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_47 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_47 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_47 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_47 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_47 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_47 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_47 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_47 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_47 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_47 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_47 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_47 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_47 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_47 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_47 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_47 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_47 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_47 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_47 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_47 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_47 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_47 _ _) = []
instance TagChildren Ent48 where
    tagChildren (Script_48 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_48 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_48 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_48 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_48 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_48 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_48 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_48 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_48 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_48 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_48 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_48 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_48 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_48 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_48 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_48 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_48 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_48 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_48 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_48 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_48 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_48 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_48 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_48 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_48 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_48 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_48 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_48 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_48 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_48 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_48 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_48 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_48 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_48 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_48 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_48 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_48 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_48 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_48 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_48 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_48 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_48 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_48 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_48 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_48 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_48 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_48 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_48 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_48 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_48 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_48 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_48 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_48 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_48 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Input_48 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_48 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_48 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_48 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Legend_48 a c) = (76,"legend",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_48 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_48 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_48 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_48 _ _) = []
instance TagChildren Ent49 where
    tagChildren (Caption_49 a c) = (80,"caption",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Thead_49 a c) = (81,"thead",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tfoot_49 a c) = (82,"tfoot",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tbody_49 a c) = (83,"tbody",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Colgroup_49 a c) = (84,"colgroup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Col_49 a) = [(-1,"col",[],(map fst (map renderAtt a)),[])]
    tagChildren (Tr_49 a c) = (86,"tr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent50 where
    tagChildren (Tr_50 a c) = (86,"tr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent51 where
    tagChildren (Col_51 a) = [(-1,"col",[],(map fst (map renderAtt a)),[])]
instance TagChildren Ent52 where
    tagChildren (Th_52 a c) = (87,"th",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Td_52 a c) = (88,"td",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent53 where
    tagChildren (Script_53 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_53 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_53 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_53 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_53 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_53 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_53 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_53 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_53 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_53 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_53 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_53 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_53 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_53 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_53 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_53 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_53 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_53 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_53 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_53 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_53 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_53 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_53 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_53 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_53 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_53 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_53 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_53 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_53 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_53 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_53 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_53 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_53 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_53 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_53 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_53 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_53 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_53 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_53 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_53 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_53 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_53 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_53 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_53 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_53 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_53 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_53 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_53 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_53 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_53 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_53 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_53 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_53 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_53 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Form_53 a c) = (68,"form",map tagStr c,(map fst (map renderAtt a)),[action_byte]):(concatMap tagChildren c)
    tagChildren (Input_53 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_53 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_53 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_53 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Legend_53 a c) = (76,"legend",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_53 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_53 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_53 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_53 _ _) = []
instance TagChildren Ent54 where
    tagChildren (Caption_54 a c) = (80,"caption",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Thead_54 a c) = (81,"thead",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tfoot_54 a c) = (82,"tfoot",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tbody_54 a c) = (83,"tbody",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Colgroup_54 a c) = (84,"colgroup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Col_54 a) = [(-1,"col",[],(map fst (map renderAtt a)),[])]
    tagChildren (Tr_54 a c) = (86,"tr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent55 where
    tagChildren (Tr_55 a c) = (86,"tr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent56 where
    tagChildren (Col_56 a) = [(-1,"col",[],(map fst (map renderAtt a)),[])]
instance TagChildren Ent57 where
    tagChildren (Th_57 a c) = (87,"th",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Td_57 a c) = (88,"td",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent58 where
    tagChildren (Script_58 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_58 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_58 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_58 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_58 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_58 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_58 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_58 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_58 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_58 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_58 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_58 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_58 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_58 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_58 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_58 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_58 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_58 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_58 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_58 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_58 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_58 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_58 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_58 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_58 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_58 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_58 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_58 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_58 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_58 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_58 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_58 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_58 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_58 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_58 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_58 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_58 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_58 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_58 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_58 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_58 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_58 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_58 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_58 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_58 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_58 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_58 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_58 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_58 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_58 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_58 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Param_58 a) = [(-1,"param",[],(map fst (map renderAtt a)),[name_byte])]
    tagChildren (Applet_58 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_58 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_58 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Form_58 a c) = (68,"form",map tagStr c,(map fst (map renderAtt a)),[action_byte]):(concatMap tagChildren c)
    tagChildren (Input_58 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_58 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_58 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_58 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_58 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_58 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_58 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_58 _ _) = []
instance TagChildren Ent59 where
    tagChildren (Script_59 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_59 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_59 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_59 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_59 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_59 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_59 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_59 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_59 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_59 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_59 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_59 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_59 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_59 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_59 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_59 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_59 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_59 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_59 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_59 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_59 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_59 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_59 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Area_59 a) = [(-1,"area",[],(map fst (map renderAtt a)),[alt_byte])]
    tagChildren (Form_59 a c) = (68,"form",map tagStr c,(map fst (map renderAtt a)),[action_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_59 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_59 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_59 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent60 where
    tagChildren (Optgroup_60 a c) = (72,"optgroup",map tagStr c,(map fst (map renderAtt a)),[label_byte]):(concatMap tagChildren c)
    tagChildren (Option_60 a c) = (73,"option",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent61 where
    tagChildren (Option_61 a c) = (73,"option",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent62 where
    tagChildren (Script_62 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_62 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_62 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_62 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_62 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_62 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_62 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_62 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_62 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_62 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_62 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_62 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_62 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_62 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_62 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_62 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_62 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_62 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_62 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_62 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_62 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_62 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_62 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_62 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_62 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_62 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_62 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_62 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_62 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_62 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_62 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_62 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_62 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_62 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_62 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_62 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_62 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_62 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_62 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_62 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_62 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_62 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_62 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_62 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_62 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_62 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_62 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_62 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_62 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_62 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_62 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_62 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_62 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Table_62 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_62 _ _) = []
instance TagChildren Ent63 where
    tagChildren (Optgroup_63 a c) = (72,"optgroup",map tagStr c,(map fst (map renderAtt a)),[label_byte]):(concatMap tagChildren c)
    tagChildren (Option_63 a c) = (73,"option",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent64 where
    tagChildren (Option_64 a c) = (73,"option",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent65 where
    tagChildren (Script_65 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_65 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_65 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_65 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_65 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_65 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_65 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_65 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_65 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_65 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_65 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_65 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_65 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_65 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_65 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_65 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_65 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_65 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_65 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_65 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_65 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_65 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_65 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_65 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_65 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_65 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_65 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_65 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_65 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_65 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_65 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_65 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_65 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_65 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_65 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_65 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_65 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_65 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_65 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_65 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_65 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_65 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_65 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_65 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_65 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_65 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_65 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_65 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_65 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_65 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_65 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_65 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_65 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Table_65 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_65 _ _) = []
instance TagChildren Ent66 where
    tagChildren (Script_66 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_66 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_66 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_66 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_66 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_66 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_66 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_66 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_66 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_66 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_66 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_66 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_66 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_66 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_66 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_66 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_66 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_66 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_66 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_66 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_66 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_66 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_66 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Area_66 a) = [(-1,"area",[],(map fst (map renderAtt a)),[alt_byte])]
    tagChildren (Form_66 a c) = (68,"form",map tagStr c,(map fst (map renderAtt a)),[action_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_66 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_66 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_66 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent67 where
    tagChildren (Script_67 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_67 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_67 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_67 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_67 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_67 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_67 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_67 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_67 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_67 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_67 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_67 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_67 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_67 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_67 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_67 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_67 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_67 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_67 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_67 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_67 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_67 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_67 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_67 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_67 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_67 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_67 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_67 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_67 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_67 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_67 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_67 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_67 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_67 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_67 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_67 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_67 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_67 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_67 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_67 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_67 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_67 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_67 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_67 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_67 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_67 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_67 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_67 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_67 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_67 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_67 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_67 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_67 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_67 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_67 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Label_67 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_67 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_67 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_67 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_67 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_67 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_67 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_67 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_67 _ _) = []
instance TagChildren Ent68 where
    tagChildren (PCDATA_68 _ _) = []
instance TagChildren Ent69 where
    tagChildren (Script_69 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Iframe_69 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_69 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_69 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_69 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_69 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_69 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_69 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_69 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_69 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_69 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_69 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_69 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_69 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_69 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_69 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_69 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_69 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_69 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_69 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_69 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_69 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_69 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_69 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_69 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_69 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_69 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_69 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_69 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_69 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_69 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_69 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_69 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_69 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_69 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Label_69 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_69 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_69 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_69 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_69 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_69 _ _) = []
instance TagChildren Ent70 where
    tagChildren (Li_70 a c) = (24,"li",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent71 where
    tagChildren (Dt_71 a c) = (26,"dt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dd_71 a c) = (27,"dd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent72 where
    tagChildren (Script_72 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Iframe_72 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_72 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_72 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_72 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_72 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_72 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_72 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_72 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_72 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_72 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_72 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_72 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_72 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_72 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_72 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_72 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_72 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_72 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_72 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_72 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_72 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_72 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_72 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_72 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_72 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_72 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_72 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_72 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_72 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_72 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_72 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_72 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_72 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_72 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_72 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Label_72 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_72 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_72 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_72 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_72 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_72 _ _) = []
instance TagChildren Ent73 where
    tagChildren (Script_73 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Ins_73 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_73 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_73 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_73 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_73 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_73 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_73 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_73 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_73 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_73 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_73 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_73 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_73 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_73 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_73 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_73 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_73 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_73 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_73 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_73 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_73 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_73 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_73 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Label_73 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_73 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_73 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_73 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_73 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_73 _ _) = []
instance TagChildren Ent74 where
    tagChildren (PCDATA_74 _ _) = []
instance TagChildren Ent75 where
    tagChildren (Script_75 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_75 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_75 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_75 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_75 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_75 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_75 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_75 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_75 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_75 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_75 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_75 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_75 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_75 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_75 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_75 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_75 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_75 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_75 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_75 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_75 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_75 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_75 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_75 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_75 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_75 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_75 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_75 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_75 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_75 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_75 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_75 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_75 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_75 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_75 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_75 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_75 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_75 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_75 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_75 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_75 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_75 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_75 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_75 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_75 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_75 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_75 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_75 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_75 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_75 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_75 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Param_75 a) = [(-1,"param",[],(map fst (map renderAtt a)),[name_byte])]
    tagChildren (Applet_75 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_75 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_75 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Label_75 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_75 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_75 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_75 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_75 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_75 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_75 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_75 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_75 _ _) = []
instance TagChildren Ent76 where
    tagChildren (Script_76 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_76 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_76 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_76 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_76 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_76 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_76 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_76 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_76 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_76 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_76 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_76 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_76 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_76 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_76 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_76 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_76 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_76 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_76 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_76 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_76 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_76 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_76 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Area_76 a) = [(-1,"area",[],(map fst (map renderAtt a)),[alt_byte])]
    tagChildren (Fieldset_76 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_76 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_76 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent77 where
    tagChildren (PCDATA_77 _ _) = []
instance TagChildren Ent78 where
    tagChildren (Script_78 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_78 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_78 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_78 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_78 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_78 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_78 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_78 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_78 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_78 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_78 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_78 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_78 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_78 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_78 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_78 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_78 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_78 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_78 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_78 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_78 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_78 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_78 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_78 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_78 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_78 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_78 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_78 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_78 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_78 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_78 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_78 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_78 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_78 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_78 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_78 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_78 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_78 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_78 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_78 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_78 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_78 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_78 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_78 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_78 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_78 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_78 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_78 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_78 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_78 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_78 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Param_78 a) = [(-1,"param",[],(map fst (map renderAtt a)),[name_byte])]
    tagChildren (Applet_78 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_78 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_78 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Input_78 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_78 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_78 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_78 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_78 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_78 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_78 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_78 _ _) = []
instance TagChildren Ent79 where
    tagChildren (Script_79 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_79 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_79 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_79 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_79 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_79 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_79 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_79 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_79 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_79 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_79 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_79 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_79 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_79 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_79 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_79 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_79 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_79 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_79 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_79 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_79 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_79 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_79 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Area_79 a) = [(-1,"area",[],(map fst (map renderAtt a)),[alt_byte])]
    tagChildren (Fieldset_79 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_79 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_79 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent80 where
    tagChildren (Optgroup_80 a c) = (72,"optgroup",map tagStr c,(map fst (map renderAtt a)),[label_byte]):(concatMap tagChildren c)
    tagChildren (Option_80 a c) = (73,"option",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent81 where
    tagChildren (Option_81 a c) = (73,"option",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent82 where
    tagChildren (Script_82 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_82 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_82 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_82 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_82 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_82 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_82 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_82 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_82 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_82 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_82 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_82 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_82 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_82 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_82 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_82 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_82 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_82 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_82 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_82 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_82 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_82 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_82 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_82 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_82 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_82 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_82 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_82 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_82 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_82 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_82 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_82 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_82 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_82 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_82 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_82 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_82 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_82 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_82 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_82 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_82 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_82 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_82 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_82 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_82 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_82 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_82 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_82 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_82 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_82 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_82 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_82 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_82 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Table_82 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_82 _ _) = []
instance TagChildren Ent83 where
    tagChildren (Optgroup_83 a c) = (72,"optgroup",map tagStr c,(map fst (map renderAtt a)),[label_byte]):(concatMap tagChildren c)
    tagChildren (Option_83 a c) = (73,"option",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent84 where
    tagChildren (Option_84 a c) = (73,"option",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent85 where
    tagChildren (Script_85 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_85 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_85 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_85 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_85 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_85 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_85 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_85 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_85 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_85 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_85 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_85 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_85 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_85 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_85 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_85 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_85 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_85 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_85 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_85 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_85 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_85 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_85 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_85 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_85 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_85 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_85 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_85 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_85 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_85 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_85 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_85 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_85 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_85 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_85 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_85 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_85 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_85 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_85 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_85 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_85 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_85 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_85 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_85 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_85 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_85 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_85 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_85 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_85 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_85 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_85 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_85 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_85 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Table_85 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_85 _ _) = []
instance TagChildren Ent86 where
    tagChildren (Script_86 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_86 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_86 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_86 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_86 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_86 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_86 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_86 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_86 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_86 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_86 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_86 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_86 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_86 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_86 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_86 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_86 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_86 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_86 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_86 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_86 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_86 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_86 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_86 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_86 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_86 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_86 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_86 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_86 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_86 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_86 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_86 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_86 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_86 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_86 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_86 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_86 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_86 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_86 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_86 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_86 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_86 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_86 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_86 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_86 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_86 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_86 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_86 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_86 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_86 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_86 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_86 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Param_86 a) = [(-1,"param",[],(map fst (map renderAtt a)),[name_byte])]
    tagChildren (Applet_86 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_86 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_86 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Label_86 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_86 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_86 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_86 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_86 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_86 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_86 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_86 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_86 _ _) = []
instance TagChildren Ent87 where
    tagChildren (Script_87 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_87 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_87 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_87 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_87 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_87 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_87 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_87 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_87 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_87 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_87 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_87 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_87 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_87 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_87 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_87 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_87 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_87 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_87 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_87 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_87 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_87 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_87 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Area_87 a) = [(-1,"area",[],(map fst (map renderAtt a)),[alt_byte])]
    tagChildren (Fieldset_87 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_87 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_87 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent88 where
    tagChildren (Script_88 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Iframe_88 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_88 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_88 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_88 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_88 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_88 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_88 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_88 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_88 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_88 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_88 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_88 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_88 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_88 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_88 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_88 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_88 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_88 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_88 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_88 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_88 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_88 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_88 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_88 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_88 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_88 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_88 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_88 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_88 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_88 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_88 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_88 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_88 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_88 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Input_88 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_88 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_88 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_88 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_88 _ _) = []
instance TagChildren Ent89 where
    tagChildren (PCDATA_89 _ _) = []
instance TagChildren Ent90 where
    tagChildren (Script_90 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_90 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_90 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_90 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_90 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_90 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_90 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_90 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_90 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_90 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_90 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_90 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_90 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_90 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_90 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_90 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_90 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_90 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_90 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_90 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_90 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_90 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_90 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_90 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_90 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_90 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_90 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_90 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_90 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_90 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_90 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_90 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_90 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_90 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_90 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_90 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_90 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_90 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_90 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_90 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_90 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_90 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_90 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_90 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_90 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_90 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_90 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_90 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_90 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_90 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_90 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_90 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_90 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_90 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_90 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Input_90 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_90 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_90 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_90 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_90 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_90 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_90 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_90 _ _) = []
instance TagChildren Ent91 where
    tagChildren (Li_91 a c) = (24,"li",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent92 where
    tagChildren (Dt_92 a c) = (26,"dt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dd_92 a c) = (27,"dd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent93 where
    tagChildren (Script_93 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Iframe_93 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_93 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_93 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_93 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_93 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_93 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_93 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_93 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_93 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_93 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_93 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_93 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_93 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_93 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_93 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_93 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_93 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_93 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_93 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_93 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_93 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_93 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_93 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_93 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_93 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_93 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_93 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_93 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_93 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_93 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_93 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_93 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_93 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_93 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_93 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Input_93 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_93 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_93 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_93 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_93 _ _) = []
instance TagChildren Ent94 where
    tagChildren (Script_94 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Ins_94 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_94 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_94 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_94 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_94 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_94 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_94 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_94 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_94 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_94 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_94 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_94 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_94 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_94 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_94 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_94 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_94 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_94 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_94 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_94 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_94 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_94 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_94 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_94 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_94 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_94 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_94 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_94 _ _) = []
instance TagChildren Ent95 where
    tagChildren (Script_95 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_95 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_95 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_95 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_95 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_95 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_95 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_95 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_95 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_95 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_95 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_95 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_95 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_95 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_95 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_95 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_95 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_95 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_95 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_95 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_95 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_95 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_95 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_95 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_95 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_95 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_95 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_95 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_95 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_95 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_95 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_95 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_95 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_95 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_95 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_95 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_95 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_95 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_95 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_95 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_95 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_95 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_95 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_95 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_95 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_95 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_95 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_95 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_95 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_95 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_95 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_95 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_95 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_95 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_95 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Input_95 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_95 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_95 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_95 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Legend_95 a c) = (76,"legend",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_95 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_95 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_95 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_95 _ _) = []
instance TagChildren Ent96 where
    tagChildren (Caption_96 a c) = (80,"caption",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Thead_96 a c) = (81,"thead",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tfoot_96 a c) = (82,"tfoot",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tbody_96 a c) = (83,"tbody",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Colgroup_96 a c) = (84,"colgroup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Col_96 a) = [(-1,"col",[],(map fst (map renderAtt a)),[])]
    tagChildren (Tr_96 a c) = (86,"tr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent97 where
    tagChildren (Tr_97 a c) = (86,"tr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent98 where
    tagChildren (Col_98 a) = [(-1,"col",[],(map fst (map renderAtt a)),[])]
instance TagChildren Ent99 where
    tagChildren (Th_99 a c) = (87,"th",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Td_99 a c) = (88,"td",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent100 where
    tagChildren (Script_100 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_100 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_100 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_100 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_100 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_100 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_100 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_100 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_100 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_100 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_100 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_100 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_100 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_100 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_100 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_100 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_100 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_100 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_100 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_100 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_100 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_100 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_100 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_100 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_100 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_100 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_100 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_100 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_100 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_100 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_100 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_100 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_100 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_100 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_100 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_100 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_100 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_100 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_100 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_100 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_100 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_100 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_100 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_100 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_100 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_100 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_100 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_100 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_100 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_100 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_100 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_100 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Param_100 a) = [(-1,"param",[],(map fst (map renderAtt a)),[name_byte])]
    tagChildren (Applet_100 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_100 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_100 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Input_100 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_100 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_100 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_100 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_100 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_100 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_100 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_100 _ _) = []
instance TagChildren Ent101 where
    tagChildren (Script_101 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_101 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_101 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_101 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_101 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_101 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_101 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_101 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_101 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_101 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_101 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_101 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_101 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_101 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_101 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_101 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_101 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_101 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_101 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_101 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_101 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_101 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_101 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Area_101 a) = [(-1,"area",[],(map fst (map renderAtt a)),[alt_byte])]
    tagChildren (Fieldset_101 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_101 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_101 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent102 where
    tagChildren (Optgroup_102 a c) = (72,"optgroup",map tagStr c,(map fst (map renderAtt a)),[label_byte]):(concatMap tagChildren c)
    tagChildren (Option_102 a c) = (73,"option",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent103 where
    tagChildren (Option_103 a c) = (73,"option",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent104 where
    tagChildren (Script_104 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_104 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_104 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_104 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_104 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_104 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_104 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_104 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_104 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_104 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_104 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_104 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_104 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_104 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_104 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_104 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_104 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_104 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_104 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_104 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_104 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_104 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_104 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_104 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_104 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_104 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_104 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_104 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_104 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_104 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_104 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_104 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_104 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_104 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_104 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_104 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_104 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_104 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_104 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_104 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_104 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_104 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_104 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_104 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_104 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_104 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_104 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_104 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_104 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_104 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_104 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_104 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_104 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Table_104 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_104 _ _) = []
instance TagChildren Ent105 where
    tagChildren (Optgroup_105 a c) = (72,"optgroup",map tagStr c,(map fst (map renderAtt a)),[label_byte]):(concatMap tagChildren c)
    tagChildren (Option_105 a c) = (73,"option",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent106 where
    tagChildren (Option_106 a c) = (73,"option",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent107 where
    tagChildren (Script_107 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_107 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_107 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_107 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_107 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_107 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_107 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_107 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_107 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_107 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_107 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_107 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_107 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_107 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_107 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_107 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_107 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_107 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_107 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_107 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_107 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_107 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_107 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_107 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_107 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_107 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_107 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_107 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_107 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_107 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_107 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_107 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_107 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_107 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_107 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_107 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_107 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_107 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_107 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_107 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_107 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_107 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_107 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_107 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_107 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_107 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_107 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_107 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_107 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_107 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_107 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_107 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_107 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_107 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_107 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Label_107 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_107 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_107 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_107 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_107 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Legend_107 a c) = (76,"legend",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_107 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_107 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_107 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_107 _ _) = []
instance TagChildren Ent108 where
    tagChildren (Script_108 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_108 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_108 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_108 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_108 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_108 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_108 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_108 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_108 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_108 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_108 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_108 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_108 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_108 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_108 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_108 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_108 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_108 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_108 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_108 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_108 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_108 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_108 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_108 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_108 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_108 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_108 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_108 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_108 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_108 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_108 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_108 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_108 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_108 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_108 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_108 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_108 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_108 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_108 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_108 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_108 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_108 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_108 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_108 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_108 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_108 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_108 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_108 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_108 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_108 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_108 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_108 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_108 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Table_108 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_108 _ _) = []
instance TagChildren Ent109 where
    tagChildren (Caption_109 a c) = (80,"caption",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Thead_109 a c) = (81,"thead",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tfoot_109 a c) = (82,"tfoot",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tbody_109 a c) = (83,"tbody",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Colgroup_109 a c) = (84,"colgroup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Col_109 a) = [(-1,"col",[],(map fst (map renderAtt a)),[])]
    tagChildren (Tr_109 a c) = (86,"tr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent110 where
    tagChildren (Tr_110 a c) = (86,"tr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent111 where
    tagChildren (Col_111 a) = [(-1,"col",[],(map fst (map renderAtt a)),[])]
instance TagChildren Ent112 where
    tagChildren (Th_112 a c) = (87,"th",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Td_112 a c) = (88,"td",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent113 where
    tagChildren (Script_113 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Iframe_113 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_113 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_113 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_113 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_113 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_113 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_113 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_113 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_113 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_113 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_113 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_113 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_113 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_113 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_113 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_113 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_113 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_113 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_113 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_113 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_113 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_113 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_113 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_113 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_113 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_113 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_113 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_113 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_113 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_113 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_113 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_113 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_113 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_113 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Input_113 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_113 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_113 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_113 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_113 _ _) = []
instance TagChildren Ent114 where
    tagChildren (PCDATA_114 _ _) = []
instance TagChildren Ent115 where
    tagChildren (Script_115 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_115 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_115 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_115 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_115 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_115 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_115 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_115 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_115 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_115 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_115 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_115 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_115 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_115 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_115 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_115 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_115 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_115 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_115 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_115 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_115 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_115 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_115 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_115 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_115 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_115 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_115 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_115 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_115 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_115 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_115 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_115 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_115 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_115 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_115 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_115 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_115 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_115 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_115 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_115 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_115 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_115 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_115 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_115 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_115 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_115 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_115 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_115 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_115 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_115 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_115 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_115 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_115 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_115 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_115 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Form_115 a c) = (68,"form",map tagStr c,(map fst (map renderAtt a)),[action_byte]):(concatMap tagChildren c)
    tagChildren (Input_115 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_115 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_115 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_115 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_115 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_115 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_115 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_115 _ _) = []
instance TagChildren Ent116 where
    tagChildren (Li_116 a c) = (24,"li",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent117 where
    tagChildren (Dt_117 a c) = (26,"dt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dd_117 a c) = (27,"dd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent118 where
    tagChildren (Script_118 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Iframe_118 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_118 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_118 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_118 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_118 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_118 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_118 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_118 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_118 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_118 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_118 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_118 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_118 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_118 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_118 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_118 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_118 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_118 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_118 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_118 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_118 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_118 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_118 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_118 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_118 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_118 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_118 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_118 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_118 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_118 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_118 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_118 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_118 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_118 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_118 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Input_118 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_118 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_118 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_118 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_118 _ _) = []
instance TagChildren Ent119 where
    tagChildren (Script_119 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Ins_119 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_119 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_119 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_119 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_119 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_119 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_119 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_119 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_119 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_119 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_119 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_119 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_119 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_119 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_119 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_119 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_119 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_119 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_119 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_119 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_119 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_119 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_119 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_119 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_119 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_119 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Button_119 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_119 _ _) = []
instance TagChildren Ent120 where
    tagChildren (Script_120 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_120 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_120 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_120 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_120 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_120 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_120 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_120 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_120 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_120 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_120 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_120 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_120 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_120 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_120 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_120 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_120 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_120 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_120 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_120 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_120 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_120 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_120 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_120 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_120 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_120 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_120 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_120 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_120 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_120 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_120 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_120 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_120 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_120 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_120 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_120 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_120 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_120 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_120 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_120 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_120 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_120 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_120 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_120 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_120 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_120 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_120 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_120 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_120 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_120 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_120 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_120 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_120 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_120 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_120 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Form_120 a c) = (68,"form",map tagStr c,(map fst (map renderAtt a)),[action_byte]):(concatMap tagChildren c)
    tagChildren (Input_120 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_120 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_120 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_120 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Legend_120 a c) = (76,"legend",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_120 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_120 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_120 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_120 _ _) = []
instance TagChildren Ent121 where
    tagChildren (Caption_121 a c) = (80,"caption",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Thead_121 a c) = (81,"thead",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tfoot_121 a c) = (82,"tfoot",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tbody_121 a c) = (83,"tbody",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Colgroup_121 a c) = (84,"colgroup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Col_121 a) = [(-1,"col",[],(map fst (map renderAtt a)),[])]
    tagChildren (Tr_121 a c) = (86,"tr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent122 where
    tagChildren (Tr_122 a c) = (86,"tr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent123 where
    tagChildren (Col_123 a) = [(-1,"col",[],(map fst (map renderAtt a)),[])]
instance TagChildren Ent124 where
    tagChildren (Th_124 a c) = (87,"th",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Td_124 a c) = (88,"td",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent125 where
    tagChildren (Script_125 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_125 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_125 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_125 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_125 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_125 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_125 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_125 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_125 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_125 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_125 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_125 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_125 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_125 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_125 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_125 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_125 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_125 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_125 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_125 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_125 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_125 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_125 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_125 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_125 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_125 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_125 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_125 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_125 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_125 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_125 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_125 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_125 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_125 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_125 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_125 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_125 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_125 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_125 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_125 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_125 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_125 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_125 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_125 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_125 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_125 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_125 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_125 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_125 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_125 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_125 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_125 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Param_125 a) = [(-1,"param",[],(map fst (map renderAtt a)),[name_byte])]
    tagChildren (Applet_125 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_125 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_125 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Form_125 a c) = (68,"form",map tagStr c,(map fst (map renderAtt a)),[action_byte]):(concatMap tagChildren c)
    tagChildren (Input_125 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_125 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_125 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_125 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_125 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_125 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_125 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_125 _ _) = []
instance TagChildren Ent126 where
    tagChildren (Script_126 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_126 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_126 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_126 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_126 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_126 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_126 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_126 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_126 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_126 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_126 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_126 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_126 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_126 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_126 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_126 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_126 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_126 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_126 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_126 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_126 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_126 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_126 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Area_126 a) = [(-1,"area",[],(map fst (map renderAtt a)),[alt_byte])]
    tagChildren (Form_126 a c) = (68,"form",map tagStr c,(map fst (map renderAtt a)),[action_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_126 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_126 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_126 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent127 where
    tagChildren (Optgroup_127 a c) = (72,"optgroup",map tagStr c,(map fst (map renderAtt a)),[label_byte]):(concatMap tagChildren c)
    tagChildren (Option_127 a c) = (73,"option",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent128 where
    tagChildren (Option_128 a c) = (73,"option",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent129 where
    tagChildren (Script_129 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_129 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_129 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_129 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_129 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_129 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_129 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_129 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_129 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_129 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_129 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_129 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_129 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_129 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_129 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_129 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_129 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_129 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_129 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_129 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_129 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_129 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_129 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_129 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_129 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_129 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_129 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_129 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_129 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_129 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_129 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_129 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_129 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_129 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_129 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_129 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_129 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_129 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_129 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_129 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_129 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_129 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_129 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_129 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_129 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_129 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_129 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_129 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_129 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_129 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_129 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_129 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_129 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Table_129 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_129 _ _) = []
instance TagChildren Ent130 where
    tagChildren (Optgroup_130 a c) = (72,"optgroup",map tagStr c,(map fst (map renderAtt a)),[label_byte]):(concatMap tagChildren c)
    tagChildren (Option_130 a c) = (73,"option",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent131 where
    tagChildren (Option_131 a c) = (73,"option",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent132 where
    tagChildren (Script_132 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_132 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Iframe_132 a c) = (9,"iframe",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_132 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_132 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_132 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_132 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_132 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_132 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_132 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_132 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_132 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_132 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_132 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_132 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_132 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_132 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_132 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_132 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_132 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_132 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_132 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_132 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_132 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (A_132 a c) = (35,"a",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_132 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_132 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_132 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_132 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_132 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_132 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_132 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_132 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_132 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_132 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_132 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_132 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_132 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_132 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_132 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_132 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_132 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_132 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_132 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_132 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_132 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_132 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_132 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_132 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_132 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_132 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_132 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_132 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_132 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_132 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Form_132 a c) = (68,"form",map tagStr c,(map fst (map renderAtt a)),[action_byte]):(concatMap tagChildren c)
    tagChildren (Label_132 a c) = (69,"label",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Input_132 a) = [(-1,"input",[],(map fst (map renderAtt a)),[])]
    tagChildren (Select_132 a c) = (71,"select",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Textarea_132 a c) = (74,"textarea",map tagStr c,(map fst (map renderAtt a)),[rows_byte,cols_byte]):(concatMap tagChildren c)
    tagChildren (Fieldset_132 a c) = (75,"fieldset",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Legend_132 a c) = (76,"legend",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Button_132 a c) = (77,"button",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Isindex_132 a) = [(-1,"isindex",[],(map fst (map renderAtt a)),[])]
    tagChildren (Table_132 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_132 _ _) = []
instance TagChildren Ent133 where
    tagChildren (Script_133 a c) = (7,"script",map tagStr c,(map fst (map renderAtt a)),[type_byte]):(concatMap tagChildren c)
    tagChildren (Noscript_133 a c) = (8,"noscript",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Noframes_133 a c) = (10,"noframes",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Div_133 a c) = (12,"div",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (P_133 a c) = (13,"p",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H1_133 a c) = (14,"h1",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H2_133 a c) = (15,"h2",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H3_133 a c) = (16,"h3",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H4_133 a c) = (17,"h4",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H5_133 a c) = (18,"h5",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (H6_133 a c) = (19,"h6",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ul_133 a c) = (20,"ul",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ol_133 a c) = (21,"ol",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Menu_133 a c) = (22,"menu",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dir_133 a c) = (23,"dir",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dl_133 a c) = (25,"dl",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Address_133 a c) = (28,"address",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Hr_133 a) = [(-1,"hr",[],(map fst (map renderAtt a)),[])]
    tagChildren (Pre_133 a c) = (30,"pre",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Blockquote_133 a c) = (31,"blockquote",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Center_133 a c) = (32,"center",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Ins_133 a c) = (33,"ins",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Del_133 a c) = (34,"del",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Span_133 a c) = (36,"span",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Bdo_133 a c) = (37,"bdo",map tagStr c,(map fst (map renderAtt a)),[dir_byte]):(concatMap tagChildren c)
    tagChildren (Br_133 a) = [(-1,"br",[],(map fst (map renderAtt a)),[])]
    tagChildren (Em_133 a c) = (39,"em",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strong_133 a c) = (40,"strong",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Dfn_133 a c) = (41,"dfn",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Code_133 a c) = (42,"code",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Samp_133 a c) = (43,"samp",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Kbd_133 a c) = (44,"kbd",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Var_133 a c) = (45,"var",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Cite_133 a c) = (46,"cite",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Abbr_133 a c) = (47,"abbr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Acronym_133 a c) = (48,"acronym",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Q_133 a c) = (49,"q",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sub_133 a c) = (50,"sub",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Sup_133 a c) = (51,"sup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tt_133 a c) = (52,"tt",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (I_133 a c) = (53,"i",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (B_133 a c) = (54,"b",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Big_133 a c) = (55,"big",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Small_133 a c) = (56,"small",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (U_133 a c) = (57,"u",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (S_133 a c) = (58,"s",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Strike_133 a c) = (59,"strike",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Basefont_133 a) = [(-1,"basefont",[],(map fst (map renderAtt a)),[size_byte])]
    tagChildren (Font_133 a c) = (61,"font",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Object_133 a c) = (62,"object",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Applet_133 a c) = (64,"applet",map tagStr c,(map fst (map renderAtt a)),[width_byte,height_byte]):(concatMap tagChildren c)
    tagChildren (Img_133 a) = [(-1,"img",[],(map fst (map renderAtt a)),[src_byte,alt_byte])]
    tagChildren (Map_133 a c) = (66,"map",map tagStr c,(map fst (map renderAtt a)),[id_byte]):(concatMap tagChildren c)
    tagChildren (Table_133 a c) = (79,"table",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (PCDATA_133 _ _) = []
instance TagChildren Ent134 where
    tagChildren (Caption_134 a c) = (80,"caption",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Thead_134 a c) = (81,"thead",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tfoot_134 a c) = (82,"tfoot",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Tbody_134 a c) = (83,"tbody",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Colgroup_134 a c) = (84,"colgroup",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Col_134 a) = [(-1,"col",[],(map fst (map renderAtt a)),[])]
    tagChildren (Tr_134 a c) = (86,"tr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent135 where
    tagChildren (Tr_135 a c) = (86,"tr",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
instance TagChildren Ent136 where
    tagChildren (Col_136 a) = [(-1,"col",[],(map fst (map renderAtt a)),[])]
instance TagChildren Ent137 where
    tagChildren (Th_137 a c) = (87,"th",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)
    tagChildren (Td_137 a c) = (88,"td",map tagStr c,(map fst (map renderAtt a)),[]):(concatMap tagChildren c)

allowchildren = [("html",(parseRegex "((head)(body))"),"(head,body)"),("head",(parseRegex "(((script)|(style)|(meta)|(link)|(object)|(isindex))*(((title)((script)|(style)|(meta)|(link)|(object)|(isindex))*((base)((script)|(style)|(meta)|(link)|(object)|(isindex))*)?)|((base)((script)|(style)|(meta)|(link)|(object)|(isindex))*((title)((script)|(style)|(meta)|(link)|(object)|(isindex))*))))"),"((script|style|meta|link|object|isindex)*,((title,(script|style|meta|link|object|isindex)*,(base,(script|style|meta|link|object|isindex)*)?)|(base,(script|style|meta|link|object|isindex)*,(title,(script|style|meta|link|object|isindex)*))))"),("title",(parseRegex "(pcdata)"),"(#pcdata)"),("base",(parseRegex "empty"),"empty"),("meta",(parseRegex "empty"),"empty"),("link",(parseRegex "empty"),"empty"),("style",(parseRegex "(pcdata)"),"(#pcdata)"),("script",(parseRegex "(pcdata)"),"(#pcdata)"),("noscript",(parseRegex "(pcdata|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("iframe",(parseRegex "(pcdata|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("noframes",(parseRegex "(pcdata|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("body",(parseRegex "(pcdata|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("div",(parseRegex "(pcdata|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("p",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("h1",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("h2",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("h3",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("h4",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("h5",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("h6",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("ul",(parseRegex "((li))+"),"(li)+"),("ol",(parseRegex "((li))+"),"(li)+"),("menu",(parseRegex "((li))+"),"(li)+"),("dir",(parseRegex "((li))+"),"(li)+"),("li",(parseRegex "(pcdata|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("dl",(parseRegex "((dt)|(dd))+"),"(dt|dd)+"),("dt",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("dd",(parseRegex "(pcdata|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("address",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script)|(p))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script|p)*"),("hr",(parseRegex "empty"),"empty"),("pre",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(tt)|(i)|(b)|(u)|(s)|(strike)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|tt|i|b|u|s|strike|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|input|select|textarea|label|button|ins|del|script)*"),("blockquote",(parseRegex "(pcdata|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("center",(parseRegex "(pcdata|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("ins",(parseRegex "(pcdata|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("del",(parseRegex "(pcdata|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("a",(parseRegex "(pcdata|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("span",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("bdo",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("br",(parseRegex "empty"),"empty"),("em",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("strong",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("dfn",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("code",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("samp",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("kbd",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("var",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("cite",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("abbr",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("acronym",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("q",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("sub",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("sup",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("tt",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("i",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("b",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("big",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("small",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("u",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("s",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("strike",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("basefont",(parseRegex "empty"),"empty"),("font",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("object",(parseRegex "(pcdata|(param)|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|param|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("param",(parseRegex "empty"),"empty"),("applet",(parseRegex "(pcdata|(param)|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|param|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("img",(parseRegex "empty"),"empty"),("map",(parseRegex "(((p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(noscript)|(ins)|(del)|(script))+|(area)+)"),"((p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|noscript|ins|del|script)+|area+)"),("area",(parseRegex "empty"),"empty"),("form",(parseRegex "(pcdata|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("label",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("input",(parseRegex "empty"),"empty"),("select",(parseRegex "((optgroup)|(option))+"),"(optgroup|option)+"),("optgroup",(parseRegex "((option))+"),"(option)+"),("option",(parseRegex "(pcdata)"),"(#pcdata)"),("textarea",(parseRegex "(pcdata)"),"(#pcdata)"),("fieldset",(parseRegex "(pcdata|(legend)|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|legend|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("legend",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("button",(parseRegex "(pcdata|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(table)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|table|br|span|bdo|object|applet|img|map|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|noscript|ins|del|script)*"),("isindex",(parseRegex "empty"),"empty"),("table",(parseRegex "((caption)?((col)*|(colgroup)*)(thead)?(tfoot)?((tbody)+|(tr)+))"),"(caption?,(col*|colgroup*),thead?,tfoot?,(tbody+|tr+))"),("caption",(parseRegex "(pcdata|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(ins)|(del)|(script))*"),"(#pcdata|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|ins|del|script)*"),("thead",(parseRegex "((tr))+"),"(tr)+"),("tfoot",(parseRegex "((tr))+"),"(tr)+"),("tbody",(parseRegex "((tr))+"),"(tr)+"),("colgroup",(parseRegex "((col))*"),"(col)*"),("col",(parseRegex "empty"),"empty"),("tr",(parseRegex "((th)|(td))+"),"(th|td)+"),("th",(parseRegex "(pcdata|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("td",(parseRegex "(pcdata|(p)|(h1)|(h2)|(h3)|(h4)|(h5)|(h6)|(div)|(ul)|(ol)|(dl)|(menu)|(dir)|(pre)|(hr)|(blockquote)|(address)|(center)|(noframes)|(isindex)|(fieldset)|(table)|(form)|(a)|(br)|(span)|(bdo)|(object)|(applet)|(img)|(map)|(iframe)|(tt)|(i)|(b)|(u)|(s)|(strike)|(big)|(small)|(font)|(basefont)|(em)|(strong)|(dfn)|(code)|(q)|(samp)|(kbd)|(var)|(cite)|(abbr)|(acronym)|(sub)|(sup)|(input)|(select)|(textarea)|(label)|(button)|(noscript)|(ins)|(del)|(script))*"),"(#pcdata|p|h1|h2|h3|h4|h5|h6|div|ul|ol|dl|menu|dir|pre|hr|blockquote|address|center|noframes|isindex|fieldset|table|form|a|br|span|bdo|object|applet|img|map|iframe|tt|i|b|u|s|strike|big|small|font|basefont|em|strong|dfn|code|q|samp|kbd|var|cite|abbr|acronym|sub|sup|input|select|textarea|label|button|noscript|ins|del|script)*"),("", parseRegex "", "")]
-- 'pageErrors' will return any compliance errors, currently tag ordering errors, tag existance errors, or missing required attributes.
-- If no errors are found an empty list is returned, otherwise
-- a list of errors in String form is returned.  Recursively scans down children, so providing the entire page will return all errors.
-- > pageErrors (_html [])
-- > = ["'html' tag error due to children: .  Must fit (head,body)"]
-- Returns an error because no children were declared for the html tag where <head> and <body> must be children in that order.
pageErrors :: TagChildren a => a -> [String]
pageErrors = childErrors
childErrors :: TagChildren a => a -> [String]
childErrors a = childErrorsHelp (tagChildren a)

validate :: (Int,String) ->  Bool
validate (ti,children)
    | ti == -1 = True
    | result == False = False
    | otherwise = True
                  where
                    (t,regex,raw) =  allowchildren !! ti
                    result = matchRE regex children 
                    
validateAtts :: [U.ByteString] -> [U.ByteString] -> (Bool,String)
validateAtts provided required
    | False = (True,"")
    | otherwise = (False,concat (intersperse ", " (map (\a->a ++ " required!")  diff)))
            where 
             diff = ((map U.toString required) \\ (map U.toString provided))

childErrorsHelp :: [(Int,String,[String],[U.ByteString],[U.ByteString])] -> [String]
childErrorsHelp [] = []
childErrorsHelp ((ti,tag,children,atts,ratts):xs)
    | validate (ti,concat children) = (childErrorsHelp xs) ++ attfixuse
    | otherwise = ("'" ++ tag ++ "' tag error due to incorrect children: " ++ (concat (intersperse "-"  children)) ++ ".  Must fit " ++ raw):( (childErrorsHelp xs) ++ attfixuse)    
        where (t,regex,raw) = allowchildren !! ti
              (validatts,attfix) = validateAtts atts ratts
              attfixuse = if null attfix then
                            [] else
                            ["'" ++ tag ++ "' tag attribute error: " ++ attfix]